@@ -47,58 +47,55 @@
 
 
 /////////////////////// Local includes
-#include "config.h"
 #include "../nongui/About_gpl_v30.hpp"
+#include "config.h"
 #include "AboutDlg.hpp"
-
+#include "ui_AboutDlg.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 AboutDlg::AboutDlg(QWidget *parent, const QString &applicationName)
-  : QDialog(parent), m_applicationName(applicationName)
+  : QDialog(parent),
+    m_applicationName(applicationName),
+    m_ui(new ::Ui::AboutDlg)
 {
   if(parent == nullptr)
     qFatal("Programming error.");
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
-  QString text = QString("msXpertSuite - module %1, version %2.")
-                   .arg(m_applicationName)
-                   .arg(VERSION);
+  QString text = QString("%1, version %2.").arg(m_applicationName).arg(VERSION);
 
-  m_ui.programVersionLabel->setText(text);
+  m_ui->programVersionLabel->setText(text);
 
   setWindowTitle(QString("%1 - About").arg(m_applicationName));
 
-  connect(m_ui.closePushButton, SIGNAL(clicked()), this, SLOT(accept()));
+  connect(m_ui->closePushButton, SIGNAL(clicked()), this, SLOT(accept()));
 
   setupGraphicsView();
 
   makeUserManualCommandLinkConnections();
 
-  m_ui.copyrightLabel->setText(
-    "msXpertSuite Copyright 2016-2024 by Filippo Rusconi");
-  m_ui.gplTextEdit->setText(gpl);
+  m_ui->copyrightLabel->setText(
+    "MineXpert3 Copyright 2016-2025 by Filippo Rusconi");
+  m_ui->gplTextEdit->setText(gpl);
 
   setApplicationFeaturesText();
 
   setHistoryText();
 }
 
-
 AboutDlg::~AboutDlg()
 {
 }
 
-
 void
 AboutDlg::setApplicationFeaturesText()
 {
-  m_ui.featuresTextEdit->setHtml(
+  m_ui->featuresTextEdit->setHtml(
     "<html><head><meta name=\"qrichtext\" content=\"1\" /><style "
     "type=\"text/css\">\n"
     " p, li { white-space: pre-wrap; }\n"
@@ -110,7 +107,7 @@ AboutDlg::setApplicationFeaturesText()
     "text-indent:0px;\"></p>\n"
     "<br>\n"
     "<br>\n"
-    "<em>mineXpert2</em> provides the following main features:\n"
+    "<em>MineXpert3</em> provides the following main features:\n"
     "<br>\n"
     "<ul>\n"
     "<li>Load any number of MS data files in mzML|mzXML|txt formats;</li>\n"
@@ -123,57 +120,60 @@ AboutDlg::setApplicationFeaturesText()
     "<li>Set the MS<sup>n</sup> data set to be integrated;"
     "<li>Configure an \"Analysis mode\" that sends the characteristics of "
     "pointed peaks to a given file to ease data mining;</li>\n"
-    "<li>mineXpert is particularly well-suited for ion mobility mass "
+    "<li>MineXpert3 is particularly well-suited for ion mobility mass "
     "spectrometry data analysis.</li>\n"
     "</ul>\n"
     "<br>\n"
     "</body></html>\n");
 }
 
-
 void
-  AboutDlg::makeUserManualCommandLinkConnections()
-  {
-    connect(m_ui.localPdfCommandLinkButton, &QPushButton::clicked, []() {
+AboutDlg::makeUserManualCommandLinkConnections()
+{
+  connect(m_ui->localPdfCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-      QString url = "file:///";
-      url += DOC_DIR;
-      url += "/minexpert2-doc.pdf";
+    QString url  = "file://";
+    url         += PROJECT_INSTALL_DOC_DIR;
+    url         += "/minexpert3-doc.pdf";
 
-      // qDebug() << "Opening url:" << url;
+    // qDebug() << "Opening url:" << url;
 
-      QDesktopServices::openUrl(QUrl(url));
-    });
+    QDesktopServices::openUrl(QUrl(url));
+  });
 
-    connect(m_ui.wwwPdfCommandLinkButton, &QPushButton::clicked, []() {
+  connect(m_ui->wwwPdfCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-      QDesktopServices::openUrl(
-        QUrl("http://www.msxpertsuite.org/user-manuals/minexpert2/minexpert2-doc.pdf"));
-    });
+    QDesktopServices::openUrl(
+      QUrl("http://www.msxpertsuite.org/user-manuals/minexpert3/"
+           "minexpert3-doc.pdf"));
+  });
 
-    connect(m_ui.localHtmlCommandLinkButton, &QPushButton::clicked, []() {
+  connect(m_ui->localHtmlCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-      QString url = "file:///";
-      url += DOC_DIR;
-      url += "/html/index.html";
+    QString url  = "file://";
+    url         += PROJECT_INSTALL_DOC_DIR;
+    url         += "/html/index.html";
 
-      // qDebug() << "Opening url:" << url;
+    // qDebug() << "Opening url:" << url;
 
-      QDesktopServices::openUrl(QUrl(url));
-    });
+    QDesktopServices::openUrl(QUrl(url));
+  });
 
-    connect(m_ui.wwwHtmlCommandLinkButton, &QPushButton::clicked, []() {
+  connect(m_ui->wwwHtmlCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-      QDesktopServices::openUrl(
-        QUrl("http://www.msxpertsuite.org/user-manuals/minexpert2/html/user-manual/"
-             "index.html"));
-    });
-  }
+    QString url =
+      "http://www.msxpertsuite.org/user-manuals/minexpert3/html/user-manual/"
+      "index.html";
 
+    // qDebug() << "Opening url:" << url;
+
+    QDesktopServices::openUrl(QUrl(url));
+  });
+}
 
 void
 AboutDlg::setHistoryText()
@@ -191,7 +191,7 @@ AboutDlg::setHistoryText()
     }
 
   QString history = historyFile.readAll();
-  m_ui.historyTextEdit->setHtml(history);
+  m_ui->historyTextEdit->setHtml(history);
 }
 
 void
@@ -204,17 +204,16 @@ AboutDlg::setupGraphicsView()
   QGraphicsPixmapItem *pixmapItem = mp_graphicsScene->addPixmap(pixmap);
   if(!pixmapItem)
     return;
-  m_ui.graphicsView->setScene(mp_graphicsScene);
+  m_ui->graphicsView->setScene(mp_graphicsScene);
 }
 
-
 void
 AboutDlg::showHowToCiteTab()
 {
-  m_ui.tabWidget->setCurrentIndex(1);
+  m_ui->tabWidget->setCurrentIndex(1);
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
