@@ -38,14 +38,16 @@
 #include <QDialog>
 #include <QGraphicsScene>
 
-
 /////////////////////// Local includes
-#include "ui_AboutDlg.h"
 
+namespace Ui
+{
+class AboutDlg;
+}
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProgramWindow;
@@ -56,11 +58,11 @@ class AboutDlg : public QDialog
 
   friend class ProgramWindow;
 
-  private:
   public:
-  AboutDlg(QWidget *parent, const QString &applicationName = "mineXpert2");
+  explicit AboutDlg(QWidget *parent,
+                    const QString &applicationName = "MineXpert3");
 
-  ~AboutDlg();
+  virtual ~AboutDlg();
 
   void setApplicationFeaturesText();
   void makeUserManualCommandLinkConnections();
@@ -69,7 +71,7 @@ class AboutDlg : public QDialog
   protected:
   QString m_applicationName;
 
-  Ui::AboutDlg m_ui;
+  ::Ui::AboutDlg *m_ui;
 
   // Allocated but ownership taken by the graphicsView.
   QGraphicsScene *mp_graphicsScene;
@@ -79,6 +81,5 @@ class AboutDlg : public QDialog
 };
 
 
-} // namespace minexpert
-
+} // namespace MineXpert
 } // namespace MsXpS
