@@ -36,17 +36,21 @@
 
 /////////////////////// Qt includes
 #include <QObject>
-
+#include <QPlainTextEdit>
 
 /////////////////////// Local includes
-#include "ui_AnalysisPreferencesDlg.h"
 #include "../nongui/AnalysisPreferences.hpp"
 #include "../nongui/globals.hpp"
 
 
+namespace Ui
+{
+class AnalysisPreferencesDlg;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -81,14 +85,15 @@ class AnalysisPreferencesDlg : public QDialog
   void historyItemActivated(int index);
 
   protected:
-  Ui::AnalysisPreferencesDlg m_ui;
-
   private:
   QString m_applicationName;
 
   QList<QPlainTextEdit *> m_plainTextEditList;
 
   AnalysisPreferences m_analysisPreferences;
+
+  ::Ui::AnalysisPreferencesDlg *m_ui;
+
   void initialize();
 
   void readSettings();
@@ -96,6 +101,6 @@ class AnalysisPreferencesDlg : public QDialog
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
