@@ -39,10 +39,11 @@
 /////////////////////// Qt includes
 #include <QApplication>
 #include <QSplashScreen>
+#include <QtQml>
 
 
 /////////////////////// pappsomspp includes
-
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
 
@@ -50,12 +51,12 @@
 namespace MsXpS
 {
 
-namespace minexpert
+namespace MineXpert
 {
 
 class ProgramWindow;
 
-class Application : public QApplication
+class Application: public QApplication
 {
   Q_OBJECT
 
@@ -69,7 +70,7 @@ class Application : public QApplication
   Q_PROPERTY(
     QString m_description READ description WRITE setDescription USER true)
   QString m_description = QString(
-    "mineXpert2: a program to view and analyze mass spectrometric data");
+    "MineXpert3: a program to view and analyze mass spectrometric data");
 
   void setProgramWindow(ProgramWindow *program_window_p);
 
@@ -82,11 +83,43 @@ class Application : public QApplication
   QString getUserConfigSettingsDirPath();
   QString getUserConfigSettingsFilePath();
 
+  // These settings are crucial throughout the whole program as they allow
+  // storing the way bins are created when combining spectra. These config bits
+  // are pretty stable because they depend on the mass spectrometer used to
+  // acquire the data and, often, one works on lots of data from the same
+  // instrument, so these config bits do not change. Store them to allow
+  // for defaults.
+  void saveMzIntegrationParamsToSettings(
+    const pappso::MzIntegrationParams &mz_integration_params);
+  void eraseMzIntegrationParamsFromSettings();
+  pappso::MzIntegrationParams::InitializationResult
+  getMzIntegrationParamsFromSavedSettings(
+    pappso::MzIntegrationParams &mz_integration_params);
+
+  // FIXME Should centralize here all the functions that read and set these
+  // MzIntegrationParams.
+
+
+  ////////////////////////////// Scripting HUB /////////////////////////////
+  ////////////////////////////// Scripting HUB /////////////////////////////
+  bool publishQObject(
+    QObject *object,
+    QObject *parent,
+    QJSValue &js_value,
+    const QString &name,
+    const QString &alias                 = QString(),
+    const QString &comment               = QString(),
+    const QString &help                  = QString(),
+    const QString &tool_tip              = QString(),
+    const QColor &color                  = Qt::black,
+    QJSEngine::ObjectOwnership ownership = QJSEngine::CppOwnership);
+
+
   ////////////////////////////// private //////////////////////////// /
   ////////////////////////////// private //////////////////////////////
 
   private:
-  QString m_applicationName       = "minexpert2";
+  QString m_applicationName       = "Minexpert3";
   ProgramWindow *mp_programWindow = nullptr;
 
   // The splash screen, that we'll remove automatically after
@@ -96,6 +129,6 @@ class Application : public QApplication
   QString m_userConfigSettingsFilePath;
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
