@@ -43,20 +43,26 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
+
+
+/////////////////////// libXpertMass includes
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
+
+/////////////////////// libXpertMassGui includes
 
 
 /////////////////////// Local includes
 #include "BaseColorMapPlotCompositeWidget.hpp"
 #include "BaseColorMapPlotWnd.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
 #include "MsFragmentationSpecDlg.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 #include "ProgramWindow.hpp"
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -72,19 +78,17 @@ BaseColorMapPlotCompositeWidget::BaseColorMapPlotCompositeWidget(
   // integrations. We do not support the stuffing more than one color map into a
   // color map plot, contrary to what we do with graphs.
 
-  // m_ui.pushPinPushButton->hide();
-  m_ui.eraseTraceCreateNewPushButton->hide();
-  m_ui.combinationsComboBox->hide();
-  m_ui.keepTraceCreateNewPushButton->hide();
+  // m_ui->pushPinPushButton->hide();
+  m_ui->eraseTraceCreateNewPushButton->hide();
+  m_ui->combinationsComboBox->hide();
+  m_ui->keepTraceCreateNewPushButton->hide();
 }
 
-
 BaseColorMapPlotCompositeWidget::~BaseColorMapPlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 BaseColorMapPlotCompositeWidget::createMainMenu()
 {
@@ -247,14 +251,14 @@ BaseColorMapPlotCompositeWidget::createMainMenu()
   z_axis_scales_menu_p->addAction(z_axis_data_to_original_p);
 
 
-  disconnect(m_ui.mainMenuPushButton,
+  disconnect(m_ui->mainMenuPushButton,
              &QPushButton::clicked,
              static_cast<BasePlotCompositeWidget *>(this),
              &BasePlotCompositeWidget::mainMenuPushButtonClicked);
 
   // We need to connect the mainMenuPushButton to the clicked slot because that
   // is how we will  create live the contextual menu.
-  connect(m_ui.mainMenuPushButton,
+  connect(m_ui->mainMenuPushButton,
           &QPushButton::clicked,
           this,
           &BaseColorMapPlotCompositeWidget::mainMenuPushButtonClicked);
@@ -262,7 +266,6 @@ BaseColorMapPlotCompositeWidget::createMainMenu()
   // qDebug() << "EXIT";
 }
 
-
 void
 BaseColorMapPlotCompositeWidget::mainMenuPushButtonClicked()
 {
@@ -275,12 +278,11 @@ BaseColorMapPlotCompositeWidget::mainMenuPushButtonClicked()
 
   // qDebug() << "Done creating menu, now showing it.";
 
-  m_ui.mainMenuPushButton->showMenu();
+  m_ui->mainMenuPushButton->showMenu();
 
   // qDebug() << "EXIT";
 }
 
-
 QCPColorMap *
 BaseColorMapPlotCompositeWidget::addColorMap(
   std::shared_ptr<std::map<double, pappso::MapTrace>> &double_map_trace_map_sp,
@@ -320,13 +322,17 @@ BaseColorMapPlotCompositeWidget::addColorMap(
   mp_parentWnd->getProgramWindow()->documentMsRunDataPlottableFiliation(
     ms_run_data_set_csp, color_map_p, parent_plottable_p, this);
 
+  // We need to allocate a new ProcessingFlow instance with the graph
+  // as its parent.
+  ProcessingFlow *processing_flow_p = processing_flow.clone(color_map_p);
+
   // Map the graph_p to the processing flow that we got to document how
   // the trace was obtained in the first place.
-  m_plottableProcessingFlowMap[color_map_p] = processing_flow;
+  m_plottableProcessingFlowMap[color_map_p] = processing_flow_p;
 
   // Note how we do  change the sample name text and its color.
   // He we do set a new color map plot.
-  m_ui.sampleNameLabel->setText(sample_name);
+  m_ui->sampleNameLabel->setText(sample_name);
   setSampleNameColor(color);
 
   mp_plotWidget->replot();
@@ -341,23 +347,20 @@ BaseColorMapPlotCompositeWidget::addColorMap(
   return color_map_p;
 }
 
-
-pappso::DataKind
+pappso::Enums::DataKind
 BaseColorMapPlotCompositeWidget::xAxisKind() const
 {
   return static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
     ->xAxisDataKind();
 }
 
-
-pappso::DataKind
+pappso::Enums::DataKind
 BaseColorMapPlotCompositeWidget::yAxisKind() const
 {
   return static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
     ->yAxisDataKind();
 }
 
-
 bool
 BaseColorMapPlotCompositeWidget::saveMatrixAs3ColumnsToTextFile()
 {
@@ -401,7 +404,6 @@ BaseColorMapPlotCompositeWidget::saveMatrixAs3ColumnsToTextFile()
   return true;
 }
 
-
 bool
 BaseColorMapPlotCompositeWidget::saveMatrixAsMatrixToTextFile(bool detailed)
 {
@@ -446,6 +448,6 @@ BaseColorMapPlotCompositeWidget::saveMatrixAsMatrixToTextFile(bool detailed)
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
