@@ -44,21 +44,19 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basetraceplotwidget.h>
-#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>
-
+#include <pappsomspp/gui/plotwidget/basetraceplotwidget.h>
+#include <pappsomspp/gui/plotwidget/colormapplotconfig.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
-#include "ui_BasePlotCompositeWidget.h"
 #include "BasePlotCompositeWidget.hpp"
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/ProcessingFlow.hpp"
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class BaseColorMapPlotWnd;
@@ -72,13 +70,13 @@ class MzIntegrationParamsDlg;
 // public:
 // DoubleSpinBoxLabelAction(QWidget *parent_p,
 // const QString &label,
-// const QString &tooltip)
+// const QString &tool_tip)
 //: QWidgetAction(parent_p)
 //{
 // QWidget *widget_p     = new QWidget(parent_p);
 // QHBoxLayout *layout_p = new QHBoxLayout();
 // mp_label              = new QLabel(label);
-// mp_label->setToolTip(tooltip);
+// mp_label->setToolTip(tool_tip);
 // layout_p->addWidget(mp_label);
 // mp_spinBox = new QDoubleSpinBox(parent_p);
 // layout_p->addWidget(mp_spinBox);
@@ -133,8 +131,8 @@ class BaseColorMapPlotCompositeWidget : public BasePlotCompositeWidget
               const ProcessingFlow &processing_flow,
               const QColor &color);
 
-  pappso::DataKind xAxisKind() const;
-  pappso::DataKind yAxisKind() const;
+  pappso::Enums::DataKind xAxisKind() const;
+  pappso::Enums::DataKind yAxisKind() const;
 
   bool saveMatrixAs3ColumnsToTextFile();
   bool saveMatrixAsMatrixToTextFile(bool detailed = false);
@@ -152,6 +150,6 @@ class BaseColorMapPlotCompositeWidget : public BasePlotCompositeWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
