@@ -43,12 +43,12 @@
 /////////////////////// Local includes
 #include "BaseColorMapPlotWnd.hpp"
 #include "ProgramWindow.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -154,13 +154,6 @@ BaseColorMapPlotWnd::finalNewColorMapPlotConfiguration(
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
 
-  // qDebug().noquote()
-  //<< "Default mz integration parameters:"
-  //<< processing_flow.getDefaultMzIntegrationParams().toString();
-
-  // qDebug()
-  //<< processing_flow.getMsRunDataSetCstSPtr()->getMsRunId()->getFileName();
-
   // Sanity check
   if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
     qFatal("Programming error.");
@@ -310,6 +303,6 @@ BaseColorMapPlotWnd::integrateToDtRt(QCPAbstractPlottable *parent_plottable_p,
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
