@@ -41,17 +41,16 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>
+#include <pappsomspp/gui/plotwidget/colormapplotconfig.h>
 
 /////////////////////// Local includes
-#include "ui_BasePlotWnd.h"
 #include "BasePlotWnd.hpp"
 #include "BaseColorMapPlotCompositeWidget.hpp"
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -120,6 +119,6 @@ class BaseColorMapPlotWnd : public BasePlotWnd
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
