@@ -38,34 +38,44 @@
 #include <QMessageBox>
 #include <QSvgGenerator>
 #include <QSpinBox>
-
-/////////////////////// QCustomPlot
+#include <QSettings>
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
+
+
+/////////////////////// libXpertMass includes
+
+
+/////////////////////// libXpertMassGui includes
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
+
+
+/////////////////////// Local includes
+#include "Application.hpp" /////////////////////// stdlib includes
 
 
 /////////////////////// Local includes
 #include "BasePlotCompositeWidget.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
 #include "MsFragmentationSpecDlg.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 #include "ProcessingFlowViewerDlg.hpp"
 #include "ProgramWindow.hpp"
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 BasePlotCompositeWidget::BasePlotCompositeWidget(QWidget *parent,
                                                  const QString &x_axis_label,
                                                  const QString &y_axis_label)
   : mp_parentWnd(static_cast<BasePlotWnd *>(parent)),
     m_axisLabelX(x_axis_label),
-    m_axisLabelY(y_axis_label)
+    m_axisLabelY(y_axis_label),
+    m_ui(new ::Ui::BasePlotCompositeWidget)
 {
   // By essence, the parent will be the plot window (derived from
   // BaseTracePlotWnd).
@@ -83,14 +93,14 @@ BasePlotCompositeWidget::BasePlotCompositeWidget(QWidget *parent,
 
   // We need to setup the widget with the QCustomPlot widget in it. Also we need
   // to setup the ui so that the widgets are known when we use them below.
-  m_ui.setupUi(dynamic_cast<QWidget *>(this));
+  m_ui->setupUi(dynamic_cast<QWidget *>(this));
 
   // Connect the integrate to Mz pushbutton so that we can show the MS level
   // slider.
 
-  // connect(m_ui.msLevelSpinBox,
+  // connect(m_ui->msLevelSpinBox,
   // static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-  connect(m_ui.msLevelSpinBox,
+  connect(m_ui->msLevelSpinBox,
           QOverload<int>::of(&QSpinBox::valueChanged),
           this,
           &BasePlotCompositeWidget::msLevelValueChanged);
@@ -102,33 +112,33 @@ BasePlotCompositeWidget::BasePlotCompositeWidget(QWidget *parent,
 
   // We need to connect the mainMenuPushButton to the clicked slot because that
   // is how we will  create live the contextual menu.
-  connect(m_ui.mainMenuPushButton,
+  connect(m_ui->mainMenuPushButton,
           &QPushButton::clicked,
           this,
           &BasePlotCompositeWidget::mainMenuPushButtonClicked);
 
   // The push pin is always present and should be toggable using a shortcut.
-  m_ui.pushPinPushButton->setShortcut(QKeySequence("Ctrl+T, P"));
-  m_ui.pushPinPushButton->setToolTip("Toggle push pin status (Ctrl+T,P)");
+  m_ui->pushPinPushButton->setShortcut(QKeySequence("Ctrl+T, P"));
+  m_ui->pushPinPushButton->setToolTip("Toggle push pin status (Ctrl+T,P)");
 
-  m_ui.keepTraceCreateNewPushButton->setToolTip(
+  m_ui->keepTraceCreateNewPushButton->setToolTip(
     "Overlay new trace onto the other(s) (Ctrl+T, O)");
-  m_ui.keepTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, O"));
+  m_ui->keepTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, O"));
 
-  m_ui.eraseTraceCreateNewPushButton->setToolTip(
+  m_ui->eraseTraceCreateNewPushButton->setToolTip(
     "Replace currently selected trace(s) with new one (Ctrl+T, R)");
-  m_ui.eraseTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, R"));
+  m_ui->eraseTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, R"));
 
   // The red cross pixmap plot widget closing button. Clicking this button
   // triggers the signal that is trapped by the containing window that then
   // handle the destruction of the widget.
 
-  m_ui.closeCompositePlotWidgetPushButton->setShortcut(
+  m_ui->closeCompositePlotWidgetPushButton->setShortcut(
     QKeySequence("Ctrl+P, C"));
-  m_ui.closeCompositePlotWidgetPushButton->setToolTip(
+  m_ui->closeCompositePlotWidgetPushButton->setToolTip(
     "Close the composite plot widget (Ctrl+P,C)");
   connect(
-    m_ui.closeCompositePlotWidgetPushButton, &QPushButton::clicked, [this]() {
+    m_ui->closeCompositePlotWidgetPushButton, &QPushButton::clicked, [this]() {
       mp_parentWnd->plotCompositeWidgetDestructionRequested(this);
     });
 
@@ -138,27 +148,23 @@ BasePlotCompositeWidget::BasePlotCompositeWidget(QWidget *parent,
   // The derived classes will have to call setupWidget() here.
 }
 
-
 BasePlotCompositeWidget::~BasePlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 BasePlotWnd *
 BasePlotCompositeWidget::getParentWnd()
 {
   return mp_parentWnd;
 }
 
-
 BasePlotWnd *
 BasePlotCompositeWidget::getParent()
 {
   return mp_parentWnd;
 }
 
-
 void
 BasePlotCompositeWidget::createMainMenu()
 {
@@ -173,12 +179,12 @@ BasePlotCompositeWidget::createMainMenu()
   // Create the menu push button.
   const QIcon main_menu_icon =
     QIcon(":/images/svg/mobile-phone-like-menu-button.svg");
-  m_ui.mainMenuPushButton->setIcon(main_menu_icon);
-  m_ui.mainMenuPushButton->setToolTip("Plot widget menu (Ctrl+P, M)");
-  m_ui.mainMenuPushButton->setShortcut(QKeySequence("Ctrl+P, M"));
+  m_ui->mainMenuPushButton->setIcon(main_menu_icon);
+  m_ui->mainMenuPushButton->setToolTip("Plot widget menu (Ctrl+P, M)");
+  m_ui->mainMenuPushButton->setShortcut(QKeySequence("Ctrl+P, M"));
 
   // Finally set the push button to be the menu...
-  m_ui.mainMenuPushButton->setMenu(mp_mainMenu);
+  m_ui->mainMenuPushButton->setMenu(mp_mainMenu);
 
   QAction *show_mz_integration_params_dlg_action_p = new QAction(
     "Open m/z &integration params dialog", dynamic_cast<QObject *>(this));
@@ -267,7 +273,6 @@ BasePlotCompositeWidget::createMainMenu()
   // qDebug() << "EXIT";
 }
 
-
 QFile *
 BasePlotCompositeWidget::getAnalysisFilePtr()
 {
@@ -277,14 +282,12 @@ BasePlotCompositeWidget::getAnalysisFilePtr()
   return mp_parentWnd->getAnalysisFilePtr();
 }
 
-
 AnalysisPreferences *
 BasePlotCompositeWidget::getAnalysisPreferences()
 {
   return mp_parentWnd->getAnalysisPreferences();
 }
 
-
 void
 BasePlotCompositeWidget::mainMenuPushButtonClicked()
 {
@@ -294,20 +297,19 @@ BasePlotCompositeWidget::mainMenuPushButtonClicked()
   //// below).
 
   createMainMenu();
-  m_ui.mainMenuPushButton->showMenu();
+  m_ui->mainMenuPushButton->showMenu();
 
   // qDebug() << "EXIT";
 }
 
-
 void
+
 BasePlotCompositeWidget::msFragmentationSpecReady(
   const MsFragmentationSpec &ms_fragmentation_spec)
 {
   m_msFragmentationSpec = ms_fragmentation_spec;
 }
 
-
 void
 BasePlotCompositeWidget::redrawBackground(bool has_focus)
 {
@@ -319,7 +321,6 @@ BasePlotCompositeWidget::redrawBackground(bool has_focus)
   mp_plotWidget->replot();
 }
 
-
 bool
 BasePlotCompositeWidget::savePlotToPdfFile(const QString &file_name,
                                            bool no_cosmetic_pen,
@@ -337,7 +338,6 @@ BasePlotCompositeWidget::savePlotToPdfFile(const QString &file_name,
                                 title);
 }
 
-
 std::pair<int, int>
 BasePlotCompositeWidget::computePlotSize(std::pair<int, int> requested,
                                          std::pair<int, int> actual) const
@@ -390,7 +390,6 @@ BasePlotCompositeWidget::computePlotSize(std::pair<int, int> requested,
   return std::pair<int, int>(final_width, final_height);
 }
 
-
 bool
 BasePlotCompositeWidget::savePlotToSvgFile(const QString &file_name)
 {
@@ -416,7 +415,7 @@ BasePlotCompositeWidget::savePlotToSvgFile(const QString &file_name)
     &qcpPainter, plot_widget_size.width(), plot_widget_size.height());
   qcpPainter.end();
 
-  qDebug() << "out_buffer size:" << out_buffer.size();
+  // qDebug() << "out_buffer size:" << out_buffer.size();
 
   QMimeData *mime_data_p = new QMimeData();
   mime_data_p->setData("image/svg+xml", out_buffer.buffer());
@@ -425,7 +424,6 @@ BasePlotCompositeWidget::savePlotToSvgFile(const QString &file_name)
   return true;
 }
 
-
 bool
 BasePlotCompositeWidget::saveSvgPlotToClipboard()
 {
@@ -449,7 +447,6 @@ BasePlotCompositeWidget::saveSvgPlotToClipboard()
   return true;
 }
 
-
 bool
 BasePlotCompositeWidget::savePlotToPngFile(
   const QString &file_name, int width, int height, int scale, int quality) const
@@ -469,7 +466,6 @@ BasePlotCompositeWidget::savePlotToPngFile(
     file_name, plot_dimensions.first, plot_dimensions.second, scale, quality);
 }
 
-
 bool
 BasePlotCompositeWidget::savePlotToJpgFile(
   const QString &file_name, int width, int height, int scale, int quality) const
@@ -489,7 +485,6 @@ BasePlotCompositeWidget::savePlotToJpgFile(
     file_name, plot_dimensions.first, plot_dimensions.second, scale, quality);
 }
 
-
 bool
 BasePlotCompositeWidget::saveRasterPlotToClipboard()
 {
@@ -504,7 +499,6 @@ BasePlotCompositeWidget::saveRasterPlotToClipboard()
   return true;
 }
 
-
 void
 BasePlotCompositeWidget::showProcessingFlow()
 {
@@ -528,7 +522,8 @@ BasePlotCompositeWidget::showProcessingFlow()
       return;
     }
 
-  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
+  const ProcessingFlow *processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(plottable_p);
 
   // qDebug() << "The processing flow to display:" <<
   // processing_flow.toString();
@@ -539,7 +534,7 @@ BasePlotCompositeWidget::showProcessingFlow()
       // qDebug() << "Allocating new ProcessingFlowViewerDlg.";
 
       mp_processingFlowViewerDlg = new ProcessingFlowViewerDlg(
-        mp_parentWnd, "mineXpert2", plottable_p->pen().color());
+        mp_parentWnd, "MineXpert3", plottable_p->pen().color());
     }
   else
     {
@@ -549,7 +544,7 @@ BasePlotCompositeWidget::showProcessingFlow()
     }
 
   mp_processingFlowViewerDlg->setProcessingFlowText(
-    processing_flow.toString(0, " "));
+    processing_flow_p->toString(0, " "));
 
   mp_processingFlowViewerDlg->activateWindow();
   mp_processingFlowViewerDlg->raise();
@@ -561,7 +556,6 @@ BasePlotCompositeWidget::showProcessingFlow()
   //          << "and visible:" << mp_processingFlowViewerDlg->isVisible();
 }
 
-
 void
 BasePlotCompositeWidget::resetPlotRangesHistory()
 {
@@ -572,14 +566,12 @@ BasePlotCompositeWidget::resetPlotRangesHistory()
   mp_plotWidget->resetAxesRangeHistory();
 }
 
-
 QString
 BasePlotCompositeWidget::getAnalysisStanza()
 {
   return m_analysisStanza;
 }
 
-
 void
 BasePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
 {
@@ -588,18 +580,17 @@ BasePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
 
   // Display the position point in the status text.
 
-  m_ui.statusLineEdit->setText(
+  m_ui->statusLineEdit->setText(
     QString("(%1,%2)").arg(pointf.x(), 0, 'f', 5).arg(pointf.y(), 0, 'f', 5));
 
   // The color might have been changed (when setting the intensity value text)
   // But here we want it in black.
   QString style = QString("color: black");
-  m_ui.statusLineEdit->setStyleSheet(style);
+  m_ui->statusLineEdit->setStyleSheet(style);
 
   // qDebug() << "point: (" << pointf.x() << "," << pointf.y() << ")";
 }
 
-
 void
 BasePlotCompositeWidget::plotRangesChanged(
   const pappso::BasePlotContext &context)
@@ -617,7 +608,6 @@ BasePlotCompositeWidget::plotRangesChanged(
   emit plotRangesChangedSignal(context);
 }
 
-
 void
 BasePlotCompositeWidget::xAxisMeasurement(
   const pappso::BasePlotContext &context)
@@ -651,8 +641,8 @@ BasePlotCompositeWidget::xAxisMeasurement(
   if(!context.msp_integrationScope->getWidth(width))
     qFatal("Failed to get the width.");
 
-  int decimals = pappso::Utils::zeroDecimalsInValue(width) + 3;
-  text += QString(" -- xDelta: %1").arg(width, 0, 'f', decimals);
+  int decimals  = pappso::Utils::zeroDecimalsInValue(width) + 3;
+  text         += QString(" -- xDelta: %1").arg(width, 0, 'f', decimals);
 
   if(width < 1)
     {
@@ -675,27 +665,25 @@ BasePlotCompositeWidget::xAxisMeasurement(
   // The color might have been changed (when setting the intensity value text)
   // But here we want it in black.
   QString style = QString("color: black");
-  m_ui.statusLineEdit->setStyleSheet(style);
-  m_ui.statusLineEdit->setText(text);
+  m_ui->statusLineEdit->setStyleSheet(style);
+  m_ui->statusLineEdit->setText(text);
 }
 
-
 void
 BasePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
 {
-  // qDebug() << "The context" << context.toString();
+  // qDebug() << "ENTER with BasePlotContext:" << context.toString();
 
   m_plotWidgetPressedKeyCode = context.m_pressedKeyCode;
 
   if(context.m_pressedKeyCode == Qt::Key_Space)
     {
-      // qDebug();
+      // qDebug() << "Going to call craftAnalysisStanza()";
       craftAnalysisStanza(context);
     }
 }
 
-
 void
 BasePlotCompositeWidget::plotWidgetKeyReleaseEvent(
   const pappso::BasePlotContext &context)
@@ -704,23 +692,28 @@ BasePlotCompositeWidget::plotWidgetKeyReleaseEvent(
   // qDebug() << "Released key:" << m_plotWidgetReleasedKeyCode;
 }
 
+void
+BasePlotCompositeWidget::plotWidgetMousePressEvent(
+  [[maybe_unused]] const pappso::BasePlotContext &context)
+{
+  // qDebug();
+}
 
 void
 BasePlotCompositeWidget::plotWidgetMouseReleaseEvent(
   [[maybe_unused]] const pappso::BasePlotContext &context)
 {
-  qDebug();
+  // qDebug();
 
-  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::NoButton)
-  // qDebug() << "no button";
+  // if(context.m_mouseButtonsAtMouseRelease == Qt::NoButton)
+  //   qDebug() << "no button with context:" << context.toString();
+  //
+  // if(context.m_mouseButtonsAtMouseRelease == Qt::LeftButton)
+  //   qDebug() << "left button with context:" << context.toString();
+  //
+  // if(context.m_mouseButtonsAtMouseRelease == Qt::RightButton)
+  //     qDebug() << "right button with context:" << context.toString();
 
-  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::LeftButton)
-  // qDebug() << "left button";
-
-  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::RightButton)
-  //{
-  // qDebug() << "right button with context:" << context.toString();
-  //}
 
   // Now check what keyboard key was being pressed while the mouse
   // operation was going on.
@@ -729,7 +722,6 @@ BasePlotCompositeWidget::plotWidgetMouseReleaseEvent(
   // qDebug() << "pressed_key_code:" << pressed_key_code;
 }
 
-
 void
 BasePlotCompositeWidget::plottableSelectionChanged(
   [[maybe_unused]] QCPAbstractPlottable *plottable_p,
@@ -750,61 +742,60 @@ BasePlotCompositeWidget::plottableSelectionChanged(
         {
           // There are more than one plottable.
           // Erase the sample name.
-          m_ui.sampleNameLabel->setText("");
+          m_ui->sampleNameLabel->setText("");
           return;
         }
     }
 
   // At this point we know we we can show the sample name with proper color.
 
-  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
+  const ProcessingFlow *processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(plottable_p);
   MsRunDataSetCstSPtr ms_run_data_set_csp =
-    processing_flow.getMsRunDataSetCstSPtr();
+    processing_flow_p->getMsRunDataSetCstSPtr();
 
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
-  m_ui.sampleNameLabel->setText(sample_name);
+  m_ui->sampleNameLabel->setText(sample_name);
 
   QColor color = plottable_p->pen().color();
   setSampleNameColor(color);
 }
 
-
 void
 BasePlotCompositeWidget::pinDown(bool push_pinned)
 {
-  m_ui.pushPinPushButton->setChecked(push_pinned);
+  m_ui->pushPinPushButton->setChecked(push_pinned);
 }
 
-
 bool
 BasePlotCompositeWidget::isPinnedDown() const
 {
-  if(m_ui.pushPinPushButton->isChecked())
+  if(m_ui->pushPinPushButton->isChecked())
     return true;
 
   return false;
 }
 
-
 const pappso::BasePlotWidget *
 BasePlotCompositeWidget::getPlotWidget() const
 {
   return mp_plotWidget;
 }
 
-
-ProcessingFlow
-BasePlotCompositeWidget::getProcessingFlowForPlottable(
+const ProcessingFlow *
+BasePlotCompositeWidget::getCstProcessingFlowPtrForPlottable(
   const QCPAbstractPlottable *plottable_p) const
 {
+  // qDebug() << "Entering getProcessingFlowForPlottable()";
+
   if(plottable_p == nullptr)
     qFatal("Cannot be that the pointer is nullptr.");
 
   // Each graph has its own ProcessingFlow, and the association is in the
   // plottableProcessingFlowMap.
 
-  std::map<QCPAbstractPlottable *, ProcessingFlow>::const_iterator it;
+  std::map<QCPAbstractPlottable *, ProcessingFlow *>::const_iterator it;
 
   for(it = m_plottableProcessingFlowMap.begin();
       it != m_plottableProcessingFlowMap.end();
@@ -812,42 +803,46 @@ BasePlotCompositeWidget::getProcessingFlowForPlottable(
     {
       if(it->first == plottable_p)
         {
+          // qDebug() << "Found ProcessingFlow:" << it->second.toString();
           return it->second;
-          break;
         }
     }
 
-  qFatal("Cannot be that graph has no processing flow associated to it.");
+  qFatal("Cannot be that a graph have no processing flow associated to it.");
 
-  return ProcessingFlow();
+  return nullptr;
 }
 
-
 ProcessingFlow *
 BasePlotCompositeWidget::getProcessingFlowPtrForPlottable(
   const QCPAbstractPlottable *plottable_p)
 {
+  // qDebug() << "Entering getProcessingFlowForPlottable()";
+
   if(plottable_p == nullptr)
     qFatal("Cannot be that the pointer is nullptr.");
 
   // Each graph has its own ProcessingFlow, and the association is in the
   // plottableProcessingFlowMap.
 
-  auto result = std::find_if(
-    m_plottableProcessingFlowMap.begin(),
-    m_plottableProcessingFlowMap.end(),
-    [plottable_p](
-      const std::pair<QCPAbstractPlottable *, ProcessingFlow> &item) {
-      return item.first == plottable_p;
-    });
+  std::map<QCPAbstractPlottable *, ProcessingFlow *>::const_iterator it;
 
-  if(result != m_plottableProcessingFlowMap.end())
-    return const_cast<ProcessingFlow *>(&(result->second));
+  for(it = m_plottableProcessingFlowMap.begin();
+      it != m_plottableProcessingFlowMap.end();
+      ++it)
+    {
+      if(it->first == plottable_p)
+        {
+          // qDebug() << "Found ProcessingFlow:" << it->second.toString();
+          return it->second;
+        }
+    }
+
+  qFatal("Cannot be that a graph have no processing flow associated to it.");
 
   return nullptr;
 }
 
-
 void
 BasePlotCompositeWidget::removePlottableProcessingFlowMapItem(
   const QCPAbstractPlottable *plottable_p)
@@ -857,7 +852,7 @@ BasePlotCompositeWidget::removePlottableProcessingFlowMapItem(
     m_plottableProcessingFlowMap.begin(),
     m_plottableProcessingFlowMap.end(),
     [plottable_p](
-      const std::pair<QCPAbstractPlottable *, ProcessingFlow> &item) {
+      const std::pair<QCPAbstractPlottable *, ProcessingFlow *> &item) {
       return item.first == plottable_p;
     });
 
@@ -867,20 +862,20 @@ BasePlotCompositeWidget::removePlottableProcessingFlowMapItem(
   m_plottableProcessingFlowMap.erase(result);
 }
 
-
 MsRunDataSetCstSPtr
 BasePlotCompositeWidget::getMsRunDataSetCstSPtrForPlottable(
   const QCPAbstractPlottable *plottable_p) const
 {
-  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
+  const ProcessingFlow *processing_flow_cp =
+    getCstProcessingFlowPtrForPlottable(plottable_p);
 
-  return processing_flow.getMsRunDataSetCstSPtr();
+  return processing_flow_cp->getMsRunDataSetCstSPtr();
 }
 
-
 QCPAbstractPlottable *
 BasePlotCompositeWidget::plottableToBeUsedAsIntegrationSource() const
 {
+  // qDebug();
 
   int plottable_count = mp_plotWidget->plottableCount();
 
@@ -889,8 +884,7 @@ BasePlotCompositeWidget::plottableToBeUsedAsIntegrationSource() const
 
   if(plottable_count == 1)
     {
-      // qDebug() << "Only a plottable is plotted, this is going to be the
-      // source";
+      qInfo() << "Only a plottable is plotted, this is going to be the source ";
 
       return mp_plotWidget->plottable();
     }
@@ -909,7 +903,6 @@ BasePlotCompositeWidget::plottableToBeUsedAsIntegrationSource() const
   return selected_plottable_list.front();
 }
 
-
 QCPAbstractPlottable *
 BasePlotCompositeWidget::firstPlottable() const
 {
@@ -921,7 +914,6 @@ BasePlotCompositeWidget::firstPlottable() const
   return mp_plotWidget->plottable(0);
 }
 
-
 QList<QCPAbstractPlottable *>
 BasePlotCompositeWidget::plottablesToBeUsedAsIntegrationDestination() const
 {
@@ -950,7 +942,6 @@ BasePlotCompositeWidget::plottablesToBeUsedAsIntegrationDestination() const
   return plottable_list;
 }
 
-
 void
 BasePlotCompositeWidget::showMsFragmentationSpecDlg()
 {
@@ -979,8 +970,8 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
 
   // Next get the processing flow for that specific graph.
 
-  const ProcessingFlow &processing_flow =
-    getProcessingFlowForPlottable(source_plottable_p);
+  const ProcessingFlow *processing_flow_cp =
+    getCstProcessingFlowPtrForPlottable(source_plottable_p);
 
   MsFragmentationSpec ms_fragmentation_spec;
 
@@ -989,7 +980,7 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
   // destination matching MZ.
 
   std::vector<ProcessingStepCstSPtr> processing_steps =
-    processing_flow.stepsMatchingDestType(ProcessingType("MZ"), true);
+    processing_flow_cp->stepsMatchingDestType(ProcessingType("MZ"), true);
 
   // qDebug() << "The number of processing specs that match processing
   // type "
@@ -1001,7 +992,8 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
       // Not a single spec had a valid ms fragmentation spec. Last resort:
       // get the default one from the flow.
 
-      ms_fragmentation_spec = processing_flow.getDefaultMsFragmentationSpec();
+      ms_fragmentation_spec =
+        processing_flow_cp->getDefaultMsFragmentationSpec();
 
       // qDebug().noquote() << "The default ms frag spec:"
       //<< ms_fragmentation_spec.toString();
@@ -1046,7 +1038,6 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
     }
 }
 
-
 void
 BasePlotCompositeWidget::msFragmentationSpecChanged(
   MsFragmentationSpec ms_fragmentation_spec)
@@ -1089,21 +1080,20 @@ BasePlotCompositeWidget::msFragmentationSpecChanged(
   // otherwise, the msLevelValueChanged() is called and it will update the ms
   // frag spec's ms level again.
 
-  disconnect(m_ui.msLevelSpinBox,
+  disconnect(m_ui->msLevelSpinBox,
              QOverload<int>::of(&QSpinBox::valueChanged),
              this,
              &BasePlotCompositeWidget::msLevelValueChanged);
 
-  m_ui.msLevelSpinBox->setValue(ms_fragmentation_spec.getMsLevel());
+  m_ui->msLevelSpinBox->setValue(ms_fragmentation_spec.getMsLevel());
 
   // And connect back
-  connect(m_ui.msLevelSpinBox,
+  connect(m_ui->msLevelSpinBox,
           QOverload<int>::of(&QSpinBox::valueChanged),
           this,
           &BasePlotCompositeWidget::msLevelValueChanged);
 }
 
-
 void
 BasePlotCompositeWidget::msLevelValueChanged(int value)
 {
@@ -1146,88 +1136,37 @@ BasePlotCompositeWidget::msLevelValueChanged(int value)
   processing_flow_p->setDefaultMsFragmentationSpec(ms_fragmentation_spec);
 }
 
-
-pappso::MzIntegrationParams
-BasePlotCompositeWidget::getMzIntegrationParams(
+/* Heap-allocated*/
+pappso::MzIntegrationParams *
+BasePlotCompositeWidget::getSensibleMzIntegrationParams(
   const QCPAbstractPlottable *plottable_p)
 {
-  // We need to be able to find mz integration params and there is a process to
-  // search for them.
+  // qDebug();
 
-  // Get the processing flow for the plottable.
-  const ProcessingFlow &processing_flow =
-    getProcessingFlowForPlottable(plottable_p);
+  // Get the processing flow for the plottable because there might be
+  // mz integration params in there.
+  const ProcessingFlow *processing_flow_cp =
+    getCstProcessingFlowPtrForPlottable(plottable_p);
+  Q_ASSERT(processing_flow_cp != nullptr);
 
-  // Now extract mz integration parameters from where they sit. That might
-  // be multiple places.
-
-  pappso::MzIntegrationParams mz_integration_params;
-
-  // First check if the processing flow has default mz integration params.
-
-  mz_integration_params = processing_flow.getDefaultMzIntegrationParams();
-
-  if(!mz_integration_params.isValid())
-    {
-      // Check if there is at least one step in the flow that has mz integration
-      // params set.
-
-      const pappso::MzIntegrationParams *most_recent_mz_integration_params_p =
-        processing_flow.mostRecentMzIntegrationParams();
-
-      if(most_recent_mz_integration_params_p == nullptr)
-        {
-          // Last resort: get the parameters out of the ms run data set, the
-          // params that are calculated on the basis of the statistical analysis
-          // of the data.
-
-          mz_integration_params = processing_flow.getMsRunDataSetCstSPtr()
-                                    ->craftInitialMzIntegrationParams();
-
-          if(!mz_integration_params.isValid())
-            {
-              qFatal(
-                "Could not find any valid integration parameters for "
-                "graph.");
-            }
-        }
-      else
-        {
-          // qDebug().noquote() << "Got the most recent mz integration params:"
-          //<< most_recent_mz_integration_params_p->toString();
-
-          mz_integration_params = *most_recent_mz_integration_params_p;
-        }
-    }
-  // else
-  //{
-  // qDebug().noquote() << "Got the default mz integration params:"
-  //<< mz_integration_params.toString();
-  //}
-
-  if(!mz_integration_params.isValid())
-    qFatal("Cannot be possible not to have valid mz integration parameters.");
-
-  return mz_integration_params;
+  return processing_flow_cp->getSensibleMzIntegrationParams();
 }
 
-
 pappso::FilterNameInterfaceCstSPtr
 BasePlotCompositeWidget::filter(const QString filter_name,
                                 const QCPAbstractPlottable *plottable_p) const
 {
 
   // Get the processing flow for the plottable.
-  const ProcessingFlow &processing_flow =
-    getProcessingFlowForPlottable(plottable_p);
+  const ProcessingFlow *processing_flow_cp =
+    getCstProcessingFlowPtrForPlottable(plottable_p);
 
   // qDebug() << "The source plottable:" << plottable_p;
   // qDebug() << "The processing flow:" << &processing_flow;
 
-  return processing_flow.filter(filter_name);
+  return processing_flow_cp->filter(filter_name);
 }
 
-
 void
 BasePlotCompositeWidget::showMzIntegrationParamsDlg()
 {
@@ -1239,7 +1178,7 @@ BasePlotCompositeWidget::showMzIntegrationParamsDlg()
   if(source_plottable_p == nullptr)
     {
       QMessageBox::information(
-        this,
+        dynamic_cast<QWidget *>(this),
         "Please select *one* trace",
         "In order to set the m/z integration parameters, the source "
         "graph needs to be selected.",
@@ -1249,19 +1188,34 @@ BasePlotCompositeWidget::showMzIntegrationParamsDlg()
       return;
     }
 
-  // Get the mz integration params for the plottable.
-  pappso::MzIntegrationParams mz_integration_params =
-    getMzIntegrationParams(source_plottable_p);
+  // Get the mz integration params for the plottable. The integration
+  // parameters contain data that we must keep (mzSmallestMz, for example) and
+  // data that actually configure the bin size calculation (bin size model).
+  // The bin size model, we want to check if the user has stored default
+  // values for it. If so we use them. If not we keep what we got.
 
-  qDebug().noquote() << "Found mz integration params:"
-                     << mz_integration_params.toString();
+  const ProcessingFlow *processing_flow_cp =
+    getCstProcessingFlowPtrForPlottable(source_plottable_p);
+  Q_ASSERT(processing_flow_cp != nullptr);
+
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    processing_flow_cp->getSensibleMzIntegrationParams();
+  Q_ASSERT(mz_integration_params_p);
+
+  qDebug().noquote() << "20250904 -Got MzIntegrationParams:\n"
+                     << mz_integration_params_p->toString(0, "  ");
 
   if(mp_mzIntegrationParamsDlg == nullptr)
     {
-      // qDebug();
+      // qDebug() << "Now opening MzIntegrationParamsDlg.";
 
-      mp_mzIntegrationParamsDlg = new MzIntegrationParamsDlg(
-        this, mz_integration_params, source_plottable_p->pen().color());
+      mp_mzIntegrationParamsDlg =
+        new MzIntegrationParamsDlg(dynamic_cast<QWidget *>(this),
+                                   *mz_integration_params_p,
+                                   source_plottable_p->pen().color());
+
+      delete mz_integration_params_p;
 
       connect(
         mp_mzIntegrationParamsDlg,
@@ -1289,13 +1243,10 @@ BasePlotCompositeWidget::showMzIntegrationParamsDlg()
     }
 }
 
-
 void
 BasePlotCompositeWidget::mzIntegrationParamsChanged(
-  pappso::MzIntegrationParams mz_integration_params)
+  pappso::MzIntegrationParams &mz_integration_params)
 {
-  // qDebug();
-
   // First we get the source plottable that might be of interest to the user.
 
   QCPAbstractPlottable *source_plottable_p =
@@ -1304,7 +1255,7 @@ BasePlotCompositeWidget::mzIntegrationParamsChanged(
   if(source_plottable_p == nullptr)
     {
       QMessageBox::information(
-        this,
+        dynamic_cast<QWidget *>(this),
         "Please select *one* trace",
         "In order to set the m/z integration parameters, the source "
         "graph needs to be selected.",
@@ -1315,7 +1266,7 @@ BasePlotCompositeWidget::mzIntegrationParamsChanged(
     }
 
   // qDebug().noquote() << "The validated mz integration parameters:"
-  //<< mz_integration_params.toString();
+  //                    << mz_integration_params.toString();
 
   // Next get the processing flow for that specific graph.
 
@@ -1326,7 +1277,6 @@ BasePlotCompositeWidget::mzIntegrationParamsChanged(
   processing_flow_p->setDefaultMzIntegrationParams(mz_integration_params);
 }
 
-
 void
 BasePlotCompositeWidget::newTicIntensityCalculated(double tic_intensity,
                                                    const QColor &color) const
@@ -1339,83 +1289,96 @@ BasePlotCompositeWidget::newTicIntensityCalculated(double tic_intensity,
   else
     style = QString("color: %1").arg(color.name());
 
-  m_ui.statusLineEdit->setStyleSheet(style);
-  m_ui.statusLineEdit->setText("TIC intensity: " +
-                               QString("%1").arg(tic_intensity));
+  m_ui->statusLineEdit->setStyleSheet(style);
+  m_ui->statusLineEdit->setText("TIC intensity: " +
+                                QString("%1").arg(tic_intensity));
 }
 
-
 void
 BasePlotCompositeWidget::resetTicIntensity()
 {
   m_lastTicIntensity = 0;
 }
 
-
 QString
 BasePlotCompositeWidget::craftAnalysisStanza(
   const pappso::BasePlotContext &context)
 {
   // qDebug();
 
+  // If no analysis preferences were defined, just return an empty string.
+  const AnalysisPreferences *analPrefs = mp_parentWnd->getAnalysisPreferences();
+  if(analPrefs == nullptr)
+    {
+      QMessageBox::information(
+        this,
+        "Crafting an analysis stanza for a graph",
+        "Please define analysis preferences and try again.");
+
+      m_analysisStanza = "";
+      return QString();
+    }
+
   QCPAbstractPlottable *plottable_p = plottableToBeUsedAsIntegrationSource();
 
   if(plottable_p == nullptr)
     {
+      qInfo()
+        << "Returned plottable is nullptr (there might be more than one).";
+
       // We should inform the user if there are more than one plottable.
 
       int plottable_count = mp_plotWidget->plottableCount();
 
       if(plottable_count > 1)
         {
-          // qDebug();
           QMessageBox::information(
             this,
             "Crafting an analysis stanza for a graph",
             "Please select a single trace and try again.");
-        }
 
-      m_analysisStanza = "";
-      return QString();
+
+          m_analysisStanza = "";
+          return QString();
+        }
     }
 
-  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
+  // qDebug() << "Plottable:" << plottable_p;
+
+  const ProcessingFlow *processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(plottable_p);
+
+  // qDebug() << "Processing flow:" << processing_flow.toString();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
-    processing_flow.getMsRunDataSetCstSPtr();
+    processing_flow_p->getMsRunDataSetCstSPtr();
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
   QString file_name   = ms_run_data_set_csp->getMsRunId()->getFileName();
 
-  // qDebug() << "sample_name:" << sample_name << "and file_name:" << file_name;
+  // qDebug() << "Sample_name:" << sample_name << "and file_name:" <<
+  // file_name;
 
   BasePlotWnd *parent_window = dynamic_cast<BasePlotWnd *>(mp_parentWnd);
   if(parent_window == nullptr)
     qFatal("Pointer returned by the function cannot be nullptr.");
 
-  const AnalysisPreferences *analPrefs = mp_parentWnd->getAnalysisPreferences();
-  if(analPrefs == nullptr)
-    {
-      m_analysisStanza = "";
-      return QString();
-    }
+  // We need to know what kind of data we are handling so that we can select
+  // the proper format.
 
-  // We need to know what kind of data we are handling so that we can select the
-  // proper format.
+  pappso::Enums::DataKind data_kind = context.m_dataKind;
 
-  pappso::DataKind data_kind = context.m_dataKind;
-
-  qDebug() << "data_kind:" << static_cast<int>(data_kind);
+  // qDebug() << "data_kind:" << static_cast<int>(data_kind);
 
   DataFormatStringSpecif *specif_p = nullptr;
 
-  if(data_kind == pappso::DataKind::mz)
+  if(data_kind == pappso::Enums::DataKind::mz)
     specif_p =
       analPrefs->m_dataFormatStringSpecifHash.value(FormatType::MASS_SPEC);
-  else if(data_kind == pappso::DataKind::rt)
+  else if(data_kind == pappso::Enums::DataKind::rt)
     specif_p =
       analPrefs->m_dataFormatStringSpecifHash.value(FormatType::TIC_CHROM);
-  else if(data_kind == pappso::DataKind::dt)
+  else if(data_kind == pappso::Enums::DataKind::dt)
     specif_p =
       analPrefs->m_dataFormatStringSpecifHash.value(FormatType::DRIFT_SPEC);
   else
@@ -1449,8 +1412,8 @@ BasePlotCompositeWidget::craftAnalysisStanza(
         {
           if(prevChar == '\\')
             {
-              stanza += '\\';
-              prevChar = ' ';
+              stanza   += '\\';
+              prevChar  = ' ';
               continue;
             }
           else
@@ -1464,8 +1427,8 @@ BasePlotCompositeWidget::craftAnalysisStanza(
         {
           if(prevChar == '\\')
             {
-              stanza += '%';
-              prevChar = ' ';
+              stanza   += '%';
+              prevChar  = ' ';
               continue;
             }
           else
@@ -1489,8 +1452,9 @@ BasePlotCompositeWidget::craftAnalysisStanza(
               if(iter == formatString.size() - 1)
                 {
 
-                  // This is the last character of the line, then, duplicate the
-                  // newline so that it actually creates a new line in the text.
+                  // This is the last character of the line, then, duplicate
+                  // the newline so that it actually creates a new line in the
+                  // text.
 
                   stanza += QString("\n");
                 }
@@ -1515,16 +1479,16 @@ BasePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 's')
             {
-              stanza += sample_name;
-              prevChar = ' ';
+              stanza   += sample_name;
+              prevChar  = ' ';
               continue;
             }
           // Do not handle the X nor the Y because it depends on the kind of
           // plot widget. Let that handling to the derived class.
           if(curChar == 'x')
             {
-              stanza += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
-              prevChar = ' ';
+              stanza   += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
+              prevChar  = ' ';
               continue;
             }
           if(curChar == 'y')
@@ -1560,13 +1524,13 @@ BasePlotCompositeWidget::craftAnalysisStanza(
 
           // At this point the '%' is not followed by any special character
           // above, so we add it as we found it, because in derived classes
-          // that %<char> might be meaningful, like %z for the charge of an ion
-          // in a mass spectrum.
+          // that %<char> might be meaningful, like %z for the charge of an
+          // ion in a mass spectrum.
           else
             {
-              stanza += '%';
-              stanza += curChar;
-              prevChar = ' ';
+              stanza   += '%';
+              stanza   += curChar;
+              prevChar  = ' ';
 
               continue;
             }
@@ -1595,7 +1559,6 @@ BasePlotCompositeWidget::craftAnalysisStanza(
   return m_analysisStanza;
 }
 
-
 void
 BasePlotCompositeWidget::setPlottingColor(QCPAbstractPlottable *plottable_p,
                                           const QColor &color)
@@ -1611,10 +1574,9 @@ BasePlotCompositeWidget::setPlottingColor(QCPAbstractPlottable *plottable_p,
 
   QPalette palette;
   palette.setColor(QPalette::WindowText, color);
-  m_ui.sampleNameLabel->setPalette(palette);
+  m_ui->sampleNameLabel->setPalette(palette);
 }
 
-
 void
 BasePlotCompositeWidget::setSampleNameColor(const QColor &color)
 {
@@ -1623,10 +1585,10 @@ BasePlotCompositeWidget::setSampleNameColor(const QColor &color)
 
   QPalette palette;
   palette.setColor(QPalette::WindowText, color);
-  m_ui.sampleNameLabel->setPalette(palette);
+  m_ui->sampleNameLabel->setPalette(palette);
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
