@@ -43,28 +43,29 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/baseplotwidget.h>
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-
+#include <pappsomspp/gui/plotwidget/baseplotwidget.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
-#include "ui_BasePlotCompositeWidget.h"
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/ProcessingFlow.hpp"
 #include "../nongui/AnalysisPreferences.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 
+namespace Ui
+{
+class BasePlotCompositeWidget;
+}
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class BasePlotWnd;
 class MsFragmentationSpecDlg;
 class ProcessingFlowViewerDlg;
 
-
 enum class NewTraceHandlingMethod
 {
   NOT_SET = 0,
@@ -88,7 +89,7 @@ enum class TraceCombinationSign
 // QCPGraph_s or QCPColorMap_s. Since all these plots all derive from
 // QCPAbstractPlottable, we can develop a plot widget hierarchy that manages a
 // lot of these plots' functionalities into the base class.
-class BasePlotCompositeWidget : public QWidget
+class BasePlotCompositeWidget: public QWidget
 {
   Q_OBJECT
 
@@ -114,24 +115,30 @@ class BasePlotCompositeWidget : public QWidget
   virtual void lastCursorHoveredPoint(const QPointF &pointf);
 
   virtual void plotRangesChanged(const pappso::BasePlotContext &context);
-  void xAxisMeasurement(const pappso::BasePlotContext& context);
+  void xAxisMeasurement(const pappso::BasePlotContext &context);
 
   virtual void plotWidgetKeyPressEvent(const pappso::BasePlotContext &context);
   virtual void
   plotWidgetKeyReleaseEvent(const pappso::BasePlotContext &context);
+
+  virtual void
+  plotWidgetMousePressEvent(const pappso::BasePlotContext &context);
   virtual void
   plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context);
+
   virtual void plottableSelectionChanged(QCPAbstractPlottable *plottable_p,
                                          bool is_selected);
 
-  void
-  mzIntegrationParamsChanged(pappso::MzIntegrationParams mz_integration_params);
+  void mzIntegrationParamsChanged(
+    pappso::MzIntegrationParams &mz_integration_params);
 
-  virtual void newTicIntensityCalculated(double tic_intensity, const QColor &color) const;
+  virtual void newTicIntensityCalculated(double tic_intensity,
+                                         const QColor &color) const;
   virtual void resetTicIntensity();
 
-  pappso::MzIntegrationParams
-  getMzIntegrationParams(const QCPAbstractPlottable *plottable_p);
+  pappso::MzIntegrationParams * /*heap-allocated*/
+  getSensibleMzIntegrationParams(const QCPAbstractPlottable *plottable_p);
+
   void msFragmentationSpecChanged(MsFragmentationSpec ms_fragmentation_spec);
 
   pappso::FilterNameInterfaceCstSPtr
@@ -143,8 +150,8 @@ class BasePlotCompositeWidget : public QWidget
 
   virtual const pappso::BasePlotWidget *getPlotWidget() const;
 
-  virtual ProcessingFlow
-  getProcessingFlowForPlottable(const QCPAbstractPlottable *plottable_p) const;
+  virtual const ProcessingFlow *getCstProcessingFlowPtrForPlottable(
+    const QCPAbstractPlottable *plottable_p) const;
   virtual ProcessingFlow *
   getProcessingFlowPtrForPlottable(const QCPAbstractPlottable *plottable_p);
 
@@ -160,6 +167,7 @@ class BasePlotCompositeWidget : public QWidget
   plottablesToBeUsedAsIntegrationDestination() const;
 
   void mainMenuPushButtonClicked();
+
   void showMsFragmentationSpecDlg();
   void showMzIntegrationParamsDlg();
 
@@ -206,6 +214,7 @@ class BasePlotCompositeWidget : public QWidget
 
   signals:
 
+  void plotWidgetMousePressEventSignal(const pappso::BasePlotContext &context);
   void plotWidgetMouseReleaseEventSignal(QMouseEvent *event);
 
   void plotRangesChangedSignal(const pappso::BasePlotContext &context);
@@ -218,6 +227,10 @@ class BasePlotCompositeWidget : public QWidget
   // not a composite widget it is a QCustomPlot-derived widget in which I coded
   // all the specific behaviour we need to work with trace of different types:
   // tic chromatograms, mass spectra, drift spectra...
+
+  // This widget is not instantiated in this class, it is instantiated in each
+  // one of the specialied composite widget classes
+  // (MassSpecTracePlotCompositeWidget:102, for example)
   pappso::BasePlotWidget *mp_plotWidget = nullptr;
 
   BasePlotWnd *mp_parentWnd = nullptr;
@@ -234,7 +247,7 @@ class BasePlotCompositeWidget : public QWidget
 
   ProcessingFlowViewerDlg *mp_processingFlowViewerDlg = nullptr;
 
-  Ui::BasePlotCompositeWidget m_ui;
+  ::Ui::BasePlotCompositeWidget *m_ui;
 
   //! Color used for the background of unfocused plot.
   QColor m_unfocusedColor = QColor("lightgray");
@@ -259,7 +272,8 @@ class BasePlotCompositeWidget : public QWidget
   // via this map contains a pointer to that ms run data set, which in turn
   // contains all that is necessary to get to the original file, the ms run id
   // and the ms run reader.
-  std::map<QCPAbstractPlottable *, ProcessingFlow> m_plottableProcessingFlowMap;
+  std::map<QCPAbstractPlottable *, ProcessingFlow *>
+    m_plottableProcessingFlowMap;
 
   QMenu *mp_mainMenu         = nullptr;
   QMenu *mp_plotGraphicsMenu = nullptr;
@@ -273,6 +287,6 @@ class BasePlotCompositeWidget : public QWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
