@@ -45,18 +45,19 @@
 
 
 /////////////////////// Local includes
-#include "BasePlotWnd.hpp"
-#include "ProgramWindow.hpp"
-#include "MzIntegrationParamsDlg.hpp"
-#include "MsFragmentationSpecDlg.hpp"
-#include "Application.hpp"
-#include "PlotAreaOverlay.hpp"
 #include "../nongui/MassDataIntegratorTask.hpp"
-
+#include "Application.hpp"
+#include "BasePlotWnd.hpp"
+#include "MsFragmentationSpecDlg.hpp"
+#include "MzIntegrationParamsDlg.hpp"
+#include "PlotAreaOverlay.hpp"
+#include "ProgramWindow.hpp"
+#include "ui_BasePlotWnd.h"
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -69,18 +70,18 @@ BasePlotWnd::BasePlotWnd(QWidget *parent,
     mp_programWindow(static_cast<ProgramWindow *>(parent)),
     m_title(title),
     m_settingsTitle(settingsTitle),
-    m_description(description)
+    m_description(description),
+    m_ui(new ::Ui::BasePlotWnd)
 {
   if(parent == Q_NULLPTR)
     qFatal("Programming error.");
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
   if(!initialize())
     qFatal("Programming error.");
 }
 
-
 //! Destruct \c this BasePlotWnd instance.
 BasePlotWnd::~BasePlotWnd()
 {
@@ -88,7 +89,6 @@ BasePlotWnd::~BasePlotWnd()
   writeSettings();
 }
 
-
 //! Write the settings to as to restore the window geometry later.
 void
 BasePlotWnd::writeSettings()
@@ -104,7 +104,6 @@ BasePlotWnd::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to as to restore the window geometry.
 void
 BasePlotWnd::readSettings()
@@ -120,7 +119,6 @@ BasePlotWnd::readSettings()
   settings.endGroup();
 }
 
-
 //! Handle the close event.
 void
 BasePlotWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
@@ -130,25 +128,23 @@ BasePlotWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
   hide();
 }
 
-
 ProgramWindow *
 BasePlotWnd::getProgramWindow()
 {
   return mp_programWindow;
 }
 
-
 //! Initialize the window.
 bool
 BasePlotWnd::initialize()
 {
-  setWindowTitle(QString("mineXpert2 - %1").arg(m_title));
+  setWindowTitle(QString("MineXpert3 - %1").arg(m_title));
 
   // We do not want to destroy on close !!!
   // setAttribute(Qt::WA_DeleteOnClose);
 
   // The default window icon.
-  QString pixmap_file_name = ":/images/icons/32x32/minexpert2.png";
+  QString pixmap_file_name = ":/images/icons/32x32/minexpert3.png";
   QPixmap icon_pixmap(pixmap_file_name);
   QIcon icon(icon_pixmap);
   setWindowIcon(icon);
@@ -239,7 +235,6 @@ BasePlotWnd::initialize()
   return true;
 }
 
-
 void
 BasePlotWnd::verticalRulerSliderValueChanged(int value)
 {
@@ -259,7 +254,6 @@ BasePlotWnd::verticalRulerSliderValueChanged(int value)
   mpa_plotAreaOverlay->update();
 }
 
-
 void
 BasePlotWnd::resizeEvent([[maybe_unused]] QResizeEvent *event)
 {
@@ -295,7 +289,6 @@ BasePlotWnd::resizeEvent([[maybe_unused]] QResizeEvent *event)
   mpa_plotAreaOverlay->update();
 }
 
-
 void
 BasePlotWnd::setupToolBar()
 {
@@ -353,7 +346,6 @@ BasePlotWnd::setupToolBar()
   mp_toolBar->addAction(mp_lockYMarkerAct);
 }
 
-
 void
 BasePlotWnd::createMainMenu()
 {
@@ -600,7 +592,6 @@ BasePlotWnd::createMainMenu()
   mp_toolBar->addWidget(mp_mainMenuPushButton);
 }
 
-
 void
 BasePlotWnd::setMzIntegrationParamsForAllPlotWidgets()
 {
@@ -627,10 +618,9 @@ BasePlotWnd::setMzIntegrationParamsForAllPlotWidgets()
   mz_integration_params_dlg_p->show();
 }
 
-
 void
 BasePlotWnd::mzIntegrationParamsChanged(
-  pappso::MzIntegrationParams mz_integration_params)
+  pappso::MzIntegrationParams &mz_integration_params)
 {
   // We now know what are the mz integ params. We need to propagate them to
   // all the pinned-down widgets.
@@ -656,34 +646,50 @@ BasePlotWnd::mzIntegrationParamsChanged(
           // know some params like the smallest/greatest m/z bin, for example.
           // Then, we'll update it with the new params set here.
 
-          pappso::MzIntegrationParams iter_mz_integration_params =
+          pappso::MzIntegrationParams *iter_mz_integration_params_p = nullptr;
+
+          iter_mz_integration_params_p =
             processing_flow_p->getDefaultMzIntegrationParams();
 
-          // Now modify the values according to the new settings:
+          if(iter_mz_integration_params_p == nullptr)
+            {
+              // Heap allocated
+              iter_mz_integration_params_p =
+                processing_flow_p->getSensibleMzIntegrationParams();
+              processing_flow_p->setDefaultMzIntegrationParams(
+                *iter_mz_integration_params_p);
+              delete iter_mz_integration_params_p;
+              iter_mz_integration_params_p =
+                processing_flow_p->getDefaultMzIntegrationParams();
+            }
 
-          iter_mz_integration_params.setBinningType(
+          // Now modify the values in place according to the new settings:
+
+          iter_mz_integration_params_p->setBinningType(
             mz_integration_params.getBinningType());
-          iter_mz_integration_params.setPrecision(
-            mz_integration_params.getPrecision());
-          iter_mz_integration_params.setDecimalPlaces(
+          iter_mz_integration_params_p->setBinSizeModel(
+            mz_integration_params.getBinSizeModel());
+          iter_mz_integration_params_p->setDecimalPlaces(
             mz_integration_params.getDecimalPlaces());
-          iter_mz_integration_params.setRemoveZeroValDataPoints(
+          iter_mz_integration_params_p->setRemoveZeroValDataPoints(
             mz_integration_params.isRemoveZeroValDataPoints());
-
-          // And finally set the default mz integration params to be our
-          // updated mz integration params.
-          processing_flow_p->setDefaultMzIntegrationParams(
-            iter_mz_integration_params);
-
-          pappso::MzIntegrationParams mz_integration_params =
-            processing_flow_p->getDefaultMzIntegrationParams();
-
-          // qDebug() << "Set the mz integration params to one plottable:"
-          //<< mz_integration_params.toString();
         }
     }
 }
 
+pappso::MzIntegrationParams::InitializationResult
+BasePlotWnd::getSavedMzIntegrationParams(
+  pappso::MzIntegrationParams &mz_integration_params)
+{
+  pappso::MzIntegrationParams::InitializationResult result =
+    static_cast<Application *>(QCoreApplication::instance())
+      ->getMzIntegrationParamsFromSavedSettings(mz_integration_params);
+
+  // qDebug() << "Got saved MzIntegrationParams:"
+  //          << mz_integration_params.toString();
+
+  return result;
+}
 
 void
 BasePlotWnd::setMsFragmentationSpecForAllPlotWidgets()
@@ -716,7 +722,6 @@ BasePlotWnd::setMsFragmentationSpecForAllPlotWidgets()
   ms_fragmentation_spec_dlg_p->show();
 }
 
-
 void
 BasePlotWnd::msFragmentationSpecChanged(
   MsFragmentationSpec ms_fragmentation_spec)
@@ -748,7 +753,6 @@ BasePlotWnd::msFragmentationSpecChanged(
     }
 }
 
-
 void
 BasePlotWnd::show()
 {
@@ -764,7 +768,6 @@ BasePlotWnd::show()
   QMainWindow::show();
 }
 
-
 void
 BasePlotWnd::savePinnedPlotsToGraphicsFile()
 {
@@ -783,7 +786,7 @@ BasePlotWnd::savePinnedPlotsToGraphicsFile()
       if(plottable_p != nullptr)
         color = plottable_p->pen().color();
 
-      QString sample_name = composite_widget_p->m_ui.sampleNameLabel->text();
+      QString sample_name = composite_widget_p->m_ui->sampleNameLabel->text();
       SaveToGraphicsFileDlg dlg(
         this, composite_widget_p, "mineXpert", sample_name, color);
 
@@ -956,10 +959,10 @@ BasePlotWnd::integrateToTicIntensity(QCPAbstractPlottable *parent_plottable_p,
 
 void
 BasePlotWnd::integrateToTicIntensity(
-    QCPAbstractPlottable *parent_plottable_p,
-    std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
-      qualified_mass_spectra_vector_sp,
-    const ProcessingFlow &processing_flow)
+  QCPAbstractPlottable *parent_plottable_p,
+  std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
+    qualified_mass_spectra_vector_sp,
+  const ProcessingFlow &processing_flow)
 {
   // qDebug().noquote() << "Integrating to mz with processing flow:"
   //<< processing_flow.toString();
@@ -1118,7 +1121,6 @@ BasePlotWnd::integrateToTicIntensity(
                &MassDataIntegratorTask::integrateToTicIntensity));
 }
 
-
 void
 BasePlotWnd::finishedIntegratingToTicIntensity(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
@@ -1135,20 +1137,15 @@ BasePlotWnd::finishedIntegratingToTicIntensity(
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
-    mass_data_integrator_p->getMsRunDataSet();
+    mass_data_integrator_p->getProcessingFlow()->getMsRunDataSetCstSPtr();
 
   double tic_intensity =
     static_cast<QualifiedMassSpectrumVectorMassDataIntegratorToTicInt *>(
       mass_data_integrator_p)
       ->getTicIntensity();
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
-
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // We can delete the integrator now that the calculation is finished and
+  // that we have made a copy of the ProcessingFlow.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -1182,7 +1179,6 @@ BasePlotWnd::finishedIntegratingToTicIntensity(
     ->newTicIntensityCalculated(tic_intensity, plot_color);
 }
 
-
 //! Set the x-axis range lock between all the plot widgets.
 void
 BasePlotWnd::lockXRangeToggle(bool checked)
@@ -1190,7 +1186,6 @@ BasePlotWnd::lockXRangeToggle(bool checked)
   m_isLockedXRange = checked;
 }
 
-
 //! Set the y-axis range lock between all the plot widgets.
 void
 BasePlotWnd::lockYRangeToggle(bool checked)
@@ -1198,7 +1193,6 @@ BasePlotWnd::lockYRangeToggle(bool checked)
   m_isLockedYRange = checked;
 }
 
-
 void
 BasePlotWnd::lockYMarkerToggle(bool checked)
 {
@@ -1214,7 +1208,6 @@ BasePlotWnd::lockYMarkerToggle(bool checked)
     }
 }
 
-
 void
 BasePlotWnd::plotWidgetGotFocus(BasePlotCompositeWidget *composite_widget_p)
 {
@@ -1249,7 +1242,6 @@ BasePlotWnd::plotWidgetGotFocus(BasePlotCompositeWidget *composite_widget_p)
     }
 }
 
-
 void
 BasePlotWnd::plotCompositeWidgetDestructionRequested(
   BasePlotCompositeWidget *composite_widget_p)
@@ -1265,7 +1257,6 @@ BasePlotWnd::plotCompositeWidgetDestructionRequested(
   // qDebug() << "Done deleting the composite widget.";
 }
 
-
 std::vector<BasePlotCompositeWidget *>
 BasePlotWnd::allWidgets() const
 {
@@ -1285,7 +1276,6 @@ BasePlotWnd::allWidgets() const
   return widget_std_vector;
 }
 
-
 std::vector<BasePlotCompositeWidget *>
 BasePlotWnd::pinnedDownWidgets() const
 {
@@ -1310,7 +1300,6 @@ BasePlotWnd::pinnedDownWidgets() const
   return pinned_down_widgets;
 }
 
-
 BasePlotCompositeWidget *
 BasePlotWnd::plotCompositeWidgetForPlottable(QCPAbstractPlottable *plottable_p)
 {
@@ -1335,7 +1324,6 @@ BasePlotWnd::plotCompositeWidgetForPlottable(QCPAbstractPlottable *plottable_p)
   return nullptr;
 }
 
-
 void
 BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
 {
@@ -1348,13 +1336,13 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
 
   if(m_isLockedXRange)
     {
-      which_plot_axis |= static_cast<int>(pappso::Axis::x);
+      which_plot_axis |= static_cast<int>(pappso::Enums::Axis::x);
       // qDebug() << "Locked range:" << (int)which_plot_axis;
     }
 
   if(m_isLockedYRange)
     {
-      which_plot_axis |= static_cast<int>(pappso::Axis::y);
+      which_plot_axis |= static_cast<int>(pappso::Enums::Axis::y);
       // qDebug() << "Locked range:" << (int)which_plot_axis;
     }
 
@@ -1390,7 +1378,9 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
 
       // Ask a replotting with a record of the new axes ranges into the history.
       widget_p->mp_plotWidget->replotWithAxesRanges(
-        x_axis_range, y_axis_range, static_cast<pappso::Axis>(which_plot_axis));
+        x_axis_range,
+        y_axis_range,
+        static_cast<pappso::Enums::Axis>(which_plot_axis));
 
       // qDebug() << "x_axis_range:" << x_axis_range.lower << "-"
       //<< x_axis_range.upper << "y_axis_range:" << y_axis_range.lower
@@ -1407,28 +1397,24 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
   // qDebug() << "Now returning from the function.";
 }
 
-
 QFile *
 BasePlotWnd::getAnalysisFilePtr()
 {
   return mp_programWindow->getAnalysisFilePtr();
 }
 
-
 AnalysisPreferences *
 BasePlotWnd::getAnalysisPreferences()
 {
   return mp_programWindow->getAnalysisPreferences();
 }
 
-
 void
 BasePlotWnd::recordAnalysisStanza(QString stanza, const QColor &color)
 {
   mp_programWindow->recordAnalysisStanza(stanza, color);
 }
 
-
 void
 BasePlotWnd::showWindow()
 {
@@ -1437,7 +1423,6 @@ BasePlotWnd::showWindow()
   show();
 }
 
-
 QPoint
 BasePlotWnd::firstCompositeWidgetPosition() const
 {
@@ -1450,7 +1435,6 @@ BasePlotWnd::firstCompositeWidgetPosition() const
   return pos();
 }
 
-
 QSize
 BasePlotWnd::firstCompositeWidgetSize() const
 {
@@ -1464,7 +1448,6 @@ BasePlotWnd::firstCompositeWidgetSize() const
   return size();
 }
 
-
 std::size_t
 BasePlotWnd::fillInQualifiedMassSpectraVector(
   MsRunDataSetCstSPtr ms_run_data_set_csp,
@@ -1484,8 +1467,9 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
 
   if(qualified_mass_spectra_sp->size())
     {
-      // qDebug() << "The vector of qualified spectra is not empty. Returning "
-      //"with no modification.";
+      // qDebug()
+      //   << "The vector of qualified spectra is not empty. Returning "
+      //      "with no modification.";
 
       return qualified_mass_spectra_sp->size();
     }
@@ -1497,7 +1481,7 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
 
   std::pair<double, double> range_pair;
 
-  // We choose RT_TO_ANY that matches in the widest possible manner all the
+  // We choose ANY_RT that matches in the widest possible manner all the
   // previous integrations that started with a rt-involving selection (both
   // mono- and two-dimensional, either from the ms run table view or any
   // trace/color map plot).
@@ -1505,10 +1489,22 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   bool integration = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration)
-    qFatal("Programming error.");
+    {
+      // It is imaginable that the data come not from a previous RT step,
+      // that is, that the data are indeed MZ data not coming from at least
+      // one integration from TIC chromatogram if the mass spectrum (MZ)
+      // comes from the net (source processing type is SOCKET_MZ).
 
-  qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
-           << "-" << range_pair.second;
+      std::vector<ProcessingStepCstSPtr> steps =
+        processing_flow.stepsMatchingSrcTypeX("SOCKET_MZ");
+
+      if(!steps.size())
+        qFatal(
+          "Programming error: the data have a problematic ProcessingFlow.");
+    }
+
+  // qDebug() << "Filling-in mass spectra for RT range: "
+  //          << range_pair.first << "-" << range_pair.second;
 
   std::size_t added_rt_mass_spectra;
 
@@ -1520,12 +1516,12 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
     [&](QPromise<int> promise) {
       promise.start(); // notifies QFuture that the computation is started
 
-      added_rt_mass_spectra =
-        ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-          ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
-                                                     range_pair.second,
-                                                     *qualified_mass_spectra_sp,
-                                                     pappso::DataKind::rt);
+      added_rt_mass_spectra = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+                                ->addDataSetQualMassSpectraInsideDtOrRtRange(
+                                  range_pair.first,
+                                  range_pair.second,
+                                  *qualified_mass_spectra_sp,
+                                  pappso::Enums::DataKind::rt);
 
 
       promise.addResult(added_rt_mass_spectra);
@@ -1543,7 +1539,7 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   //     ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
   //                                                range_pair.second,
   //                                                *qualified_mass_spectra_sp,
-  //                                                pappso::DataKind::rt);
+  //                                                pappso::Enums::DataKind::rt);
 
   qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
 
@@ -1558,9 +1554,9 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   // the mass spectral acquisitions involved ion mobility.
   if(integration)
     {
-      qDebug()
-        << "Detected DT integration, removing mass spectra outside DT range: "
-        << range_pair.first << "-" << range_pair.second;
+      qDebug() << "Detected DT integration, removing mass spectra outside DT "
+                  "range:"
+               << range_pair.first << "-" << range_pair.second;
 
       std::size_t removed_mass_spectra;
 
@@ -1574,11 +1570,11 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
 
           removed_mass_spectra =
             ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-              ->removeDataSetQualMassSpectraOutsideDtRtRange(
+              ->removeDataSetQualMassSpectraOutsideDtOrRtRange(
                 range_pair.first,
                 range_pair.second,
                 *qualified_mass_spectra_sp,
-                pappso::DataKind::dt);
+                pappso::Enums::DataKind::dt);
 
 
           promise.addResult(removed_mass_spectra);
@@ -1597,19 +1593,20 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
       //                            range_pair.first,
       //                            range_pair.second,
       //                            *qualified_mass_spectra_sp,
-      //                            pappso::DataKind::dt);
+      //                            pappso::Enums::DataKind::dt);
 
-      qDebug() << "Number of mass spectra removed on the basis of DT:"
-               << removed_mass_spectra;
+      qDebug() << "Removed DT mass spectra:" << removed_mass_spectra;
     }
 
   // At this point we need to really check which of the remaining spectra are
   // inside of the selection polygon.
 
+  qDebug() << "Finally returning" << qualified_mass_spectra_sp->size()
+           << "spectra.";
+
   return qualified_mass_spectra_sp->size();
 }
 
-
 void
 BasePlotWnd::removeEmptyPlotWidgets()
 {
@@ -1637,6 +1634,6 @@ BasePlotWnd::removeEmptyPlotWidgets()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
