@@ -41,11 +41,9 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
-#include "ui_BasePlotWnd.h"
 #include "BasePlotCompositeWidget.hpp"
 #include "../nongui/MassDataIntegrator.hpp"
 #include "SaveToGraphicsFileDlg.hpp"
@@ -54,9 +52,14 @@
 #include "PlotAreaOverlay.hpp"
 
 
+namespace Ui
+{
+class BasePlotWnd;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -133,7 +136,10 @@ class BasePlotWnd : public QMainWindow
 
   void setMzIntegrationParamsForAllPlotWidgets();
   void
-  mzIntegrationParamsChanged(pappso::MzIntegrationParams mz_integration_params);
+  mzIntegrationParamsChanged(pappso::MzIntegrationParams &mz_integration_params);
+
+  pappso::MzIntegrationParams::InitializationResult getSavedMzIntegrationParams(
+    pappso::MzIntegrationParams &mz_integration_params);
 
   void setMsFragmentationSpecForAllPlotWidgets();
   void msFragmentationSpecChanged(MsFragmentationSpec ms_fragmentation_spec);
@@ -155,11 +161,6 @@ class BasePlotWnd : public QMainWindow
       &qualified_mass_spectra_sp,
     const ProcessingFlow &processing_flow);
 
-  ////// Setting up the window layout.
-
-  //! Graphical interface definition.
-  Ui::BasePlotWnd m_ui;
-
   ProgramWindow *mp_programWindow = nullptr;
 
   QFile *getAnalysisFilePtr();
@@ -216,9 +217,13 @@ class BasePlotWnd : public QMainWindow
   QString m_title;
   QString m_settingsTitle;
   QString m_description;
+
+  ////// Setting up the window layout.
+  //! Graphical interface definition.
+  ::Ui::BasePlotWnd *m_ui;
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
