@@ -41,23 +41,24 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/traceminuscombiner.h>
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/traceminuscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
-#include <pappsomspp/processing/filters/savgolfilter.h>
-#include <pappsomspp/processing/filters/filterlowintensitysignalremoval.h>
+#include <pappsomspp/core/processing/filters/savgolfilter.h>
+#include <pappsomspp/core/processing/filters/filterlowintensitysignalremoval.h>
 
 /////////////////////// Local includes
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "BaseTracePlotWnd.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "ProgramWindow.hpp"
 #include "LabelledNumberLineEditAction.hpp"
 #include "Application.hpp"
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -69,6 +70,13 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
 
   createMainMenu();
 
+  createLabellingSessionMenu();
+
+  connect(m_ui->labellingSessionMenuPushButton,
+          &QPushButton::clicked,
+          this,
+          &BaseTracePlotCompositeWidget::labellingSessionMenuPushButtonClicked);
+
   // The trace combined plot widget receives traces from integrations. It is
   // possible to perform various actions with the traces inside a composite plot
   // widget and the selection of the action to perform is done using check
@@ -76,15 +84,15 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
 
   // The replace trace(s) with new one action.
 
-  m_ui.eraseTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, E"));
-  connect(m_ui.eraseTraceCreateNewPushButton, &QPushButton::clicked, [this]() {
+  m_ui->eraseTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, E"));
+  connect(m_ui->eraseTraceCreateNewPushButton, &QPushButton::clicked, [this]() {
     m_newTraceHandlingMethod = NewTraceHandlingMethod::REPLACE;
   });
 
   // The overlay action.
 
-  m_ui.keepTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, O"));
-  connect(m_ui.keepTraceCreateNewPushButton, &QPushButton::clicked, [this]() {
+  m_ui->keepTraceCreateNewPushButton->setShortcut(QKeySequence("Ctrl+T, O"));
+  connect(m_ui->keepTraceCreateNewPushButton, &QPushButton::clicked, [this]() {
     m_newTraceHandlingMethod = NewTraceHandlingMethod::OVERLAY;
   });
 
@@ -100,17 +108,18 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
   const QIcon minus_combine_icon =
     QIcon(":/images/svg/keep-trace-and-minus-combine-new-one.svg");
 
-  m_ui.combinationsComboBox->insertItem(
+  m_ui->combinationsComboBox->insertItem(
     -1, minus_combine_icon, "", static_cast<int>(TraceCombinationSign::MINUS));
-  m_ui.combinationsComboBox->insertItem(
+  m_ui->combinationsComboBox->insertItem(
     10, plus_combine_icon, "", static_cast<int>(TraceCombinationSign::PLUS));
 
-  connect(m_ui.combinationsComboBox,
+  connect(m_ui->combinationsComboBox,
           QOverload<int>::of(&QComboBox::activated),
           [=]([[maybe_unused]] int index) {
             bool ok = false;
 
-            int item_data = m_ui.combinationsComboBox->currentData().toInt(&ok);
+            int item_data =
+              m_ui->combinationsComboBox->currentData().toInt(&ok);
 
             if(static_cast<TraceCombinationSign>(item_data) ==
                TraceCombinationSign::PLUS)
@@ -130,19 +139,13 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
             else
               qFatal("Programming error.");
           });
-
-  connect(m_ui.pinPointPeakApexPushButton, &QPushButton::clicked, [this]() {
-    m_isPeakApexPinPointing = m_ui.pinPointPeakApexPushButton->isChecked();
-  });
 }
 
-
 BaseTracePlotCompositeWidget::~BaseTracePlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 BaseTracePlotCompositeWidget::createMainMenu()
 {
@@ -338,7 +341,6 @@ BaseTracePlotCompositeWidget::createMainMenu()
   });
 }
 
-
 QCPGraph *
 BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
                                        QCPAbstractPlottable *parent_plottable_p,
@@ -488,7 +490,7 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
       // End of
       // else of if(!graph_count), that if there are graphs in the plot widget.
     }
-  // End of if(m_ui.keepTraceCombineNewPushButton->isChecked())
+  // End of if(m_ui->keepTraceCombineNewPushButton->isChecked())
   else if(m_newTraceHandlingMethod == NewTraceHandlingMethod::REPLACE)
     {
       // Start by erasing all the traces that are selected.
@@ -527,13 +529,17 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
       mp_parentWnd->getProgramWindow()->documentMsRunDataPlottableFiliation(
         ms_run_data_set_csp, graph_p, parent_plottable_p, this);
 
-      // Map the graph_p to the processing flow that we got to document how
-      // the trace was obtained in the first place.
-      m_plottableProcessingFlowMap[graph_p] = processing_flow;
+      // We need to allocate a new ProcessingFlow instance with the graph
+      // as its parent.
+      ProcessingFlow *processing_flow_p     = processing_flow.clone(graph_p);
+
+      // Map the graph_p to the processing flow that we got to document
+      // how the trace was obtained in the first place.
+      m_plottableProcessingFlowMap[graph_p] = processing_flow_p;
 
       // Note how we do  change the sample name text and its color.
       // He we do set a new trace.
-      m_ui.sampleNameLabel->setText(sample_name);
+      m_ui->sampleNameLabel->setText(sample_name);
       setSampleNameColor(color);
     }
 
@@ -551,7 +557,6 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
   return graph_p;
 }
 
-
 void
 BaseTracePlotCompositeWidget::showSavitzkyGolayFilterParamsDlg()
 {
@@ -667,7 +672,6 @@ BaseTracePlotCompositeWidget::showSavitzkyGolayFilterParamsDlg()
   mp_savitzkyGolayFilterParamsDlg->show();
 }
 
-
 void
 BaseTracePlotCompositeWidget::loadFilterParamsFromSettings(
   const QString &filter_name, QString &filter_parameters)
@@ -687,7 +691,6 @@ BaseTracePlotCompositeWidget::loadFilterParamsFromSettings(
   settings.endGroup();
 }
 
-
 void
 BaseTracePlotCompositeWidget::writeFilterParamsToSettings(
   const QString &filter_name, const QString &filter_parameters)
@@ -715,7 +718,6 @@ BaseTracePlotCompositeWidget::writeFilterParamsToSettings(
   // #endif
 }
 
-
 void
 BaseTracePlotCompositeWidget::savitzkyGolayFilterParamsChanged(
   pappso::SavGolParams sav_gol_params)
@@ -768,7 +770,7 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
   QCPAbstractPlottable *source_plottable_p =
     plottableToBeUsedAsIntegrationSource();
 
-  qDebug() << "The source plottable:" << source_plottable_p;
+  // qDebug() << "The source plottable:" << source_plottable_p;
 
   if(source_plottable_p == nullptr)
     {
@@ -830,19 +832,23 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
 
   if(!filtered_trace.size())
     {
-      qDebug() << "The trace produced by the filter is empty.";
+      // qDebug() << "The trace produced by the filter is empty.";
 
-      m_ui.statusLineEdit->setText(
+      m_ui->statusLineEdit->setText(
         QString("The filter %1 produced an empty trace. Plotting nothing.")
           .arg(filter_name));
 
       return;
     }
 
-  ProcessingFlow local_processing_flow =
-    getProcessingFlowForPlottable(source_plottable_p);
+  // Make a copy of the ProcessingFlow, without parentship, because we'll
+  // pass that instance by reference to downstream code that will allocate
+  // an instance with proper parentship. Just delete the temporary pointer
+  // after that call.
+  ProcessingFlow *temp_processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(source_plottable_p)->clone(nullptr);
 
-  local_processing_flow.addFilter(filter_csp);
+  temp_processing_flow_p->addFilter(filter_csp);
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(source_plottable_p);
@@ -851,10 +857,11 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
            source_plottable_p,
            ms_run_data_set_csp,
            ms_run_data_set_csp->getMsRunId()->getSampleName(),
-           local_processing_flow,
+           *temp_processing_flow_p,
            source_plottable_p->pen().color());
-}
 
+  delete temp_processing_flow_p;
+}
 
 void
 BaseTracePlotCompositeWidget::runSavitzkyGolayFilter()
@@ -864,7 +871,6 @@ BaseTracePlotCompositeWidget::runSavitzkyGolayFilter()
   runFilter("Savitzky-Golay");
 }
 
-
 void
 BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
@@ -894,7 +900,6 @@ BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // the fields have been met.
 }
 
-
 void
 BaseTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
   const pappso::BasePlotContext &context)
@@ -947,49 +952,46 @@ BaseTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
     }
 }
 
+void
+BaseTracePlotCompositeWidget::plotWidgetMousePressEvent(
+  [[maybe_unused]] const pappso::BasePlotContext &context)
+{
+  // qDebug() << "The BasePlotContext:" << context.toString();
+  BasePlotCompositeWidget::plotWidgetMousePressEvent(context);
+}
 
 void
 BaseTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(
   [[maybe_unused]] const pappso::BasePlotContext &context)
 {
-  // qDebug();
-
-  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::NoButton)
-  // qDebug() << "no button";
-
-  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::LeftButton)
-  // qDebug() << "left button";
-
-  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::RightButton)
-  //{
-  // qDebug() << "right button with context:" << context.toString();
-  //}
-
-  // Now check what keyboard key was being pressed while the mouse
-  // operation was going on.
-
-  // int pressed_key_code = context.m_pressedKeyCode;
-  // qDebug() << "pressed_key_code:" << pressed_key_code;
+  BasePlotCompositeWidget::plotWidgetMouseReleaseEvent(context);
 
   // If the user clicks on a trace plot widget while maintaining the 'X' or 'Y'
   // keys pressed, and if m_isPeakApexPinPointing is true, then the user is
   // capturing the x axis (or y axis) value in the console.
 
-  if(m_isPeakApexPinPointing)
-    {
-      if(context.m_pressedKeyCode == Qt::Key_X)
-        {
-          mp_parentWnd->getProgramWindow()->logTextToConsole(
-            QString("%1").arg(context.m_lastCursorHoveredPoint.x(), 0, 'f', 4));
-          // qDebug() << "The x value:" << context.m_lastCursorHoveredPoint.x();
-        }
-      else if(context.m_pressedKeyCode == Qt::Key_Y)
-        {
-          mp_parentWnd->getProgramWindow()->logTextToConsole(
-            QString("%1").arg(context.m_lastCursorHoveredPoint.y(), 0, 'f', 4));
-          // qDebug() << "The x value:" << context.m_lastCursorHoveredPoint.y();
-        }
-    }
+  if (m_isPinPointingPeakApex) {
+      // qDebug() << "Peak apex pin pointing.";
+
+      double x_value = context.m_lastCursorHoveredPoint.x();
+      double y_value = context.m_lastCursorHoveredPoint.y();
+
+      QString text;
+
+      if (context.m_pressedKeyCode == Qt::Key_X) {
+          text = QString("%1").arg(x_value, 0, 'f', 4);
+      } else if (context.m_pressedKeyCode == Qt::Key_Y) {
+          text = QString("%1").arg(y_value, 0, 'f', 4);
+      } else if (context.m_pressedKeyCode == Qt::Key_C) {
+          // (X,Y)
+          text = QString("(%1,%2)").arg(x_value, 0, 'f', 4).arg(y_value, 0, 'f', 4);
+      }
+
+      if (!text.isEmpty()) {
+          mp_parentWnd->getProgramWindow()->logTextToConsole(text);
+          labelPeak(text, QPointF(x_value, y_value));
+      }
+  }
 }
 
 void
@@ -1154,7 +1156,6 @@ BaseTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
     }
 }
 
-
 void
 BaseTracePlotCompositeWidget::setNoiseSampleTrace()
 {
@@ -1184,7 +1185,6 @@ BaseTracePlotCompositeWidget::setNoiseSampleTrace()
   static_cast<BaseTracePlotWnd *>(mp_parentWnd)->setNoiseSampleTrace(trace);
 }
 
-
 void
 BaseTracePlotCompositeWidget::resetNoiseSampleTrace()
 {
@@ -1210,6 +1210,287 @@ BaseTracePlotCompositeWidget::resetNoiseSampleTrace()
   static_cast<BaseTracePlotWnd *>(mp_parentWnd)->resetNoiseSampleTrace();
 }
 
+void
+BaseTracePlotCompositeWidget::pinPointPeakApexCheckBoxStateChanged(
+  Qt::CheckState state)
+{
+  // When entering the pin point peak apex data analysis mode,
+  // we do not want to select traces.
+  // By default, pappso::BasePlotWidget is set with:
+  // setInteractions(QCP::iRangeZoom | QCP::iSelectPlottables |
+  // QCP::iMultiSelect);
+
+  if(state == Qt::Checked)
+    {
+      // qDebug() << "The pin point peak apex button is checked.";
+      m_isPinPointingPeakApex = true;
+      mp_plotWidget->setInteractions(QCP::iRangeZoom);
+    }
+  else if(state == Qt::Unchecked || state == Qt::PartiallyChecked)
+    {
+      // qDebug() << "The pin point peak apex button is not checked.";
+      m_isPinPointingPeakApex = false;
+      mp_plotWidget->setInteractions(QCP::iRangeZoom | QCP::iSelectPlottables |
+                                     QCP::iMultiSelect);
+    }
+}
+
+void BaseTracePlotCompositeWidget::createLabellingSessionMenu()
+{
+    // qDebug() << "ENTER";
+
+    if (mp_labelSessionMenu != nullptr)
+        delete mp_labelSessionMenu;
+
+    // Create the menu.
+    mp_labelSessionMenu = new QMenu(this);
+
+    // Create the menu push button.
+    const QIcon menu_icon = QIcon(":/images/svg/label-session-menu-button.svg");
+    mp_labelSessionMenu->setIcon(menu_icon);
+    mp_labelSessionMenu->setToolTip("Labelling session menu (Ctrl+L, S)");
+
+    // Finally set the push button to be the menu...
+    m_ui->labellingSessionMenuPushButton->setMenu(mp_labelSessionMenu);
+
+    QAction *pick_peaks_only_on_visible_maxima_p = mp_labelSessionMenu->addAction(
+        "Pick peaks only on visible maxima");
+
+    connect(pick_peaks_only_on_visible_maxima_p,
+            &QAction::triggered,
+            this,
+            &BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima);
+
+    mp_labelSessionMenu->addSeparator();
+
+    QAction *start_stop_labelling_session_p = mp_labelSessionMenu->addAction(
+        "Start/Stop labelling session");
+
+    start_stop_labelling_session_p->setCheckable(true);
+    start_stop_labelling_session_p->setShortcut(QKeySequence("Ctrl+L, S"));
+
+    connect(start_stop_labelling_session_p, &QAction::toggled, [this](bool checked) {
+        m_isPinPointingPeakApex = checked;
+        // qDebug() << "Labelling session open?" << checked;
+    });
+
+    mp_labelSessionMenu->addSeparator();
+
+    QAction *toggle_all_labels_visibility_action_p = mp_labelSessionMenu->addAction(
+        "Toggle all peak labels visibility");
+
+    toggle_all_labels_visibility_action_p->setShortcut(QKeySequence("Ctrl+T, V"));
+
+    connect(toggle_all_labels_visibility_action_p,
+            &QAction::triggered,
+            this,
+            &BaseTracePlotCompositeWidget::toggleAllPeakLabelsVisibility);
+
+    mp_labelSessionMenu->addSeparator();
+
+    QAction *remove_first_label_action_p = mp_labelSessionMenu->addAction(
+        "Remove first peak label");
+
+    remove_first_label_action_p->setShortcut(QKeySequence("Ctrl+R, F"));
+
+    connect(remove_first_label_action_p,
+            &QAction::triggered,
+            this,
+            &BaseTracePlotCompositeWidget::removeFirstPeakLabel);
+
+    QAction *remove_last_label_action_p = mp_labelSessionMenu->addAction("Remove last peak label");
+
+    remove_last_label_action_p->setShortcut(QKeySequence("Ctrl+R, L"));
+
+    connect(remove_last_label_action_p,
+            &QAction::triggered,
+            this,
+            &BaseTracePlotCompositeWidget::removeLastPeakLabel);
+
+    mp_labelSessionMenu->addSeparator();
+
+    QAction *remove_all_labels_action_p = mp_labelSessionMenu->addAction("Remove all peak labels");
+
+    remove_all_labels_action_p->setShortcut(QKeySequence("Ctrl+R, A"));
+
+    connect(remove_all_labels_action_p,
+            &QAction::triggered,
+            this,
+            &BaseTracePlotCompositeWidget::removeAllPeakLabels);
+
+    mp_labelSessionMenu->addSeparator();
+
+    QAction *export_labels_to_clipboard_action_p = mp_labelSessionMenu->addAction(
+        "Export peak labels to clipboard");
+
+    export_labels_to_clipboard_action_p->setShortcut(QKeySequence("Ctrl+E, L"));
+
+    connect(export_labels_to_clipboard_action_p,
+            &QAction::triggered,
+            this,
+            &BaseTracePlotCompositeWidget::exportPeakLabelsToClipboard);
+}
+
+void BaseTracePlotCompositeWidget::labellingSessionMenuPushButtonClicked()
+{
+    createLabellingSessionMenu();
+    m_ui->mainMenuPushButton->showMenu();
+}
+
+void BaseTracePlotCompositeWidget::labelPeak(const QString &text, const QPointF &plot_point)
+{
+    PeakLabelSPtr peak_label_sp = std::make_shared<PeakLabel>(mp_plotWidget, text, plot_point);
+
+    m_peakLabels.push_back(peak_label_sp);
+
+    mp_plotWidget->replot();
+}
+
+void BaseTracePlotCompositeWidget::labelPeaks(const pappso::Trace &trace)
+{
+    QString text;
+
+    for (const pappso::DataPoint &dp : trace) {
+        text = QString("(%1,%2)").arg(dp.x, 0, 'f', 4).arg(dp.y, 0, 'f', 4);
+
+        PeakLabelSPtr peak_label_sp = std::make_shared<PeakLabel>(mp_plotWidget,
+                                                                  text,
+                                                                  QPointF(dp.x, dp.y));
+
+        m_peakLabels.push_back(peak_label_sp);
+    }
+
+    mp_plotWidget->replot();
+}
+
+void BaseTracePlotCompositeWidget::toggleAllPeakLabelsVisibility()
+{
+    // qDebug();
+
+    if (!m_peakLabels.size())
+        return;
+
+    for (PeakLabelSPtr peak_label_sp : m_peakLabels)
+        peak_label_sp->rp_qcpItemText->setVisible(!peak_label_sp->rp_qcpItemText->visible());
+
+    mp_plotWidget->replot();
+}
+
+void BaseTracePlotCompositeWidget::removeFirstPeakLabel()
+{
+    // qDebug();
+
+    if (!m_peakLabels.size())
+        return;
+
+    PeakLabelSPtr peak_label_sp = *m_peakLabels.begin();
+
+    bool res = mp_plotWidget->removeItem(peak_label_sp->rp_qcpItemText);
+    if (!res)
+        qDebug() << "The item could not be removed.";
+    else
+        mp_plotWidget->replot();
+
+    m_peakLabels.erase(m_peakLabels.begin());
+}
+
+void BaseTracePlotCompositeWidget::removeLastPeakLabel()
+{
+    // qDebug();
+
+    if (!m_peakLabels.size())
+        return;
+
+    PeakLabelSPtr peak_label_sp = *std::prev(m_peakLabels.end());
+
+    bool res = mp_plotWidget->removeItem(peak_label_sp->rp_qcpItemText);
+    if (!res)
+        qCritical() << "The item could not be removed.";
+    else
+        mp_plotWidget->replot();
+
+    m_peakLabels.erase(std::prev(m_peakLabels.end()));
+}
+
+void BaseTracePlotCompositeWidget::removeAllPeakLabels()
+{
+    // qDebug();
+
+    if (!m_peakLabels.size())
+        return;
+
+    std::vector<PeakLabelSPtr>::iterator the_iterator = m_peakLabels.begin();
+
+    while (the_iterator != m_peakLabels.end()) {
+        bool res = mp_plotWidget->removeItem((*the_iterator)->rp_qcpItemText);
+        if (!res)
+            qCritical() << "The item could not be removed.";
+        else
+            mp_plotWidget->replot();
+
+        the_iterator = m_peakLabels.erase(the_iterator);
+    }
+}
+
+void BaseTracePlotCompositeWidget::exportPeakLabelsToClipboard()
+{
+    QString text;
+
+    for (const PeakLabelSPtr &peak_label_sp : m_peakLabels)
+        text += QString("%1\n").arg(peak_label_sp->rp_qcpItemText->text());
+
+    if (!text.isEmpty()) {
+        QClipboard *clipboard_p = QApplication::clipboard();
+
+        clipboard_p->setText(text, QClipboard::Clipboard);
+    }
+}
+
+pappso::Trace BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima()
+{
+pappso::Trace  trace;
+  // First we get the source graph that might be of interest to the user.
+
+  QCPAbstractPlottable *source_plottable_p =
+    plottableToBeUsedAsIntegrationSource();
+
+  if(source_plottable_p == nullptr)
+    {
+      QMessageBox::information(this,
+                               "Please select *one* trace",
+                               "In order to perform peak picking, the source "
+                               "graph needs to be selected.",
+                               QMessageBox::StandardButton::Ok,
+                               QMessageBox::StandardButton::NoButton);
+
+      return trace;
+    }
+
+  // Thus user has zoomed in such a manner that only the desired peaks
+  // in a trace are visible.
+
+  // Get the y range, so that we know what the bottom clipping end is (the floor
+  // of the visible data).
+
+  QCPRange plot_widget_x_axis_range = mp_plotWidget->xAxis->range();
+  QCPRange plot_widget_y_axis_range = mp_plotWidget->yAxis->range();
+
+  double y_floor_value = plot_widget_y_axis_range.lower;
+
+  pappso::Trace data_trace =
+    static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
+      ->toTrace(plot_widget_x_axis_range,
+                static_cast<QCPGraph *>(source_plottable_p));
+
+  // Now use the Trace filter to get a new trace with the local maxima points
+  // only:
+
+  trace =
+    flooredLocalMaxima(data_trace.begin(), data_trace.end(), y_floor_value);
+
+  labelPeaks(trace);
+  return trace;
+}
 
 bool
 BaseTracePlotCompositeWidget::savePeakListToClipboard()
@@ -1248,7 +1529,6 @@ BaseTracePlotCompositeWidget::savePeakListToClipboard()
   return true;
 }
 
-
 bool
 BaseTracePlotCompositeWidget::savePeakListToFile()
 {
@@ -1287,6 +1567,6 @@ BaseTracePlotCompositeWidget::savePeakListToFile()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
