@@ -44,8 +44,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basetraceplotwidget.h>
-#include <pappsomspp/trace/trace.h>
+#include <pappsomspp/gui/plotwidget/basetraceplotwidget.h>
+#include <pappsomspp/core/trace/trace.h>
 
 
 /////////////////////// Local includes
@@ -57,9 +57,31 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
+struct PeakLabel
+{
+    QCPItemText *rp_qcpItemText = nullptr;
+    QPointF position;
+
+    PeakLabel(QCustomPlot *plot_p, const QString text, const QPointF &position)
+    {
+        rp_qcpItemText = new QCPItemText(plot_p);
+        rp_qcpItemText->setText(text);
+        rp_qcpItemText->setLayer("plotsLayer");
+        rp_qcpItemText->setColor(QColor("black"));
+
+        rp_qcpItemText->setPositionAlignment(Qt::AlignBottom | Qt::AlignLeft);
+        rp_qcpItemText->position->setType(QCPItemPosition::ptPlotCoords);
+        rp_qcpItemText->position->setCoords(position.x(), position.y());
+        rp_qcpItemText->setRotation(-60);
+        rp_qcpItemText->setVisible(true);
+    }
+};
+
+using PeakLabelSPtr = std::shared_ptr<PeakLabel>;
+
 class BaseTracePlotWnd;
 class MsFragmentationSpecDlg;
 
@@ -75,6 +97,10 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
   friend class BasePlotWnd;
   friend class BaseTracePlotWnd;
 
+  public slots:
+
+  void labellingSessionMenuPushButtonClicked();
+
   public:
   explicit BaseTracePlotCompositeWidget(QWidget *parent,
                                         const QString &x_axis_label,
@@ -104,6 +130,17 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
   void runFilter(const QString &filter_name);
   void runSavitzkyGolayFilter();
 
+  pappso::Trace pickPeaksOnlyOnVisibleMaxima();
+
+  virtual void createLabellingSessionMenu();
+  virtual void labelPeak(const QString &text, const QPointF &plot_point);
+  virtual void labelPeaks(const pappso::Trace &trace);
+  virtual void toggleAllPeakLabelsVisibility();
+  virtual void removeFirstPeakLabel();
+  virtual void removeLastPeakLabel();
+  virtual void removeAllPeakLabels();
+  virtual void exportPeakLabelsToClipboard();
+
   bool savePeakListToClipboard();
   bool savePeakListToFile();
 
@@ -115,12 +152,18 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
 
   virtual void
   plotWidgetKeyReleaseEvent(const pappso::BasePlotContext &context) override;
+
+  virtual void
+  plotWidgetMousePressEvent(const pappso::BasePlotContext &context) override;
+
   virtual void
   plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context) override;
 
   virtual void setNoiseSampleTrace();
   virtual void resetNoiseSampleTrace();
 
+  virtual void pinPointPeakApexCheckBoxStateChanged(Qt::CheckState state);
+
   signals:
 
   void plotWidgetMouseReleaseEventSignal(QMouseEvent *event);
@@ -128,16 +171,19 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
   protected:
   // These are the members that are specific to the BaseTrace plot composite
   // widget.
-  bool m_isSinglePointIntegrationMode = false;
-  QCPRange m_integrationRange;
-  bool m_isPeakApexPinPointing                                  = false;
-  SavitzkyGolayFilterParamsDlg *mp_savitzkyGolayFilterParamsDlg = nullptr;
+      QMenu *mp_labelSessionMenu = nullptr;
+      bool m_isSinglePointIntegrationMode = false;
+      QCPRange m_integrationRange;
+      SavitzkyGolayFilterParamsDlg *mp_savitzkyGolayFilterParamsDlg = nullptr;
 
-  virtual void createMainMenu() override;
-  pappso::Trace lowIntensitySignalRemoval(pappso::Trace &trace, double value);
+      bool m_isPinPointingPeakApex = false;
+      std::vector<PeakLabelSPtr> m_peakLabels;
+
+      virtual void createMainMenu() override;
+      pappso::Trace lowIntensitySignalRemoval(pappso::Trace &trace, double value);
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
