@@ -46,7 +46,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -555,6 +555,6 @@ DataPlottableNode::toDebug(int offset, bool with_children) const
     }
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
