@@ -56,7 +56,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class DataPlottableNode;
@@ -140,6 +140,6 @@ class DataPlottableNode
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
