@@ -48,7 +48,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -715,6 +715,6 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
