@@ -41,18 +41,19 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/driftspecmassspeccolormapplotwidget.h>
-#include <pappsomspp/processing/combiners/integrationscoperect.h>
-#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
+#include <pappsomspp/gui/plotwidget/driftspecmassspeccolormapplotwidget.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperhomb.h>
+
 
 /////////////////////// Local includes
 #include "DriftSpecMassSpecColorMapPlotCompositeWidget.hpp"
 #include "BaseColorMapPlotWnd.hpp"
-
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -67,14 +68,12 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::
   setupWidget();
 }
 
-
 DriftSpecMassSpecColorMapPlotCompositeWidget::
   ~DriftSpecMassSpecColorMapPlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 DriftSpecMassSpecColorMapPlotCompositeWidget::setupWidget()
 {
@@ -84,7 +83,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::setupWidget()
   /************  The QCustomPlot widget *************/
   mp_plotWidget = new pappso::DriftSpecMassSpecColorMapPlotWidget(
     this, m_axisLabelX, m_axisLabelY);
-  m_ui.qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
+  m_ui->qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
 
   connect(mp_plotWidget,
           &pappso::DriftSpecMassSpecColorMapPlotWidget::setFocusSignal,
@@ -156,10 +155,9 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::setupWidget()
   // The button that triggers the duplication of the trace into another trace
   // plot widget. We do not do that for color maps yet.
 
-  m_ui.duplicateTracePushButton->hide();
+  m_ui->duplicateTracePushButton->hide();
 }
 
-
 void
 DriftSpecMassSpecColorMapPlotCompositeWidget::lastCursorHoveredPoint(
   const QPointF &pointf)
@@ -171,7 +169,6 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::lastCursorHoveredPoint(
   // calculations.
 }
 
-
 void
 DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
@@ -223,7 +220,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   //**context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
   context.msp_integrationScope->range(
-    pappso::Axis::x, x_range_start, x_range_end);
+    pappso::Enums::Axis::x, x_range_start, x_range_end);
 
   // qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
@@ -235,7 +232,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   //**context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
   context.msp_integrationScope->range(
-    pappso::Axis::y, y_range_start, y_range_end);
+    pappso::Enums::Axis::y, y_range_start, y_range_end);
 
   // qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
@@ -276,8 +273,8 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // Create a local copy of the processing flow so that we can modify it by
   // adding the new processing step that describes what we are doing now.
 
-  ProcessingFlow local_processing_flow =
-    getProcessingFlowForPlottable(plottable_p);
+  ProcessingFlow *temp_processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(plottable_p)->clone(this);
 
   // qDebug().noquote() << "Processing flow for graph:"
   //<< local_processing_flow.toString();
@@ -299,7 +296,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // ProcessingFlow's ms fragmentation specification.
 
   MsFragmentationSpec ms_fragmentation_spec =
-    local_processing_flow.getDefaultMsFragmentationSpec();
+    temp_processing_flow_p->getDefaultMsFragmentationSpec();
 
   // Only set the ms frag spec to the processing spec if it is valid.
   if(ms_fragmentation_spec.isValid())
@@ -320,38 +317,38 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Sanity check.
 
-  pappso::DataKind x_axis_data_kind =
+  pappso::Enums::DataKind x_axis_data_kind =
     static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
       ->xAxisDataKind();
-  pappso::DataKind y_axis_data_kind =
+  pappso::Enums::DataKind y_axis_data_kind =
     static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
       ->yAxisDataKind();
 
-  if(x_axis_data_kind == pappso::DataKind::dt)
+  if(x_axis_data_kind == pappso::Enums::DataKind::dt)
     {
       // qDebug() << "X axis: dt";
     }
-  else if(x_axis_data_kind == pappso::DataKind::mz)
+  else if(x_axis_data_kind == pappso::Enums::DataKind::mz)
     {
       // qDebug() << "X axis: mz";
     }
 
-  if(y_axis_data_kind == pappso::DataKind::dt)
+  if(y_axis_data_kind == pappso::Enums::DataKind::dt)
     {
       // qDebug() << "Y axis: dt";
     }
-  else if(y_axis_data_kind == pappso::DataKind::mz)
+  else if(y_axis_data_kind == pappso::Enums::DataKind::mz)
     {
       // qDebug() << "Y axis: mz";
     }
 
-  if(x_axis_data_kind == pappso::DataKind::dt &&
-     y_axis_data_kind != pappso::DataKind::mz)
+  if(x_axis_data_kind == pappso::Enums::DataKind::dt &&
+     y_axis_data_kind != pappso::Enums::DataKind::mz)
     {
       qFatal("Programming error.");
     }
-  else if(x_axis_data_kind == pappso::DataKind::mz &&
-          y_axis_data_kind != pappso::DataKind::dt)
+  else if(x_axis_data_kind == pappso::Enums::DataKind::mz &&
+          y_axis_data_kind != pappso::Enums::DataKind::dt)
     {
       qFatal("Programming error.");
     }
@@ -434,7 +431,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // qDebug() << "New local integration scope is Rhomb:"
   //          << local_integration_scope_base_sp->isRhomboid();
 
-  if(x_axis_data_kind == pappso::DataKind::mz)
+  if(x_axis_data_kind == pappso::Enums::DataKind::mz)
     {
       // We transpose to have x::dt and y::mz.
       //**local_selection_polygon = local_selection_polygon.transpose();
@@ -448,11 +445,11 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right selection polygon for x:MZ and y:DT.
 
-  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
-  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::mz);
 
-  local_integration_scope_base_sp->setDataKindX(pappso::DataKind::dt);
-  local_integration_scope_base_sp->setDataKindY(pappso::DataKind::mz);
+  local_integration_scope_base_sp->setDataKindX(pappso::Enums::DataKind::dt);
+  local_integration_scope_base_sp->setDataKindY(pappso::Enums::DataKind::mz);
 
   // And now actually set the integration scope to the step.
 
@@ -460,13 +457,13 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   processing_step_sp->setIntegrationScope(local_integration_scope_base_sp);
 
   // We must say what is the data source processing type.
-  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
-  processing_step_sp->setSrcProcessingType(pappso::Axis::y, "MZ");
+  processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "DT");
+  processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::y, "MZ");
 
   // Now we need to document not the source but the destination. What kind of
   // integration are we about to perform?
 
-  if(m_ui.integrateToRtPushButton->isChecked())
+  if(m_ui->integrateToRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to XIC chromatogram.";
 
@@ -475,41 +472,41 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       processing_step_sp->setDestProcessingType("RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-        ->integrateToRt(plottable_p, local_processing_flow);
+        ->integrateToRt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToDtRtPushButton->isChecked())
+  else if(m_ui->integrateToDtRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to dt / rt color map.";
 
       processing_step_sp->setDestProcessingType("DT_RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-        ->integrateToDtRt(plottable_p, local_processing_flow);
+        ->integrateToDtRt(plottable_p, *temp_processing_flow_p);
     }
   // Handle all the integrations to MZ in one place
-  else if(m_ui.integrateToMzPushButton->isChecked() ||
-          m_ui.integrateToDtMzPushButton->isChecked() ||
-          m_ui.integrateToMzRtPushButton->isChecked())
+  else if(m_ui->integrateToMzPushButton->isChecked() ||
+          m_ui->integrateToDtMzPushButton->isChecked() ||
+          m_ui->integrateToMzRtPushButton->isChecked())
     {
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to mass spectrum.";
 
           processing_step_sp->setDestProcessingType("MZ");
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to rt / m/z color map.";
 
           processing_step_sp->setDestProcessingType("MZ_RT");
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt / m/z color map.";
 
@@ -524,48 +521,10 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // Extract from it the default pappso::MzIntegrationParams:
 
-      pappso::MzIntegrationParams mz_integration_params =
-        local_processing_flow.getDefaultMzIntegrationParams();
-
-      // qDebug()
-      //<< "The graph's processing flow has default mz integration params:"
-      //<< mz_integration_params.toString();
-
-      // If it is not valid, then try mz integration params from the various
-      // steps of the flow. Preferentially the most recent ones.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug()
-          //<< "The processing flow's default mz integ params are not "
-          //"valid. Trying to get the most recent mz integ params "
-          //"from the processing flow. If valid, we may tune them later.";
-
-          mz_integration_params =
-            *(local_processing_flow.mostRecentMzIntegrationParams());
-        }
-
-      // If it is not valid, finally resort to the parameters that can be
-      // crafted on the basis of the statistical analysis of the ms run data set
-      // while it was loaded from file.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug() << "The most recent mz integ param are not valid. We use "
-          //"the getMsRunDataSetStats to craft new ones that we may "
-          //"tune later.";
-
-          mz_integration_params =
-            ms_run_data_set_csp->craftInitialMzIntegrationParams();
-        }
-      else
-        {
-          // qDebug() << "The most recent mz integ params are valid. Use them, "
-          //"with potential tuning.";
-        }
-
-      if(!mz_integration_params.isValid())
-        qFatal(
-          "The mz integ params from the ms run data set stats are not "
-          "valid.");
+      // This heap-allocated instance will contain the found
+      // MzIntegrationParams.
+      pappso::MzIntegrationParams *successful_mz_integration_params_p =
+        getSensibleMzIntegrationParams(plottable_p);
 
       // At this point, let's see if we can optimize the integration
       // computation. Indeed, if we know we have an mz range in the selection
@@ -579,7 +538,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       //**bool res = local_selection_polygon.rangeY(mz_range_lower,
       // mz_range_upper);
       bool res = local_integration_scope_base_sp->range(
-        pappso::Axis::y, mz_range_lower, mz_range_upper);
+        pappso::Enums::Axis::y, mz_range_lower, mz_range_upper);
 
       if(!res)
         {
@@ -593,8 +552,8 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // integration comes right from the intial TIC, then the range is the
       // whole range of the mass data in the dataset.
 
-      mz_integration_params.setSmallestMz(mz_range_lower);
-      mz_integration_params.setGreatestMz(mz_range_upper);
+      successful_mz_integration_params_p->setSmallestMz(mz_range_lower);
+      successful_mz_integration_params_p->setGreatestMz(mz_range_upper);
 
       // qDebug() << "After tuning the mz range, mz integration params:"
       //<< mz_integration_params.toString();
@@ -608,10 +567,10 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
-      if(m_ui.integrateToDtMzPushButton->isChecked() ||
-         m_ui.integrateToMzRtPushButton->isChecked())
+      if(m_ui->integrateToDtMzPushButton->isChecked() ||
+         m_ui->integrateToMzRtPushButton->isChecked())
         {
-          mz_integration_params.setBinningType(pappso::BinningType::NONE);
+          mz_integration_params.setBinningType(pappso::MzIntegrationParams::BinningType::NONE);
           mz_integration_params.setDecimalPlaces(0);
         }
 
@@ -619,14 +578,15 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing
       // step that we are creating to document this current integration.
-      processing_step_sp->setMzIntegrationParams(mz_integration_params);
+      processing_step_sp->setMzIntegrationParams(
+        successful_mz_integration_params_p);
 
       // And now add the new processing step to the local copy of the
       // processing flow, so that we document on top of all the previous
       // steps, also this last one.
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -634,45 +594,46 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // The local processing flow contains all the previous steps and the
       // last one that documents this current integration.
 
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-            ->integrateToMz(plottable_p, local_processing_flow);
+            ->integrateToMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-            ->integrateToDtMz(plottable_p, local_processing_flow);
+            ->integrateToDtMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-            ->integrateToMzRt(plottable_p, local_processing_flow);
+            ->integrateToMzRt(plottable_p, *temp_processing_flow_p);
         }
     }
-  else if(m_ui.integrateToDtPushButton->isChecked())
+  else if(m_ui->integrateToDtPushButton->isChecked())
     {
       // qDebug() << "Integrating to drift spectrum.";
 
       processing_step_sp->setDestProcessingType("DT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-        ->integrateToDt(plottable_p, local_processing_flow);
+        ->integrateToDt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToIntPushButton->isChecked())
+  else if(m_ui->integrateToIntPushButton->isChecked())
     {
       // qDebug() << "Integrating to TIC intensity.";
 
       processing_step_sp->setDestProcessingType("INT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
+        ->integrateToTicIntensity(
+          plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -685,8 +646,12 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::Ok,
         QMessageBox::StandardButton::NoButton);
     }
+
+  delete temp_processing_flow_p;
+
+  return;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
