@@ -41,21 +41,21 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>
+#include <pappsomspp/gui/plotwidget/colormapplotconfig.h>
 
 
 /////////////////////// Local includes
 #include "ProgramWindow.hpp"
 #include "DriftSpecMassSpecColorMapWnd.hpp"
 #include "DriftSpecMassSpecColorMapPlotCompositeWidget.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -97,7 +97,7 @@ DriftSpecMassSpecColorMapWnd::addColorMapPlot(
   QString ion_mobility_axis_label = "drift time (ms)";
 
   if(ms_run_data_set_csp->getMsRunId()->getMsDataFormat() ==
-     pappso::MsDataFormat::brukerTims)
+     pappso::Enums::MsDataFormat::brukerTims)
     {
       ion_mobility_axis_label = "inverse mobility (1/K0)";
     }
@@ -135,6 +135,7 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
+
   std::pair<double, double> range_pair;
 
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
@@ -142,14 +143,15 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   if(!integration_rt)
     qFatal("Programming error.");
 
-  qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
-           << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
+  //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  //
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  //
+  // if(integration_dt)
+  //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
+  //            << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
-
-  if(integration_dt)
-    qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-             << "for y axis: " << range_pair.first << "-" << range_pair.second;
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
 
@@ -216,7 +218,7 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
     new MassDataIntegratorTask();
 
   qRegisterMetaType<std::size_t>("std::size_t");
-  qRegisterMetaType<pappso::DataKind>("pappso::DataKind");
+  qRegisterMetaType<pappso::Enums::DataKind>("pappso::Enums::DataKind");
 
   // This signal starts the computation in the MassDataIntegratorTask object.
   connect(this,
@@ -306,10 +308,10 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
           &QualifiedMassSpectrumVectorMassDataIntegrator::cancelOperation);
 
   // We need to register the meta type for std::size_t because otherwise it
-  // cannot be shipped though signals. Same for pappso::DataKind.
+  // cannot be shipped though signals. Same for pappso::Enums::DataKind.
 
   qRegisterMetaType<std::size_t>("std::size_t");
-  qRegisterMetaType<pappso::DataKind>("pappso::DataKind");
+  qRegisterMetaType<pappso::Enums::DataKind>("pappso::Enums::DataKind");
 
   // Now make all the connections that will allow the integrator to provide
   // dynamic feedback to the user via the task monitor widget.
@@ -355,11 +357,26 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
   // We get back the integrator that was made to work in another thread. Now get
   // the obtained data and work with them.
 
+  // Make sure we make a copy of the ProcessingFlow stored in the
+  // mass data integrator, because that ProcessingFlow is owned by the
+  // mass data integrator and the latter will be destroyed below. We can make
+  // the copy without parentship because we'll pass it as reference to
+  // downstream code that will use that ref to allocate a new fully parented
+  // instance.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
+
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
+  // Sanity check
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
+    qFatal() << "Programming error. Not possible that the MsRunDataSet "
+                "pointers do not match.";
+
   // We need some specific function from the specialized integrator.
   QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
     *mass_data_integrator_to_rtdtmz_p =
@@ -387,11 +404,11 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
   // the minimum/maximum mz value.
 
   pappso::ColorMapPlotConfig color_map_plot_config(
-    pappso::DataKind::dt,
-    pappso::DataKind::mz,
-    pappso::AxisScale::orig,
-    pappso::AxisScale::orig,
-    pappso::AxisScale::orig,
+    pappso::Enums::DataKind::dt,
+    pappso::Enums::DataKind::mz,
+    pappso::Enums::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
     mass_data_integrator_to_rtdtmz_p->getColorMapKeyCellCount(),
     mass_data_integrator_to_rtdtmz_p->getColorMapMzCellCount(),
     mass_data_integrator_to_rtdtmz_p->getColorMapMinKey(),
@@ -403,17 +420,8 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
 
   // qDebug() << "color_map_plot_config:" << color_map_plot_config.toString();
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
-
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // Now that we got all we need and that we have made a safe copy
+  // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -436,7 +444,7 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
   addColorMapPlot(double_map_trace_map_sp,
                   color_map_plot_config,
                   ms_run_data_set_csp,
-                  processing_flow,
+                  *temp_processing_flow_p,
                   plot_color,
                   static_cast<QCPAbstractPlottable *>(parent_plottable_p));
 
@@ -448,9 +456,13 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
     {
       showWindow();
     }
+
+  delete temp_processing_flow_p;
+
+  return;
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
