@@ -51,7 +51,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProcessingFlow;
@@ -100,6 +100,6 @@ class DriftSpecMassSpecColorMapWnd : public BaseColorMapPlotWnd
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
