@@ -41,20 +41,20 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/driftspectraceplotwidget.h>
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-#include <pappsomspp/processing/combiners/integrationscope.h>
+#include <pappsomspp/gui/plotwidget/driftspectraceplotwidget.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/integrationscope.h>
 
 
 /////////////////////// Local includes
 #include "DriftSpecTracePlotCompositeWidget.hpp"
 #include "DriftSpecTracePlotWidget.hpp"
 #include "DriftSpecTracePlotWnd.hpp"
-
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -67,13 +67,11 @@ DriftSpecTracePlotCompositeWidget::DriftSpecTracePlotCompositeWidget(
   setupWidget();
 }
 
-
 DriftSpecTracePlotCompositeWidget::~DriftSpecTracePlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 DriftSpecTracePlotCompositeWidget::setupWidget()
 {
@@ -83,7 +81,7 @@ DriftSpecTracePlotCompositeWidget::setupWidget()
   /************  The QCustomPlot widget *************/
   mp_plotWidget =
     new pappso::DriftSpecTracePlotWidget(this, m_axisLabelX, m_axisLabelY);
-  m_ui.qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
+  m_ui->qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
 
   connect(
     mp_plotWidget, &pappso::DriftSpecTracePlotWidget::setFocusSignal, [this]() {
@@ -144,13 +142,12 @@ DriftSpecTracePlotCompositeWidget::setupWidget()
   // The button that triggers the duplication of the trace into another trace
   // plot widget.
 
-  connect(m_ui.duplicateTracePushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->duplicateTracePushButton, &QPushButton::clicked, [this]() {
     // qDebug();
     static_cast<BaseTracePlotWnd *>(getParentWnd())->duplicateTracePlot(this);
   });
 }
 
-
 void
 DriftSpecTracePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
 
@@ -160,7 +157,6 @@ DriftSpecTracePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
   // At this point we can start doing drift spectrum-specific calculations.
 }
 
-
 void
 DriftSpecTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
   const pappso::BasePlotContext &context)
@@ -170,7 +166,8 @@ DriftSpecTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
   // Modify the context to conform to the integration range that was computed
   // in the base class function.
 
-  pappso::BasePlotContext local_context = context;
+  pappso::BasePlotContext local_context;
+  local_context.initialize(context);
   local_context.m_xRegionRangeStart     = m_integrationRange.lower;
   local_context.m_xRegionRangeEnd       = m_integrationRange.upper;
 
@@ -178,7 +175,6 @@ DriftSpecTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
     integrationRequested(local_context);
 }
 
-
 void
 DriftSpecTracePlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
@@ -189,7 +185,8 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
   // one. Look there for all the explanative comments.
 
   // Make a local copy of the context because we may need to modify it.
-  pappso::BasePlotContext local_context = context;
+  pappso::BasePlotContext local_context;
+  local_context.initialize(context);
 
   // Check if the integration scope contains meaningful data. We are in trace
   // plot widget, so the scope might be in the form of a
@@ -218,7 +215,7 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
 
   std::const_pointer_cast<pappso::IntegrationScopeBase>(
     local_context.msp_integrationScope)
-    ->setDataKindX(pappso::DataKind::dt);
+    ->setDataKindX(pappso::Enums::DataKind::dt);
 
   // Sanity check.
 
@@ -229,9 +226,9 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
 
   //**local_context.m_selectionPolygon.rangeX(range_start, range_end);
   local_context.msp_integrationScope->range(
-    pappso::Axis::x, range_start, range_end);
+    pappso::Enums::Axis::x, range_start, range_end);
 
-  qDebug() << "X axis range:" << range_start << "-" << range_end;
+  // qDebug() << "X axis range:" << range_start << "-" << range_end;
 
   // Having negative drift times does not make any sense.
   if(range_start < 0 && range_end < 0)
@@ -271,13 +268,12 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       return;
     }
 
-  // Create a local copy of the processing flow.
+  // Create a temporary copy of the ProcessingFlow (with no parentship) so that
+  // we can modify it with new steps and then pass it as reference to downstream
+  // code that will allocate a fully parented instance.
 
-  ProcessingFlow local_processing_flow =
-    getProcessingFlowForPlottable(plottable_p);
-
-  // qDebug().noquote() << "Processing flow for graph:"
-  //<< local_processing_flow.toString();
+  ProcessingFlow *temp_processing_flow_p =
+    getProcessingFlowPtrForPlottable(plottable_p)->clone(nullptr);
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
@@ -289,7 +285,7 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
   ProcessingStepSPtr processing_step_sp = std::make_shared<ProcessingStep>();
 
   MsFragmentationSpec ms_fragmentation_spec =
-    local_processing_flow.getDefaultMsFragmentationSpec();
+    temp_processing_flow_p->getDefaultMsFragmentationSpec();
 
   // Only set the ms frag spec to the processing spec if it is valid.
   if(ms_fragmentation_spec.isValid())
@@ -306,46 +302,48 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       //"valid. Not using it.";
     }
 
+  // Now make sure we document the selection polygon.
+  // Now define the graph range for the integration operation.
   //**processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
   processing_step_sp->setIntegrationScope(local_context.msp_integrationScope);
 
   // We must say what is the data source processing type.
-  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
+  processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "DT");
 
   // It is essential that we document the relation between the axes and the
   // corresponding data type.
-  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
-  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::unset);
 
-  if(m_ui.integrateToRtPushButton->isChecked())
+  if(m_ui->integrateToRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to XIC chromatogram.";
 
       processing_step_sp->setDestProcessingType("RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-        ->integrateToRt(plottable_p, local_processing_flow);
+        ->integrateToRt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToMzPushButton->isChecked() ||
-          m_ui.integrateToDtMzPushButton->isChecked() ||
-          m_ui.integrateToMzRtPushButton->isChecked())
+  else if(m_ui->integrateToMzPushButton->isChecked() ||
+          m_ui->integrateToDtMzPushButton->isChecked() ||
+          m_ui->integrateToMzRtPushButton->isChecked())
     {
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to mass spectrum.";
 
           processing_step_sp->setDestProcessingType("MZ");
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to rt|m/z color map.";
 
           processing_step_sp->setDestProcessingType("MZ_RT");
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt|m/z color map.";
 
@@ -358,58 +356,40 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       // This is a multi-layer work: the graph has a ProcessingFlow associated
       // to it via the m_graphProcessingFlowMap. We have gotten it above.
 
-      // Extract from it the default pappso::MzIntegrationParams:
+      // At this point we need to define how the mass data integrator will
+      // combine spectra, since we are integrating to a mass spectrum.
 
-      pappso::MzIntegrationParams mz_integration_params =
-        local_processing_flow.getDefaultMzIntegrationParams();
+      // The function below will first get the potential settings that might
+      // have been stored by the user when "Set as default" is checked in the
+      // MzIntegrationParamsDlg window. If no integration settings were found,
+      // then other possibilities are tested (in particular by looking into
+      // the ProcessingFlow).
 
-      // If it is not valid, then try mz integration params from the various
-      // steps of the flow. Preferentially the most recent ones.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
+      // Heap-allocated
+      pappso::MzIntegrationParams *mz_integration_params_p =
+        BasePlotCompositeWidget::getSensibleMzIntegrationParams(plottable_p);
 
-          const pappso::MzIntegrationParams *mz_integration_params_p =
-            local_processing_flow.mostRecentMzIntegrationParams();
-
-          if(mz_integration_params_p != nullptr)
-            mz_integration_params = *mz_integration_params_p;
-        }
-
-      // If it is not valid, finally resort to the parameters that can be
-      // crafted on the basis of the statistical analysis of the ms run data set
-      // while it was loaded from file.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug() << "The most recent mz integ param are not valid.";
-
-          mz_integration_params =
-            ms_run_data_set_csp->craftInitialMzIntegrationParams();
-        }
-
-      if(!mz_integration_params.isValid())
-        qFatal(
-          "The mz integ params from the ms run data set stats are not valid.");
-
-      // Note that we cannot integrate mass spectra with a high resolution
-      // here. We need to reduce the resolution to integer resolution.
-      if(m_ui.integrateToDtMzPushButton->isChecked())
-        {
-          mz_integration_params.setBinningType(pappso::BinningType::NONE);
-          mz_integration_params.setDecimalPlaces(0);
-        }
+      // This is no more true, we let the user set the binning logic.
+      // // Note that we cannot integrate mass spectra with a high resolution
+      // // here. We need to reduce the resolution to integer resolution.
+      // if(m_ui->integrateToDtMzPushButton->isChecked())
+      //   {
+      //     mz_integration_params_p->setBinningType(
+      //       pappso::MzIntegrationParams::BinningType::NONE);
+      //     mz_integration_params_p->setDecimalPlaces(0);
+      //   }
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
-      processing_step_sp->setMzIntegrationParams(mz_integration_params);
+      // Takes ownership
+      processing_step_sp->setMzIntegrationParams(mz_integration_params_p);
 
       // And nwo add the new processing step to the local copy of the processing
       // flow, so that we document on top of all the previous steps, also this
       // last one.
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -417,35 +397,35 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       // The local processing flow contains all the previous steps and the last
       // one that documents this current integration.
 
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-            ->integrateToMz(plottable_p, local_processing_flow);
+            ->integrateToMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-            ->integrateToDtMz(plottable_p, local_processing_flow);
+            ->integrateToDtMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-            ->integrateToMzRt(plottable_p, local_processing_flow);
+            ->integrateToMzRt(plottable_p, *temp_processing_flow_p);
         }
     }
-  else if(m_ui.integrateToDtPushButton->isChecked())
+  else if(m_ui->integrateToDtPushButton->isChecked())
     {
       // qDebug() << "Integrating to drift spectrum.";
 
       processing_step_sp->setDestProcessingType("DT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-        ->integrateToDt(plottable_p, nullptr, local_processing_flow);
+        ->integrateToDt(plottable_p, nullptr, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToDtRtPushButton->isChecked())
+  else if(m_ui->integrateToDtRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to TIC|XIC chromatogram / drift spectrum
       // colormap.";
@@ -453,22 +433,22 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       processing_step_sp->setDestProcessingType("DT_RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-        ->integrateToDtRt(plottable_p, local_processing_flow);
+        ->integrateToDtRt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToIntPushButton->isChecked())
+  else if(m_ui->integrateToIntPushButton->isChecked())
     {
       // qDebug() << "Integrating to TIC intensity.";
 
       processing_step_sp->setDestProcessingType("INT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
+        ->integrateToTicIntensity(plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -482,106 +462,11 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::NoButton);
     }
 
-#if 0
-
-	// Old version not accounting for the color map integrations.
-
-  else if(m_ui.integrateToMzPushButton->isChecked())
-    {
-      qDebug() << "Integration to mass spectrum.";
-
-      // Now we can set the new spec to the step that we allocated earlier.
-      // While doing so we make the map between the type and the spec itself.
-
-      processing_step_p->newSpec(ProcessingType("DT_TO_MZ"), processing_spec_p);
-
-      pappso::MzIntegrationParams mz_integration_params =
-        local_processing_flow.getDefaultMzIntegrationParams();
-
-      // If it is not valid, then try mz integration params from the various
-      // steps of the flow. Preferentially the most recent ones.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
-
-          mz_integration_params =
-            *(local_processing_flow.mostRecentMzIntegrationParams());
-        }
-
-      // If it is not valid, finally resort to the parameters that can be
-      // crafted on the basis of the statistical analysis of the ms run data set
-      // while it was loaded from file.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug() << "The most recent mz integ param are not valid.";
-
-          mz_integration_params =
-            ms_run_data_set_csp->craftInitialMzIntegrationParams();
-        }
-
-      if(!mz_integration_params.isValid())
-        qFatal(
-          "The mz integ params from the ms run data set stats are not valid.");
-
-      // We finally have mz integ params that we can set to the processing step
-      // that we are creating to document this current integration.
-      processing_step_p->setMzIntegrationParams(mz_integration_params);
-
-      // And nwo add the new processing step to the local copy of the processing
-      // flow, so that we document on top of all the previous steps, also this
-      // last one.
-      local_processing_flow.push_back(processing_step_p);
-
-      // qDebug().noquote() << "Pushed back new processing step:"
-      //<< processing_step_p->toString();
-
-      // The local processing flow contains all the previous steps and the last
-      // one that documents this current integration.
-
-      static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-        ->integrateToMz(plottable_p, local_processing_flow);
-    }
-  else if(m_ui.integrateToDtPushButton->isChecked())
-    {
-      qDebug() << "Integrating to drift spectrum.";
-
-      processing_step_p->newSpec(ProcessingType("DT_TO_DT"), processing_spec_p);
-
-      local_processing_flow.push_back(processing_step_p);
-
-      static_cast<DriftSpecTracePlotWnd *>(mp_parentWnd)
-        ->integrateToDt(plottable_p, local_processing_flow);
-    }
-  else if(m_ui.integrateToIntPushButton->isChecked())
-    {
-      qDebug() << "Integrating to TIC intensity.";
-
-      processing_step_p->newSpec(ProcessingType("DT_TO_INT"),
-                                 processing_spec_p);
-
-      local_processing_flow.push_back(processing_step_p);
-
-      static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, local_processing_flow);
-    }
-  else
-    {
-      QMessageBox::information(
-        this,
-        "Please select a destination for the integration",
-        "In order to perform an integration, select a destination "
-        "like a mass spectrum or a drift spectrum by clicking one "
-        "of the buttons on the right margin of the plot widget.",
-        QMessageBox::StandardButton::Ok,
-        QMessageBox::StandardButton::NoButton);
-    }
-#endif
+    delete temp_processing_flow_p;
 
   return;
 }
 
-
 void
 DriftSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
@@ -608,7 +493,7 @@ DriftSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
 #if 0
 					// We actually do not do this because that part is handled by the base
 					// class.
-					
+
           // We should inform the user if there are more than one plottable.
 
           int plottable_count = mp_plotWidget->plottableCount();
@@ -638,7 +523,6 @@ DriftSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // if(context.m_baseContext.pressedKeyCode == Qt::Key_Space)
 }
 
-
 QString
 DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
   const pappso::BasePlotContext &context)
@@ -665,10 +549,8 @@ DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
       return QString();
     }
 
-  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
-
   MsRunDataSetCstSPtr ms_run_data_set_csp =
-    processing_flow.getMsRunDataSetCstSPtr();
+    getCstProcessingFlowPtrForPlottable(plottable_p)->getMsRunDataSetCstSPtr();
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
 
@@ -691,8 +573,8 @@ DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
         {
           if(prevChar == '\\')
             {
-              stanza += '\\';
-              prevChar = ' ';
+              stanza   += '\\';
+              prevChar  = ' ';
               continue;
             }
           else
@@ -706,8 +588,8 @@ DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
         {
           if(prevChar == '\\')
             {
-              stanza += '%';
-              prevChar = ' ';
+              stanza   += '%';
+              prevChar  = ' ';
               continue;
             }
           else
@@ -792,8 +674,8 @@ DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 'x')
             {
-              stanza += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
-              prevChar = ' ';
+              stanza   += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
+              prevChar  = ' ';
               continue;
             }
           if(curChar == 'y')
@@ -849,6 +731,6 @@ DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
