@@ -44,8 +44,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basetraceplotwidget.h>
-#include <pappsomspp/trace/trace.h>
+#include <pappsomspp/gui/plotwidget/basetraceplotwidget.h>
+#include <pappsomspp/core/trace/trace.h>
 
 
 /////////////////////// Local includes
@@ -54,7 +54,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class DriftSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
@@ -89,6 +89,6 @@ class DriftSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
