@@ -46,7 +46,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 DriftSpecTracePlotWidget::DriftSpecTracePlotWidget(QWidget *parent_p,
@@ -61,6 +61,6 @@ DriftSpecTracePlotWidget::~DriftSpecTracePlotWidget()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
