@@ -38,14 +38,14 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basetraceplotwidget.h>
+#include <pappsomspp/gui/plotwidget/basetraceplotwidget.h>
 
 /////////////////////// Local includes
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class DriftSpecTracePlotWidget : public pappso::BaseTracePlotWidget
@@ -68,6 +68,6 @@ class DriftSpecTracePlotWidget : public pappso::BaseTracePlotWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
