@@ -47,7 +47,7 @@
 #include "ProgramWindow.hpp"
 #include "DriftSpecTracePlotWnd.hpp"
 #include "DriftSpecTracePlotCompositeWidget.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 #include "TaskMonitorWnd.hpp"
@@ -55,7 +55,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -91,7 +91,7 @@ DriftSpecTracePlotWnd::addTracePlot(
   QString ion_mobility_axis_label = "drift time (ms)";
 
   if(ms_run_data_set_csp->getMsRunId()->getMsDataFormat() ==
-     pappso::MsDataFormat::brukerTims)
+     pappso::Enums::MsDataFormat::brukerTims)
     {
       ion_mobility_axis_label = "inverse mobility (1/K0)";
     }
@@ -100,7 +100,7 @@ DriftSpecTracePlotWnd::addTracePlot(
     new DriftSpecTracePlotCompositeWidget(
       this, ion_mobility_axis_label, "counts (a.u.)");
 
-    qDebug() << "At addTracePlot time, the color:" << color;
+  // qDebug() << "At addTracePlot time, the color:" << color;
 
   return finalNewTracePlotConfiguration(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
@@ -114,8 +114,8 @@ DriftSpecTracePlotWnd::integrateToDt(
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
-  qDebug().noquote() << "Integrating to dt with processing flow:"
-                     << processing_flow.toString();
+  // qDebug().noquote() << "Integrating to dt with processing flow:"
+  //                    << processing_flow.toString();
 
   // Get the ms run data set that for the graph we are going to base the
   // integration on.
@@ -126,6 +126,7 @@ DriftSpecTracePlotWnd::integrateToDt(
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
+
   std::pair<double, double> range_pair;
 
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
@@ -133,16 +134,17 @@ DriftSpecTracePlotWnd::integrateToDt(
   if(!integration_rt)
     qFatal("Programming error.");
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "Innermost RT range:" << range_pair.first << "-"
-           << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10)
+  //          << "Innermost RT range:" << range_pair.first << "-"
+  //          << range_pair.second;
 
-  bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  //
+  // if(integration_dt)
+  //   qDebug() << qSetRealNumberPrecision(10)
+  //            << "Innermost DT range:" << range_pair.first << "-"
+  //            << range_pair.second;
 
-  if(integration_dt)
-    qDebug() << qSetRealNumberPrecision(10)
-             << "Innermost DT range:" << range_pair.first << "-"
-             << range_pair.second;
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
 
@@ -154,9 +156,9 @@ DriftSpecTracePlotWnd::integrateToDt(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  qDebug()
-    << "The number of selected mass spectra on the basis of rough RT/DT values:"
-    << qualified_mass_spectra_count;
+  // qDebug()
+  //   << "The number of selected mass spectra on the basis of rough RT/DT values:"
+  //   << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -328,11 +330,26 @@ DriftSpecTracePlotWnd::finishedIntegratingToDt(
   // We get back the integrator that was made to work in another thread. Now get
   // the obtained data and work with them.
 
+  // Make sure we make a copy of the ProcessingFlow stored in the
+  // mass data integrator, because that ProcessingFlow is owned by the
+  // mass data integrator and the latter will be destroyed below. We can make
+  // the copy without parentship because we'll pass it as reference to
+  // downstream code that will use that ref to allocate a new fully parented
+  // instance.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
+
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
+  // Sanity check
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
+    qFatal() << "Programming error. Not possible that the MsRunDataSet "
+                "pointers do not match.";
+
   pappso::Trace integrated_trace =
     mass_data_integrator_p->getMapTrace().toTrace();
 
@@ -342,17 +359,9 @@ DriftSpecTracePlotWnd::finishedIntegratingToDt(
       return;
     }
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
 
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // Now that we got all we need and that we have made a safe copy
+  // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -376,7 +385,7 @@ DriftSpecTracePlotWnd::finishedIntegratingToDt(
 
   newTrace(integrated_trace,
            ms_run_data_set_csp,
-           processing_flow,
+           *temp_processing_flow_p,
            plot_color,
            static_cast<QCPGraph *>(parent_plottable_p));
 
@@ -388,6 +397,8 @@ DriftSpecTracePlotWnd::finishedIntegratingToDt(
     {
       showWindow();
     }
+
+    delete temp_processing_flow_p;
 }
 
 
@@ -463,6 +474,6 @@ DriftSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *parent_plottable_p,
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
