@@ -44,7 +44,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/massspectraceplotwidget.h>
+#include <pappsomspp/core/trace/datapoint.h>
+#include <pappsomspp/gui/plotwidget/massspectraceplotwidget.h>
 
 /////////////////////// Local includes
 #include "BaseTracePlotCompositeWidget.hpp"
@@ -52,7 +53,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
@@ -81,7 +82,10 @@ class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
   plotWidgetKeyPressEvent(const pappso::MassSpecTracePlotContext &context);
 
   virtual void
-  plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context) override;
+  plotWidgetMousePressEvent(const pappso::MassSpecTracePlotContext &context);
+
+  virtual void
+  plotWidgetMouseReleaseEvent(const pappso::MassSpecTracePlotContext &context);
 
   virtual void moveMouseCursorToNextGraphPoint(
     const pappso::BasePlotContext &context) override;
@@ -116,6 +120,6 @@ class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
