@@ -46,7 +46,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent_p,
@@ -58,9 +58,10 @@ MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent_p,
 
 MassSpecTracePlotWidget::~MassSpecTracePlotWidget()
 {
+  // qDebug();
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
