@@ -40,12 +40,13 @@
 #include <QColor>
 
 
-/////////////////////// libmass includes
-#include <libXpertMass/MassDataCborMassSpectrumHandler.hpp>
-#include <pappsomspp/massspectrum/massspectrum.h>
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/msrun/msrundatasettree.h>
-#include <pappsomspp/msrun/msrunid.h>
+/////////////////////// libXpertMass includes
+#include <MsXpS/libXpertMassCore/MassDataCborMassSpectrumHandler.hpp>
+#include <pappsomspp/core/massspectrum/massspectrum.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/msrun/msrundatasettree.h>
+#include <pappsomspp/core/msrun/msrunid.h>
+#include <pappsomspp/core/processing/combiners/integrationscope.h>
 
 
 /////////////////////// pappsomspp includes
@@ -58,12 +59,11 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 #include "TaskMonitorWnd.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
-
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -76,13 +76,12 @@ MassSpecTracePlotWnd::MassSpecTracePlotWnd(QWidget *parent,
   extendMainMenu();
 }
 
-
 //! Destruct \c this MassSpecTracePlotWnd instance.
 MassSpecTracePlotWnd::~MassSpecTracePlotWnd()
 {
+  // qDebug();
 }
 
-
 void
 MassSpecTracePlotWnd::extendMainMenu()
 {
@@ -173,7 +172,6 @@ MassSpecTracePlotWnd::extendMainMenu()
   mp_mainMenu->addSeparator();
 }
 
-
 // This function does not check if there are widgets that are pinned-down so as
 // to gather new trace data. This function creates a brand new plot composite
 // widget.
@@ -194,7 +192,6 @@ MassSpecTracePlotWnd::addTracePlot(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
 }
 
-
 void
 MassSpecTracePlotWnd::integrateToMz(
   QCPAbstractPlottable *parent_plottable_p,
@@ -202,10 +199,10 @@ MassSpecTracePlotWnd::integrateToMz(
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
-  // qDebug().noquote() << "Integrating to mz with processing flow:"
-  //<< processing_flow.toString();
+  qDebug().noquote() << "20250904 - Integrating to mz with processing flow:"
+                     << processing_flow.toString(0, "  ");
 
-  // Get the ms run data set that for the graph we are going to base the
+  // Get the ms run data set for the graph that we are going to base the
   // integration on.
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
@@ -214,15 +211,29 @@ MassSpecTracePlotWnd::integrateToMz(
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
+
   std::pair<double, double> range_pair;
 
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration_rt)
-    qFatal("Programming error.");
+    {
+      // It is imaginable that the data come not from a previous RT step,
+      // that is, that the data are indeed MZ data not coming from at least
+      // one integration from TIC chromatogram if the mass spectrum (MZ)
+      // comes from the net (source processing type is SOCKET_MZ).
 
-  // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
-  //<< "for y axis: " << range_pair.first << "-" << range_pair.second;
+      std::vector<ProcessingStepCstSPtr> steps =
+        processing_flow.stepsMatchingSrcTypeX("SOCKET_MZ");
+
+      if(!steps.size())
+        qFatal(
+          "Programming error: the data have a problematic ProcessingFlow.");
+    }
+
+  qDebug() << qSetRealNumberPrecision(10)
+           << "20250904 - Innermost RT range:" << range_pair.first << "-"
+           << range_pair.second;
 
   // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
   // if(integration_dt)
@@ -232,13 +243,20 @@ MassSpecTracePlotWnd::integrateToMz(
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
 
-  // What integration parameters are we going to use ? Since we do integrate to
-  // a mass spectrum it is compulsory that the most recent step has valid mz
-  // integration params.
+  // What integration parameters are we going to use ?
+  // We can ask that the most relevant MzIntegrationParams be returned
+  // by the ProcessingFlow.
 
-  // Set aside an object for later use.
+  // Get a copy to the MzIntegrationParams in the most recent step.
   const pappso::MzIntegrationParams *mz_integration_params_p =
-    processing_flow.mostRecentStep()->getMzIntegrationParamsPtr();
+    processing_flow.getSensibleMzIntegrationParams();
+
+  // FIXME This might be the place where we need to change the
+  // mz integration params to reflect the m/z range to be integrated ?
+  // Question question
+
+  qDebug().noquote() << "20250904 - Got sensible m/z integration params:\n"
+                     << mz_integration_params_p->toString(0, "  ");
 
   if(mz_integration_params_p == nullptr || !mz_integration_params_p->isValid())
     qFatal(
@@ -253,9 +271,9 @@ MassSpecTracePlotWnd::integrateToMz(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  // qDebug()
-  //<< "The number of selected mass spectra on the basis of rough RT/DT values:"
-  //<< qualified_mass_spectra_count;
+  qDebug() << "20250904 - The number of selected mass spectra on the basis of "
+              "rough RT/DT values:"
+           << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -279,8 +297,6 @@ MassSpecTracePlotWnd::integrateToMz(
     mp_programWindow,
     &ProgramWindow::logTextToConsole);
 
-  // qDebug() << "Receiving processing flow:" << processing_flow.toString();
-
   MassDataIntegratorTask *mass_data_integrator_task_p =
     new MassDataIntegratorTask();
 
@@ -351,7 +367,7 @@ MassSpecTracePlotWnd::integrateToMz(
   task_monitor_composite_widget_p->setMsRunIdText(
     ms_run_data_set_csp->getMsRunId()->getSampleName());
   task_monitor_composite_widget_p->setTaskDescriptionText(
-    "Integrating to mass spectrum from the table view");
+    "Integrating to mass spectrum");
   task_monitor_composite_widget_p->setProgressBarMinValue(0);
 
   // Make the connections
@@ -409,7 +425,6 @@ MassSpecTracePlotWnd::integrateToMz(
                &MassDataIntegratorTask::integrateToMz));
 }
 
-
 void
 MassSpecTracePlotWnd::finishedIntegratingToMz(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
@@ -421,35 +436,41 @@ MassSpecTracePlotWnd::finishedIntegratingToMz(
 
   // qDebug() << "the integrator pointer:" << mass_data_integrator_p;
 
-  // We get back the integrator that was made to work in another thread. Now
-  // get the obtained data and work with them.
+  // We get back the integrator that was made to work in another thread. Now get
+  // the obtained data and work with them.
+
+  // Make sure we make a copy of the ProcessingFlow stored in the
+  // mass data integrator, because that ProcessingFlow is owned by the
+  // mass data integrator and the latter will be destroyed below. We can make
+  // the copy without parentship because we'll pass it as reference to
+  // downstream code that will use that ref to allocate a new fully parented
+  // instance.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
 
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
+  // Sanity check
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
+    qFatal() << "Programming error. Not possible that the MsRunDataSet "
+                "pointers do not match.";
+
   pappso::Trace integrated_trace =
     mass_data_integrator_p->getMapTrace().toTrace();
   // qDebug() << "mass spectrum trace size:" << integrated_trace.size();
 
   if(!integrated_trace.size())
     {
-      qDebug() << "There is not a single point in the integrated trace.";
+      qInfo() << "There is not a single point in the integrated trace.";
       return;
     }
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
-
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // Now that we got all we need and that we have made a safe copy
+  // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -473,7 +494,7 @@ MassSpecTracePlotWnd::finishedIntegratingToMz(
 
   newTrace(integrated_trace,
            ms_run_data_set_csp,
-           processing_flow,
+           *temp_processing_flow_p,
            plot_color,
            static_cast<QCPGraph *>(parent_plottable_p));
 
@@ -485,35 +506,30 @@ MassSpecTracePlotWnd::finishedIntegratingToMz(
     {
       showWindow();
     }
-}
 
+  delete temp_processing_flow_p;
+}
 
 void
 MassSpecTracePlotWnd::integrateToRt(QCPAbstractPlottable *parent_plottable_p,
                                     const ProcessingFlow &processing_flow)
 {
-  // qDebug();
-
   if(parent_plottable_p == nullptr)
     qFatal("Cannot be that pointer is nullptr.");
 
   mp_programWindow->integrateToRt(parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 MassSpecTracePlotWnd::integrateToDt(QCPAbstractPlottable *parent_plottable_p,
                                     const ProcessingFlow &processing_flow)
 {
-  // qDebug();
-
   if(parent_plottable_p == nullptr)
     qFatal("Cannot be that pointer is nullptr.");
 
   mp_programWindow->integrateToDt(parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 MassSpecTracePlotWnd::integrateToMzRt(QCPAbstractPlottable *plottable_p,
                                       const ProcessingFlow &processing_flow)
@@ -524,7 +540,6 @@ MassSpecTracePlotWnd::integrateToMzRt(QCPAbstractPlottable *plottable_p,
   mp_programWindow->integrateToMzRt(plottable_p, nullptr, processing_flow);
 }
 
-
 void
 MassSpecTracePlotWnd::integrateToDtMz(QCPAbstractPlottable *plottable_p,
                                       const ProcessingFlow &processing_flow)
@@ -535,7 +550,6 @@ MassSpecTracePlotWnd::integrateToDtMz(QCPAbstractPlottable *plottable_p,
   mp_programWindow->integrateToDtMz(plottable_p, nullptr, processing_flow);
 }
 
-
 void
 MassSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *plottable_p,
                                       const ProcessingFlow &processing_flow)
@@ -546,7 +560,6 @@ MassSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *plottable_p,
   mp_programWindow->integrateToDtRt(plottable_p, nullptr, processing_flow);
 }
 
-
 void
 MassSpecTracePlotWnd::setMinimalChargeFractionalPartPinnedDownWidgets(
   double value)
@@ -560,7 +573,6 @@ MassSpecTracePlotWnd::setMinimalChargeFractionalPartPinnedDownWidgets(
     }
 }
 
-
 void
 MassSpecTracePlotWnd::setChargeStateEnvelopePeakSpanPinnedDownWidgets(
   std::size_t value)
@@ -574,22 +586,20 @@ MassSpecTracePlotWnd::setChargeStateEnvelopePeakSpanPinnedDownWidgets(
     }
 }
 
-
 void
 MassSpecTracePlotWnd::handleReceivedData(const QByteArray &byte_array)
 {
-
-  libXpertMass::MassDataCborMassSpectrumHandler cbor_handler(this);
+  libXpertMassCore::MassDataCborMassSpectrumHandler cbor_handler(this);
 
   if(!cbor_handler.readByteArray(byte_array))
     {
-      qDebug() << "Failed to read CBOR mass spectrum data.";
+      qCritical() << "Failed to read CBOR mass spectrum data.";
 
       return;
     }
 
   pappso::Trace trace = cbor_handler.getTrace();
-  qDebug() << "Received trace of size:" << trace.size();
+  qDebug() << "20250904 - Received trace of size:" << trace.size();
 
   QString title               = cbor_handler.getTitle();
   QByteArray color_byte_array = cbor_handler.getTraceColor();
@@ -602,7 +612,6 @@ MassSpecTracePlotWnd::handleReceivedData(const QByteArray &byte_array)
     title, color_byte_array, std::make_shared<const pappso::Trace>(trace));
 }
 
-
 void
 MassSpecTracePlotWnd::handleReceivedData(const QString &title,
                                          const QByteArray &color_byte_array,
@@ -611,6 +620,9 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   // Create a new ms run data set piece by piece.
 
+  qDebug() << "20250904 -  Handling received data, create a ms run data set "
+              "piecemeal.";
+
   pappso::MsRunIdSPtr ms_run_id_sp = std::make_shared<pappso::MsRunId>();
   ms_run_id_sp->setSampleName(title);
   ms_run_id_sp->setFileName(title);
@@ -626,9 +638,21 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   // Now create the mass spectrum with the trace.
 
+  qDebug() << "20250904 - The trace's first point:"
+           << trace_sp->minXDataPoint().x;
+  qDebug() << "20250904 - The trace's last point:"
+           << trace_sp->maxXDataPoint().x;
+
   pappso::MassSpectrumSPtr mass_spectrum_sp =
     std::make_shared<pappso::MassSpectrum>(*trace_sp);
 
+  qDebug().noquote()
+    << "20250904 - Before computing statistics for ms run data set:"
+    << ms_run_data_set_sp->getMsRunDataSetStats().toString();
+  ms_run_data_set_sp->incrementStatistics(mass_spectrum_sp);
+  qDebug().noquote() << "20250904 - After:"
+                     << ms_run_data_set_sp->getMsRunDataSetStats().toString();
+
   // Now create the qualified mass spectrum that we'll add to the ms run data
   // set.
 
@@ -643,29 +667,80 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   ms_run_data_set_sp->mapMassSpectrum(qualified_mass_spectrum_sp);
 
-  ProcessingFlow processing_flow;
-  processing_flow.setMsRunDataSetCstSPtr(ms_run_data_set_sp);
+  qDebug().noquote() << "20250904 - Mapped the mass spectrum to the data set:"
+                     << qualified_mass_spectrum_sp->toString();
 
+  // We will need the MzIntegrationParams and we set them specifically
+  // for this MsRunDataSet:
+  // Heap-allocated
+  pappso::MzIntegrationParams *ms_run_data_set_mz_integration_params_p =
+    ms_run_data_set_sp->craftMzIntegrationParams();
+
+  // Create a temporary ProcessingFlow with nullptr parent because we'll
+  // pass it to downstream code as a reference. That will be used to allocate
+  // a new instance with proper parentship. We'll delete the temporary
+  // instance when done.
+  ProcessingFlow *temp_processing_flow_p = new ProcessingFlow(nullptr);
+  temp_processing_flow_p->setMsRunDataSetCstSPtr(ms_run_data_set_sp);
+
+  // We are creating a mass spectrum from a single trace. We arbitrarily set
+  // the retention time to 1 min (60 s). We *need* to craft a fake processing
+  // flow step because when the user will use the graph that we will show in the
+  // plot widget to perform an integration, if there is no RT_ANY-related step
+  // in the processing flow, then the integration will invariably yield no data:
+  // no mass spectrum will be found to have a proper retention time.
+
+  ///////////// THE RETENTION TIME (RT) STEP //////////////////
   ProcessingStepSPtr new_step_sp = std::make_shared<ProcessingStep>();
-  new_step_sp->setSrcProcessingType(pappso::Axis::x, "SOCKET_MZ");
+  new_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "SOCKET_RT");
   new_step_sp->setDestProcessingType(ProcessingType("MZ"));
-  new_step_sp->setMzIntegrationParams(
-    ms_run_data_set_sp->craftInitialMzIntegrationParams());
-
+  // Craft the data for the creation of the IntegrationScope.
+  QPointF rt_point(0, 0);
+  double width = 1 - 0;
+  // Allocate a brand new integration scope (mono-dimensional, starting at
+  // rt_point with a width of 1 on the horizontal axis).
+  pappso::IntegrationScopeBaseCstSPtr integration_scope_csp =
+    std::make_shared<pappso::IntegrationScope>(rt_point, width);
+  qDebug() << "Created integration scope. Is it 1D ?:"
+           << integration_scope_csp->is1D()
+           << "is it 2D ?:" << integration_scope_csp->is2D();
+  // Finally, set the IntegrationScope to the step.
+  new_step_sp->setIntegrationScope(integration_scope_csp);
   // Should perform automatically the conversion from non-const to const.
-  processing_flow.push_back(new_step_sp);
+  temp_processing_flow_p->getStepsRef().push_back(new_step_sp);
+
+  ///////////// THE MASS SPEC (MZ) STEP //////////////////
+  new_step_sp = std::make_shared<ProcessingStep>();
+  new_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "SOCKET_MZ");
+  new_step_sp->setDestProcessingType(ProcessingType("MZ"));
+  // We now want to create an IntegrationScope that matches the full m/z range.
+  QPointF mz_point(ms_run_data_set_sp->getMsRunDataSetStats().m_minMz, 0);
+  width = ms_run_data_set_sp->getMsRunDataSetStats().m_maxMz -
+          ms_run_data_set_sp->getMsRunDataSetStats().m_minMz;
+  // Allocate a brand new integration scope (mono-dimensional, starting at
+  // mz_point with a width of m/z full range on the horizontal axis).
+  integration_scope_csp =
+    std::make_shared<pappso::IntegrationScope>(mz_point, width);
+  qDebug() << "Created integration scope. Is it 1D ?:"
+           << integration_scope_csp->is1D()
+           << "is it 2D ?:" << integration_scope_csp->is2D();
+  // Finally, set the IntegrationScope to the step.
+  new_step_sp->setIntegrationScope(integration_scope_csp);
+  new_step_sp->setMzIntegrationParams(*ms_run_data_set_mz_integration_params_p);
+  // Should perform automatically the conversion from non-const to const.
+  temp_processing_flow_p->getStepsRef().push_back(new_step_sp);
 
   // We need to const_cast the step in order to overwrite is
   // MsFragmentationSpec.
   MsFragmentationSpec fragmentation_spec =
-    processing_flow.getDefaultMsFragmentationSpec();
+    temp_processing_flow_p->getDefaultMsFragmentationSpec();
 
   // Set the MS level it to 0 because all the later integrations need to be
   // capable of involving any MS level. 0 states that MS level matches.
 
   fragmentation_spec.setMsLevel(0);
 
-  processing_flow.setDefaultMsFragmentationSpec(fragmentation_spec);
+  temp_processing_flow_p->setDefaultMsFragmentationSpec(fragmentation_spec);
 
   // First thing is create the data plot graph tree, because this is the entry
   // point to the whole set of data plot graphs : the tree is root into the TIC
@@ -690,15 +765,22 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   // parameters that were calculated while loading the ms run from file are
   // available for the very first integration to mz that might occur.
 
-  // Immediately set the default mz integration params to the local copy of the
-  // processing flow that we'll use later to craft the plot widget.
+  temp_processing_flow_p->setDefaultMzIntegrationParams(
+    *ms_run_data_set_mz_integration_params_p);
 
-  processing_flow.setDefaultMzIntegrationParams(
-    ms_run_data_set_sp->craftInitialMzIntegrationParams());
+  // We have used that object twice, we do not need it anymore.
+  delete ms_run_data_set_mz_integration_params_p;
+
+#ifndef NDEBUG
+  ms_run_data_set_mz_integration_params_p =
+    temp_processing_flow_p->getDefaultMzIntegrationParams();
+  // We have set them above, they must be found!
+  Q_ASSERT(ms_run_data_set_mz_integration_params_p);
+  qDebug().noquote()
+    << "The mz integration params set to the processing flow:\n"
+    << ms_run_data_set_mz_integration_params_p->toString(0, "  ");
+#endif
 
-  // qDebug().noquote()
-  //<< "Default mz integration parameters:"
-  //<< processing_flow.getDefaultMzIntegrationParams().toString();
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   //	qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
@@ -710,12 +792,15 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   newTrace(*mass_spectrum_sp,
            ms_run_data_set_sp,
-           processing_flow,
+           *temp_processing_flow_p,
            plot_color,
            nullptr);
+
+  // Finally delete the temporary instance:
+  delete temp_processing_flow_p;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 
 } // namespace MsXpS
