@@ -46,11 +46,11 @@
 #include "BaseTracePlotWnd.hpp"
 #include "MassSpecTracePlotCompositeWidget.hpp"
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
-#include <pappsomspp/trace/trace.h>
+#include <pappsomspp/core/trace/trace.h>
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -76,10 +76,10 @@ class MassSpecTracePlotWnd : public BaseTracePlotWnd
                QCPAbstractPlottable *parent_plottable_p) override;
 
   void integrateToMz(
-    QCPAbstractPlottable *plottable_p,
-    std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
-      qualified_mass_spectra_sp,
-    const ProcessingFlow &processing_flow);
+  QCPAbstractPlottable *parent_plottable_p,
+  std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
+    qualified_mass_spectra_sp,
+  const ProcessingFlow &processing_flow);
 
   void integrateToRt(QCPAbstractPlottable *plottable_p,
                      const ProcessingFlow &processing_flow);
@@ -130,6 +130,6 @@ class MassSpecTracePlotWnd : public BaseTracePlotWnd
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
