@@ -40,7 +40,7 @@
 /////////////////////// Qt includes
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
 
 
 /////////////////////// Local includes
@@ -49,7 +49,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -85,5 +85,5 @@ class MsRunDataSetTableViewItem
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
