@@ -51,7 +51,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 MsRunDataSetTableViewProxyModel::MsRunDataSetTableViewProxyModel(
@@ -217,7 +217,7 @@ MsRunDataSetTableViewProxyModel::parseSizeTString(const QString &text,
 
       // At this point we have the pair.
 
-      qDebug() << "pair:" << range_pair;
+      // qDebug() << "pair:" << range_pair;
 
       return range_pair;
     }
@@ -462,7 +462,7 @@ std::pair<double, double>
 MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
                                                    double accepted_lower_value)
 {
-  qDebug() << "text:" << text;
+  // qDebug() << "text:" << text;
 
   // The accepted syntax is like this:
   //
@@ -539,7 +539,7 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
 
       // At this point we have the pair.
 
-      qDebug() << "pair:" << range_pair;
+      // qDebug() << "pair:" << range_pair;
 
       return range_pair;
     }
@@ -548,7 +548,7 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
   // Range of values pattern (xxx -- yyy)
   regexp.setPattern("^\\s*" + sci_number + "\\s*--\\s*" + sci_number + "\\s*$");
 
-  qDebug() << "testing range:" << regexp.pattern();
+  // qDebug() << "testing range:" << regexp.pattern();
 
   match = regexp.match(text);
 
@@ -576,7 +576,7 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
 
       // At this point we have the pair.
 
-      qDebug() << "pair:" << range_pair;
+      // qDebug() << "pair:" << range_pair;
 
       return range_pair;
     }
@@ -1405,5 +1405,5 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
     qFatal("Should never reach this point.");
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
