@@ -51,7 +51,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class MsRunDataSetTableViewProxyModel : public QSortFilterProxyModel
@@ -99,5 +99,5 @@ class MsRunDataSetTableViewProxyModel : public QSortFilterProxyModel
                                               double accepted_lower_value);
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
