@@ -42,41 +42,43 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/integrationscopebase.h>
-#include <pappsomspp/processing/combiners/integrationscope.h>
-#include <pappsomspp/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/core/processing/combiners/integrationscopebase.h>
+#include <pappsomspp/core/processing/combiners/integrationscope.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperect.h>
 
 /////////////////////// Local includes
-#include "MsRunDataSetTableViewWnd.hpp"
-#include "MsRunDataSetTableViewItem.hpp"
 #include "../nongui/MsRunDataSet.hpp"
-#include "ProgramWindow.hpp"
-#include "MzIntegrationParamsDlg.hpp"
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
 #include "Application.hpp"
-
+#include "MsRunDataSetTableViewItem.hpp"
+#include "MsRunDataSetTableViewWnd.hpp"
+#include "MzIntegrationParamsDlg.hpp"
+#include "ProgramWindow.hpp"
+#include "ui_MsRunDataSetTableViewWnd.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
 //! Construct an MsRunDataSetTableViewWnd instance.
 MsRunDataSetTableViewWnd::MsRunDataSetTableViewWnd(
-  QWidget *parent_p,
   ProgramWindow *program_window_p,
   MsRunDataSetCstSPtr ms_run_data_set_csp,
-  const QColor &color)
-  : QMainWindow(parent_p),
+  const QColor &color,
+  QWidget *parent)
+  : QMainWindow(parent),
     mp_programWindow(program_window_p),
+    mp_processingFlow(new ProcessingFlow(this)),
     mcsp_msRunDataSet(ms_run_data_set_csp),
-    m_color(color)
+    m_color(color),
+    m_ui(new ::Ui::MsRunDataSetTableViewWnd)
 {
   if(program_window_p == Q_NULLPTR)
     qFatal("Programming error.");
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(dynamic_cast<QMainWindow *>(this));
 
   if(!initialize())
     qFatal("Programming error.");
@@ -85,20 +87,23 @@ MsRunDataSetTableViewWnd::MsRunDataSetTableViewWnd(
   // the ones found in the file during file load:
 
   // Set the MsRunDataSet pointer that we need when using toString().
-  m_processingFlow.setMsRunDataSetCstSPtr(ms_run_data_set_csp);
+  mp_processingFlow->setMsRunDataSetCstSPtr(ms_run_data_set_csp);
 
-  m_processingFlow.setDefaultMzIntegrationParams(
-    mcsp_msRunDataSet->craftInitialMzIntegrationParams());
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mcsp_msRunDataSet->craftMzIntegrationParams();
+
+  mp_processingFlow->setDefaultMzIntegrationParams(*mz_integration_params_p);
+
+  delete mz_integration_params_p;
 }
 
-
 //! Destruct \c this MsRunDataSetTableViewWnd instance.
 MsRunDataSetTableViewWnd::~MsRunDataSetTableViewWnd()
 {
   writeSettings();
 }
 
-
 //! Handle the close event.
 void
 MsRunDataSetTableViewWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
@@ -107,7 +112,6 @@ MsRunDataSetTableViewWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
   hide();
 }
 
-
 //! Write the settings to as to restore the window geometry later.
 void
 MsRunDataSetTableViewWnd::writeSettings()
@@ -119,14 +123,13 @@ MsRunDataSetTableViewWnd::writeSettings()
 
   settings.setValue("geometry", saveGeometry());
   settings.setValue("visible", isVisible());
-  settings.setValue("topSplitter", m_ui.topSplitter->saveState());
-  settings.setValue("bottomSplitter", m_ui.bottomSplitter->saveState());
+  settings.setValue("topSplitter", m_ui->topSplitter->saveState());
+  settings.setValue("bottomSplitter", m_ui->bottomSplitter->saveState());
 
 
   settings.endGroup();
 }
 
-
 //! Read the settings to as to restore the window geometry.
 void
 MsRunDataSetTableViewWnd::readSettings()
@@ -138,8 +141,8 @@ MsRunDataSetTableViewWnd::readSettings()
 
   restoreGeometry(settings.value("geometry").toByteArray());
 
-  m_ui.topSplitter->restoreState(settings.value("topSplitter").toByteArray());
-  m_ui.bottomSplitter->restoreState(
+  m_ui->topSplitter->restoreState(settings.value("topSplitter").toByteArray());
+  m_ui->bottomSplitter->restoreState(
     settings.value("bottomSplitter").toByteArray());
 
 
@@ -149,12 +152,11 @@ MsRunDataSetTableViewWnd::readSettings()
   settings.endGroup();
 }
 
-
 //! Initialize the window.
 bool
 MsRunDataSetTableViewWnd::initialize()
 {
-  setWindowTitle("mineXpert2 - MS run data set table view");
+  setWindowTitle("MineXpert3 - MS run data set table view");
 
   // The tool bar will host the main menu button.
   QToolBar *mp_toolBar = QMainWindow::addToolBar("Settings");
@@ -182,16 +184,16 @@ MsRunDataSetTableViewWnd::initialize()
 
   QPalette palette;
   palette.setColor(QPalette::WindowText, m_color);
-  m_ui.sampleNameLabel->setPalette(palette);
-  m_ui.sampleNameLabel->setText(
+  m_ui->sampleNameLabel->setPalette(palette);
+  m_ui->sampleNameLabel->setText(
     mcsp_msRunDataSet->getMsRunId()->getSampleName());
 
   mp_msRunDataSetTableView = new MsRunDataSetTableView(this);
 
-  m_ui.tableViewVerticalLayout->addWidget(mp_msRunDataSetTableView);
+  m_ui->tableViewVerticalLayout->addWidget(mp_msRunDataSetTableView);
 
-  m_ui.filteringOptionsGroupBox->setChecked(false);
-  m_ui.filteringOptionsFrame->setVisible(false);
+  m_ui->filteringOptionsGroupBox->setChecked(false);
+  m_ui->filteringOptionsFrame->setVisible(false);
 
   mcsp_msRunDataSetTree = mcsp_msRunDataSet->getMsRunDataSetTreeCstSPtr();
 
@@ -214,7 +216,7 @@ MsRunDataSetTableViewWnd::initialize()
   // is required to specify the precursor m/z values search tolerance.
 
   mp_precisionWidget = new pappso::PrecisionWidget(this);
-  m_ui.precisionWidgetHorizontalLayout->addWidget(mp_precisionWidget);
+  m_ui->precisionWidgetHorizontalLayout->addWidget(mp_precisionWidget);
   mp_precisionWidget->setToolTip(
     "Set the tolerance with which the m/z values are matched");
 
@@ -229,21 +231,21 @@ MsRunDataSetTableViewWnd::initialize()
 
   // Set explanatory text for the different filtering line edit widgets.
 
-  m_ui.indexLineEdit->setToolTip(
+  m_ui->indexLineEdit->setToolTip(
     "The accepted syntax: \nval\nval1--val2\n< val\n> val\n< val1 > val2\n");
 
-  m_ui.retentionTimeLineEdit->setToolTip(
+  m_ui->retentionTimeLineEdit->setToolTip(
     "The accepted syntax: \nval\nval%tol (tol is the tolerance)\nval1--val2\n< "
     "val\n> val\n< val1 > val2\n");
 
-  m_ui.driftTimeLineEdit->setToolTip(
+  m_ui->driftTimeLineEdit->setToolTip(
     "The accepted syntax: \nval\nval%tol (tol is the tolerance)\nval1--val2\n< "
     "val\n> val\n< val1 > val2\n");
 
-  m_ui.precursorIndexLineEdit->setToolTip(
+  m_ui->precursorIndexLineEdit->setToolTip(
     "The accepted syntax: \nval\nval1--val2\n< val\n> val\n< val1 > val2\n");
 
-  m_ui.precursorChargeLineEdit->setToolTip(
+  m_ui->precursorChargeLineEdit->setToolTip(
     "The accepted syntax: \nval\nval1--val2\n< val\n> val\n< val1 > val2\n");
 
   // Make the connections
@@ -255,35 +257,35 @@ MsRunDataSetTableViewWnd::initialize()
             mp_msRunDataSetTableViewProxyModel->setPrecision(mp_precision);
           });
 
-  connect(m_ui.executeFilteringPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->executeFilteringPushButton, &QPushButton::clicked, [this]() {
     executeFilteringPushButtonClicked();
   });
 
-  connect(m_ui.integrateToDtPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToDtPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_DT");
   });
 
-  connect(m_ui.integrateToMzPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToMzPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_MZ");
   });
 
-  connect(m_ui.integrateToRtPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToRtPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_RT");
   });
 
-  connect(m_ui.integrateToIntPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToIntPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_INT");
   });
 
-  connect(m_ui.integrateToDtMzPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToDtMzPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_DT_MZ");
   });
 
-  connect(m_ui.integrateToDtRtPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToDtRtPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_DT_RT");
   });
 
-  connect(m_ui.integrateToMzRtPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->integrateToMzRtPushButton, &QPushButton::clicked, [this]() {
     integrate("TO_MZ_RT");
   });
 
@@ -291,7 +293,7 @@ MsRunDataSetTableViewWnd::initialize()
   // everything
 
   connect(
-    m_ui.filteringOptionsGroupBox, &QGroupBox::clicked, [this](bool checked) {
+    m_ui->filteringOptionsGroupBox, &QGroupBox::clicked, [this](bool checked) {
       if(!checked)
         {
           // Deactivate the filtering.
@@ -314,7 +316,7 @@ MsRunDataSetTableViewWnd::initialize()
               .arg(row_count > 1 ? "spectra" : "spectrum"));
         }
 
-      m_ui.filteringOptionsFrame->setVisible(checked);
+      m_ui->filteringOptionsFrame->setVisible(checked);
     });
 
   readSettings();
@@ -322,7 +324,6 @@ MsRunDataSetTableViewWnd::initialize()
   return true;
 }
 
-
 void
 MsRunDataSetTableViewWnd::show()
 {
@@ -331,24 +332,23 @@ MsRunDataSetTableViewWnd::show()
   QMainWindow::show();
 }
 
-
 void
 MsRunDataSetTableViewWnd::executeFilteringPushButtonClicked()
 {
   // qDebug();
 
   // We need to get all the strings from the various line edit widgets.
-  std::size_t ms_level           = m_ui.msLevelSpinBox->value();
-  QString indices                = m_ui.indexLineEdit->text();
-  QString rt_values              = m_ui.retentionTimeLineEdit->text();
-  QString dt_values              = m_ui.driftTimeLineEdit->text();
-  QString precursor_index_values = m_ui.precursorIndexLineEdit->text();
+  std::size_t ms_level           = m_ui->msLevelSpinBox->value();
+  QString indices                = m_ui->indexLineEdit->text();
+  QString rt_values              = m_ui->retentionTimeLineEdit->text();
+  QString dt_values              = m_ui->driftTimeLineEdit->text();
+  QString precursor_index_values = m_ui->precursorIndexLineEdit->text();
 
-  QString precursor_mz_values = m_ui.precursorMzLineEdit->text();
+  QString precursor_mz_values = m_ui->precursorMzLineEdit->text();
   // qDebug() << "The precursor mz values in the table cell:"
   //<< precursor_mz_values;
 
-  QString precursor_charge_values = m_ui.precursorChargeLineEdit->text();
+  QString precursor_charge_values = m_ui->precursorChargeLineEdit->text();
   // qDebug() << "The precursor charge values in the table cell:"
   //<< precursor_charge_values;
 
@@ -389,18 +389,24 @@ MsRunDataSetTableViewWnd::executeFilteringPushButtonClicked()
                              .arg(row_count > 1 ? "spectra" : "spectrum"));
 }
 
-
 void
 MsRunDataSetTableViewWnd::showMzIntegrationParamsDlg()
 {
 
-  qDebug() << "Showing mz integration params for values:"
-           << m_processingFlow.getDefaultMzIntegrationParams().toString();
+  // Heap-allocated.
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
+
+  Q_ASSERT(mz_integration_params_p != nullptr);
+
+  // qDebug() << "Showing mz integration params for values:"
+  //          << mz_integration_params_p->toString(
+  //               /*offset*/ 0, /*spacer*/ " ");
 
   if(mp_mzIntegrationParamsDlg == nullptr)
     {
-      mp_mzIntegrationParamsDlg = new MzIntegrationParamsDlg(
-        this, m_processingFlow.getDefaultMzIntegrationParams(), m_color);
+      mp_mzIntegrationParamsDlg =
+        new MzIntegrationParamsDlg(this, *mz_integration_params_p, m_color);
 
       connect(
         mp_mzIntegrationParamsDlg,
@@ -420,48 +426,47 @@ MsRunDataSetTableViewWnd::showMzIntegrationParamsDlg()
     }
 }
 
-
 void
 MsRunDataSetTableViewWnd::mzIntegrationParamsChanged(
-  pappso::MzIntegrationParams mz_integration_params)
+  const pappso::MzIntegrationParams &mz_integration_params)
 {
-  qDebug().noquote() << "The validated mz integration parameters:"
-                     << mz_integration_params.toString();
+  // qDebug().noquote() << "The validated mz integration parameters:"
+  //                    << mz_integration_params.toString(/*offset*/ 0,
+  //                                                      /*spacer*/ " ");
 
   // We cannot copy the params returned as parameter into the destination
   // because we would loose the greatestMz/smallesMz values that we got from the
   // ms run data set upon creation of this window.
 
   // Create a local copy of the processing flow's default mz integration params.
-  pappso::MzIntegrationParams local_mz_integration_params =
-    m_processingFlow.getDefaultMzIntegrationParams();
+  // Heap-allocated
+  pappso::MzIntegrationParams *local_mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
 
   // Update some of the values with the params after change.
-  local_mz_integration_params.setBinningType(
+  local_mz_integration_params_p->setBinningType(
     mz_integration_params.getBinningType());
-  local_mz_integration_params.setPrecision(
-    mz_integration_params.getPrecision());
-  local_mz_integration_params.setDecimalPlaces(
+  local_mz_integration_params_p->setBinSizeModel(
+    mz_integration_params.getBinSizeModel());
+  local_mz_integration_params_p->setDecimalPlaces(
     mz_integration_params.getDecimalPlaces());
-  local_mz_integration_params.setRemoveZeroValDataPoints(
+  local_mz_integration_params_p->setRemoveZeroValDataPoints(
     mz_integration_params.isRemoveZeroValDataPoints());
 
-  // Now set the updated mz integration params back to the m_processingFlow.
+  // Now set the updated mz integration params back to the mp_processingFlow->
 
-  m_processingFlow.setDefaultMzIntegrationParams(local_mz_integration_params);
+  mp_processingFlow->setDefaultMzIntegrationParams(
+    *local_mz_integration_params_p);
 
-  qDebug() << "Set new mz integ params to m_processingFlow:"
-           << m_processingFlow.getDefaultMzIntegrationParams().toString();
+  delete local_mz_integration_params_p;
 }
 
-
 void
 MsRunDataSetTableViewWnd::ticIntensityValue(double intensity_value)
 {
   statusBar()->showMessage(QString::number(intensity_value, 'g', 6), 2000);
 }
 
-
 void
 MsRunDataSetTableViewWnd::keyPressEvent(QKeyEvent *event)
 {
@@ -475,13 +480,12 @@ MsRunDataSetTableViewWnd::keyPressEvent(QKeyEvent *event)
 
   if(event->key() == Qt::Key_Return &&
      event->modifiers() & Qt::ControlModifier &&
-     m_ui.filteringOptionsGroupBox->isChecked())
+     m_ui->filteringOptionsGroupBox->isChecked())
     {
       executeFilteringPushButtonClicked();
     }
 }
 
-
 void
 MsRunDataSetTableViewWnd::createMainMenu()
 {
@@ -514,22 +518,20 @@ MsRunDataSetTableViewWnd::createMainMenu()
   mp_mainMenuPushButton->setMenu(mp_mainMenu);
 }
 
-
 bool
 MsRunDataSetTableViewWnd::recordMsFragmentationSpec()
 {
 
   MsFragmentationSpec ms_fragmentation_spec =
-    m_processingFlow.getDefaultMsFragmentationSpec();
+    mp_processingFlow->getDefaultMsFragmentationSpec();
 
-  ms_fragmentation_spec.setMsLevel(m_ui.msLevelSpinBox->value());
+  ms_fragmentation_spec.setMsLevel(m_ui->msLevelSpinBox->value());
 
-  m_processingFlow.setDefaultMsFragmentationSpec(ms_fragmentation_spec);
+  mp_processingFlow->setDefaultMsFragmentationSpec(ms_fragmentation_spec);
 
   return true;
 }
 
-
 void
 MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
   std::vector<pappso::QualifiedMassSpectrumCstSPtr>
@@ -606,12 +608,12 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
       // Get the format of the file, because that will condition the
       // way we provide mobility values.
 
-      pappso::MsDataFormat file_format =
+      pappso::Enums::MsDataFormat file_format =
         qualified_mass_spectrum_csp->getMassSpectrumId()
           .getMsRunIdCstSPtr()
           ->getMsDataFormat();
 
-      if(file_format == pappso::MsDataFormat::brukerTims)
+      if(file_format == pappso::Enums::MsDataFormat::brukerTims)
         {
           QVariant ion_mobility_variant_value =
             qualified_mass_spectrum_csp->getParameterValue(
@@ -762,12 +764,14 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 
       // qDebug() << "The integration scope is 2D.";
 
-      processing_step.setDataKind(pappso::Axis::x, pappso::DataKind::dt);
-      processing_step.setDataKind(pappso::Axis::y, pappso::DataKind::rt);
+      processing_step.setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::dt);
+      processing_step.setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::rt);
 
-      processing_step.setSrcProcessingType(pappso::Axis::x,
+      processing_step.setSrcProcessingType(pappso::Enums::Axis::x,
                                            "DATA_TABLE_VIEW_DT");
-      processing_step.setSrcProcessingType(pappso::Axis::y,
+      processing_step.setSrcProcessingType(pappso::Enums::Axis::y,
                                            "DATA_TABLE_VIEW_RT");
     }
   else
@@ -777,12 +781,14 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 
       // qDebug() << "The integration scope is 1D.";
 
-      processing_step.setDataKind(pappso::Axis::x, pappso::DataKind::rt);
-      processing_step.setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+      processing_step.setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::rt);
+      processing_step.setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::unset);
 
-      processing_step.setSrcProcessingType(pappso::Axis::x,
+      processing_step.setSrcProcessingType(pappso::Enums::Axis::x,
                                            "DATA_TABLE_VIEW_RT");
-      processing_step.setSrcProcessingType(pappso::Axis::y, "NOT_SET");
+      processing_step.setSrcProcessingType(pappso::Enums::Axis::y, "NOT_SET");
     }
 
   // And now configure the destination type.
@@ -807,7 +813,6 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
   // qDebug() << "Finally configured step:" << processing_step.toString();
 }
 
-
 void
 MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 {
@@ -818,7 +823,8 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 
   recordMsFragmentationSpec();
 
-  ProcessingFlow local_processing_flow(m_processingFlow);
+  ProcessingFlow local_processing_flow;
+  local_processing_flow.initialize(*mp_processingFlow);
 
   // Immediately set the mz integration params to the step. These are located in
   // the processing flow as the default mz integartion params.
@@ -829,11 +835,9 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 
   ProcessingStepSPtr step_sp = std::make_shared<ProcessingStep>();
 
+  // Takes ownership
   step_sp->setMzIntegrationParams(
-    local_processing_flow.getDefaultMzIntegrationParams());
-
-  // qDebug() << "At integration time, mz integration params"
-  //<< local_processing_flow.getDefaultMzIntegrationParams().toString();
+    local_processing_flow.getSensibleMzIntegrationParams());
 
   // At this point, make sure we document in the processing flow the other
   // critical parameters: the RT and DT values along with the MS fragmentation
@@ -845,8 +849,12 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   // "virtually restricting" the data set to the innermost ranges used all along
   // the integrations.
 
-  std::vector<pappso::QualifiedMassSpectrumCstSPtr>
-    vector_of_qualified_mass_spectra;
+  typedef std::vector<pappso::QualifiedMassSpectrumCstSPtr>
+    QualifiedMassSpectraVector;
+  typedef std::shared_ptr<QualifiedMassSpectraVector>
+    QualifiedMassSpectraVectorSPtr;
+
+  QualifiedMassSpectraVector vector_of_qualified_mass_spectra;
 
   recordQualifiedMassSpectraToIntegrate(
     vector_of_qualified_mass_spectra, *step_sp, integration_type);
@@ -854,24 +862,22 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   if(!vector_of_qualified_mass_spectra.size())
     return;
 
-  qDebug() << "The number of spectra recorded for integration:"
-           << vector_of_qualified_mass_spectra.size();
+  // qDebug() << "The number of spectra recorded for integration:"
+  //          << vector_of_qualified_mass_spectra.size();
 
   // We have finished documenting the flow's step, append it to the processing
   // flow.
 
   // Should perform automatically the conversion from non-const to const.
-  local_processing_flow.push_back(step_sp);
+  local_processing_flow.getStepsRef().push_back(step_sp);
 
-  qDebug().noquote() << "Right before integrating, processing flow:"
-                     << local_processing_flow.toString();
+  // qDebug().noquote() << "Right before integrating, processing flow:"
+  //                    << local_processing_flow_p->toString();
 
   // Finally make a shared pointer with the vector of qualified mass spectra.
-  using VectorOfQualMassSpecCstSPtrSPtr =
-    std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>;
 
-  VectorOfQualMassSpecCstSPtrSPtr vector_of_qualified_mass_spectra_sp =
-    std::make_shared<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>(
+  QualifiedMassSpectraVectorSPtr vector_of_qualified_mass_spectra_sp =
+    std::make_shared<QualifiedMassSpectraVector>(
       vector_of_qualified_mass_spectra);
 
   // We can now select the right integration.
@@ -902,6 +908,6 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
