@@ -43,14 +43,12 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msrun/msrundatasettree.h>
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/widget/precisionwidget/precisionwidget.h>
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-
+#include <pappsomspp/core/msrun/msrundatasettree.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/gui/precisionwidget/precisionwidget.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
-#include "ui_MsRunDataSetTableViewWnd.h"
 #include "MsRunDataSetTableView.hpp"
 #include "MsRunDataSetTableViewModel.hpp"
 #include "MsRunDataSetTableViewProxyModel.hpp"
@@ -58,10 +56,14 @@
 #include "../nongui/ProcessingFlow.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 
+namespace Ui
+{
+class MsRunDataSetTableViewWnd;
+}
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -69,17 +71,16 @@ class MsRunDataSet;
 class ProgramWindow;
 class MsFragmentationSpecDlg;
 
-
-class MsRunDataSetTableViewWnd : public QMainWindow
+class MsRunDataSetTableViewWnd: public QMainWindow
 {
   Q_OBJECT
 
   public:
   // Construction/destruction
-  MsRunDataSetTableViewWnd(QWidget *parent_p,
-                           ProgramWindow *program_window_p,
+  MsRunDataSetTableViewWnd(ProgramWindow *program_window_p,
                            MsRunDataSetCstSPtr ms_run_data_set_csp,
-                           const QColor &color);
+                           const QColor &color,
+                           QWidget *parent = nullptr);
 
   virtual ~MsRunDataSetTableViewWnd();
 
@@ -95,8 +96,9 @@ class MsRunDataSetTableViewWnd : public QMainWindow
   void executeFilteringPushButtonClicked();
 
   void showMzIntegrationParamsDlg();
+
   void
-  mzIntegrationParamsChanged(pappso::MzIntegrationParams mz_integration_params);
+  mzIntegrationParamsChanged(const pappso::MzIntegrationParams &mz_integration_params);
 
   public slots:
 
@@ -107,10 +109,7 @@ class MsRunDataSetTableViewWnd : public QMainWindow
   protected:
   ProgramWindow *mp_programWindow = nullptr;
 
-  ProcessingFlow m_processingFlow;
-
-  //! Graphical interface definition.
-  Ui::MsRunDataSetTableViewWnd m_ui;
+  ProcessingFlow *mp_processingFlow;
 
   QToolBar *mp_toolBar = nullptr;
   QMenu *mp_mainMenu   = nullptr;
@@ -124,6 +123,9 @@ class MsRunDataSetTableViewWnd : public QMainWindow
 
   QColor m_color;
 
+  //! Graphical interface definition.
+  ::Ui::MsRunDataSetTableViewWnd *m_ui;
+
   MsRunDataSetTableViewModel *mp_msRunDataSetTableViewModel           = nullptr;
   MsRunDataSetTableViewProxyModel *mp_msRunDataSetTableViewProxyModel = nullptr;
   MsRunDataSetTableView *mp_msRunDataSetTableView                     = nullptr;
@@ -150,6 +152,6 @@ class MsRunDataSetTableViewWnd : public QMainWindow
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
