@@ -50,7 +50,7 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msfile/msfileaccessor.h>
 
 /////////////////////// Local includes
 #include "MsRunLoader.hpp"
@@ -58,18 +58,18 @@
 #include "../nongui/MsRunDataSet.hpp"
 
 
-int MsRunLoaderMetaTypeId = qRegisterMetaType<MsXpS::minexpert::MsRunLoader>(
-  "MsXpS::minexpert::MsRunLoader");
+int MsRunLoaderMetaTypeId = qRegisterMetaType<MsXpS::MineXpert::MsRunLoader>(
+  "MsXpS::MineXpert::MsRunLoader");
 
 int MsRunLoaderSPtrMetaTypeId =
-  qRegisterMetaType<MsXpS::minexpert::MsRunLoaderSPtr>(
-    "MsXpS::minexpert::MsRunLoaderSPtr");
+  qRegisterMetaType<MsXpS::MineXpert::MsRunLoaderSPtr>(
+    "MsXpS::MineXpert::MsRunLoaderSPtr");
 
 
 namespace MsXpS
 {
 
-namespace minexpert
+namespace MineXpert
 {
 
 MsRunLoader::MsRunLoader(ProgramWindow *program_window_p,
@@ -89,6 +89,6 @@ MsRunLoader::~MsRunLoader()
 {
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
