@@ -43,7 +43,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msfile/msfileaccessor.h>
 
 
 /////////////////////// Local includes
@@ -52,7 +52,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProgramWindow;
@@ -70,7 +70,8 @@ class MsRunLoader : public QObject
   // helper functions in cases where the loading cannot occur easily right away.
   // For example, when loading Bruker timsTOF data, there is a probing function
   // that is called that will present the user with metadata to help them
-  // configure the way data are actually loaded. Conversely, with mzML data (pwiz), the loadMsRun does the job right away.
+  // configure the way data are actually loaded. Conversely, with mzML data
+  // (pwiz), the loadMsRun does the job right away.
   virtual void loadMsRun(bool full_in_memory = false) = 0;
 
   protected:
@@ -80,13 +81,13 @@ class MsRunLoader : public QObject
 
 typedef std::shared_ptr<MsRunLoader> MsRunLoaderSPtr;
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunLoader)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::MsRunLoader)
 extern int MsRunLoaderMetaTypeId;
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunLoaderSPtr)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::MsRunLoaderSPtr)
 extern int MsRunLoaderSPtrMetaTypeId;
