@@ -43,18 +43,18 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msrun/private/timsmsrunreader.h>
+#include <pappsomspp/core/msrun/private/timsmsrunreader.h>
 
 /////////////////////// Local includes
+#include "../nongui/MassDataIntegratorTask.hpp"
+#include "Application.hpp"
 #include "MsRunProbeInfoViewerDlg.hpp"
 #include "ProgramWindow.hpp"
-#include "Application.hpp"
-#include "../nongui/MassDataIntegratorTask.hpp"
-
+#include "ui_MsRunProbeInfoViewerDlg.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -74,7 +74,8 @@ MsRunProbeInfoViewerDlg::MsRunProbeInfoViewerDlg(
     m_description(description),
     m_vendor(vendor),
     m_msRunIdCstSPtr(ms_run_id_csp),
-    msp_msRunProbeInfo(ms_run_probe_info_sp)
+    msp_msRunProbeInfo(ms_run_probe_info_sp),
+    m_ui(new ::Ui::MsRunProbeInfoViewerDlg)
 {
   if(parent == Q_NULLPTR)
     qFatal("Programming error.");
@@ -82,7 +83,7 @@ MsRunProbeInfoViewerDlg::MsRunProbeInfoViewerDlg(
   if(ms_run_id_csp == nullptr)
     qFatal("Programming error.");
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
   if(!initialize())
     qFatal("Programming error.");
@@ -108,7 +109,7 @@ MsRunProbeInfoViewerDlg::writeSettings()
   settings.beginGroup(m_settingsTitle);
 
   settings.setValue("geometry", saveGeometry());
-  // settings.setValue("splitter", m_ui.splitter->saveState());
+  // settings.setValue("splitter", m_ui->splitter->saveState());
   settings.setValue("RtTimeUnitSeconds", m_areRtTimeUnitSeconds);
 
   settings.endGroup();
@@ -126,12 +127,12 @@ MsRunProbeInfoViewerDlg::readSettings()
   settings.beginGroup(m_settingsTitle);
 
   restoreGeometry(settings.value("geometry").toByteArray());
-  // m_ui.splitter->restoreState(settings.value("splitter").toByteArray());
+  // m_ui->splitter->restoreState(settings.value("splitter").toByteArray());
 
   // By default we want retention times in seconds (this is in the Bruker data).
   m_areRtTimeUnitSeconds = settings.value("RtTimeUnitSeconds", true).toBool();
 
-  m_ui.rtInSecondsRadioButton->setChecked(m_areRtTimeUnitSeconds);
+  m_ui->rtInSecondsRadioButton->setChecked(m_areRtTimeUnitSeconds);
 
   settings.endGroup();
 }
@@ -158,14 +159,14 @@ MsRunProbeInfoViewerDlg::getProgramWindow()
 bool
 MsRunProbeInfoViewerDlg::initialize()
 {
-  setWindowTitle(QString("mineXpert2 - %1").arg(m_title));
-  m_ui.descriptionLabel->setText(m_description);
-  m_ui.vendorLabel->setText(m_vendor);
+  setWindowTitle(QString("MineXpert3 - %1").arg(m_title));
+  m_ui->descriptionLabel->setText(m_description);
+  m_ui->vendorLabel->setText(m_vendor);
 
   setAttribute(Qt::WA_DeleteOnClose);
 
   // The default window icon.
-  QString pixmap_file_name = ":/images/icons/32x32/minexpert2.png";
+  QString pixmap_file_name = ":/images/icons/32x32/minexpert3.png";
   QPixmap icon_pixmap(pixmap_file_name);
   QIcon icon(icon_pixmap);
   setWindowIcon(icon);
@@ -176,25 +177,25 @@ MsRunProbeInfoViewerDlg::initialize()
   /****************** The widgetry  ******************/
 
   // Now that we have read the settings, check the right radio button.
-  m_ui.rtInSecondsRadioButton->setChecked(m_areRtTimeUnitSeconds);
-  m_ui.rtInMinutesRadioButton->setChecked(!m_areRtTimeUnitSeconds);
+  m_ui->rtInSecondsRadioButton->setChecked(m_areRtTimeUnitSeconds);
+  m_ui->rtInMinutesRadioButton->setChecked(!m_areRtTimeUnitSeconds);
 
-  m_ui.ms1SpectraCountSpinBox->setValue(msp_msRunProbeInfo->ms1SpectraCount);
-  m_ui.ms2SpectraCountSpinBox->setValue(msp_msRunProbeInfo->ms2SpectraCount);
+  m_ui->ms1SpectraCountSpinBox->setValue(msp_msRunProbeInfo->ms1SpectraCount);
+  m_ui->ms2SpectraCountSpinBox->setValue(msp_msRunProbeInfo->ms2SpectraCount);
 
   mp_plotWidget = new pappso::TicXicChromTracePlotWidget(
     this, "Retention time", "Intensity (a.u.)");
 
-  m_ui.qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
+  m_ui->qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
 
   // Set the widest range possible for retention times
-  m_ui.rtRangeBeginDoubleSpinBox->setRange(std::numeric_limits<double>::min(),
-                                           std::numeric_limits<double>::max());
+  m_ui->rtRangeBeginDoubleSpinBox->setRange(std::numeric_limits<double>::min(),
+                                            std::numeric_limits<double>::max());
 
   connect(
-    m_ui.rtRangeBeginDoubleSpinBox, &QDoubleSpinBox::editingFinished, [&]() {
+    m_ui->rtRangeBeginDoubleSpinBox, &QDoubleSpinBox::editingFinished, [&]() {
       mp_plotWidget->xAxis->setRange(
-        QCPRange(m_ui.rtRangeBeginDoubleSpinBox->value(),
+        QCPRange(m_ui->rtRangeBeginDoubleSpinBox->value(),
                  mp_plotWidget->xAxis->range().upper));
 
       // setRange orders lower and upper in  the right  ascending order. If the
@@ -204,14 +205,14 @@ MsRunProbeInfoViewerDlg::initialize()
       mp_plotWidget->replot();
     });
 
-  m_ui.rtRangeEndDoubleSpinBox->setRange(std::numeric_limits<double>::min(),
-                                         std::numeric_limits<double>::max());
+  m_ui->rtRangeEndDoubleSpinBox->setRange(std::numeric_limits<double>::min(),
+                                          std::numeric_limits<double>::max());
 
   connect(
-    m_ui.rtRangeEndDoubleSpinBox, &QDoubleSpinBox::editingFinished, [&]() {
+    m_ui->rtRangeEndDoubleSpinBox, &QDoubleSpinBox::editingFinished, [&]() {
       mp_plotWidget->xAxis->setRange(
         QCPRange(mp_plotWidget->xAxis->range().lower,
-                 m_ui.rtRangeEndDoubleSpinBox->value()));
+                 m_ui->rtRangeEndDoubleSpinBox->value()));
 
       // setRange orders lower and upper in  the right  ascending order. If the
       // user enters an upper value < lower value, then setRange fixes this.
@@ -220,7 +221,7 @@ MsRunProbeInfoViewerDlg::initialize()
       mp_plotWidget->replot();
     });
 
-  connect(m_ui.rtInSecondsRadioButton, &QRadioButton::clicked, [&]() {
+  connect(m_ui->rtInSecondsRadioButton, &QRadioButton::clicked, [&]() {
     if(!m_areRtTimeUnitSeconds)
       {
         // We are converting the data to seconds.
@@ -230,7 +231,7 @@ MsRunProbeInfoViewerDlg::initialize()
       }
   });
 
-  connect(m_ui.rtInMinutesRadioButton, &QRadioButton::clicked, [&]() {
+  connect(m_ui->rtInMinutesRadioButton, &QRadioButton::clicked, [&]() {
     if(m_areRtTimeUnitSeconds)
       {
         // We are converting the data to minutes.
@@ -243,18 +244,18 @@ MsRunProbeInfoViewerDlg::initialize()
   connect(mp_plotWidget,
           &pappso::TicXicChromTracePlotWidget::plotRangesChangedSignal,
           [&]() {
-            m_ui.rtRangeBeginDoubleSpinBox->setValue(
+            m_ui->rtRangeBeginDoubleSpinBox->setValue(
               mp_plotWidget->xAxis->range().lower);
-            m_ui.rtRangeEndDoubleSpinBox->setValue(
+            m_ui->rtRangeEndDoubleSpinBox->setValue(
               mp_plotWidget->xAxis->range().upper);
 
-            qDebug("New x axis range: %f.5--%f.5",
-                   mp_plotWidget->xAxis->range().lower,
-                   mp_plotWidget->xAxis->range().upper);
+            // qDebug("New x axis range: %f.5--%f.5",
+            //        mp_plotWidget->xAxis->range().lower,
+            //        mp_plotWidget->xAxis->range().upper);
           });
 
-  connect(m_ui.loadDataPushButton, &QPushButton::clicked, [&]() {
-    qDebug("Clicked to load data.");
+  connect(m_ui->loadDataPushButton, &QPushButton::clicked, [&]() {
+    // qDebug("Clicked to load data.");
 
     if(!validateData())
       return;
@@ -262,18 +263,18 @@ MsRunProbeInfoViewerDlg::initialize()
       QDialog::accept();
   });
 
-  connect(m_ui.cancelPushButton, &QPushButton::clicked, [&]() {
-    qDebug("Clicked to cancel.");
+  connect(m_ui->cancelPushButton, &QPushButton::clicked, [&]() {
+    // qDebug("Clicked to cancel.");
     QDialog::reject();
   });
 
-  connect(m_ui.imOneOverKoGroupBox, &QGroupBox::clicked, [&](bool checked) {
+  connect(m_ui->imOneOverKoGroupBox, &QGroupBox::clicked, [&](bool checked) {
     if(checked)
-      m_ui.imScansGroupBox->setChecked(!checked);
+      m_ui->imScansGroupBox->setChecked(!checked);
   });
-  connect(m_ui.imScansGroupBox, &QGroupBox::clicked, [&](bool checked) {
+  connect(m_ui->imScansGroupBox, &QGroupBox::clicked, [&](bool checked) {
     if(checked)
-      m_ui.imOneOverKoGroupBox->setChecked(!checked);
+      m_ui->imOneOverKoGroupBox->setChecked(!checked);
   });
 
   // Now get the TIC chromatogram out of the file in question.
@@ -301,23 +302,23 @@ MsRunProbeInfoViewerDlg::initialize()
 
   // Now all the other data.
 
-  m_ui.imOneOverKoRangeBeginDoubleSpinBox->setValue(
+  m_ui->imOneOverKoRangeBeginDoubleSpinBox->setValue(
     msp_msRunProbeInfo->ionMobilityOneOverKoBegin);
-  m_ui.imOneOverKoRangeEndDoubleSpinBox->setValue(
+  m_ui->imOneOverKoRangeEndDoubleSpinBox->setValue(
     msp_msRunProbeInfo->ionMobilityOneOverKoEnd);
 
-  m_ui.imScansRangeBeginSpinBox->setValue(
+  m_ui->imScansRangeBeginSpinBox->setValue(
     msp_msRunProbeInfo->ionMobilityScansBegin);
-  m_ui.imScansRangeEndSpinBox->setValue(
+  m_ui->imScansRangeEndSpinBox->setValue(
     msp_msRunProbeInfo->ionMobilityScansEnd);
 
-  m_ui.mzRangeBeginDoubleSpinBox->setValue(msp_msRunProbeInfo->mzBegin);
-  m_ui.mzRangeEndDoubleSpinBox->setValue(msp_msRunProbeInfo->mzEnd);
+  m_ui->mzRangeBeginDoubleSpinBox->setValue(msp_msRunProbeInfo->mzBegin);
+  m_ui->mzRangeEndDoubleSpinBox->setValue(msp_msRunProbeInfo->mzEnd);
 
   // It is necessary that msp_msRunProbeInfo->mzBinCount be non-naught.
   if(msp_msRunProbeInfo->mzBinCount)
     {
-      m_ui.binCountSpinBox->setValue(msp_msRunProbeInfo->mzBinCount);
+      m_ui->binCountSpinBox->setValue(msp_msRunProbeInfo->mzBinCount);
 
       // The bin size is nothing else than the whole m/z range divided by the
       // number of bins in the whole acquisition.
@@ -325,10 +326,10 @@ MsRunProbeInfoViewerDlg::initialize()
         (msp_msRunProbeInfo->mzEnd - msp_msRunProbeInfo->mzBegin) /
         static_cast<double>(msp_msRunProbeInfo->mzBinCount);
 
-      m_ui.mzBinSizeDoubleSpinBox->setValue(mz_bin_size);
+      m_ui->mzBinSizeDoubleSpinBox->setValue(mz_bin_size);
     }
   else
-    m_ui.mzBinSizeDoubleSpinBox->setValue(0);
+    m_ui->mzBinSizeDoubleSpinBox->setValue(0);
 
   // At this point we need to configure the behaviour of the m/z bin radiobutton
   // widgets
@@ -338,12 +339,12 @@ MsRunProbeInfoViewerDlg::initialize()
     // for example, the bin size over the whole m/z range is 0.005, then, if the
     // user sets 0.05, that would mean that the user wants to merge 10 bins into
     // a single bin, that is make a bin out of 10 bins in the original data set.
-    m_ui.mzMergeBinsByMzDoubleSpinBox,
+    m_ui->mzMergeBinsByMzDoubleSpinBox,
     &QDoubleSpinBox::editingFinished,
     [&]() {
       // qDebug();
-      double mz_window = m_ui.mzMergeBinsByMzDoubleSpinBox->value();
-      m_ui.mzMergeBinsByMzRadioButton->setChecked(true);
+      double mz_window = m_ui->mzMergeBinsByMzDoubleSpinBox->value();
+      m_ui->mzMergeBinsByMzRadioButton->setChecked(true);
 
       if(msp_msRunProbeInfo->mzBinCount)
         {
@@ -355,15 +356,15 @@ MsRunProbeInfoViewerDlg::initialize()
           // Compute the equivalent TOF indices window (that is, the
           // number of bins that correspond to the size of m/z window)
           uint mz_bin_count = mz_window / mz_bin_size;
-          m_ui.mzMergeBinsByCountSpinBox->setValue(mz_bin_count);
+          m_ui->mzMergeBinsByCountSpinBox->setValue(mz_bin_count);
         }
     });
 
   connect(
-    m_ui.mzMergeBinsByCountSpinBox, &QDoubleSpinBox::editingFinished, [&]() {
+    m_ui->mzMergeBinsByCountSpinBox, &QDoubleSpinBox::editingFinished, [&]() {
       // qDebug();
-      uint mz_bin_count = m_ui.mzMergeBinsByCountSpinBox->value();
-      m_ui.mzMergeBinsByCountRadioButton->setChecked(true);
+      uint mz_bin_count = m_ui->mzMergeBinsByCountSpinBox->value();
+      m_ui->mzMergeBinsByCountRadioButton->setChecked(true);
 
       if(msp_msRunProbeInfo->mzBinCount)
         {
@@ -375,7 +376,7 @@ MsRunProbeInfoViewerDlg::initialize()
           // Compute the equivalent m/z window (that is, the
           // size of the m/z bin in which m/z values will be packed)
           double mz_window = mz_bin_count * mz_bin_size;
-          m_ui.mzMergeBinsByMzDoubleSpinBox->setValue(mz_window);
+          m_ui->mzMergeBinsByMzDoubleSpinBox->setValue(mz_window);
         }
     });
 
@@ -389,12 +390,12 @@ MsRunProbeInfoViewerDlg::initialize()
         (msp_msRunProbeInfo->mzEnd - msp_msRunProbeInfo->mzBegin) /
         static_cast<double>(msp_msRunProbeInfo->mzBinCount);
 
-      m_ui.mzMergeBinsByMzDoubleSpinBox->setValue(mz_bin_size);
-      qDebug("Set m_ui.mzMergeBinsByMzDoubleSpinBox to %f.5", mz_bin_size);
+      m_ui->mzMergeBinsByMzDoubleSpinBox->setValue(mz_bin_size);
+      // qDebug("Set m_ui->mzMergeBinsByMzDoubleSpinBox to %f.5", mz_bin_size);
     }
 
-  m_ui.renderMzRangeGroupBox->setChecked(false);
-  m_ui.mergeMzBinsGroupBox->setChecked(false);
+  m_ui->renderMzRangeGroupBox->setChecked(false);
+  m_ui->mergeMzBinsGroupBox->setChecked(false);
 
   return true;
 }
@@ -466,28 +467,29 @@ MsRunProbeInfoViewerDlg::convertTicChromatogramRetTimeUnit()
 void
 MsRunProbeInfoViewerDlg::updateRtRangeSpinBoxes()
 {
-  m_ui.rtRangeBeginDoubleSpinBox->setValue(mp_plotWidget->xAxis->range().lower);
-  m_ui.rtRangeEndDoubleSpinBox->setValue(mp_plotWidget->xAxis->range().upper);
+  m_ui->rtRangeBeginDoubleSpinBox->setValue(
+    mp_plotWidget->xAxis->range().lower);
+  m_ui->rtRangeEndDoubleSpinBox->setValue(mp_plotWidget->xAxis->range().upper);
 }
 
 bool
 MsRunProbeInfoViewerDlg::validateData()
 {
-  if(m_ui.retentionTimeRangeGroupBox->isChecked())
+  if(m_ui->retentionTimeRangeGroupBox->isChecked())
     {
-      if(m_ui.rtInSecondsRadioButton->isChecked())
+      if(m_ui->rtInSecondsRadioButton->isChecked())
         {
           msp_msRunProbeInfo->retentionTimeBeginInSeconds =
-            m_ui.rtRangeBeginDoubleSpinBox->value();
+            m_ui->rtRangeBeginDoubleSpinBox->value();
           msp_msRunProbeInfo->retentionTimeEndInSeconds =
-            m_ui.rtRangeEndDoubleSpinBox->value();
+            m_ui->rtRangeEndDoubleSpinBox->value();
         }
       else
         {
           msp_msRunProbeInfo->retentionTimeBeginInSeconds =
-            m_ui.rtRangeBeginDoubleSpinBox->value() * 60;
+            m_ui->rtRangeBeginDoubleSpinBox->value() * 60;
           msp_msRunProbeInfo->retentionTimeEndInSeconds =
-            m_ui.rtRangeEndDoubleSpinBox->value() * 60;
+            m_ui->rtRangeEndDoubleSpinBox->value() * 60;
         }
     }
   else
@@ -503,24 +505,24 @@ MsRunProbeInfoViewerDlg::validateData()
   // By default, do not flatten frames, that is, we do not merge IMS scans.
   msp_msRunProbeInfo->ionMobilityScansMergeRequired = false;
 
-  if(m_ui.ionMobilityGroupBox->isChecked())
+  if(m_ui->ionMobilityGroupBox->isChecked())
     {
       // Is the user asking to restrict the IM data to some range?
-      if(m_ui.imOneOverKoGroupBox->isChecked())
+      if(m_ui->imOneOverKoGroupBox->isChecked())
         {
           msp_msRunProbeInfo->ionMobilityUnit = IonMobilityUnit::ONE_OVER_KO;
           msp_msRunProbeInfo->ionMobilityOneOverKoBegin =
-            m_ui.imOneOverKoRangeBeginDoubleSpinBox->value();
+            m_ui->imOneOverKoRangeBeginDoubleSpinBox->value();
           msp_msRunProbeInfo->ionMobilityOneOverKoEnd =
-            m_ui.imOneOverKoRangeEndDoubleSpinBox->value();
+            m_ui->imOneOverKoRangeEndDoubleSpinBox->value();
         }
-      else if(m_ui.imScansGroupBox->isChecked())
+      else if(m_ui->imScansGroupBox->isChecked())
         {
           msp_msRunProbeInfo->ionMobilityUnit = IonMobilityUnit::SCAN;
           msp_msRunProbeInfo->ionMobilityScansBegin =
-            m_ui.imScansRangeBeginSpinBox->value();
+            m_ui->imScansRangeBeginSpinBox->value();
           msp_msRunProbeInfo->ionMobilityScansEnd =
-            m_ui.imScansRangeEndSpinBox->value();
+            m_ui->imScansRangeEndSpinBox->value();
         }
 
       // Whatever the IM data restriction above, it is still possible, inside
@@ -528,21 +530,21 @@ MsRunProbeInfoViewerDlg::validateData()
       // (every x scans, merge them together) or by 1/K0 window (each time a set
       // of IM scans span that 1/K0 window, merge them together).
 
-      if(m_ui.mergeImScansCheckBox->isChecked())
+      if(m_ui->mergeImScansCheckBox->isChecked())
         {
           msp_msRunProbeInfo->ionMobilityScansMergeRequired =
-            m_ui.mergeImScansCheckBox->isChecked();
+            m_ui->mergeImScansCheckBox->isChecked();
         }
     }
 
-  QString ms_levels_to_render = m_ui.msLevelsLineEdit->text();
+  QString ms_levels_to_render = m_ui->msLevelsLineEdit->text();
 
   bool ok = false;
 
   if(!ms_levels_to_render.isEmpty())
     {
-      qDebug() << "The MS levels line edit widget contains this text:"
-               << ms_levels_to_render;
+      // qDebug() << "The MS levels line edit widget contains this text:"
+      //          << ms_levels_to_render;
 
       QStringList ms_levels_string_list =
         ms_levels_to_render.split(",", Qt::SkipEmptyParts);
@@ -572,10 +574,10 @@ MsRunProbeInfoViewerDlg::validateData()
       msp_msRunProbeInfo->msLevels.clear();
     }
 
-  if(m_ui.renderMzRangeGroupBox->isChecked())
+  if(m_ui->renderMzRangeGroupBox->isChecked())
     {
-      msp_msRunProbeInfo->mzBegin = m_ui.mzRangeBeginDoubleSpinBox->value();
-      msp_msRunProbeInfo->mzEnd   = m_ui.mzRangeEndDoubleSpinBox->value();
+      msp_msRunProbeInfo->mzBegin = m_ui->mzRangeBeginDoubleSpinBox->value();
+      msp_msRunProbeInfo->mzEnd   = m_ui->mzRangeEndDoubleSpinBox->value();
     }
   else
     {
@@ -583,22 +585,22 @@ MsRunProbeInfoViewerDlg::validateData()
       msp_msRunProbeInfo->mzEnd   = -1;
     }
 
-  if(m_ui.mergeMzBinsGroupBox->isChecked())
+  if(m_ui->mergeMzBinsGroupBox->isChecked())
     {
-      qDebug("The merge m/z bins is asked for.");
+      // qDebug("The merge m/z bins is asked for.");
 
       // Since the m/z window is computed automatically (connection in the
       // initialize) just read the mz window.
       msp_msRunProbeInfo->mzBinsMergeWindow =
-        m_ui.mzMergeBinsByCountSpinBox->value();
+        m_ui->mzMergeBinsByCountSpinBox->value();
 
-      qDebug("The mz merge window was set to a bin window of bin count: %d",
-             msp_msRunProbeInfo->mzBinsMergeWindow);
+      // qDebug("The mz merge window was set to a bin window of bin count: %d",
+      //        msp_msRunProbeInfo->mzBinsMergeWindow);
     }
 
   return true;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
