@@ -43,8 +43,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msfile/msfileaccessor.h>
-#include <pappsomspp/msrun/msrunreader.h>
+#include <pappsomspp/core/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msrun/msrunreader.h>
 
 
 /////////////////////// Local includes
@@ -54,7 +54,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProgramWindow;
@@ -88,13 +88,13 @@ class MsRunReadTask : public QObject
 
 typedef std::shared_ptr<MsRunReadTask> MsRunReadTaskSPtr;
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunReadTask)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::MsRunReadTask)
 extern int MsRunReadTaskMetaTypeId;
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunReadTaskSPtr)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::MsRunReadTaskSPtr)
 extern int MsRunReadTaskSPtrMetaTypeId;
