@@ -43,20 +43,22 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/precisionwidget/precisionwidget.h>
-
+#include <pappsomspp/gui/precisionwidget/precisionwidget.h>
 
 /////////////////////// Local includes
-#include "ui_MzIntegrationParamsDlg.h"
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 
+namespace Ui
+{
+class MzIntegrationParamsDlg;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 class MzIntegrationParamsDlg : public QDialog
 {
   Q_OBJECT
@@ -67,6 +69,7 @@ class MzIntegrationParamsDlg : public QDialog
     QWidget *parent,
     const pappso::MzIntegrationParams &mz_integration_params,
     const QColor &color);
+
   ~MzIntegrationParamsDlg();
 
   void readSettings();
@@ -75,7 +78,7 @@ class MzIntegrationParamsDlg : public QDialog
   void keyPressEvent(QKeyEvent *event);
 
   void show();
-  void setBinningType(pappso::BinningType binningType);
+  void setBinningType(pappso::MzIntegrationParams::BinningType binningType);
   void setBinSizePrecisionPtr(pappso::PrecisionPtr bin_size_precsion_p);
   void setDecimalPlaces(int decimal_places);
   void setRemoveZeroValDataPoints(bool apply);
@@ -89,21 +92,21 @@ class MzIntegrationParamsDlg : public QDialog
   void binningRadioButtonToggled(bool checked);
 
   signals:
-  void mzIntegrationParamsChangedSignal(pappso::MzIntegrationParams params);
+  void mzIntegrationParamsChangedSignal(pappso::MzIntegrationParams &params);
   void mzIntegrationParamsDlgShouldBeDestroyedSignal();
 
   protected:
-  Ui::MzIntegrationParamsDlg m_ui;
-  pappso::MzIntegrationParams m_mzIntegrationParams;
-  pappso::PrecisionWidget *mp_precisionWidget;
-  pappso::PrecisionPtr mp_precision =
-    pappso::PrecisionFactory::getDaltonInstance(0.05);
+  pappso::MzIntegrationParams *mp_mzIntegrationParams = nullptr;
+  pappso::PrecisionWidget *mp_binSizeModelWidget;
+  pappso::PrecisionPtr mp_binSizeModel =
+    pappso::PrecisionFactory::getResInstance(40000);
   QColor m_color;
+  ::Ui::MzIntegrationParamsDlg *m_ui;
 
   void setupWidget();
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
