@@ -39,6 +39,7 @@
 #include <QMenuBar>
 #include <QMenu>
 #include <QDebug>
+#include <QColor>
 
 
 /////////////////////// pappsomspp includes
@@ -46,22 +47,24 @@
 
 /////////////////////// Local includes
 #include "OpenMsRunDataSetsDlg.hpp"
+#include "ui_OpenMsRunDataSetsDlg.h"
 #include "../nongui/MsRunDataSet.hpp"
+#include "Application.hpp"
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "ProgramWindow.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
-#include "Application.hpp"
-
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
 //! Construct an OpenMsRunDataSetsDlg instance.
 OpenMsRunDataSetsDlg::OpenMsRunDataSetsDlg(QWidget *parent)
-  : QDialog(parent), mp_programWindow(static_cast<ProgramWindow *>(parent))
+  : QDialog(parent),
+    mp_programWindow(static_cast<ProgramWindow *>(parent)),
+    m_ui(new ::Ui::OpenMsRunDataSetsDlg)
 {
   if(parent == Q_NULLPTR)
     qFatal("Programming error.");
@@ -123,9 +126,9 @@ OpenMsRunDataSetsDlg::readSettings()
 bool
 OpenMsRunDataSetsDlg::initialize()
 {
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
-  setWindowTitle("mineXpert2 - Open MS run data sets");
+  setWindowTitle("MineXpert3 - Open MS run data sets");
 
   createMainMenu();
 
@@ -148,10 +151,10 @@ OpenMsRunDataSetsDlg::createMainMenu()
   // Create the menu push button.
   const QIcon main_menu_icon =
     QIcon(":/images/svg/mobile-phone-like-menu-button.svg");
-  m_ui.mainMenuPushButton->setIcon(main_menu_icon);
+  m_ui->mainMenuPushButton->setIcon(main_menu_icon);
 
   // Finally set the push button to be the menu...
-  m_ui.mainMenuPushButton->setMenu(mp_mainMenu);
+  m_ui->mainMenuPushButton->setMenu(mp_mainMenu);
 
   QAction *close_selected_act_p = new QAction(tr("&Close selected..."), this);
   close_selected_act_p->setStatusTip(tr("Close all but selected"));
@@ -212,7 +215,7 @@ OpenMsRunDataSetsDlg::show()
 int
 OpenMsRunDataSetsDlg::itemCount()
 {
-  return m_ui.openMsRunDataSetsListWidget->count();
+  return m_ui->openMsRunDataSetsListWidget->count();
 }
 
 
@@ -220,7 +223,7 @@ OpenMsRunDataSetsDlg::itemCount()
 int
 OpenMsRunDataSetsDlg::selectedItemCount()
 {
-  return m_ui.openMsRunDataSetsListWidget->selectedItems().size();
+  return m_ui->openMsRunDataSetsListWidget->selectedItems().size();
 }
 
 
@@ -368,8 +371,8 @@ OpenMsRunDataSetsDlg::newOpenMsRunDataSet(
   item->setForeground(brush);
 
   // Append the new items to the current list widget.
-  int row = m_ui.openMsRunDataSetsListWidget->count();
-  m_ui.openMsRunDataSetsListWidget->insertItem(row, item);
+  int row = m_ui->openMsRunDataSetsListWidget->count();
+  m_ui->openMsRunDataSetsListWidget->insertItem(row, item);
 
   using Pair        = std::pair<MsRunDataSetCstSPtr, QListWidgetItem *>;
   using Map         = std::map<MsRunDataSetCstSPtr, QListWidgetItem *>;
@@ -390,7 +393,7 @@ OpenMsRunDataSetsDlg::newOpenMsRunDataSet(
 
   // Select the lastly added item.
 
-  m_ui.openMsRunDataSetsListWidget->setCurrentItem(item);
+  m_ui->openMsRunDataSetsListWidget->setCurrentItem(item);
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   //  qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
@@ -423,7 +426,7 @@ MsRunDataSetCstSPtr
 OpenMsRunDataSetsDlg::msRunDataSetForListWidgetItem(int index)
 {
   QListWidgetItem *list_widget_item_p =
-    m_ui.openMsRunDataSetsListWidget->item(index);
+    m_ui->openMsRunDataSetsListWidget->item(index);
 
   if(list_widget_item_p == nullptr)
     return nullptr;
@@ -521,7 +524,7 @@ OpenMsRunDataSetsDlg::closeSelected(void)
   // qDebug();
 
   QList<QListWidgetItem *> selected_item_list =
-    m_ui.openMsRunDataSetsListWidget->selectedItems();
+    m_ui->openMsRunDataSetsListWidget->selectedItems();
 
   closeItems(selected_item_list);
 }
@@ -544,7 +547,7 @@ OpenMsRunDataSetsDlg::showMsRunDataSetTableView()
   // selected.
 
   QList<QListWidgetItem *> selected_item_list =
-    m_ui.openMsRunDataSetsListWidget->selectedItems();
+    m_ui->openMsRunDataSetsListWidget->selectedItems();
 
   for(int iter = 0; iter < selected_item_list.size(); ++iter)
     {
@@ -575,14 +578,14 @@ OpenMsRunDataSetsDlg::showMsRunDataSetTableView()
 QList<QListWidgetItem *>
 OpenMsRunDataSetsDlg::unselectedItems()
 {
-  int item_count = m_ui.openMsRunDataSetsListWidget->count();
+  int item_count = m_ui->openMsRunDataSetsListWidget->count();
 
   QList<QListWidgetItem *> unselected_items;
 
   for(int iter = 0; iter < item_count; ++iter)
     {
       QListWidgetItem *current_widget_item =
-        m_ui.openMsRunDataSetsListWidget->item(iter);
+        m_ui->openMsRunDataSetsListWidget->item(iter);
 
       if(!current_widget_item->isSelected())
         unselected_items.append(current_widget_item);
@@ -595,7 +598,7 @@ OpenMsRunDataSetsDlg::unselectedItems()
 std::size_t
 OpenMsRunDataSetsDlg::msRunDataSetCount() const
 {
-  return m_ui.openMsRunDataSetsListWidget->count();
+  return m_ui->openMsRunDataSetsListWidget->count();
 }
 
 
@@ -603,10 +606,10 @@ void
 OpenMsRunDataSetsDlg::selectFirstMsRunDataSet()
 {
 
-  if(!m_ui.openMsRunDataSetsListWidget->count())
+  if(!m_ui->openMsRunDataSetsListWidget->count())
     return;
 
-  m_ui.openMsRunDataSetsListWidget->setCurrentRow(0);
+  m_ui->openMsRunDataSetsListWidget->setCurrentRow(0);
 }
 
 
@@ -627,7 +630,7 @@ OpenMsRunDataSetsDlg::singleSelectedOrUniqueMsRunDataSet(
   // without loading any mass spectral data file (like working with the IsoSpec
   // framework).
 
-  int list_widget_count = m_ui.openMsRunDataSetsListWidget->count();
+  int list_widget_count = m_ui->openMsRunDataSetsListWidget->count();
 
   // qDebug() << "Number of list widget items:" << list_widget_count;
 
@@ -640,9 +643,9 @@ OpenMsRunDataSetsDlg::singleSelectedOrUniqueMsRunDataSet(
     }
 
   if(list_widget_count == 1)
-    item_list.append(m_ui.openMsRunDataSetsListWidget->item(0));
+    item_list.append(m_ui->openMsRunDataSetsListWidget->item(0));
   else
-    item_list = m_ui.openMsRunDataSetsListWidget->selectedItems();
+    item_list = m_ui->openMsRunDataSetsListWidget->selectedItems();
 
   if(item_list.size() != 1)
     {
@@ -664,8 +667,8 @@ OpenMsRunDataSetsDlg::allMsRunDataSets() const
   std::vector<MsRunDataSetCstSPtr> vector_of_ms_run_data_set_csp;
 
   QList<QListWidgetItem *> item_list =
-    m_ui.openMsRunDataSetsListWidget->findItems(".*",
-                                                Qt::MatchRegularExpression);
+    m_ui->openMsRunDataSetsListWidget->findItems(".*",
+                                                 Qt::MatchRegularExpression);
 
   for(int iter = 0; iter < item_list.size(); ++iter)
     {
@@ -683,7 +686,7 @@ OpenMsRunDataSetsDlg::allSelectedOrUniqueMsRunDataSets() const
   std::vector<MsRunDataSetCstSPtr> vector_of_ms_run_data_set_csp;
 
   QList<QListWidgetItem *> selected_item_list =
-    m_ui.openMsRunDataSetsListWidget->selectedItems();
+    m_ui->openMsRunDataSetsListWidget->selectedItems();
 
   for(int iter = 0; iter < selected_item_list.size(); ++iter)
     {
@@ -693,9 +696,9 @@ OpenMsRunDataSetsDlg::allSelectedOrUniqueMsRunDataSets() const
 
   if(!vector_of_ms_run_data_set_csp.size())
     {
-      if(m_ui.openMsRunDataSetsListWidget->count() == 1)
+      if(m_ui->openMsRunDataSetsListWidget->count() == 1)
         vector_of_ms_run_data_set_csp.push_back(msRunDataSetForListWidgetItem(
-          m_ui.openMsRunDataSetsListWidget->item(0)));
+          m_ui->openMsRunDataSetsListWidget->item(0)));
     }
 
   return vector_of_ms_run_data_set_csp;
@@ -712,10 +715,10 @@ OpenMsRunDataSetsDlg::msRunDataSetFromSampleName(
   // qDebug() << "The sample name searched for:" << sample_name;
 
   // qDebug() << "Number of items:" <<
-  // m_ui.openMsRunDataSetsListWidget->count();
+  // m_ui->openMsRunDataSetsListWidget->count();
 
   QList<QListWidgetItem *> matched_items =
-    m_ui.openMsRunDataSetsListWidget->findItems(sample_name, Qt::MatchExactly);
+    m_ui->openMsRunDataSetsListWidget->findItems(sample_name, Qt::MatchExactly);
 
   if(!matched_items.size())
     {
@@ -744,6 +747,6 @@ OpenMsRunDataSetsDlg::colorFromMsRunDataSet(
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
