@@ -43,23 +43,23 @@
 
 
 /////////////////////// Local includes
+#include "Application.hpp"
 #include "ProcessingFlowViewerDlg.hpp"
 #include "ProgramWindow.hpp"
-#include "Application.hpp"
-
+#include "ui_ProcessingFlowViewerDlg.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 ProcessingFlowViewerDlg::ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p,
                                                  const QString &applicationName,
-                          const QColor &color)
+                                                 const QColor &color)
   : QDialog(dynamic_cast<QWidget *>(base_plot_wnd_p)),
     m_applicationName{applicationName},
-    m_color(color)
+    m_color(color),
+    m_ui(new ::Ui::ProcessingFlowViewerDlg)
 {
   if(base_plot_wnd_p == nullptr)
     qFatal("Programming error.");
@@ -68,7 +68,7 @@ ProcessingFlowViewerDlg::ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p,
   // We want to destroy the dialog when it is closed.
   // setAttribute(Qt::WA_DeleteOnClose);
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
   // Set the window title amongst other operations.
   setupDialog();
@@ -122,23 +122,22 @@ ProcessingFlowViewerDlg::setupDialog()
 {
   setWindowTitle(QString("%1 - ProcessingFlow viewer").arg(m_applicationName));
 
-updateTraceColor(m_color);
+  updateTraceColor(m_color);
   readSettings();
 
   return true;
 }
 
 
-  void
+void
 ProcessingFlowViewerDlg::updateTraceColor(const QColor &color)
 {
-m_color = color;
+  m_color = color;
 
   QString style =
     QString("QPlainTextEdit {border: 2px solid %1;}").arg(m_color.name());
 
-  m_ui.plainTextEdit->setStyleSheet(style);
-
+  m_ui->plainTextEdit->setStyleSheet(style);
 }
 
 
@@ -146,11 +145,11 @@ void
 ProcessingFlowViewerDlg::setProcessingFlowText(
   const QString &processing_flow_text)
 {
-  m_ui.plainTextEdit->clear();
-  m_ui.plainTextEdit->insertPlainText(processing_flow_text);
+  m_ui->plainTextEdit->clear();
+  m_ui->plainTextEdit->insertPlainText(processing_flow_text);
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
