@@ -43,15 +43,18 @@
 
 /////////////////////// Local includes
 #include "BasePlotWnd.hpp"
-#include "ui_ProcessingFlowViewerDlg.h"
 
 
+namespace Ui
+{
+class ProcessingFlowViewerDlg;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 class ProgramWindow;
 
 class ProcessingFlowViewerDlg : public QDialog
@@ -71,8 +74,6 @@ class ProcessingFlowViewerDlg : public QDialog
   public slots:
 
   private:
-  Ui::ProcessingFlowViewerDlg m_ui;
-
   QString m_applicationName;
   QString m_fileName;
 
@@ -80,6 +81,8 @@ class ProcessingFlowViewerDlg : public QDialog
 
   ProgramWindow *mp_programWindow = nullptr;
 
+  ::Ui::ProcessingFlowViewerDlg *m_ui;
+
   Q_INVOKABLE void writeSettings();
   Q_INVOKABLE void readSettings();
 
@@ -88,6 +91,6 @@ class ProcessingFlowViewerDlg : public QDialog
   bool setupDialog();
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
