@@ -47,16 +47,15 @@
 
 
 /////////////////////// Local includes
-#include "SaveToGraphicsFileDlg.hpp"
 #include "Application.hpp"
-
+#include "SaveToGraphicsFileDlg.hpp"
+#include "ui_SaveToGraphicsFileDlg.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 SaveToGraphicsFileDlg::SaveToGraphicsFileDlg(
   QWidget *parent,
   BasePlotCompositeWidget *plot_widget_p,
@@ -67,9 +66,10 @@ SaveToGraphicsFileDlg::SaveToGraphicsFileDlg(
     mp_plotWidget(plot_widget_p),
     m_applicationName(application_name),
     m_sampleName(sample_name),
-    m_color(color)
+    m_color(color),
+    m_ui(new ::Ui::SaveToGraphicsFileDlg)
 {
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
   initialize();
 }
@@ -90,22 +90,22 @@ SaveToGraphicsFileDlg::readSettings()
 
   // No, let the pdf format be the real default one.
   // QString format = settings.value("format").toString();
-  // m_ui.formatComboBox->setCurrentText(format);
+  // m_ui->formatComboBox->setCurrentText(format);
 
   QString creator = settings.value("creator").toString();
-  m_ui.creatorLineEdit->setText(creator);
+  m_ui->creatorLineEdit->setText(creator);
 
   QString title = settings.value("title").toString();
-  m_ui.titleLineEdit->setText(title);
+  m_ui->titleLineEdit->setText(title);
 
   int width = settings.value("width").toInt();
-  m_ui.widthSpinBox->setValue(width);
+  m_ui->widthSpinBox->setValue(width);
 
   int height = settings.value("height").toInt();
-  m_ui.heightSpinBox->setValue(height);
+  m_ui->heightSpinBox->setValue(height);
 
   int scale = settings.value("scale", 1).toDouble();
-  m_ui.scaleSpinBox->setValue(scale);
+  m_ui->scaleSpinBox->setValue(scale);
 
   // Also restore the geometry of the window.
   restoreGeometry(settings.value("geometry").toByteArray());
@@ -122,12 +122,12 @@ SaveToGraphicsFileDlg::writeSettings()
                      QSettings::IniFormat);
   settings.beginGroup("SaveToGraphicsFileDlg");
 
-  settings.setValue("format", m_ui.formatComboBox->currentText());
-  settings.setValue("creator", m_ui.creatorLineEdit->text());
-  settings.setValue("title", m_ui.titleLineEdit->text());
-  settings.setValue("width", m_ui.widthSpinBox->value());
-  settings.setValue("height", m_ui.heightSpinBox->value());
-  settings.setValue("scale", m_ui.scaleSpinBox->value());
+  settings.setValue("format", m_ui->formatComboBox->currentText());
+  settings.setValue("creator", m_ui->creatorLineEdit->text());
+  settings.setValue("title", m_ui->titleLineEdit->text());
+  settings.setValue("width", m_ui->widthSpinBox->value());
+  settings.setValue("height", m_ui->heightSpinBox->value());
+  settings.setValue("scale", m_ui->scaleSpinBox->value());
 
   settings.setValue("geometry", saveGeometry());
 
@@ -138,11 +138,11 @@ SaveToGraphicsFileDlg::writeSettings()
 void
 SaveToGraphicsFileDlg::initialize()
 {
-  m_ui.fileNameLineEdit->setText(m_sampleName);
+  m_ui->fileNameLineEdit->setText(m_sampleName);
 
   QPalette palette;
   palette.setColor(QPalette::Text, m_color);
-  m_ui.fileNameLineEdit->setPalette(palette);
+  m_ui->fileNameLineEdit->setPalette(palette);
 
   m_graphicsFormatMap.insert(GRAPHICS_FORMAT_PDF, "pdf");
   m_graphicsFormatMap.insert(GRAPHICS_FORMAT_SVG, "svg");
@@ -153,47 +153,47 @@ SaveToGraphicsFileDlg::initialize()
   readSettings();
 
   connect(
-    m_ui.formatComboBox,
+    m_ui->formatComboBox,
     static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
     this,
     static_cast<void (SaveToGraphicsFileDlg::*)(int)>(
       &SaveToGraphicsFileDlg::formatItemChanged));
 
-  m_ui.formatComboBox->insertItem(
+  m_ui->formatComboBox->insertItem(
     GraphicsFormat::GRAPHICS_FORMAT_PDF,
     m_graphicsFormatMap.value(GRAPHICS_FORMAT_PDF));
 
-  m_ui.formatComboBox->insertItem(
+  m_ui->formatComboBox->insertItem(
     GraphicsFormat::GRAPHICS_FORMAT_SVG,
     m_graphicsFormatMap.value(GRAPHICS_FORMAT_SVG));
 
-  m_ui.formatComboBox->insertItem(
+  m_ui->formatComboBox->insertItem(
     GraphicsFormat::GRAPHICS_FORMAT_PNG,
     m_graphicsFormatMap.value(GRAPHICS_FORMAT_PNG));
 
-  m_ui.formatComboBox->insertItem(
+  m_ui->formatComboBox->insertItem(
     GraphicsFormat::GRAPHICS_FORMAT_JPG,
     m_graphicsFormatMap.value(GRAPHICS_FORMAT_JPG));
 
-  m_ui.formatComboBox->insertItem(
+  m_ui->formatComboBox->insertItem(
     GraphicsFormat::GRAPHICS_FORMAT_CLIPBOARD,
     m_graphicsFormatMap.value(GRAPHICS_FORMAT_CLIPBOARD));
 
   // Now make sure the "pdf" item is currently displayed.
 
-  m_ui.formatComboBox->setCurrentIndex(GraphicsFormat::GRAPHICS_FORMAT_PDF);
+  m_ui->formatComboBox->setCurrentIndex(GraphicsFormat::GRAPHICS_FORMAT_PDF);
 
-  connect(m_ui.fileNamePushButton, &QPushButton::clicked, [&]() {
+  connect(m_ui->fileNamePushButton, &QPushButton::clicked, [&]() {
     m_fileName = QFileDialog::getSaveFileName(
       this, "Please select the destination file name.", m_sampleName);
-    m_ui.fileNameLineEdit->setText(m_fileName);
+    m_ui->fileNameLineEdit->setText(m_fileName);
   });
 
-  connect(m_ui.okPushButton,
+  connect(m_ui->okPushButton,
           &QPushButton::clicked,
           this,
           &SaveToGraphicsFileDlg::okPushButton);
-  connect(m_ui.cancelPushButton,
+  connect(m_ui->cancelPushButton,
           &QPushButton::clicked,
           this,
           &SaveToGraphicsFileDlg::cancelPushButton);
@@ -208,12 +208,12 @@ SaveToGraphicsFileDlg::okPushButton()
 
   // We only need file names if the destination is not the clipboard.
 
-  int format = m_ui.formatComboBox->currentIndex();
+  int format = m_ui->formatComboBox->currentIndex();
 
   if(format != GraphicsFormat::GRAPHICS_FORMAT_CLIPBOARD)
     {
       if(m_fileName.isEmpty())
-        m_fileName = m_ui.fileNameLineEdit->text();
+        m_fileName = m_ui->fileNameLineEdit->text();
 
       if(m_fileName.isEmpty())
         {
@@ -229,9 +229,9 @@ SaveToGraphicsFileDlg::okPushButton()
   // The data seem to be fine, save them for next iteration use.
   writeSettings();
 
-  int width  = m_ui.widthSpinBox->value();
-  int height = m_ui.heightSpinBox->value();
-  int scale  = m_ui.scaleSpinBox->value();
+  int width  = m_ui->widthSpinBox->value();
+  int height = m_ui->heightSpinBox->value();
+  int scale  = m_ui->scaleSpinBox->value();
 
   if(format != GraphicsFormat::GRAPHICS_FORMAT_PDF &&
      format != GraphicsFormat::GRAPHICS_FORMAT_SVG)
@@ -253,8 +253,8 @@ SaveToGraphicsFileDlg::okPushButton()
   switch(format)
     {
       case GraphicsFormat::GRAPHICS_FORMAT_PDF:
-        creator = m_ui.creatorLineEdit->text();
-        title   = m_ui.titleLineEdit->text();
+        creator = m_ui->creatorLineEdit->text();
+        title   = m_ui->titleLineEdit->text();
         mp_plotWidget->savePlotToPdfFile(
           m_fileName, width, height, QCP::epNoCosmetic, creator, title);
         break;
@@ -294,26 +294,24 @@ SaveToGraphicsFileDlg::cancelPushButton()
 void
 SaveToGraphicsFileDlg::formatItemChanged(int index)
 {
-  qDebug() << "Activated!: " << index;
-
-  QString text = m_ui.formatComboBox->itemText(index);
+  QString text = m_ui->formatComboBox->itemText(index);
 
   if(text == "pdf")
     {
-      m_ui.pdfCreatorTitleGroupBox->setVisible(true);
-      m_ui.scaleLabel->setVisible(false);
-      m_ui.scaleSpinBox->setVisible(false);
+      m_ui->pdfCreatorTitleGroupBox->setVisible(true);
+      m_ui->scaleLabel->setVisible(false);
+      m_ui->scaleSpinBox->setVisible(false);
     }
   else
     {
-      m_ui.pdfCreatorTitleGroupBox->setVisible(false);
+      m_ui->pdfCreatorTitleGroupBox->setVisible(false);
 
-      m_ui.scaleLabel->setVisible(true);
-      m_ui.scaleSpinBox->setVisible(true);
+      m_ui->scaleLabel->setVisible(true);
+      m_ui->scaleSpinBox->setVisible(true);
     }
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
