@@ -42,19 +42,21 @@
 
 /////////////////////// pappsomspp includes
 
-
 /////////////////////// Local includes
-#include "ui_SaveToGraphicsFileDlg.h"
 #include "BasePlotWnd.hpp"
 #include "BasePlotCompositeWidget.hpp"
 
 
+namespace Ui
+{
+class SaveToGraphicsFileDlg;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 class SaveToGraphicsFileDlg : public QDialog
 {
   Q_OBJECT
@@ -73,8 +75,6 @@ class SaveToGraphicsFileDlg : public QDialog
   void formatItemChanged(int index);
 
   protected:
-  Ui::SaveToGraphicsFileDlg m_ui;
-
   private:
   enum GraphicsFormat
   {
@@ -93,6 +93,8 @@ class SaveToGraphicsFileDlg : public QDialog
   QColor m_color;
   QMap<int, QString> m_graphicsFormatMap;
 
+  ::Ui::SaveToGraphicsFileDlg *m_ui;
+
   void initialize();
 
   void readSettings();
@@ -100,6 +102,6 @@ class SaveToGraphicsFileDlg : public QDialog
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
