@@ -50,29 +50,31 @@
 
 /////////////////////// Local includes
 #include "TaskMonitorCompositeWidget.hpp"
-
+#include "ui_TaskMonitorCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 TaskMonitorCompositeWidget::TaskMonitorCompositeWidget(QWidget *parent_p)
-  : QWidget(parent_p)
+  : QWidget(parent_p), m_ui(new ::Ui::TaskMonitorCompositeWidget)
 {
   // By essence, the parent will be the task monitor window.
 
   if(parent_p == nullptr)
     qFatal("parent cannot be nullptr");
 
+
   setupWindow();
 }
 
 
 TaskMonitorCompositeWidget::TaskMonitorCompositeWidget(QWidget *parent_p,
                                                        const QColor &color)
-  : QWidget(parent_p), m_color(color)
+  : QWidget(parent_p),
+    m_color(color),
+    m_ui(new ::Ui::TaskMonitorCompositeWidget)
 {
   // By essence, the parent will be the task monitor window.
 
@@ -92,10 +94,9 @@ TaskMonitorCompositeWidget::~TaskMonitorCompositeWidget()
 void
 TaskMonitorCompositeWidget::setupWindow()
 {
+  m_ui->setupUi(this);
 
-  m_ui.setupUi(this);
-
-  connect(m_ui.cancelTaskPushButton,
+  connect(m_ui->cancelTaskPushButton,
           &QPushButton::clicked,
           this,
           &TaskMonitorCompositeWidget::cancelTask);
@@ -113,9 +114,9 @@ TaskMonitorCompositeWidget::setColor(const QColor &color)
   palette.setColor(QPalette::Window, color);
   palette.setColor(QPalette::WindowText, color);
 
-  m_ui.msRunIdLabel->setAutoFillBackground(true);
-  m_ui.msRunIdLabel->setPalette(palette);
-  m_ui.msRunIdLabel->setText("ms run id");
+  m_ui->msRunIdLabel->setAutoFillBackground(true);
+  m_ui->msRunIdLabel->setPalette(palette);
+  m_ui->msRunIdLabel->setText("ms run id");
 }
 
 
@@ -525,9 +526,9 @@ TaskMonitorCompositeWidget::setupProgressBar(int min_value, int max_value)
 {
   if(!m_isLocked)
     {
-      m_ui.progressBar->setMinimum(min_value);
+      m_ui->progressBar->setMinimum(min_value);
       m_currentValue = min_value;
-      m_ui.progressBar->setMaximum(max_value);
+      m_ui->progressBar->setMaximum(max_value);
     }
 }
 
@@ -537,7 +538,7 @@ TaskMonitorCompositeWidget::setProgressBarMinValue(int value)
 {
   if(!m_isLocked)
     {
-      m_ui.progressBar->setMinimum(value);
+      m_ui->progressBar->setMinimum(value);
       m_currentValue = value;
     }
 }
@@ -550,7 +551,7 @@ TaskMonitorCompositeWidget::setProgressBarMaxValue(int value)
     {
       // qDebug() << "setting max value:" << value;
 
-      m_ui.progressBar->setMaximum(value);
+      m_ui->progressBar->setMaximum(value);
     }
 }
 
@@ -558,11 +559,11 @@ TaskMonitorCompositeWidget::setProgressBarMaxValue(int value)
 void
 TaskMonitorCompositeWidget::incrementProgressBarMaxValue(int increment)
 {
-  int new_value = m_ui.progressBar->maximum() + increment;
+  int new_value = m_ui->progressBar->maximum() + increment;
 
   // qDebug() << "incrementing max value to:" << new_value;
 
-  m_ui.progressBar->setMaximum(new_value);
+  m_ui->progressBar->setMaximum(new_value);
 }
 
 
@@ -571,7 +572,7 @@ TaskMonitorCompositeWidget::setProgressBarCurrentValue(int value)
 {
   if(!m_isLocked && shouldUpdate())
     {
-      m_ui.progressBar->setValue(value);
+      m_ui->progressBar->setValue(value);
       m_currentValue = value;
     }
 }
@@ -581,14 +582,14 @@ void
 TaskMonitorCompositeWidget::setMsRunIdText(QString text)
 {
   if(!m_isLocked)
-    m_ui.msRunIdLabel->setText(text);
+    m_ui->msRunIdLabel->setText(text);
 }
 
 
 QString
 TaskMonitorCompositeWidget::getMsRunIdText()
 {
-  return m_ui.msRunIdLabel->text();
+  return m_ui->msRunIdLabel->text();
 }
 
 
@@ -596,7 +597,7 @@ void
 TaskMonitorCompositeWidget::setTaskDescriptionText(QString text)
 {
   if(!m_isLocked)
-    m_ui.taskDescriptionLineEdit->setText(text);
+    m_ui->taskDescriptionLineEdit->setText(text);
 }
 
 
@@ -604,14 +605,14 @@ void
 TaskMonitorCompositeWidget::clearTaskDescriptionText()
 {
   if(!m_isLocked)
-    m_ui.taskDescriptionLineEdit->setText("");
+    m_ui->taskDescriptionLineEdit->setText("");
 }
 
 
 QString
 TaskMonitorCompositeWidget::getTaskDescriptionText()
 {
-  return m_ui.taskDescriptionLineEdit->text();
+  return m_ui->taskDescriptionLineEdit->text();
 }
 
 
@@ -622,7 +623,7 @@ TaskMonitorCompositeWidget::setStatusText(QString text)
   // shouldUpdate();
 
   if(!m_isLocked && shouldUpdate())
-    m_ui.statusLineEdit->setText(text);
+    m_ui->statusLineEdit->setText(text);
 }
 
 
@@ -630,14 +631,14 @@ void
 TaskMonitorCompositeWidget::appendStatusText(QString text)
 {
   if(!m_isLocked && shouldUpdate())
-    m_ui.statusLineEdit->setText(m_ui.statusLineEdit->text() + text);
+    m_ui->statusLineEdit->setText(m_ui->statusLineEdit->text() + text);
 }
 
 
 QString
 TaskMonitorCompositeWidget::getStatusText()
 {
-  return m_ui.statusLineEdit->text();
+  return m_ui->statusLineEdit->text();
 }
 
 
@@ -645,7 +646,7 @@ void
 TaskMonitorCompositeWidget::clearStatusText()
 {
   if(!m_isLocked && shouldUpdate())
-    m_ui.statusLineEdit->setText("");
+    m_ui->statusLineEdit->setText("");
 }
 
 
@@ -655,8 +656,8 @@ TaskMonitorCompositeWidget::setStatusTextAndCurrentValue(QString text,
 {
   if(!m_isLocked && shouldUpdate())
     {
-      m_ui.statusLineEdit->setText(text);
-      m_ui.progressBar->setValue(value);
+      m_ui->statusLineEdit->setText(text);
+      m_ui->progressBar->setValue(value);
       m_currentValue = value;
     }
 }
@@ -668,7 +669,7 @@ TaskMonitorCompositeWidget::incrementProgressBarCurrentValue(int increment)
   if(!m_isLocked && shouldUpdate())
     {
       m_currentValue += increment;
-      m_ui.progressBar->setValue(m_currentValue);
+      m_ui->progressBar->setValue(m_currentValue);
     }
 }
 
@@ -691,9 +692,9 @@ TaskMonitorCompositeWidget::incrementProgressBarCurrentValueAndSetStatusText(
 
       if(shouldUpdate())
         {
-          m_ui.progressBar->setValue(m_currentValue);
+          m_ui->progressBar->setValue(m_currentValue);
           QString new_text = craftStringIfFormattedText(text);
-          m_ui.statusLineEdit->setText(new_text);
+          m_ui->statusLineEdit->setText(new_text);
 
           // qDebug() << "current thread:" << QThread::currentThread()
           //<< "after increment current value:" << m_currentValue
@@ -755,6 +756,6 @@ TaskMonitorCompositeWidget::craftStringIfFormattedText(
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
