@@ -47,9 +47,7 @@
 
 /////////////////////// pappsomspp includes
 
-
 /////////////////////// Local includes
-#include "ui_TaskMonitorCompositeWidget.h"
 #include "../nongui/MassDataIntegrator.hpp"
 #include "../nongui/MassSpecDataFileLoader.hpp"
 #include "../nongui/MsRunProber.hpp"
@@ -57,12 +55,16 @@
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 
+namespace Ui
+{
+class TaskMonitorCompositeWidget;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 class TaskMonitorCompositeWidget : public QWidget
 {
   Q_OBJECT
@@ -130,7 +132,7 @@ class TaskMonitorCompositeWidget : public QWidget
   void cancelTaskSignal();
 
   protected:
-  Ui::TaskMonitorCompositeWidget m_ui;
+  ::Ui::TaskMonitorCompositeWidget *m_ui;
 
   void setupWindow();
 
@@ -145,6 +147,6 @@ class TaskMonitorCompositeWidget : public QWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
