@@ -45,14 +45,14 @@
 
 
 /////////////////////// Local includes
-#include "TaskMonitorWnd.hpp"
-#include "TaskMonitorCompositeWidget.hpp"
+#include "ui_TaskMonitorWnd.h"
 #include "Application.hpp"
-
+#include "TaskMonitorCompositeWidget.hpp"
+#include "TaskMonitorWnd.hpp"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -64,12 +64,13 @@ TaskMonitorWnd::TaskMonitorWnd(QWidget *parent,
   : QMainWindow(parent),
     m_title(title),
     m_settingsTitle(settingsTitle),
-    m_description(description)
+    m_description(description),
+    m_ui(new ::Ui::TaskMonitorWnd)
 {
   if(parent == Q_NULLPTR)
     qFatal("Programming error.");
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
   if(!initialize())
     qFatal("Programming error.");
@@ -130,7 +131,7 @@ TaskMonitorWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
 bool
 TaskMonitorWnd::initialize()
 {
-  setWindowTitle(QString("mineXpert2 - %1").arg(m_title));
+  setWindowTitle(QString("MineXpert3 - %1").arg(m_title));
 
   readSettings();
 
@@ -167,12 +168,12 @@ TaskMonitorWnd::addTaskMonitorWidget(const QColor &color)
   // The new widget should be preprended so that the newly created ones are at
   // the top of the vertical layout box.
 
-  m_ui.scrollAreaVerticalLayout->insertWidget(0, widget_p);
+  m_ui->scrollAreaVerticalLayout->insertWidget(0, widget_p);
 
   return widget_p;
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
