@@ -44,18 +44,20 @@
 
 /////////////////////// pappsomspp includes
 
-
 /////////////////////// Local includes
-#include "ui_TaskMonitorWnd.h"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
+namespace Ui
+{
+class TaskMonitorWnd;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 class TaskMonitorWnd : public QMainWindow
 {
   Q_OBJECT
@@ -81,16 +83,15 @@ class TaskMonitorWnd : public QMainWindow
   protected:
   ////// Setting up the window layout.
 
-  //! Graphical interface definition.
-  Ui::TaskMonitorWnd m_ui;
-
-  private:
   QString m_title;
   QString m_settingsTitle;
   QString m_description;
+
+  //! Graphical interface definition.
+  ::Ui::TaskMonitorWnd *m_ui;
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
