@@ -41,21 +41,21 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>
+#include <pappsomspp/gui/plotwidget/colormapplotconfig.h>
 
 
 /////////////////////// Local includes
 #include "ProgramWindow.hpp"
 #include "TicXicChromDriftSpecColorMapWnd.hpp"
 #include "TicXicChromDriftSpecColorMapPlotCompositeWidget.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -102,12 +102,12 @@ TicXicChromDriftSpecColorMapWnd::addColorMapPlot(
   QString ion_mobility_axis_label = "drift time (ms)";
 
   if(ms_run_data_set_csp->getMsRunId()->getMsDataFormat() ==
-     pappso::MsDataFormat::brukerTims)
+     pappso::Enums::MsDataFormat::brukerTims)
     {
       ion_mobility_axis_label = "inverse mobility (1/K0)";
     }
 
-  if(color_map_plot_config.xAxisDataKind == pappso::DataKind::rt)
+  if(color_map_plot_config.xAxisDataKind == pappso::Enums::DataKind::rt)
     {
       composite_widget_p = new TicXicChromDriftSpecColorMapPlotCompositeWidget(
         this, "retention time (min)", ion_mobility_axis_label);
@@ -147,6 +147,7 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
+
   std::pair<double, double> range_pair;
 
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
@@ -154,14 +155,14 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   if(!integration_rt)
     qFatal("Programming error.");
 
-  qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
-           << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
+  //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
-
-  if(integration_dt)
-    qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-             << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  //
+  // if(integration_dt)
+  //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
+  //            << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
@@ -174,9 +175,9 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  qDebug()
-    << "The number of selected mass spectra on the basis of rough RT/DT values:"
-    << qualified_mass_spectra_count;
+  // qDebug()
+  //   << "The number of selected mass spectra on the basis of rough RT/DT values:"
+  //   << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -204,7 +205,7 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
     new MassDataIntegratorTask();
 
   qRegisterMetaType<std::size_t>("std::size_t");
-  qRegisterMetaType<pappso::DataKind>("pappso::DataKind");
+  qRegisterMetaType<pappso::Enums::DataKind>("pappso::Enums::DataKind");
 
   // This signal starts the computation in the MassDataIntegratorTask object.
   connect(this,
@@ -297,7 +298,7 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   // cannot be shipped though signals.
 
   qRegisterMetaType<std::size_t>("std::size_t");
-  qRegisterMetaType<pappso::DataKind>("pappso::DataKind");
+  qRegisterMetaType<pappso::Enums::DataKind>("pappso::Enums::DataKind");
 
   // Now make all the connections that will allow the integrator to provide
   // dynamic feedback to the user via the task monitor widget.
@@ -342,11 +343,26 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
   // We get back the integrator that was made to work in another thread. Now get
   // the obtained data and work with them.
 
+  // Make sure we make a copy of the ProcessingFlow stored in the
+  // mass data integrator, because that ProcessingFlow is owned by the
+  // mass data integrator and the latter will be destroyed below. We can make
+  // the copy without parentship because we'll pass it as reference to
+  // downstream code that will use that ref to allocate a new fully parented
+  // instance.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
+
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
+  // Sanity check
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
+    qFatal() << "Programming error. Not possible that the MsRunDataSet "
+                "pointers do not match.";
+
   // We need some specific function from the specialized integrator.
   QualifiedMassSpectrumVectorMassDataIntegratorToRtDt
     *mass_data_integrator_to_dtrt_p =
@@ -382,16 +398,16 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
 
   pappso::ColorMapPlotConfig color_map_plot_config(
     // x data kind
-    pappso::DataKind::rt,
+    pappso::Enums::DataKind::rt,
     // y data kind
-    pappso::DataKind::dt,
+    pappso::Enums::DataKind::dt,
 
     // x axis scale
-    pappso::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
     // y axis scale
-    pappso::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
     // z axis scale
-    pappso::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
 
     mass_data_integrator_to_dtrt_p->getColorMapKeyCellCount(),
     mass_data_integrator_to_dtrt_p->getColorMapMzCellCount(),
@@ -408,20 +424,8 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
     /*the min Z value will be determined later*/ 0,
     /*the max Z value will be determined later*/ 0);
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
-
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // qDebug() << "The processing flow after integration to dt|rt:" <<
-  // processing_flow.toString();
-
-  // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // Now that we got all we need and that we have made a safe copy
+  // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -445,7 +449,7 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
   addColorMapPlot(rt_maptrace_map,
                   color_map_plot_config,
                   ms_run_data_set_csp,
-                  processing_flow,
+                  *temp_processing_flow_p,
                   plot_color,
                   static_cast<QCPAbstractPlottable *>(parent_plottable_p));
 
@@ -457,8 +461,12 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
     {
       showWindow();
     }
+
+  delete temp_processing_flow_p;
+
+  return;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
