@@ -41,21 +41,22 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/types.h>
-#include <pappsomspp/widget/plotwidget/ticxicchrommassspeccolormapplotwidget.h>
-#include <pappsomspp/processing/combiners/integrationscoperect.h>
-#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
+#include <pappsomspp/core/types.h>
+#include <pappsomspp/gui/plotwidget/ticxicchrommassspeccolormapplotwidget.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperhomb.h>
 
 
 /////////////////////// Local includes
 #include "TicXicChromMassSpecColorMapPlotCompositeWidget.hpp"
 #include "TicXicChromTracePlotWidget.hpp"
 #include "TicXicChromMassSpecColorMapWnd.hpp"
+#include "ui_BasePlotCompositeWidget.h"
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -85,7 +86,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::setupWidget()
   /************  The QCustomPlot widget *************/
   mp_plotWidget = new pappso::TicXicChromMassSpecColorMapPlotWidget(
     this, m_axisLabelX, m_axisLabelY);
-  m_ui.qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
+  m_ui->qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
 
   connect(mp_plotWidget,
           &pappso::TicXicChromMassSpecColorMapPlotWidget::setFocusSignal,
@@ -161,7 +162,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::setupWidget()
   // The button that triggers the duplication of the trace into another trace
   // plot widget. We do not do that for color maps yet.
 
-  m_ui.duplicateTracePushButton->hide();
+  m_ui->duplicateTracePushButton->hide();
 }
 
 
@@ -228,7 +229,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   //**context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
   context.msp_integrationScope->range(
-    pappso::Axis::x, x_range_start, x_range_end);
+    pappso::Enums::Axis::x, x_range_start, x_range_end);
 
   // qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
@@ -240,7 +241,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   //**context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
   context.msp_integrationScope->range(
-    pappso::Axis::y, y_range_start, y_range_end);
+    pappso::Enums::Axis::y, y_range_start, y_range_end);
 
   // qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
@@ -278,14 +279,12 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       return;
     }
 
-  // Create a local copy of the processing flow so that we can modify it by
-  // adding the new processing step that describes what we are doing now.
+  // Create a temporary copy of the ProcessingFlow (with no parentship) so that
+  // we can modify it with new steps and then pass it as reference to downstream
+  // code that will allocate a fully parented instance.
 
-  ProcessingFlow local_processing_flow =
-    getProcessingFlowForPlottable(plottable_p);
-
-  // qDebug().noquote() << "Processing flow for graph:"
-  //<< local_processing_flow.toString();
+  ProcessingFlow *temp_processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(plottable_p)->clone(nullptr);
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
@@ -305,7 +304,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // ProcessingFlow's ms fragmentation specification.
 
   MsFragmentationSpec ms_fragmentation_spec =
-    local_processing_flow.getDefaultMsFragmentationSpec();
+    temp_processing_flow_p->getDefaultMsFragmentationSpec();
 
   // Only set the ms frag spec to the processing spec if it is valid.
   if(ms_fragmentation_spec.isValid())
@@ -326,38 +325,38 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Sanity check.
 
-  pappso::DataKind x_axis_data_kind =
+  pappso::Enums::DataKind x_axis_data_kind =
     static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
       ->xAxisDataKind();
-  pappso::DataKind y_axis_data_kind =
+  pappso::Enums::DataKind y_axis_data_kind =
     static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
       ->yAxisDataKind();
 
-  if(x_axis_data_kind == pappso::DataKind::mz)
+  if(x_axis_data_kind == pappso::Enums::DataKind::mz)
     {
       // qDebug() << "X axis: mz";
     }
-  else if(x_axis_data_kind == pappso::DataKind::rt)
+  else if(x_axis_data_kind == pappso::Enums::DataKind::rt)
     {
       // qDebug() << "X axis: rt";
     }
 
-  if(y_axis_data_kind == pappso::DataKind::mz)
+  if(y_axis_data_kind == pappso::Enums::DataKind::mz)
     {
       // qDebug() << "Y axis: mz";
     }
-  else if(y_axis_data_kind == pappso::DataKind::rt)
+  else if(y_axis_data_kind == pappso::Enums::DataKind::rt)
     {
       // qDebug() << "Y axis: rt";
     }
 
-  if(x_axis_data_kind == pappso::DataKind::mz &&
-     y_axis_data_kind != pappso::DataKind::rt)
+  if(x_axis_data_kind == pappso::Enums::DataKind::mz &&
+     y_axis_data_kind != pappso::Enums::DataKind::rt)
     {
       qFatal("Programming error.");
     }
-  else if(x_axis_data_kind == pappso::DataKind::rt &&
-          y_axis_data_kind != pappso::DataKind::mz)
+  else if(x_axis_data_kind == pappso::Enums::DataKind::rt &&
+          y_axis_data_kind != pappso::Enums::DataKind::mz)
     {
       qFatal("Programming error.");
     }
@@ -461,7 +460,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // qDebug() << "New local integration scope is Rhomb:"
   //          << local_integration_scope_base_sp->isRhomboid();
 
-  if(x_axis_data_kind == pappso::DataKind::mz)
+  if(x_axis_data_kind == pappso::Enums::DataKind::mz)
     {
       // We transpose to have x::rt and y::mz.
       //**local_selection_polygon = local_selection_polygon.transpose();
@@ -475,8 +474,8 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right selection polygon for x:RT and y:MZ.
 
-  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
-  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::mz);
 
   // And now actually set the integration scope to the step.
 
@@ -484,54 +483,54 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
   processing_step_sp->setIntegrationScope(local_integration_scope_base_sp);
 
   // We must say what is the data source processing type.
-  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "RT");
-  processing_step_sp->setSrcProcessingType(pappso::Axis::y, "MZ");
+  processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "RT");
+  processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::y, "MZ");
 
   // Now we need to document not the source but the destination. What kind of
   // integration are we about to perform?
 
-  if(m_ui.integrateToRtPushButton->isChecked())
+  if(m_ui->integrateToRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to XIC chromatogram.";
 
       processing_step_sp->setDestProcessingType("RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-        ->integrateToRt(plottable_p, local_processing_flow);
+        ->integrateToRt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToDtRtPushButton->isChecked())
+  else if(m_ui->integrateToDtRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to dt / rt color map.";
 
       processing_step_sp->setDestProcessingType("DT_RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-        ->integrateToDtRt(plottable_p, local_processing_flow);
+        ->integrateToDtRt(plottable_p, *temp_processing_flow_p);
     }
   // Handle all the integrations to MZ in one place
-  else if(m_ui.integrateToMzPushButton->isChecked() ||
-          m_ui.integrateToDtMzPushButton->isChecked() ||
-          m_ui.integrateToMzRtPushButton->isChecked())
+  else if(m_ui->integrateToMzPushButton->isChecked() ||
+          m_ui->integrateToDtMzPushButton->isChecked() ||
+          m_ui->integrateToMzRtPushButton->isChecked())
     {
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to mass spectrum.";
 
           processing_step_sp->setDestProcessingType("MZ");
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to m/z / rt color map.";
 
           processing_step_sp->setDestProcessingType("MZ_RT");
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt / m/z color map.";
 
@@ -541,52 +540,20 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // At this point we need to define how the mass data integrator will
       // combine spectra, since we are integrating to a mass spectrum.
 
-      // This is a multi-layer work: the graph has a ProcessingFlow associated
-      // to it via the m_graphProcessingFlowMap. We have gotten it above.
+      // The function below will first get the potential settings that might
+      // have been stored by the user when "Set as default" is checked in the
+      // MzIntegrationParamsDlg window. If no integration settings were found,
+      // then other possibilities are tested (in particular by looking into
+      // the ProcessingFlow).
 
-      // Extract from it the default pappso::MzIntegrationParams:
+      // Heap-allocated
+      pappso::MzIntegrationParams *mz_integration_params_p =
+        BasePlotCompositeWidget::getSensibleMzIntegrationParams(plottable_p);
 
-      pappso::MzIntegrationParams mz_integration_params =
-        local_processing_flow.getDefaultMzIntegrationParams();
-
-      // qDebug()
-      //<< "The graph's processing flow has default mz integration params:"
-      //<< mz_integration_params.toString();
-
-      // If it is not valid, then try mz integration params from the various
-      // steps of the flow. Preferentially the most recent ones.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug()
-          //<< "The processing flow's default mz integ params are not "
-          //"valid. Trying to get the most recent mz integ params "
-          //"from the processing flow. If valid, we may tune them later.";
-
-          mz_integration_params =
-            *(local_processing_flow.mostRecentMzIntegrationParams());
-        }
-
-      // If it is not valid, finally resort to the parameters that can be
-      // crafted on the basis of the statistical analysis of the ms run data set
-      // while it was loaded from file.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug() << "The most recent mz integ param are not valid. We use "
-          //"the getMsRunDataSetStats to craft new ones that we may "
-          //"tune later.";
-
-          mz_integration_params =
-            ms_run_data_set_csp->craftInitialMzIntegrationParams();
-        }
-      else
-        {
-          // qDebug() << "The most recent mz integ params are valid. Use them, "
-          //"with potential tuning.";
-        }
-
-      if(!mz_integration_params.isValid())
+      if(!mz_integration_params_p->isValid())
         qFatal(
-          "The mz integ params from the ms run data set stats are not valid.");
+          "The mz integ params from the ms run data set stats are not "
+          "valid.");
 
       // At this point, let's see if we can optimize the integration
       // computation. Indeed, if we know we have an mz range in the selection
@@ -600,7 +567,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // bool res = local_selection_polygon.rangeY(mz_range_lower,
       // mz_range_upper);
       bool res = local_integration_scope_base_sp->range(
-        pappso::Axis::y, mz_range_lower, mz_range_upper);
+        pappso::Enums::Axis::y, mz_range_lower, mz_range_upper);
 
       if(!res)
         {
@@ -614,8 +581,8 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // integration comes right from the intial TIC, then the range is the
       // whole range of the mass data in the dataset.
 
-      mz_integration_params.setSmallestMz(mz_range_lower);
-      mz_integration_params.setGreatestMz(mz_range_upper);
+      mz_integration_params_p->setSmallestMz(mz_range_lower);
+      mz_integration_params_p->setGreatestMz(mz_range_upper);
 
       // qDebug() << "After tuning the mz range, mz integration params:"
       //<< mz_integration_params.toString();
@@ -625,13 +592,13 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // This is no more true: we do not force a low resolution computation for
       // the color maps. The mz integration parameters are now entirely
       // satisfied.
-      
+
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
-      if(m_ui.integrateToDtMzPushButton->isChecked() ||
-         m_ui.integrateToMzRtPushButton->isChecked())
+      if(m_ui->integrateToDtMzPushButton->isChecked() ||
+         m_ui->integrateToMzRtPushButton->isChecked())
         {
-          mz_integration_params.setBinningType(pappso::BinningType::NONE);
+          mz_integration_params.setBinningType(pappso::MzIntegrationParams::BinningType::NONE);
           mz_integration_params.setDecimalPlaces(0);
         }
 
@@ -639,14 +606,15 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
-      processing_step_sp->setMzIntegrationParams(mz_integration_params);
+      // Takes ownership
+      processing_step_sp->setMzIntegrationParams(mz_integration_params_p);
 
       // And nwo add the new processing step to the local copy of the processing
       // flow, so that we document on top of all the previous steps, also this
       // last one.
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -654,45 +622,45 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // The local processing flow contains all the previous steps and the last
       // one that documents this current integration.
 
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-            ->integrateToMz(plottable_p, local_processing_flow);
+            ->integrateToMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-            ->integrateToDtMz(plottable_p, local_processing_flow);
+            ->integrateToDtMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-            ->integrateToMzRt(plottable_p, local_processing_flow);
+            ->integrateToMzRt(plottable_p, *temp_processing_flow_p);
         }
     }
-  else if(m_ui.integrateToDtPushButton->isChecked())
+  else if(m_ui->integrateToDtPushButton->isChecked())
     {
       // qDebug() << "Integrating to drift spectrum.";
 
       processing_step_sp->setDestProcessingType("DT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
-        ->integrateToDt(plottable_p, local_processing_flow);
+        ->integrateToDt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToIntPushButton->isChecked())
+  else if(m_ui->integrateToIntPushButton->isChecked())
     {
       // qDebug() << "Integrating to TIC intensity.";
 
       processing_step_sp->setDestProcessingType("INT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
+        ->integrateToTicIntensity(plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -705,8 +673,12 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::Ok,
         QMessageBox::StandardButton::NoButton);
     }
+
+    delete temp_processing_flow_p;
+
+  return;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
