@@ -44,7 +44,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basecolormapplotwidget.h>
+#include <pappsomspp/gui/plotwidget/basecolormapplotwidget.h>
 
 
 /////////////////////// Local includes
@@ -53,7 +53,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class TicXicChromMassSpecColorMapPlotCompositeWidget
@@ -80,6 +80,6 @@ class TicXicChromMassSpecColorMapPlotCompositeWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
