@@ -41,21 +41,21 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>
+#include <pappsomspp/gui/plotwidget/colormapplotconfig.h>
 
 
 /////////////////////// Local includes
 #include "ProgramWindow.hpp"
 #include "TicXicChromMassSpecColorMapWnd.hpp"
 #include "TicXicChromMassSpecColorMapPlotCompositeWidget.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -130,14 +130,15 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
   if(!integration_rt)
     qFatal("Programming error.");
 
-  qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
-           << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
+  //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  //
+  // if(integration_dt)
+  //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
+  //            << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  if(integration_dt)
-    qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-             << "for y axis: " << range_pair.first << "-" << range_pair.second;
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
 
@@ -179,7 +180,7 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
     new MassDataIntegratorTask();
 
   qRegisterMetaType<std::size_t>("std::size_t");
-  qRegisterMetaType<pappso::DataKind>("pappso::DataKind");
+  qRegisterMetaType<pappso::Enums::DataKind>("pappso::Enums::DataKind");
 
   // This signal starts the computation in the MassDataIntegratorTask object.
   connect(this,
@@ -272,7 +273,7 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
   // cannot be shipped though signals.
 
   qRegisterMetaType<std::size_t>("std::size_t");
-  qRegisterMetaType<pappso::DataKind>("pappso::DataKind");
+  qRegisterMetaType<pappso::Enums::DataKind>("pappso::Enums::DataKind");
 
   // Now make all the connections that will allow the integrator to provide
   // dynamic feedback to the user via the task monitor widget.
@@ -317,11 +318,26 @@ TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
   // We get back the integrator that was made to work in another thread. Now get
   // the obtained data and work with them.
 
+  // Make sure we make a copy of the ProcessingFlow stored in the
+  // mass data integrator, because that ProcessingFlow is owned by the
+  // mass data integrator and the latter will be destroyed below. We can make
+  // the copy without parentship because we'll pass it as reference to
+  // downstream code that will use that ref to allocate a new fully parented
+  // instance.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
+
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
+  // Sanity check
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
+    qFatal() << "Programming error. Not possible that the MsRunDataSet "
+                "pointers do not match.";
+
   // We need some specific function from the specialized integrator.
   QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
     *mass_data_integrator_to_rtdtmz_p =
@@ -346,11 +362,11 @@ TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
   // the minimum/maximum mz value.
 
   pappso::ColorMapPlotConfig color_map_plot_config(
-    pappso::DataKind::rt,
-    pappso::DataKind::mz,
-    pappso::AxisScale::orig,
-    pappso::AxisScale::orig,
-    pappso::AxisScale::orig,
+    pappso::Enums::DataKind::rt,
+    pappso::Enums::DataKind::mz,
+    pappso::Enums::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
+    pappso::Enums::AxisScale::orig,
     mass_data_integrator_to_rtdtmz_p->getColorMapKeyCellCount(),
     mass_data_integrator_to_rtdtmz_p->getColorMapMzCellCount(),
     mass_data_integrator_to_rtdtmz_p->getColorMapMinKey(),
@@ -360,17 +376,8 @@ TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
     /*the min Z value will be determined later*/ 0,
     /*the max Z value will be determined later*/ 0);
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
-
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // Now that we got all we need and that we have made a safe copy
+  // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -394,7 +401,7 @@ TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
   addColorMapPlot(double_map_trace_map_sp,
                   color_map_plot_config,
                   ms_run_data_set_csp,
-                  processing_flow,
+                  *temp_processing_flow_p,
                   plot_color,
                   static_cast<QCPAbstractPlottable *>(parent_plottable_p));
 
@@ -406,8 +413,12 @@ TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
     {
       showWindow();
     }
+
+  delete temp_processing_flow_p;
+
+  return;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
