@@ -41,19 +41,19 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/ticxicchromtraceplotwidget.h>
-#include <pappsomspp/processing/combiners/integrationscope.h>
+#include <pappsomspp/gui/plotwidget/ticxicchromtraceplotwidget.h>
+#include <pappsomspp/core/processing/combiners/integrationscope.h>
 
 
 /////////////////////// Local includes
 #include "TicXicChromTracePlotCompositeWidget.hpp"
 #include "TicXicChromTracePlotWidget.hpp"
 #include "TicXicChromTracePlotWnd.hpp"
-
+#include "ui_BasePlotCompositeWidget.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -61,17 +61,14 @@ TicXicChromTracePlotCompositeWidget::TicXicChromTracePlotCompositeWidget(
   QWidget *parent, const QString &x_axis_label, const QString &y_axis_label)
   : BaseTracePlotCompositeWidget(parent, x_axis_label, y_axis_label)
 {
-
   setupWidget();
 }
 
-
 TicXicChromTracePlotCompositeWidget::~TicXicChromTracePlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 TicXicChromTracePlotCompositeWidget::setupWidget()
 {
@@ -81,7 +78,7 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
   /************  The QCustomPlot widget *************/
   mp_plotWidget =
     new pappso::TicXicChromTracePlotWidget(this, m_axisLabelX, m_axisLabelY);
-  m_ui.qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
+  m_ui->qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
 
   connect(mp_plotWidget,
           &pappso::TicXicChromTracePlotWidget::setFocusSignal,
@@ -115,18 +112,26 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
           this,
           &TicXicChromTracePlotCompositeWidget::plotWidgetKeyReleaseEvent);
 
-  connect(mp_plotWidget,
-          &pappso::BaseTracePlotWidget::mouseReleaseEventSignal,
+  connect(static_cast<pappso::TicXicChromTracePlotWidget *>(mp_plotWidget),
+          static_cast<void (pappso::TicXicChromTracePlotWidget::*)(
+            const pappso::BasePlotContext &)>(
+            &pappso::TicXicChromTracePlotWidget::mousePressEventSignal),
           this,
-          &TicXicChromTracePlotCompositeWidget::plotWidgetMouseReleaseEvent);
+          static_cast<void (TicXicChromTracePlotCompositeWidget::*)(
+            const pappso::BasePlotContext &)>(
+            &TicXicChromTracePlotCompositeWidget::plotWidgetMousePressEvent));
 
   // This connection might be required if the specialized tic/xic chrom plot
   // widget has some specific data to provide in the specialized context.
-  //
-  // connect(static_cast<pappso::TicXicChromTracePlotWidget *>(mp_plotWidget),
-  //&pappso::TicXicChromTracePlotWidget::mouseReleaseEventSignal,
-  // this,
-  //&TicXicChromTracePlotCompositeWidget::plotWidgetMouseReleaseEvent);
+  connect(static_cast<pappso::TicXicChromTracePlotWidget *>(mp_plotWidget),
+          static_cast<void (pappso::TicXicChromTracePlotWidget::*)(
+            const pappso::BasePlotContext &)>(
+            &pappso::TicXicChromTracePlotWidget::mouseReleaseEventSignal),
+          this,
+          static_cast<void (TicXicChromTracePlotCompositeWidget::*)(
+            const pappso::BasePlotContext &)>(
+            &TicXicChromTracePlotCompositeWidget::plotWidgetMouseReleaseEvent));
+
 
   connect(mp_plotWidget,
           &pappso::TicXicChromTracePlotWidget::plottableSelectionChangedSignal,
@@ -147,13 +152,12 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
   // The button that triggers the duplication of the trace into another trace
   // plot widget.
 
-  connect(m_ui.duplicateTracePushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->duplicateTracePushButton, &QPushButton::clicked, [this]() {
     // qDebug();
     static_cast<BaseTracePlotWnd *>(getParentWnd())->duplicateTracePlot(this);
   });
 }
 
-
 void
 TicXicChromTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
@@ -208,6 +212,23 @@ TicXicChromTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // if(context.m_pressedKeyCode == Qt::Key_Space)
 }
 
+void
+TicXicChromTracePlotCompositeWidget::plotWidgetMousePressEvent(
+  const pappso::BasePlotContext &context)
+{
+  // qDebug() << "The MassSpecTracePlotContext:" << context.toString();
+
+  BaseTracePlotCompositeWidget::plotWidgetMousePressEvent(context);
+}
+
+void
+TicXicChromTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(
+  const pappso::BasePlotContext &context)
+{
+  // qDebug() << "The BasePlotContext:" << context.toString();
+
+  BaseTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(context);
+}
 
 void
 TicXicChromTracePlotCompositeWidget::lastCursorHoveredPoint(
@@ -221,7 +242,6 @@ TicXicChromTracePlotCompositeWidget::lastCursorHoveredPoint(
   // calculations.
 }
 
-
 void
 TicXicChromTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
   const pappso::BasePlotContext &context)
@@ -231,23 +251,24 @@ TicXicChromTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
   // Modify the context to conform to the integration range that was computed
   // in the base class function.
 
-  pappso::BasePlotContext local_context = context;
-  local_context.m_xRegionRangeStart     = m_integrationRange.lower;
-  local_context.m_xRegionRangeEnd       = m_integrationRange.upper;
+  pappso::BasePlotContext local_context;
+  local_context.initialize(context);
+  local_context.m_xRegionRangeStart = m_integrationRange.lower;
+  local_context.m_xRegionRangeEnd   = m_integrationRange.upper;
 
   if(m_isSinglePointIntegrationMode)
     integrationRequested(local_context);
 }
 
-
 void
 TicXicChromTracePlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
 {
-  // qDebug().noquote() << "context:" << context.toString();
+  qDebug().noquote() << "20250904 - context:" << context.toString();
 
   // Make a local copy of the context because we may need to modify it.
-  pappso::BasePlotContext local_context = context;
+  pappso::BasePlotContext local_context;
+  local_context.initialize(context);
 
   // Check if the integration scope contains meaningful data. We are in trace
   // plot widget, so the scope might be in the form of a
@@ -255,12 +276,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   if(local_context.msp_integrationScope->is2D())
     {
-      qDebug()
-        << "Odd situation where the selection polygon is two-dimensional "
-           "and the trace plot selection is mono-dimensional. Converting "
-           "it to a 1D selection polygon.";
+      qInfo() << "Odd situation where the selection polygon is two-dimensional "
+                 "and the trace plot selection is mono-dimensional. Converting "
+                 "it to a 1D selection polygon.";
 
-      //**local_context.msp_integrationScope->convertTo1D();
       double width;
       if(!local_context.msp_integrationScope->getWidth(width))
         qFatal("Failed to get width.");
@@ -276,7 +295,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   std::const_pointer_cast<pappso::IntegrationScopeBase>(
     local_context.msp_integrationScope)
-    ->setDataKindX(pappso::DataKind::rt);
+    ->setDataKindX(pappso::Enums::DataKind::rt);
 
   // Sanity check.
 
@@ -286,11 +305,12 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   double range_end;
 
   local_context.msp_integrationScope->range(
-    pappso::Axis::x, range_start, range_end);
+    pappso::Enums::Axis::x, range_start, range_end);
 
-  // qDebug() << "integration scope:" <<
-  // local_context.msp_integrationScope->toString(); qDebug() << "X axis range:"
-  // << range_start << "-" << range_end;
+  qDebug().noquote() << "20250904 - Local copy of context:" << local_context.toString();
+
+  qDebug() << "20250904 - X axis range extracted from integration scope:"
+           << range_start << "-" << range_end;
 
   // Having negative retention times does not make any sense.
   if(range_start < 0 && range_end < 0)
@@ -331,19 +351,12 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       return;
     }
 
-  // Create a local copy of the processing flow so that we can modify it by
-  // adding the new processing step that describes what we are doing now.
-
-  // qDebug();
-
-  ProcessingFlow local_processing_flow =
-    getProcessingFlowForPlottable(plottable_p);
-
-  // qDebug() <<
-  // local_processing_flow.getMsRunDataSetCstSPtr()->getMsRunId()->getFileName();
-
-  // qDebug().noquote() << "Processing flow for graph:"
-  //<< local_processing_flow.toString();
+  // Create a temporary copy of the ProcessingFlow (with no parentship) so that
+  // we can modify it with new steps and then pass it as reference to downstream
+  // code that will allocate a fully parented instance.
+  // clone() returns heap-allocated instance.
+  ProcessingFlow *temp_processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(plottable_p)->clone(/*parent*/ nullptr);
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
@@ -362,7 +375,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // ProcessingFlow's ms fragmentation specification.
 
   MsFragmentationSpec ms_fragmentation_spec =
-    local_processing_flow.getDefaultMsFragmentationSpec();
+    temp_processing_flow_p->getDefaultMsFragmentationSpec();
 
   // Only set the ms frag spec to the processing spec if it is valid.
   if(ms_fragmentation_spec.isValid())
@@ -383,20 +396,17 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // Now make sure we document the selection polygon.
   // Now define the graph range for the integration operation.
 
-  // qDebug();
-
-  //**processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
   processing_step_sp->setIntegrationScope(local_context.msp_integrationScope);
 
-  // qDebug();
-
   // We must say what is the data source processing type.
-  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "RT");
+  processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "RT");
 
   // It is essential that we document the relation between the axes and the
   // corresponding data type.
-  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
-  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::unset);
 
   // Now handle the specific part of the ProcessingStep, that part that depends
   // on the kind of integration the user is willing to perform. Note below that
@@ -404,22 +414,22 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // mass spectra. This is because we factorize the requriement to have proper
   // mz integation params set for these integrations.
 
-  if(m_ui.integrateToRtPushButton->isChecked())
+  if(m_ui->integrateToRtPushButton->isChecked())
     {
       // qDebug() << "Integration to XIC chromatogram.";
 
       processing_step_sp->setDestProcessingType("RT");
 
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
-        ->integrateToRt(plottable_p, nullptr, local_processing_flow);
+        ->integrateToRt(plottable_p, nullptr, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToMzPushButton->isChecked() ||
-          m_ui.integrateToDtMzPushButton->isChecked() ||
-          m_ui.integrateToMzRtPushButton->isChecked())
+  else if(m_ui->integrateToMzPushButton->isChecked() ||
+          m_ui->integrateToDtMzPushButton->isChecked() ||
+          m_ui->integrateToMzRtPushButton->isChecked())
     {
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to mass spectrum.";
           processing_step_sp->setDestProcessingType("MZ");
@@ -427,133 +437,115 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
           // qDebug() << "Currently elaborating processing_step_p: "
           //<< processing_step_p->toString();
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to rt|m/z color map.";
           processing_step_sp->setDestProcessingType("MZ_RT");
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt|m/z color map.";
           processing_step_sp->setDestProcessingType("DT_MZ");
         }
 
+      // qDebug() << "The configured step:"
+      //          << processing_step_sp->toString();
+
       // At this point we need to define how the mass data integrator will
       // combine spectra, since we are integrating to a mass spectrum.
 
-      // This is a multi-layer work: the graph has a ProcessingFlow associated
-      // to it via the m_graphProcessingFlowMap. We have gotten it above.
+      // The function below will first get the potential settings that might
+      // have been stored by the user when "Set as default" is checked in the
+      // MzIntegrationParamsDlg window. If no integration settings were found,
+      // then other possibilities are tested (in particular by looking into
+      // the ProcessingFlow).
 
-      // Extract from it the default pappso::MzIntegrationParams:
+      /* Heap-allocated*/
+      pappso::MzIntegrationParams *mz_integration_params_p =
+        BasePlotCompositeWidget::getSensibleMzIntegrationParams(plottable_p);
 
-      pappso::MzIntegrationParams mz_integration_params =
-        local_processing_flow.getDefaultMzIntegrationParams();
-
-      // If it is not valid, then try mz integration params from the various
-      // steps of the flow. Preferentially the most recent ones.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
-
-          const pappso::MzIntegrationParams *mz_integration_params_p =
-            local_processing_flow.mostRecentMzIntegrationParams();
-
-          if(mz_integration_params_p != nullptr)
-            mz_integration_params = *mz_integration_params_p;
-        }
-
-      // If it is not valid, finally resort to the parameters that can be
-      // crafted on the basis of the statistical analysis of the ms run data set
-      // while it was loaded from file.
-      if(!mz_integration_params.isValid())
-        {
-          // qDebug() << "The most recent mz integ param are not valid.";
-
-          mz_integration_params =
-            ms_run_data_set_csp->craftInitialMzIntegrationParams();
-        }
-
-      if(!mz_integration_params.isValid())
-        qFatal(
-          "The mz integ params from the ms run data set stats are not valid.");
-
-      // Note that we cannot integrate mass spectra with a high resolution
-      // here. We need to reduce the resolution to integer resolution.
-      if(m_ui.integrateToDtMzPushButton->isChecked() ||
-         m_ui.integrateToMzRtPushButton->isChecked())
-        {
-          mz_integration_params.setBinningType(pappso::BinningType::NONE);
-          mz_integration_params.setDecimalPlaces(0);
-        }
+      // FIXME: this is no more correct, we now let the user define the way
+      // the integrations are performed.
+      // // Note that we cannot integrate mass spectra with a high resolution
+      // // here. We need to reduce the resolution to integer resolution.
+      // if(m_ui->integrateToDtMzPushButton->isChecked() ||
+      //    m_ui->integrateToMzRtPushButton->isChecked())
+      //   {
+      //     mz_integration_params_p->setBinningType(
+      //       pappso::MzIntegrationParams::BinningType::NONE);
+      //     mz_integration_params_p->setDecimalPlaces(0);
+      //   }
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
-      processing_step_sp->setMzIntegrationParams(mz_integration_params);
+      // Takes ownership.
+      processing_step_sp->setMzIntegrationParams(mz_integration_params_p);
 
       // And nwo add the new processing step to the local copy of the processing
       // flow, so that we document on top of all the previous steps, also this
       // last one.
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
-      // qDebug();
+      // qDebug() << "The temp processing flow with the new step:"
+      //          << temp_processing_flow_p->toString();
 
       // The local processing flow contains all the previous steps and the last
       // one that documents this current integration.
 
-      if(m_ui.integrateToMzPushButton->isChecked())
+      if(m_ui->integrateToMzPushButton->isChecked())
         {
           static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
-            ->integrateToMz(plottable_p, local_processing_flow);
+            ->integrateToMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToDtMzPushButton->isChecked())
+      else if(m_ui->integrateToDtMzPushButton->isChecked())
         {
           static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
-            ->integrateToDtMz(plottable_p, local_processing_flow);
+            ->integrateToDtMz(plottable_p, *temp_processing_flow_p);
         }
-      else if(m_ui.integrateToMzRtPushButton->isChecked())
+      else if(m_ui->integrateToMzRtPushButton->isChecked())
         {
           static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
-            ->integrateToMzRt(plottable_p, local_processing_flow);
+            ->integrateToMzRt(plottable_p, *temp_processing_flow_p);
         }
     }
-  else if(m_ui.integrateToDtPushButton->isChecked())
+  else if(m_ui->integrateToDtPushButton->isChecked())
     {
       // qDebug() << "Integrating to drift spectrum.";
 
       processing_step_sp->setDestProcessingType("DT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
-        ->integrateToDt(plottable_p, local_processing_flow);
+        ->integrateToDt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToDtRtPushButton->isChecked())
+  else if(m_ui->integrateToDtRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to dt/rt colormap.";
 
       processing_step_sp->setDestProcessingType("DT_RT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
-        ->integrateToDtRt(plottable_p, local_processing_flow);
+        ->integrateToDtRt(plottable_p, *temp_processing_flow_p);
     }
-  else if(m_ui.integrateToIntPushButton->isChecked())
+  else if(m_ui->integrateToIntPushButton->isChecked())
     {
       // qDebug() << "Integrating to TIC intensity.";
 
       processing_step_sp->setDestProcessingType("INT");
 
       // Should perform automatically the conversion from non-const to const.
-      local_processing_flow.push_back(processing_step_sp);
+      temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
+        ->integrateToTicIntensity(
+          plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -567,12 +559,11 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::NoButton);
     }
 
-  // qDebug();
+  delete temp_processing_flow_p;
 
   return;
 }
 
-
 QString
 TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
   const pappso::BasePlotContext &context)
@@ -599,10 +590,8 @@ TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
       return QString();
     }
 
-  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
-
   MsRunDataSetCstSPtr ms_run_data_set_csp =
-    processing_flow.getMsRunDataSetCstSPtr();
+    getProcessingFlowPtrForPlottable(plottable_p)->getMsRunDataSetCstSPtr();
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
 
@@ -625,8 +614,8 @@ TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
         {
           if(prevChar == '\\')
             {
-              stanza += '\\';
-              prevChar = ' ';
+              stanza   += '\\';
+              prevChar  = ' ';
               continue;
             }
           else
@@ -640,8 +629,8 @@ TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
         {
           if(prevChar == '\\')
             {
-              stanza += '%';
-              prevChar = ' ';
+              stanza   += '%';
+              prevChar  = ' ';
               continue;
             }
           else
@@ -726,8 +715,8 @@ TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
             }
           if(curChar == 'x')
             {
-              stanza += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
-              prevChar = ' ';
+              stanza   += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
+              prevChar  = ' ';
               continue;
             }
           if(curChar == 'y')
@@ -783,6 +772,5 @@ TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
 }
 
 
-} // namespace minexpert
-
+} // namespace MineXpert
 } // namespace MsXpS
