@@ -44,8 +44,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basetraceplotwidget.h>
-#include <pappsomspp/trace/trace.h>
+#include <pappsomspp/gui/plotwidget/basetraceplotwidget.h>
+#include <pappsomspp/core/trace/trace.h>
 
 
 /////////////////////// Local includes
@@ -54,7 +54,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 // The TicXicChromTracePlotCompositeWidget class is aimed at implementing TIC /
@@ -78,6 +78,12 @@ class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
   virtual void
   plotWidgetKeyPressEvent(const pappso::BasePlotContext &context) override;
 
+  virtual void
+  plotWidgetMousePressEvent(const pappso::BasePlotContext &context);
+
+  virtual void
+  plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context);
+
   virtual void moveMouseCursorToNextGraphPoint(
     const pappso::BasePlotContext &context) override;
 
@@ -92,6 +98,6 @@ class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
