@@ -46,7 +46,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 TicXicChromTracePlotWidget::TicXicChromTracePlotWidget(
@@ -57,9 +57,10 @@ TicXicChromTracePlotWidget::TicXicChromTracePlotWidget(
 
 TicXicChromTracePlotWidget::~TicXicChromTracePlotWidget()
 {
+  // qDebug();
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
