@@ -30,6 +30,7 @@
  * END software license
  */
 
+#pragma once
 
 /////////////////////// StdLib includes
 
@@ -38,14 +39,14 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/plotwidget/basetraceplotwidget.h>
+#include <pappsomspp/gui/plotwidget/basetraceplotwidget.h>
 
 /////////////////////// Local includes
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class TicXicChromTracePlotWidget : public pappso::BaseTracePlotWidget
@@ -68,6 +69,6 @@ class TicXicChromTracePlotWidget : public pappso::BaseTracePlotWidget
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
