@@ -38,8 +38,8 @@
 #include <QSettings>
 #include <QDebug>
 #include <QMainWindow>
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-#include <pappsomspp/trace/datapoint.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/trace/datapoint.h>
 
 
 /////////////////////// pappsomspp includes
@@ -50,14 +50,13 @@
 #include "ProgramWindow.hpp"
 #include "TicXicChromTracePlotWnd.hpp"
 #include "TicXicChromTracePlotCompositeWidget.hpp"
-#include <libXpertMassGui/ColorSelector.hpp>
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 int TicXicChromTracePlotWnd::widgetCount = 0;
@@ -71,13 +70,12 @@ TicXicChromTracePlotWnd::TicXicChromTracePlotWnd(QWidget *parent,
 {
 }
 
-
 //! Destruct \c this TicXicChromTracePlotWnd instance.
 TicXicChromTracePlotWnd::~TicXicChromTracePlotWnd()
 {
+  // qDebug();
 }
 
-
 QCPGraph *
 TicXicChromTracePlotWnd::addTracePlot(
   const pappso::Trace &trace,
@@ -95,19 +93,59 @@ TicXicChromTracePlotWnd::addTracePlot(
     new TicXicChromTracePlotCompositeWidget(
       this, "retention time (min)", "counts (a.u.)");
 
-    qDebug() << "The color:" << color;
+  // qDebug() << "The color:" << color;
 
   QCPGraph *new_graph_p = finalNewTracePlotConfiguration(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
 
+  // Make sure we do create a new JS item for both the plot widget and the
+  // graph.
+
+  QJSValue script_value;
+
+  static_cast<Application *>(qApp)->publishQObject(
+    dynamic_cast<QObject *>(composite_widget_p),
+    dynamic_cast<QObject *>(this),
+    script_value,
+    "plotWidget" /*name*/,
+    QString() /*alias*/,
+    "Make available the created TicXicChromTracePlot widget.\n" /*comment*/,
+    "TicXicChromTracePlot widget can plot any number of trace graphs" /*help*/,
+    "" /*tool_tip*/,
+    color,
+    QJSEngine::CppOwnership);
+
+  QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
+
+  // qDebug() << "The color:" << color;
+
+  static_cast<Application *>(qApp)->publishQObject(
+    dynamic_cast<QObject *>(new_graph_p),
+    dynamic_cast<QObject *>(composite_widget_p),
+    script_value,
+    "plotGraph" /*name*/,
+    sample_name /*alias*/,
+    "Make available the created TicXicChromTracePlot graph.\n" /*comment*/,
+    "" /*help*/,
+    QString("Graph for sample %1").arg(sample_name) /*tool_tip*/,
+    color,
+    QJSEngine::CppOwnership);
+
   return new_graph_p;
 }
 
-
 std::pair<MsRunDataSetCstSPtr, QColor>
 TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   MsRunDataSetTreeMassDataIntegratorToRt *mass_data_integrator_p)
 {
+  // qDebug();
+
+  // This place might be construed as the root of the data analysis process,
+  // because this function is called right after having loaded a mass spectrum
+  // acquisition file. This is the place some of the parameters for integration
+  // to a mass spectrum are defined depending on the fact that the user
+  // has saved such parameters as default using the QSettings feature.
+
   // We get back the integrator that was made to work in another thread. Now get
   // the obtained data and work with them.
 
@@ -116,19 +154,42 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
-  // Let's see the usage count of the MsRunDataSetCstSPtr.
-  // qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
-
   pappso::Trace integrated_trace =
     mass_data_integrator_p->getMapTrace().toTrace();
 
-  // qDebug() << "tic trace size:" << integrated_trace.size();
+  // Let's see the usage count of the MsRunDataSetCstSPtr.
+  // qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
+
+  if(!ms_run_data_set_csp->size())
+    {
+      qInfo() << "The MS run data set is empty.";
+
+      // We can double-check this:
+      if(integrated_trace.size())
+        {
+          // That's absurd, if the MS run data set is empty and we get data
+          // points, programming error.
+          qFatal("Programming error.");
+        }
+
+      // At this point, we have nothing to do. Inform the user.
+
+      QMessageBox::information(
+        this,
+        "The MS run that was to be loaded is empty.",
+        "Please, check that the file is not corrupted.\n",
+        QMessageBox::Ok);
+
+      // We have nothing to show, return.
+      return std::pair(nullptr, QColor());
+    }
+
+  // Another possibility is that there are only MSn (n>1) data in the file, in
+  // which case it is logical that the TIC trace returned by the integrator is
+  // empty. Just inform the user.
 
   if(!integrated_trace.size())
     {
-      // qDebug() << "There is not a single point in the integrated trace."
-      //"It might be that the data contain only MSn data (n > 1) ?";
-
       QMessageBox::information(
         this,
         "The TIC chromatogram has no single point in it",
@@ -146,8 +207,6 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
     }
   else if(integrated_trace.size() < 2)
     {
-
-
       // Note that if the mass data file that was loaded contained a single mass
       // spectrum, or if the integration yielded a single TIC value for a single
       // retention time, then there would be no TIC. So we need to craft a fake
@@ -173,10 +232,23 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
       // qDebug() << "tic trace:" << integrated_trace.toString();
     }
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
+  // The mass data integrator, in its constructor (MassDataIntegrator base
+  // class) allocates a new ProcessingFlow. That member is never nullptr.
 
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
+  // Do not forget to copy the processing flow from the integrator,
+  // because the integrator is the parent of that ProcessingFlow instance and it
+  // will be deleted below. This processing flow will be set into the plot
+  // widget ! Do a copy of it, without parentship (nullptr) because that copy
+  // will later be passed as a reference to downstream code that will actually
+  // allocate a new instance with proper parentship. Right after that we delete
+  // the temporary ProcessingFlow.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
+
+  qDebug()
+    << "After integrating to the first TIC chromatogram, processing flow:"
+    << temp_processing_flow_p->toString(0, "  ");
 
   // Note that we are in special situation: we are now handling a TIC
   // chromatogram that was computed as a very first integration right after
@@ -185,35 +257,26 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   // is a problem: we cannot let that MS level: 1 value there, because it will
   // prevent all the other integrations to access data with MS level > 1. We
   // thus replace that MS level to 0, that means that all the data (whatever the
-  // MS level) will be handled from there.
-
-  // ProcessingStepCstSPtr most_recent_step_csp =
-  // processing_flow.mostRecentStep();
+  // MS level) will be handled from here.
 
   ProcessingStepSPtr most_recent_step_sp =
-    std::const_pointer_cast<ProcessingStep>(processing_flow.mostRecentStep());
+    std::const_pointer_cast<ProcessingStep>(
+      temp_processing_flow_p->mostRecentStep());
 
-  // Logically, this should be the very first step in the processing flow, since
-  // this is the very first processing step that is performed when opening a
-  // data file.
+  // Logically, there should be no previous step since this should be the very
+  // first step in the processing flow right after opening a data file.
 
   if(most_recent_step_sp != nullptr)
-    qDebug() << "Odd situation that a processing step existed before now.";
+    qInfo() << "Odd situation that a processing step existed before now.";
 
   // if(most_recent_step_sp->destMatches("FILE_RT"))
   //   qFatal(
   //     "Cannot be that there are either no or more than one processing step
   //     for " "type FILE_RT");
 
-  // We need to const_cast the step in order to overwrite is
-  // MsFragmentationSpec.
   MsFragmentationSpec *fragmentation_spec_p =
     most_recent_step_sp->getMsFragmentationSpecPtr();
 
-  /*     MsFragmentationSpec *fragmentation_spec_p =
-       const_pointer_cast<ProcessingStepSPtr>(most_recent_step_sp)
-       ->getMsFragmentationSpecPtr();
-  */
   // While we had set the MS level to 1 because when computing a TIC
   // chromatogram we only do that with MS1 data, we now want to set it to 0
   // because all the later integrations need to be capable of involving any
@@ -222,10 +285,10 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   fragmentation_spec_p->setMsLevel(0);
 
   // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
     qFatal("Cannot be that the ms run data set pointers be different.");
 
-  // Finally, do not forget that we need to delete the integrator now that the
+  // Finally, we can delete the integrator, now that the
   // calculation is finished.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
@@ -247,15 +310,26 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   // parameters that were calculated while loading the ms run from file are
   // available for the very first integration to mz that might occur.
 
-  // Immediately set the default mz integration params to the local copy of the
-  // processing flow that we'll use later to craft the plot widget.
+  // All this is handled by the ProcessingFlow:
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    temp_processing_flow_p->getSensibleMzIntegrationParams();
 
-  processing_flow.setDefaultMzIntegrationParams(
-    ms_run_data_set_csp->craftInitialMzIntegrationParams());
+  // Finally, set it.
+  temp_processing_flow_p->setDefaultMzIntegrationParams(
+    *mz_integration_params_p);
 
-  // qDebug().noquote()
-  //<< "Default mz integration parameters:"
-  //<< processing_flow.getDefaultMzIntegrationParams().toString();
+  delete mz_integration_params_p;
+
+#ifndef NDEBUG
+  mz_integration_params_p =
+    temp_processing_flow_p->getDefaultMzIntegrationParams();
+  // We have set them above, they must be found!
+  Q_ASSERT(mz_integration_params_p);
+  qDebug().noquote()
+    << "The mz integration params set to the processing flow:\n"
+    << mz_integration_params_p->toString(0, "  ");
+#endif
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   //	qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
@@ -267,15 +341,16 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
 
   addTracePlot(integrated_trace,
                ms_run_data_set_csp,
-               processing_flow,
+               *temp_processing_flow_p,
                plot_color,
                nullptr);
 
+  delete temp_processing_flow_p;
+
   return std::pair<MsRunDataSetCstSPtr, QColor>(ms_run_data_set_csp,
                                                 plot_color);
 }
 
-
 void
 TicXicChromTracePlotWnd::integrateToRt(
   QCPAbstractPlottable *parent_plottable_p,
@@ -298,14 +373,16 @@ TicXicChromTracePlotWnd::integrateToRt(
   if(!integration_rt)
     qFatal("Programming error.");
 
-  qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
-           << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
+  //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  //
+  // if(integration_dt)
+  //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
+  //            << "for y axis: " << range_pair.first << "-" <<
+  //            range_pair.second;
 
-  if(integration_dt)
-    qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-             << "for y axis: " << range_pair.first << "-" << range_pair.second;
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
 
@@ -317,9 +394,10 @@ TicXicChromTracePlotWnd::integrateToRt(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  qDebug()
-    << "The number of selected mass spectra on the basis of rough RT/DT values:"
-    << qualified_mass_spectra_count;
+  // qDebug()
+  //   << "The number of selected mass spectra on the basis of rough RT/DT
+  //   values:"
+  //   << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -469,7 +547,6 @@ TicXicChromTracePlotWnd::integrateToRt(
                &MassDataIntegratorTask::integrateToRt));
 }
 
-
 void
 TicXicChromTracePlotWnd::finishedIntegratingToRt(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
@@ -483,18 +560,33 @@ TicXicChromTracePlotWnd::finishedIntegratingToRt(
   // We get back the integrator that was made to work in another thread. Now get
   // the obtained data and work with them.
 
+  // Make sure we make a copy of the ProcessingFlow stored in the
+  // mass data integrator, because that ProcessingFlow is owned by the
+  // mass data integrator and the latter will be destroyed below. We can make
+  // the copy without parentship because we'll pass it as reference to
+  // downstream code that will use that ref to allocate a new fully parented
+  // instance.
+
+  ProcessingFlow *temp_processing_flow_p =
+    mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
+
   // Store the MsRunDataSetSPtr for later use before deleting the integrattor.
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
 
+  // Sanity check
+  if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
+    qFatal() << "Programming error. Not possible that the MsRunDataSet "
+                "pointers do not match.";
+
   pappso::Trace integrated_trace =
     mass_data_integrator_p->getMapTrace().toTrace();
   // qDebug() << "mass spectrum trace size:" << integrated_trace.size();
 
   if(!integrated_trace.size())
     {
-      qDebug() << "There is not a single point in the integrated trace.";
+      qInfo() << "There is not a single point in the integrated trace.";
       return;
     }
 
@@ -526,17 +618,9 @@ TicXicChromTracePlotWnd::finishedIntegratingToRt(
       // qDebug() << "tic trace:" << integrated_trace.toString();
     }
 
-  // Also, do not forget to copy the processing flow from the integrator. This
-  // processing flow will be set into the plot widget !
 
-  ProcessingFlow processing_flow = mass_data_integrator_p->getProcessingFlow();
-
-  // Sanity check
-  if(ms_run_data_set_csp != processing_flow.getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
-
-  // Finally, do not forget that we need to delete the integrator now that the
-  // calculation is finished.
+  // Now that we got all we need and that we have made a safe copy
+  // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
   mass_data_integrator_p = nullptr;
 
@@ -560,7 +644,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToRt(
 
   newTrace(integrated_trace,
            ms_run_data_set_csp,
-           processing_flow,
+           *temp_processing_flow_p,
            plot_color,
            static_cast<QCPGraph *>(parent_plottable_p));
 
@@ -572,8 +656,9 @@ TicXicChromTracePlotWnd::finishedIntegratingToRt(
     {
       showWindow();
     }
-}
 
+  delete temp_processing_flow_p;
+}
 
 void
 TicXicChromTracePlotWnd::integrateToMz(QCPAbstractPlottable *parent_plottable_p,
@@ -586,13 +671,13 @@ TicXicChromTracePlotWnd::integrateToMz(QCPAbstractPlottable *parent_plottable_p,
   // handles their own data. So we just relay this call to the main program
   // window that will in turn relay it to the mass spec plot window.
 
-  // qDebug().noquote() << "Integrating to mz for graph with processing flow:"
-  //<< processing_flow.toString();
+  // qDebug().noquote()
+  //   << "Integrating to mz for graph with processing flow:"
+  //   << processing_flow.toString();
 
   mp_programWindow->integrateToMz(parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 TicXicChromTracePlotWnd::integrateToDt(QCPAbstractPlottable *parent_plottable_p,
                                        const ProcessingFlow &processing_flow)
@@ -607,7 +692,6 @@ TicXicChromTracePlotWnd::integrateToDt(QCPAbstractPlottable *parent_plottable_p,
   mp_programWindow->integrateToDt(parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 TicXicChromTracePlotWnd::integrateToDtMz(
   QCPAbstractPlottable *parent_plottable_p,
@@ -624,7 +708,6 @@ TicXicChromTracePlotWnd::integrateToDtMz(
     parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 TicXicChromTracePlotWnd::integrateToMzRt(
   QCPAbstractPlottable *parent_plottable_p,
@@ -637,7 +720,6 @@ TicXicChromTracePlotWnd::integrateToMzRt(
     parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 TicXicChromTracePlotWnd::integrateToDtRt(
   QCPAbstractPlottable *parent_plottable_p,
@@ -651,6 +733,6 @@ TicXicChromTracePlotWnd::integrateToDtRt(
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
