@@ -52,7 +52,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProcessingFlow;
@@ -81,8 +81,7 @@ class TicXicChromTracePlotWnd : public BaseTracePlotWnd
 
   void integrateToRt(
     QCPAbstractPlottable *plottable_p,
-    std::shared_ptr<QualifiedMassSpectraVector>
-      qualified_mass_spectra_sp,
+    std::shared_ptr<QualifiedMassSpectraVector> qualified_mass_spectra_sp,
     const ProcessingFlow &processing_flow);
 
   void integrateToMz(QCPAbstractPlottable *plottable_p,
@@ -129,6 +128,6 @@ class TicXicChromTracePlotWnd : public BaseTracePlotWnd
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
