@@ -41,81 +41,77 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/integrationscopebase.h>
-#include <pappsomspp/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/core/processing/combiners/integrationscopebase.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperect.h>
 
 
 /////////////////////// Local includes
 #include "../nongui/globals.hpp"
-#include "XicExtractionWnd.hpp"
-#include "ProgramWindow.hpp"
 #include "Application.hpp"
-
+#include "ProgramWindow.hpp"
+#include "XicExtractionWnd.hpp"
+#include "ui_XicExtractionWnd.h"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 XicExtractionWnd::XicExtractionWnd(ProgramWindow *program_window_p,
                                    const QString &title,
                                    const QString &settings_title)
   : QMainWindow(dynamic_cast<QWidget *>(program_window_p)),
     mp_programWindow(program_window_p),
     m_title(title),
-    m_settingsTitle(settings_title)
+    m_settingsTitle(settings_title),
+    m_ui(new ::Ui::XicExtractionWnd)
 {
   // qDebug();
 
   if(program_window_p == nullptr)
     qFatal("Pointer cannot be nullptr.");
 
-  m_ui.setupUi(this);
+  m_ui->setupUi(this);
 
   initialize();
 }
 
-
 XicExtractionWnd::~XicExtractionWnd()
 {
   writeSettings();
 }
 
-
 void
 XicExtractionWnd::initialize()
 {
   // The precision widget required to specify the precursor m/z values
   // search tolerance.
   mp_precisionWidget = new pappso::PrecisionWidget(this);
-  m_ui.precisionWidgetHorizontalLayout->addWidget(mp_precisionWidget);
+  m_ui->precisionWidgetHorizontalLayout->addWidget(mp_precisionWidget);
   mp_precisionWidget->setToolTip(
     "Set the tolerance with which the m/z value match is performed.");
 
   connect(mp_precisionWidget,
           &pappso::PrecisionWidget::precisionChanged,
           [this](pappso::PrecisionPtr precision_p) {
-            qDebug();
             mp_precision = precision_p;
           });
 
-  connect(m_ui.runPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->runPushButton, &QPushButton::clicked, [this]() {
     runPushButtonClicked();
   });
 
-  connect(m_ui.abortPushButton,
+  connect(m_ui->abortPushButton,
           &QPushButton::clicked,
           this,
           &XicExtractionWnd::abortPushButtonClicked);
 
-  connect(m_ui.closePushButton,
+  connect(m_ui->closePushButton,
           &QPushButton::clicked,
           this,
           &XicExtractionWnd::closePushButtonClicked);
 }
 
-
 void
 XicExtractionWnd::readSettings()
 {
@@ -133,7 +129,6 @@ XicExtractionWnd::readSettings()
   settings.endGroup();
 }
 
-
 void
 XicExtractionWnd::writeSettings()
 {
@@ -149,11 +144,10 @@ XicExtractionWnd::writeSettings()
   settings.endGroup();
 }
 
-
 void
 XicExtractionWnd::runPushButtonClicked()
 {
-  QString all_mz_values = m_ui.mzValuesPlainTextEdit->toPlainText();
+  QString all_mz_values = m_ui->mzValuesPlainTextEdit->toPlainText();
   // qDebug() << "All the m/z values:" << all_mz_values;
   QStringList all_mz_values_string_list =
     all_mz_values.split(QRegularExpression("\\s+"), Qt::SkipEmptyParts);
@@ -222,19 +216,26 @@ XicExtractionWnd::runPushButtonClicked()
     {
       for(auto mz_range : mz_ranges)
         {
-          ProcessingFlow processing_flow(ms_run_data_set_csp);
+
+          // Create a temporary instance of the ProcessingFlow (with no
+          // parentship) so that we can modify it with new steps and then pass
+          // it as reference to downstream code that will allocate a fully
+          // parented instance. We'll delete that temporary instance.
+
+          ProcessingFlow *temp_processing_flow_p =
+            new ProcessingFlow(ms_run_data_set_csp, nullptr);
 
           ProcessingStepSPtr processing_step_sp =
             std::make_shared<ProcessingStep>();
 
-          processing_step_sp->setSrcProcessingType(pappso::Axis::x, "RT");
-          processing_step_sp->setSrcProcessingType(pappso::Axis::y,
+          processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "RT");
+          processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::y,
                                                    "DATA_XIC_MZ");
 
-          processing_step_sp->setDataKind(pappso::Axis::x,
-                                          pappso::DataKind::rt);
-          processing_step_sp->setDataKind(pappso::Axis::y,
-                                          pappso::DataKind::mz);
+          processing_step_sp->setDataKind(pappso::Enums::Axis::x,
+                                          pappso::Enums::DataKind::rt);
+          processing_step_sp->setDataKind(pappso::Enums::Axis::y,
+                                          pappso::Enums::DataKind::mz);
 
           double rt_start = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
                               ->getRootNodes()
@@ -266,9 +267,12 @@ XicExtractionWnd::runPushButtonClicked()
 
           // Should perform automatically the conversion from non-const to
           // const.
-          processing_flow.push_back(processing_step_sp);
+          temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
-          mp_programWindow->integrateToRt(nullptr, nullptr, processing_flow);
+          mp_programWindow->integrateToRt(
+            nullptr, nullptr, *temp_processing_flow_p);
+
+          delete temp_processing_flow_p;
         }
       // End of
       // for(auto mz_range : mz_ranges)
@@ -279,18 +283,16 @@ XicExtractionWnd::runPushButtonClicked()
   return;
 }
 
-
 void
 XicExtractionWnd::closePushButtonClicked()
 {
   QMainWindow::close();
 }
 
-
 void
 XicExtractionWnd::abortPushButtonClicked()
 {
-  qDebug() << "emit cancelOperationSignal();";
+  // qDebug() << "emit cancelOperationSignal();";
   emit cancelOperationSignal();
 }
 
@@ -303,6 +305,6 @@ XicExtractionWnd::showWindow()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
