@@ -42,19 +42,21 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/precisionwidget/precisionwidget.h>
-
+#include <pappsomspp/gui/precisionwidget/precisionwidget.h>
 
 /////////////////////// Local includes
-#include "ui_XicExtractionWnd.h"
 
 
+namespace Ui
+{
+class XicExtractionWnd;
+}
+
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-
 class ProgramWindow;
 
 //! The XicExtractionWnd class provides an interface to the XIC extraction
@@ -92,8 +94,6 @@ class XicExtractionWnd : public QMainWindow
   void cancelOperationSignal();
 
   protected:
-  Ui::XicExtractionWnd m_ui;
-
   private:
   ProgramWindow *mp_programWindow = nullptr;
   pappso::PrecisionPtr mp_precision =
@@ -103,10 +103,12 @@ class XicExtractionWnd : public QMainWindow
   QString m_title;
   QString m_settingsTitle;
 
+  ::Ui::XicExtractionWnd *m_ui;
+
   void initialize();
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
