@@ -50,7 +50,7 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msfile/msfileaccessor.h>
 
 /////////////////////// Local includes
 #include "XyMsRunLoader.hpp"
@@ -59,18 +59,18 @@
 
 
 int XyMsRunLoaderMetaTypeId =
-  qRegisterMetaType<MsXpS::minexpert::XyMsRunLoader>(
-    "MsXpS::minexpert::XyMsRunLoader");
+  qRegisterMetaType<MsXpS::MineXpert::XyMsRunLoader>(
+    "MsXpS::MineXpert::XyMsRunLoader");
 
 int XyMsRunLoaderSPtrMetaTypeId =
-  qRegisterMetaType<MsXpS::minexpert::XyMsRunLoaderSPtr>(
-    "MsXpS::minexpert::XyMsRunLoaderSPtr");
+  qRegisterMetaType<MsXpS::MineXpert::XyMsRunLoaderSPtr>(
+    "MsXpS::MineXpert::XyMsRunLoaderSPtr");
 
 
 namespace MsXpS
 {
 
-namespace minexpert
+namespace MineXpert
 {
 
 XyMsRunLoader::XyMsRunLoader(ProgramWindow *program_window_p,
@@ -82,7 +82,6 @@ XyMsRunLoader::XyMsRunLoader(ProgramWindow *program_window_p,
 
 XyMsRunLoader::~XyMsRunLoader()
 {
-  qDebug();
 }
 
 void
@@ -127,7 +126,7 @@ XyMsRunLoader::readMsRun(pappso::MsRunReadConfig ms_run_read_config,
                << base_file_name;
     }
 
-  qDebug().noquote() << "The run id as text:" << ms_run_id_csp->toString();
+  // qDebug().noquote() << "The run id as text:" << ms_run_id_csp->toString();
 
   MassSpecDataFileLoaderSPtr loader_sp =
     std::make_shared<MassSpecDataFileLoader>(msp_msFileAccessor->getFileName(),
@@ -195,8 +194,8 @@ XyMsRunLoader::readMsRun(pappso::MsRunReadConfig ms_run_read_config,
   // Inform the loader that the mass spec data is there.
   loader_sp->setMsRunDataSet(ms_run_data_set_sp);
 
-  qRegisterMetaType<MsXpS::minexpert::MsRunDataSetSPtr>(
-    "MsXpS::minexpert::MsRunDataSetSPtr");
+  qRegisterMetaType<MsXpS::MineXpert::MsRunDataSetSPtr>(
+    "MsXpS::MineXpert::MsRunDataSetSPtr");
 
   qRegisterMetaType<MsRunDataSetSPtr>("MsRunDataSetSPtr");
 
@@ -239,8 +238,8 @@ XyMsRunLoader::readMsRun(pappso::MsRunReadConfig ms_run_read_config,
             thread_p->wait();
           });
 
-  qDebug() << "Emitting readMsRunDataSignal(ms_run_read_task_p, "
-              "ms_run_reader_sp, loader_sp)";
+  // qDebug() << "Emitting readMsRunDataSignal(ms_run_read_task_p, "
+  //             "ms_run_reader_sp, loader_sp)";
 
   emit readMsRunDataSignal(
     ms_run_read_task_p, ms_run_reader_sp, ms_run_read_config, loader_sp);
@@ -253,9 +252,8 @@ void
 XyMsRunLoader::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp,
                                         double duration_seconds)
 {
-
-  qDebug() << "Finished reading ms run data for sample name:"
-           << ms_run_data_set_sp->getMsRunId()->getSampleName();
+  // qDebug() << "Finished reading ms run data for sample name:"
+  //          << ms_run_data_set_sp->getMsRunId()->getSampleName();
 
   std::chrono::duration<long double> duration_in_seconds(duration_seconds);
 
@@ -339,6 +337,6 @@ XyMsRunLoader::loadMsRun([[maybe_unused]] bool full_in_memory)
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
