@@ -43,7 +43,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msfile/msfileaccessor.h>
+#include <pappsomspp/core/msfile/msfileaccessor.h>
 
 
 /////////////////////// Local includes
@@ -59,7 +59,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class XyMsRunLoader : public MsRunLoader
@@ -67,9 +67,8 @@ class XyMsRunLoader : public MsRunLoader
   Q_OBJECT
 
   public:
-  explicit XyMsRunLoader(
-    ProgramWindow *program_window_p,
-    pappso::MsFileAccessorSPtr ms_file_accessor_sp);
+  explicit XyMsRunLoader(ProgramWindow *program_window_p,
+                         pappso::MsFileAccessorSPtr ms_file_accessor_sp);
   virtual ~XyMsRunLoader();
 
   void probeMsRun(bool full_in_memory = false);
@@ -94,13 +93,13 @@ class XyMsRunLoader : public MsRunLoader
 
 typedef std::shared_ptr<XyMsRunLoader> XyMsRunLoaderSPtr;
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::XyMsRunLoader)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::XyMsRunLoader)
 extern int XyMsRunLoaderMetaTypeId;
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::XyMsRunLoaderSPtr)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::XyMsRunLoaderSPtr)
 extern int XyMsRunLoaderSPtrMetaTypeId;
