@@ -46,67 +46,68 @@
 #include "ProcessingStep.hpp"
 #include <cmath>
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
+BaseMsRunDataSetTreeNodeVisitor::BaseMsRunDataSetTreeNodeVisitor(
+  QObject *parent)
+  : QObject(parent),
+    mp_processingFlow(new ProcessingFlow(dynamic_cast<QObject *>(this)))
+{
+}
 
 BaseMsRunDataSetTreeNodeVisitor::BaseMsRunDataSetTreeNodeVisitor(
   MsRunDataSetCstSPtr ms_run_data_set_csp,
-  const ProcessingFlow &processing_flow)
-  : mcsp_msRunDataSet(ms_run_data_set_csp), m_processingFlow(processing_flow)
+  const ProcessingFlow &processing_flow,
+  QObject *parent)
+  : QObject(parent),
+    mcsp_msRunDataSet(ms_run_data_set_csp),
+    mp_processingFlow(processing_flow.clone(dynamic_cast<QObject *>(this)))
 {
   // qDebug() << "Going to call setInnermostRanges().";
   setInnermostRanges();
 }
 
-
-BaseMsRunDataSetTreeNodeVisitor::BaseMsRunDataSetTreeNodeVisitor(
-  const BaseMsRunDataSetTreeNodeVisitor &other)
-  : QObject(),
-    mcsp_msRunDataSet(other.mcsp_msRunDataSet),
-    m_processingFlow(other.m_processingFlow),
-    m_dtRange(other.m_dtRange),
-    m_mzRange(other.m_mzRange),
-    m_rtRange(other.m_rtRange)
-{
-}
-
 BaseMsRunDataSetTreeNodeVisitor::~BaseMsRunDataSetTreeNodeVisitor()
 {
 }
 
+void
+BaseMsRunDataSetTreeNodeVisitor::setMsRunDataSet(
+  MsRunDataSetCstSPtr ms_run_data_set_csp)
+{
+  mcsp_msRunDataSet = ms_run_data_set_csp;
+}
 
 void
 BaseMsRunDataSetTreeNodeVisitor::setProcessingFlow(
   const ProcessingFlow &processing_flow)
 {
-  m_processingFlow = processing_flow;
+  mp_processingFlow = processing_flow.clone(dynamic_cast<QObject *>(this));
 
   // qDebug() << "Going to call setInnermostRanges().";
   setInnermostRanges();
 }
 
-
-BaseMsRunDataSetTreeNodeVisitor &
-BaseMsRunDataSetTreeNodeVisitor::operator=(
-  const BaseMsRunDataSetTreeNodeVisitor &other)
+const ProcessingFlow &
+BaseMsRunDataSetTreeNodeVisitor::getProcessingFlowCstRef() const
 {
-  if(this == &other)
-    return *this;
-
-  mcsp_msRunDataSet = other.mcsp_msRunDataSet;
-  m_processingFlow  = other.m_processingFlow;
-
-  m_dtRange = other.m_dtRange;
-  m_rtRange = other.m_rtRange;
-  m_mzRange = other.m_mzRange;
-
-  return *this;
+  return *mp_processingFlow;
 }
 
+ProcessingFlow &
+BaseMsRunDataSetTreeNodeVisitor::getProcessingFlowRef()
+{
+  return *mp_processingFlow;
+}
+
+ProcessingFlow *
+BaseMsRunDataSetTreeNodeVisitor::getProcessingFlowPtr()
+{
+  return mp_processingFlow;
+}
 
 pappso::QualifiedMassSpectrumCstSPtr
 BaseMsRunDataSetTreeNodeVisitor::checkQualifiedMassSpectrum(
@@ -153,7 +154,6 @@ BaseMsRunDataSetTreeNodeVisitor::checkQualifiedMassSpectrum(
   return qualified_mass_spectrum_csp;
 }
 
-
 bool
 BaseMsRunDataSetTreeNodeVisitor::checkMsLevel(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -176,7 +176,7 @@ BaseMsRunDataSetTreeNodeVisitor::checkMsLevel(
   // the processing flow. We are not going going to accept a mass spectrum with
   // a differing MS level.
 
-  std::size_t greatest_ms_level = m_processingFlow.greatestMsLevel();
+  std::size_t greatest_ms_level = mp_processingFlow->greatestMsLevel();
 
   // qDebug().noquote() << "Greatest ms level in the processing flow:"
   //<< greatest_ms_level;
@@ -215,7 +215,6 @@ BaseMsRunDataSetTreeNodeVisitor::checkMsLevel(
   return true;
 }
 
-
 void
 BaseMsRunDataSetTreeNodeVisitor::setInnermostRanges()
 {
@@ -252,7 +251,7 @@ BaseMsRunDataSetTreeNodeVisitor::setInnermostRanges()
 
   // true: only 2D steps
   // true: only skewed 2D steps
-  if(m_processingFlow.innermostRange("ANY_DT", range_pair))
+  if(mp_processingFlow->innermostRange("ANY_DT", range_pair))
     {
       // qDebug() << "innermost DT range:" << range_pair.first << "-"
       //<< range_pair.second;
@@ -266,7 +265,7 @@ BaseMsRunDataSetTreeNodeVisitor::setInnermostRanges()
 
   // true: only 2D steps
   // true: only skewed 2D steps
-  if(m_processingFlow.innermostRange("ANY_MZ", range_pair))
+  if(mp_processingFlow->innermostRange("ANY_MZ", range_pair))
     {
       // qDebug() << "innermost MZ range:" << range_pair.first << "-"
       //<< range_pair.second;
@@ -280,7 +279,7 @@ BaseMsRunDataSetTreeNodeVisitor::setInnermostRanges()
 
   // true: only 2D steps
   // true: only skewed 2D steps
-  if(m_processingFlow.innermostRange("ANY_RT", range_pair))
+  if(mp_processingFlow->innermostRange("ANY_RT", range_pair))
     {
       // qDebug() << "innermost RT range:" << range_pair.first << "-"
       //<< range_pair.second;
@@ -300,7 +299,6 @@ BaseMsRunDataSetTreeNodeVisitor::setInnermostRanges()
     }
 }
 
-
 bool
 BaseMsRunDataSetTreeNodeVisitor::checkDtRange(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -330,12 +328,12 @@ BaseMsRunDataSetTreeNodeVisitor::checkDtRange(
   // Get the format of the file, because that will condition the
   // way we provide mobility values.
 
-  pappso::MsDataFormat file_format =
+  pappso::Enums::MsDataFormat file_format =
     qualified_mass_spectrum_csp->getMassSpectrumId()
       .getMsRunIdCstSPtr()
       ->getMsDataFormat();
 
-  if(file_format == pappso::MsDataFormat::brukerTims)
+  if(file_format == pappso::Enums::MsDataFormat::brukerTims)
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
@@ -377,7 +375,6 @@ BaseMsRunDataSetTreeNodeVisitor::checkDtRange(
   return true;
 }
 
-
 bool
 BaseMsRunDataSetTreeNodeVisitor::checkRtRange(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -401,7 +398,6 @@ BaseMsRunDataSetTreeNodeVisitor::checkRtRange(
   return true;
 }
 
-
 void
 BaseMsRunDataSetTreeNodeVisitor::cancelOperation()
 {
@@ -411,7 +407,6 @@ BaseMsRunDataSetTreeNodeVisitor::cancelOperation()
   //"m_isOperationCancelled to true.";
 }
 
-
 void
 BaseMsRunDataSetTreeNodeVisitor::setNodesToProcessCount(
   std::size_t nodes_to_process)
@@ -428,7 +423,6 @@ BaseMsRunDataSetTreeNodeVisitor::setNodesToProcessCount(
   emit incrementProgressBarMaxValueSignal(nodes_to_process);
 }
 
-
 bool
 BaseMsRunDataSetTreeNodeVisitor::shouldStop() const
 {
@@ -437,20 +431,18 @@ BaseMsRunDataSetTreeNodeVisitor::shouldStop() const
   return m_isOperationCancelled;
 }
 
-
 void
 BaseMsRunDataSetTreeNodeVisitor::silenceFeedback(bool silence_feedback)
 {
   m_isProgressFeedbackSilenced = silence_feedback;
 }
 
-
 bool
 BaseMsRunDataSetTreeNodeVisitor::shouldSilenceFeedback()
 {
   return m_isProgressFeedbackSilenced;
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
