@@ -45,13 +45,13 @@
 
 
 int massSpecDataFileLoaderSPtrMetaTypeId =
-  qRegisterMetaType<MsXpS::minexpert::MassSpecDataFileLoaderSPtr>(
-    "MsXpS::minexpert::MassSpecDataFileLoaderSPtr");
+  qRegisterMetaType<MsXpS::MineXpert::MassSpecDataFileLoaderSPtr>(
+    "MsXpS::MineXpert::MassSpecDataFileLoaderSPtr");
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -271,5 +271,5 @@ MassSpecDataFileLoader::loadingEnded()
   // qDebug() << "Loading ended !";
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
