@@ -46,8 +46,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msrun/msrunreader.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/msrun/msrunreader.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -56,7 +56,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -162,9 +162,9 @@ typedef std::shared_ptr<MassSpecDataFileLoader> MassSpecDataFileLoaderSPtr;
 typedef std::shared_ptr<const MassSpecDataFileLoader>
   MassSpecDataFileLoaderCstSPtr;
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::MassSpecDataFileLoaderSPtr)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::MassSpecDataFileLoaderSPtr)
 extern int massSpecDataFileLoaderSPtrMetaTypeId;
