@@ -34,8 +34,8 @@
 #include <QObject>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/exception/exceptionnotfound.h>
-#include <pappsomspp/msrun/spectrumcollectionhandlerinterface.h>
+#include <pappsomspp/core/exception/exceptionnotfound.h>
+#include <pappsomspp/core/msrun/spectrumcollectionhandlerinterface.h>
 
 
 /////////////////////// Local includes
@@ -44,7 +44,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -86,7 +86,7 @@ MassSpecDataFileLoaderToVector::setQualifiedMassSpectrum(
   // needPeakList set to false (not reading mass spectra from file, thus
   // not having mass spectral data, thus having mass spectrum nullptr.)
   // if(qualified_mass_spectrum.getMassSpectrumCstSPtr() == nullptr)
-    // qFatal("The mass spectrum is nullptr.");
+  // qFatal("The mass spectrum is nullptr.");
 
   m_qualifiedMassSpectra.push_back(qualified_mass_spectrum);
 }
@@ -122,6 +122,6 @@ MassSpecDataFileLoaderToVector::loadingEnded()
   // qDebug() << "Loading ended !";
 }
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
