@@ -44,7 +44,7 @@
 #include <QMap>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/trace/maptrace.h>
+#include <pappsomspp/core/trace/maptrace.h>
 
 
 /////////////////////// Local includes
@@ -52,7 +52,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -97,7 +97,8 @@ class MassSpecDataFileLoaderToVector
   public slots:
   void cancelOperation();
 
-  const std::vector<pappso::QualifiedMassSpectrum> &getQualifiedMassSpectra() const;
+  const std::vector<pappso::QualifiedMassSpectrum> &
+  getQualifiedMassSpectra() const;
 
   void clearMassSpectra();
 
@@ -142,6 +143,6 @@ typedef std::shared_ptr<const MassSpecDataFileLoaderToVector>
   MassSpecDataFileLoaderToVectorCstSPtr;
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
