@@ -39,23 +39,23 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/msrun/msrundatasettreenode.h>
-#include <pappsomspp/msrun/msrundatasettreevisitor.h>
-#include <pappsomspp/trace/maptrace.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/msrun/msrundatasettreenode.h>
+#include <pappsomspp/core/msrun/msrundatasettreevisitor.h>
+#include <pappsomspp/core/trace/maptrace.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
 #include "ProcessingFlow.hpp"
 #include "MsRunDataSet.hpp"
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class MassDataIntegrator;
@@ -135,6 +135,6 @@ class MassSpectrumTreeNodeCombinerVisitor
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
