@@ -39,7 +39,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
 
 
 /////////////////////// Local includes
@@ -48,7 +48,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -391,6 +391,6 @@ MsFragmentationSpec::toString(int offset, const QString &spacer) const
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
