@@ -45,8 +45,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/widget/precisionwidget/precisionwidget.h>
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/gui/precisionwidget/precisionwidget.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
 
 
 /////////////////////// Local includes
@@ -54,7 +54,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProcessingSpec;
@@ -113,6 +113,6 @@ class MsFragmentationSpec
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
