@@ -48,7 +48,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -788,5 +788,5 @@ MsRunDataSetStats::toString() const
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
