@@ -48,9 +48,9 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/integrationscope.h>
-#include <pappsomspp/trace/maptrace.h>
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/integrationscope.h>
+#include <pappsomspp/core/trace/maptrace.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -63,75 +63,61 @@
 #include "MsRunStatisticsTreeNodeVisitor.hpp"
 #include "MultiTreeNodeCombinerVisitor.hpp"
 
-
-int msRunDataSetTreeMassDataIntegratorToRtMetaTypeId =
-  qRegisterMetaType<MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRt>(
-    "MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRt");
-
-int msRunDataSetTreeMassDataIntegratorToRtSPtrMetaTypeId = qRegisterMetaType<
-  MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr>(
-  "MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr");
-
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
-MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt()
-  : MassDataIntegrator()
-{
-}
-
-
 MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
-  MsRunDataSetCstSPtr ms_run_data_set_csp)
-  : MassDataIntegrator(ms_run_data_set_csp)
+  QObject *parent)
+  : MassDataIntegrator(parent)
 {
-  // Essential that the m_processingFlow member is configured to have the right
-  // pointer to the ms run data set.
-
-  m_processingFlow.setMsRunDataSetCstSPtr(ms_run_data_set_csp);
 }
 
+MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
+  MsRunDataSetCstSPtr ms_run_data_set_csp, QObject *parent)
+  : MassDataIntegrator(ms_run_data_set_csp, parent)
+{
+  // Essential that the mp_processingFlow member is configured to have the right
+  // pointer to the ms run data set.
+
+  mp_processingFlow->setMsRunDataSetCstSPtr(ms_run_data_set_csp);
+}
 
 MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
   MsRunDataSetCstSPtr ms_run_data_set_csp,
-  const ProcessingFlow &processing_flow)
-  : MassDataIntegrator(ms_run_data_set_csp, processing_flow)
+  const ProcessingFlow &processing_flow,
+  QObject *parent)
+  : MassDataIntegrator(ms_run_data_set_csp, processing_flow, parent)
 {
-  // Essential that the m_processingFlow member is configured to have the right
+  // Essential that the mp_processingFlow member is configured to have the right
   // pointer to the ms run data set.
-  if(ms_run_data_set_csp != m_processingFlow.getMsRunDataSetCstSPtr())
+  if(ms_run_data_set_csp != mp_processingFlow->getMsRunDataSetCstSPtr())
     qFatal("The pointers should be identical.");
 }
 
-
-MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
-  const MsRunDataSetTreeMassDataIntegratorToRt &other)
-  : MassDataIntegrator(other.mcsp_msRunDataSet, other.m_processingFlow)
-{
-  // Essential that the m_processingFlow member is configured to have the right
-  // pointer to the ms run data set.
-  if(other.mcsp_msRunDataSet != m_processingFlow.getMsRunDataSetCstSPtr())
-    qFatal("The pointers should be identical.");
-}
-
-
 MsRunDataSetTreeMassDataIntegratorToRt::
   ~MsRunDataSetTreeMassDataIntegratorToRt()
 {
   // qDebug() << "Destroying integrator:" << this;
 }
 
-
-ProcessingFlow
-MsRunDataSetTreeMassDataIntegratorToRt::getProcessingFlow() const
+MassDataIntegrator *
+MsRunDataSetTreeMassDataIntegratorToRt::clone(QObject *parent) const
 {
-  return m_processingFlow;
-}
+  MsRunDataSetTreeMassDataIntegratorToRt *copy =
+    new MsRunDataSetTreeMassDataIntegratorToRt(
+      mcsp_msRunDataSet, *mp_processingFlow, parent);
 
+  copy->m_mapTrace              = m_mapTrace;
+  copy->m_doubleMapTraceMapSPtr = m_doubleMapTraceMapSPtr;
+  copy->m_isOperationCancelled  = m_isOperationCancelled;
+
+  copy->m_msRunDataSetStats = m_msRunDataSetStats;
+
+  return copy;
+}
 
 const MsRunDataSetStats &
 MsRunDataSetTreeMassDataIntegratorToRt::getMsRunDataSetStats() const
@@ -139,11 +125,13 @@ MsRunDataSetTreeMassDataIntegratorToRt::getMsRunDataSetStats() const
   return m_msRunDataSetStats;
 }
 
-
 void
 MsRunDataSetTreeMassDataIntegratorToRt::
   seedInitialTicChromatogramAndMsRunDataSetStatistics()
 {
+  qDebug() << "From thread" << QThread::currentThreadId()
+           << "starting the calculation.";
+
   std::chrono::system_clock::time_point chrono_start_time =
     std::chrono::system_clock::now();
 
@@ -195,7 +183,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::
 
   pappso::IntegrationScopeCstSPtr integration_scope_csp =
     std::make_shared<const pappso::IntegrationScope>(
-      QPointF(range_start, 0), range_end - range_start, pappso::DataKind::rt);
+      QPointF(range_start, 0), range_end - range_start, pappso::Enums::DataKind::rt);
   step_sp->setIntegrationScope(integration_scope_csp);
   qDebug() << "Step is:" << step_sp->toString();
 
@@ -204,11 +192,11 @@ MsRunDataSetTreeMassDataIntegratorToRt::
 
   // qDebug() << "Is1D:" << step_p->getSelectionPolygon().is1D();
 
-  step_sp->setSrcProcessingType(pappso::Axis::x, "FILE_RT");
-  step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
+  step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "FILE_RT");
+  step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::rt);
 
-  step_sp->setSrcProcessingType(pappso::Axis::y, "NOT_SET");
-  step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+  step_sp->setSrcProcessingType(pappso::Enums::Axis::y, "NOT_SET");
+  step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::unset);
 
   // Now document the destination processing type:
   step_sp->setDestProcessingType("RT");
@@ -216,8 +204,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   // At this point we have document all the necessary to perform the
   // integration.
 
-  // There should be auto conversio from non-const to const.
-  m_processingFlow.push_back(step_sp);
+  // There should be auto conversion from non-const to const.
+  mp_processingFlow->getStepsRef().push_back(step_sp);
 
   // We need to clear the map trace!
   m_mapTrace.clear();
@@ -231,34 +219,51 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   std::pair<std::size_t, std::size_t> best_parallel_params =
     bestParallelIntegrationParams(node_count);
 
-  // qDebug() << "ideal_thread_count:" << best_parallel_params.first
-  //<< "nodes_per_thread:" << best_parallel_params.second;
+  qDebug() << "ideal thread count:" << best_parallel_params.first << "with"
+           << best_parallel_params.second << "mass spec nodes per thread";
 
+  std::vector<MultiTreeNodeCombinerVisitor *> visitors;
+
+  // Determine the number of parallel loops that will perform
+  // the calculation.
   using Iterator = std::vector<pappso::MsRunDataSetTreeNode *>::const_iterator;
 
-  std::vector<MultiTreeNodeCombinerVisitorSPtr> visitors;
+  qDebug() << "Now computing calculateMsRunDataSetTreeNodeIteratorPairs, thread"
+           << QThread::currentThreadId();
+
   std::vector<std::pair<Iterator, Iterator>> iterators =
     calculateMsRunDataSetTreeNodeIteratorPairs(
       node_count, best_parallel_params.first, best_parallel_params.second);
+  qDebug()
+    << "Done computing calculateMsRunDataSetTreeNodeIteratorPairs, thread"
+    << QThread::currentThreadId();
 
   for(std::size_t iter = 0; iter < iterators.size(); ++iter)
     {
-      // qDebug() << "thread index:" << iter;
-
-      MultiTreeNodeCombinerVisitorSPtr multi_visitor_sp =
-        std::make_shared<MultiTreeNodeCombinerVisitor>(mcsp_msRunDataSet,
-                                                       m_processingFlow);
+      qDebug() << "Now preparing visitors for new thread - index:" << iter
+               << "thread" << QThread::currentThreadId()
+               << "with parent's (this) thread:" << this->thread();
+      MultiTreeNodeCombinerVisitor *multi_visitor_p =
+        new MultiTreeNodeCombinerVisitor(
+          mcsp_msRunDataSet, *mp_processingFlow, this);
+      qDebug() << "Done preparing visitors for new thread - index:" << iter
+               << "thread" << QThread::currentThreadId()
+               << "with parent's (this) thread:" << this->thread();
 
       // Now configure the visitor to hold as many visitors as we need. We want
       // one visitor for initial TIC chrom calculation and one for the initial
       // ms run data set statistics.
 
+      qDebug() << "Now heap-allocating TicChromTreeNodeCombinerVisitor, thread"
+               << QThread::currentThreadId();
       // Start with first visitor that will compute the TIC chromatogram
-      TicChromTreeNodeCombinerVisitorSPtr tic_visitor_sp =
-        std::make_shared<TicChromTreeNodeCombinerVisitor>(mcsp_msRunDataSet,
-                                                          m_processingFlow);
+      TicChromTreeNodeCombinerVisitor *tic_visitor_p =
+        new TicChromTreeNodeCombinerVisitor(
+          mcsp_msRunDataSet, *mp_processingFlow, multi_visitor_p);
+      qDebug() << "Done heap-allocating TicChromTreeNodeCombinerVisitor, thread"
+               << QThread::currentThreadId();
 
-      multi_visitor_sp->m_visitors.push_back(tic_visitor_sp);
+      multi_visitor_p->addVisitor(tic_visitor_p);
 
       // And now the other visitor that will compute some statistics for the ms
       // run data set.
@@ -267,23 +272,31 @@ MsRunDataSetTreeMassDataIntegratorToRt::
 
       MsRunDataSetStats ms_run_data_set_stats;
 
-      MsRunStatisticsTreeNodeVisitorSPtr stats_visitor_sp =
-        std::make_shared<MsRunStatisticsTreeNodeVisitor>(
-          mcsp_msRunDataSet, m_processingFlow, ms_run_data_set_stats);
+      MsRunStatisticsTreeNodeVisitor *stats_visitor_p =
+        new MsRunStatisticsTreeNodeVisitor(mcsp_msRunDataSet,
+                                           *mp_processingFlow,
+                                           ms_run_data_set_stats,
+                                           multi_visitor_p);
 
-      multi_visitor_sp->m_visitors.push_back(stats_visitor_sp);
+      multi_visitor_p->addVisitor(stats_visitor_p);
 
       // We want to be able to intercept any cancellation of the operation.
 
+      // qDebug() << "Making connection for the cancel operation signal";
+
       connect(this,
               &MsRunDataSetTreeMassDataIntegratorToRt::cancelOperationSignal,
-              [multi_visitor_sp]() { multi_visitor_sp->cancelOperation(); });
+              [multi_visitor_p]() {
+                multi_visitor_p->cancelOperation();
+              });
 
       // The visitor gets the number of nodes to process from the data set tree
       // node. This signal tells the final user of the signal to set the max
       // value of the progress bar to number_of_nodes_to_process.
 
-      connect(multi_visitor_sp.get(),
+      // qDebug() << "Making connection for the progress bar signal.";
+
+      connect(multi_visitor_p,
               &MultiTreeNodeCombinerVisitor::setProgressBarMaxValueSignal,
               [this](std::size_t number_of_nodes_to_process) {
                 emit setProgressBarMaxValueSignal(number_of_nodes_to_process);
@@ -298,21 +311,25 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       // thus update the max progress bar value by number_of_nodes_to_process.
       // In a typical setting, the user of the signal is the monitoring object,
       // be it a non-gui object or the TaskMonitorCompositeWidget.
+
+      // qDebug()
+      // << "Making connection for the progress bar incrementation signal.";
+
       connect(
-        multi_visitor_sp.get(),
+        multi_visitor_p,
         &TicChromTreeNodeCombinerVisitor::incrementProgressBarMaxValueSignal,
         [this](std::size_t number_of_nodes_to_process) {
           emit incrementProgressBarMaxValueSignal(number_of_nodes_to_process);
         });
 
       connect(
-        multi_visitor_sp.get(),
+        multi_visitor_p,
         &TicChromTreeNodeCombinerVisitor::setProgressBarCurrentValueSignal,
         [this](std::size_t number_of_processed_nodes) {
           emit setProgressBarCurrentValueSignal(number_of_processed_nodes);
         });
 
-      connect(multi_visitor_sp.get(),
+      connect(multi_visitor_p,
               &TicChromTreeNodeCombinerVisitor::
                 incrementProgressBarCurrentValueAndSetStatusTextSignal,
               [this](std::size_t increment, QString text) {
@@ -320,43 +337,41 @@ MsRunDataSetTreeMassDataIntegratorToRt::
                   increment, text);
               });
 
-      connect(multi_visitor_sp.get(),
+      connect(multi_visitor_p,
               &TicChromTreeNodeCombinerVisitor::setStatusTextSignal,
-              [this](QString text) { emit setStatusTextSignal(text); });
+              [this](QString text) {
+                emit setStatusTextSignal(text);
+              });
 
       connect(
-        multi_visitor_sp.get(),
+        multi_visitor_p,
         &TicChromTreeNodeCombinerVisitor::setStatusTextAndCurrentValueSignal,
         [this](QString text, std::size_t value) {
           emit setStatusTextAndCurrentValueSignal(text, value);
         });
 
-      visitors.push_back(multi_visitor_sp);
+      visitors.push_back(multi_visitor_p);
     }
 
-  // Now perform a parallel iteration in the various visitors and ask them to
-  // work on the matching ms run data set iterators pair.
+  qDebug() << "Done preparing all the visitors" << visitors.size()
+           << "in their container.";
+
+  // Now that we have configured all the visitors, perform a parallel iteration
+  // in these and ask them to work on the matching ms run data
+  // set iterators pair.
   omp_set_num_threads(visitors.size());
 #pragma omp parallel for ordered
   for(std::size_t iter = 0; iter < visitors.size(); ++iter)
     {
-      auto multi_visitor_sp = visitors.at(iter);
+      auto multi_visitor_p = visitors.at(iter);
 
-      // qDebug() << "Multi-visitor:" << multi_visitor_sp.get()
-      //<< "at index:" << iter
-      //<< "Executing from thread:" << QThread::currentThreadId();
+      qDebug() << "Multi-visitor:" << multi_visitor_p << "at index:" << iter
+               << "Executing from thread:" << QThread::currentThreadId();
 
       mcsp_msRunDataSet->msp_msRunDataSetTree->accept(
-        *(multi_visitor_sp.get()),
-        iterators.at(iter).first,
-        iterators.at(iter).second);
+        *multi_visitor_p, iterators.at(iter).first, iterators.at(iter).second);
 
-      // qDebug() << "Finished running the visitor at index:" << iter
-      //<< "and the m_maxMz for the data stats is:"
-      //<< dynamic_cast<const MsRunStatisticsTreeNodeVisitor *>(
-      // multi_visitor_sp->m_visitors.back().get())
-      //->getMsRunDataSetStats()
-      //.m_maxMz;
+      qDebug() << "Finished running the visitor at index:" << iter;
     }
   // End of
   // #pragma omp parallel for
@@ -394,16 +409,18 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       if(m_isOperationCancelled)
         break;
 
-      auto &&multi_visitor_sp = visitors.at(iter);
+      auto multi_visitor_p = visitors.at(iter);
 
       // We know that the first visitor is the visitor for the TIC chromatogram.
       // So, handle this one first.
 
-      TicChromTreeNodeCombinerVisitorSPtr tic_visitor_sp =
-        std::dynamic_pointer_cast<TicChromTreeNodeCombinerVisitor>(
-          multi_visitor_sp->m_visitors.front());
+      TicChromTreeNodeCombinerVisitor *tic_visitor_p =
+        dynamic_cast<TicChromTreeNodeCombinerVisitor *>(
+          multi_visitor_p->m_visitors.front());
+      // I do not understand why a new visitor needs to be allocated ?
+      // multi_visitor_p->m_visitors.front()->clone();
 
-      const pappso::MapTrace &map_trace = tic_visitor_sp->getTicChromMapTrace();
+      const pappso::MapTrace &map_trace = tic_visitor_p->getTicChromMapTrace();
 
       // Use the trace plus combiner instance to combine the iterated trace into
       // the member map trace that the integrator users will query after that
@@ -413,9 +430,11 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       // Now we know that the second visitor is for the statistics. Handle this
       // now.
 
-      MsRunStatisticsTreeNodeVisitorSPtr stats_visitor_sp =
-        std::dynamic_pointer_cast<MsRunStatisticsTreeNodeVisitor>(
-          multi_visitor_sp->m_visitors.back());
+      MsRunStatisticsTreeNodeVisitor *stats_visitor_p =
+        dynamic_cast<MsRunStatisticsTreeNodeVisitor *>(
+          multi_visitor_p->m_visitors.back());
+      // I do not understand why a new visitor needs to be allocated ?
+      // multi_visitor_p->m_visitors.back()->clone();
 
       // qDebug() << "In the consolidating loop, iter:" << iter
       //<< "with a map trace of this size : " << map_trace.size();
@@ -441,7 +460,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       //<< ms_run_data_set_stats_merge.m_maxMz;
 
       ms_run_data_set_stats_merge.merge(
-        stats_visitor_sp.get()->getMsRunDataSetStats());
+        stats_visitor_p->getMsRunDataSetStats());
 
       // qDebug()
       //<< "After the merge, the ms_run_data_set_stats_merge has m_maxMz:"
@@ -481,7 +500,6 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   emit finishedIntegratingToInitialTicChromatogramSignal(this);
 }
 
-
 bool
 MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
 {
@@ -498,11 +516,12 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
   // must have been set by the caller either at construction time or later
   // before using the integrator, that is, calling this function.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // Get the most recent step that holds all the specifics of this integration.
-  ProcessingStepCstSPtr processing_step_csp = m_processingFlow.mostRecentStep();
+  ProcessingStepCstSPtr processing_step_csp =
+    mp_processingFlow->mostRecentStep();
 
   if(!processing_step_csp->srcMatches("ANY_RT"))
     qFatal(
@@ -517,7 +536,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
 
   std::pair<double, double> range_pair;
 
-  bool integration_rt = m_processingFlow.innermostRange("ANY_RT", range_pair);
+  bool integration_rt = mp_processingFlow->innermostRange("ANY_RT", range_pair);
 
   using Iterator = std::vector<pappso::MsRunDataSetTreeNode *>::const_iterator;
   using Pair     = std::pair<Iterator, Iterator>;
@@ -568,7 +587,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
 
   using Iterator = std::vector<pappso::MsRunDataSetTreeNode *>::const_iterator;
 
-  std::vector<TicChromTreeNodeCombinerVisitorSPtr> visitors;
+  std::vector<TicChromTreeNodeCombinerVisitor *> visitors;
   std::vector<std::pair<Iterator, Iterator>> iterators =
     calculateMsRunDataSetTreeNodeIteratorPairs(begin_iterator,
                                                end_iterator,
@@ -579,15 +598,17 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
     {
       // qDebug() << "thread index:" << iter;
 
-      TicChromTreeNodeCombinerVisitorSPtr visitor_sp =
-        std::make_shared<TicChromTreeNodeCombinerVisitor>(mcsp_msRunDataSet,
-                                                          m_processingFlow);
+      TicChromTreeNodeCombinerVisitor *visitor_p =
+        new TicChromTreeNodeCombinerVisitor(
+          mcsp_msRunDataSet, *mp_processingFlow, this);
 
       // We want to be able to intercept any cancellation of the operation.
 
       connect(this,
               &MsRunDataSetTreeMassDataIntegratorToRt::cancelOperationSignal,
-              [visitor_sp]() { visitor_sp->cancelOperation(); });
+              [visitor_p]() {
+                visitor_p->cancelOperation();
+              });
       // visitor_sp.get(),
       //&TicChromTreeNodeCombinerVisitor::cancelOperation,
       // Qt::QueuedConnection);
@@ -596,7 +617,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
       // node. This signal tells the final user of the signal to set the max
       // value of the progress bar to number_of_nodes_to_process.
 
-      connect(visitor_sp.get(),
+      connect(visitor_p,
               &TicChromTreeNodeCombinerVisitor::setProgressBarMaxValueSignal,
               [this](std::size_t number_of_nodes_to_process) {
                 emit setProgressBarMaxValueSignal(number_of_nodes_to_process);
@@ -612,20 +633,20 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
       // In a typical setting, the user of the signal is the monitoring object,
       // be it a non-gui object or the TaskMonitorCompositeWidget.
       connect(
-        visitor_sp.get(),
+        visitor_p,
         &TicChromTreeNodeCombinerVisitor::incrementProgressBarMaxValueSignal,
         [this](std::size_t number_of_nodes_to_process) {
           emit incrementProgressBarMaxValueSignal(number_of_nodes_to_process);
         });
 
       connect(
-        visitor_sp.get(),
+        visitor_p,
         &TicChromTreeNodeCombinerVisitor::setProgressBarCurrentValueSignal,
         [this](std::size_t number_of_processed_nodes) {
           emit setProgressBarCurrentValueSignal(number_of_processed_nodes);
         });
 
-      connect(visitor_sp.get(),
+      connect(visitor_p,
               &TicChromTreeNodeCombinerVisitor::
                 incrementProgressBarCurrentValueAndSetStatusTextSignal,
               [this](std::size_t increment, QString text) {
@@ -633,18 +654,20 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
                   increment, text);
               });
 
-      connect(visitor_sp.get(),
+      connect(visitor_p,
               &TicChromTreeNodeCombinerVisitor::setStatusTextSignal,
-              [this](QString text) { emit setStatusTextSignal(text); });
+              [this](QString text) {
+                emit setStatusTextSignal(text);
+              });
 
       connect(
-        visitor_sp.get(),
+        visitor_p,
         &TicChromTreeNodeCombinerVisitor::setStatusTextAndCurrentValueSignal,
         [this](QString text, std::size_t value) {
           emit setStatusTextAndCurrentValueSignal(text, value);
         });
 
-      visitors.push_back(visitor_sp);
+      visitors.push_back(visitor_p);
     }
 
   // Now perform a parallel iteration in the various visitors and ask them to
@@ -653,15 +676,13 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
 #pragma omp parallel for ordered
   for(std::size_t iter = 0; iter < visitors.size(); ++iter)
     {
-      auto visitor_sp = visitors.at(iter);
+      auto visitor_p = visitors.at(iter);
 
       // qDebug() << "Visitor:" << visitor_sp.get() << "at index:" << iter
       //<< "Executing from thread:" << QThread::currentThreadId();
 
       mcsp_msRunDataSet->msp_msRunDataSetTree->accept(
-        *(visitor_sp.get()),
-        iterators.at(iter).first,
-        iterators.at(iter).second);
+        *(visitor_p), iterators.at(iter).first, iterators.at(iter).second);
     }
   // End of
   // #pragma omp parallel for
@@ -727,6 +748,6 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
