@@ -39,22 +39,22 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/msrun/msrundatasettreenode.h>
-#include <pappsomspp/msrun/msrundatasettreevisitor.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/msrun/msrundatasettreenode.h>
+#include <pappsomspp/core/msrun/msrundatasettreevisitor.h>
 
 
 /////////////////////// Local includes
 #include "ProcessingFlow.hpp"
 #include "MsRunDataSet.hpp"
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 #include "MsRunDataSetStats.hpp"
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class MsRunStatisticsTreeNodeVisitor;
@@ -64,21 +64,19 @@ typedef std::shared_ptr<MsRunStatisticsTreeNodeVisitor>
 
 class MsRunStatisticsTreeNodeVisitor : public BaseMsRunDataSetTreeNodeVisitor
 {
-
   public:
   MsRunStatisticsTreeNodeVisitor(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    const MsRunDataSetStats &ms_run_data_set_stats);
+    const MsRunDataSetStats &ms_run_data_set_stats,
+  QObject *parent = nullptr);
 
-  MsRunStatisticsTreeNodeVisitor(const MsRunStatisticsTreeNodeVisitor &other);
 
   virtual ~MsRunStatisticsTreeNodeVisitor();
 
-  const MsRunDataSetStats &getMsRunDataSetStats() const;
+  virtual BaseMsRunDataSetTreeNodeVisitor *clone(QObject *parent = nullptr) const override;
 
-  MsRunStatisticsTreeNodeVisitor &
-  operator=(const MsRunStatisticsTreeNodeVisitor &other);
+  const MsRunDataSetStats &getMsRunDataSetStats() const;
 
   // Overrides the base class.
   virtual bool visit(const pappso::MsRunDataSetTreeNode &node) override;
@@ -88,6 +86,6 @@ class MsRunStatisticsTreeNodeVisitor : public BaseMsRunDataSetTreeNodeVisitor
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
