@@ -39,23 +39,22 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/msrun/msrundatasettreenode.h>
-#include <pappsomspp/msrun/msrundatasettreevisitor.h>
-#include <pappsomspp/trace/maptrace.h>
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/msrun/msrundatasettreenode.h>
+#include <pappsomspp/core/msrun/msrundatasettreevisitor.h>
+#include <pappsomspp/core/trace/maptrace.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
 #include "ProcessingFlow.hpp"
 #include "MsRunDataSet.hpp"
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class MassDataIntegrator;
@@ -65,7 +64,7 @@ class MultiTreeNodeCombinerVisitor;
 typedef std::shared_ptr<MultiTreeNodeCombinerVisitor>
   MultiTreeNodeCombinerVisitorSPtr;
 
-class MultiTreeNodeCombinerVisitor : public BaseMsRunDataSetTreeNodeVisitor
+class MultiTreeNodeCombinerVisitor: public BaseMsRunDataSetTreeNodeVisitor
 {
 
   friend class MassDataIntegrator;
@@ -73,25 +72,23 @@ class MultiTreeNodeCombinerVisitor : public BaseMsRunDataSetTreeNodeVisitor
 
   public:
   MultiTreeNodeCombinerVisitor(MsRunDataSetCstSPtr ms_run_data_set_csp,
-                               const ProcessingFlow &processing_flow);
-
-  MultiTreeNodeCombinerVisitor(const MultiTreeNodeCombinerVisitor &other);
+                               const ProcessingFlow &processing_flow,
+                               QObject *parent = nullptr);
 
   virtual ~MultiTreeNodeCombinerVisitor();
 
-  MultiTreeNodeCombinerVisitor &
-  operator=(const MultiTreeNodeCombinerVisitor &other);
+  BaseMsRunDataSetTreeNodeVisitor *clone(QObject *parent = nullptr) const override;
 
   // Overrides the base class.
   virtual bool visit(const pappso::MsRunDataSetTreeNode &node) override;
 
-  void addVisitor(BaseMsRunDataSetTreeNodeVisitorSPtr visitor_sp);
+  void addVisitor(BaseMsRunDataSetTreeNodeVisitor *visitor_p);
 
   protected:
-  std::vector<BaseMsRunDataSetTreeNodeVisitorSPtr> m_visitors;
+  std::vector<BaseMsRunDataSetTreeNodeVisitor *> m_visitors;
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
