@@ -38,6 +38,7 @@
 
 /////////////////////// Qt includes
 #include <QDebug>
+#include <QtQml>
 
 
 /////////////////////// pappsomspp includes
@@ -46,88 +47,235 @@
 /////////////////////// Local includes
 #include "ProcessingFlow.hpp"
 #include "ProcessingStep.hpp"
-
+#include "Application.hpp"
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
-ProcessingFlow::ProcessingFlow()
+ProcessingFlow::ProcessingFlow(QObject *parent): QObject(parent)
 {
 }
 
-
-ProcessingFlow::ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp)
-  : mcsp_msRunDataSet(ms_run_data_set_csp)
+ProcessingFlow::ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp,
+                               QObject *parent)
+  : QObject(parent), mcsp_msRunDataSet(ms_run_data_set_csp)
 {
 }
 
-ProcessingFlow::ProcessingFlow(const ProcessingFlow &other)
-  : std::vector<MsXpS::minexpert::ProcessingStepCstSPtr>(),
-    mcsp_msRunDataSet(other.mcsp_msRunDataSet),
-    m_defaultMzIntegrationParams(other.m_defaultMzIntegrationParams),
-    m_defaultMsFragmentationSpec(other.m_defaultMsFragmentationSpec)
-{
-  assign(other.begin(), other.end());
-  m_filterMap = other.m_filterMap;
-}
-
-
 ProcessingFlow::~ProcessingFlow()
 {
   // Now clear the vector.
-  clear();
+  m_steps.clear();
 }
 
-
-ProcessingFlow &
-ProcessingFlow::operator=(const ProcessingFlow &other)
+ProcessingFlow *
+ProcessingFlow::clone(QObject *parent) const
 {
-  if(this == &other)
-    return *this;
+  ProcessingFlow *copy = new ProcessingFlow(parent);
+  copy->initialize(*this);
+
+  return copy;
+}
+
+void
+ProcessingFlow::initialize(const ProcessingFlow &other)
+{
+
+  mcsp_msRunDataSet = other.mcsp_msRunDataSet;
+
+  if(other.mp_defaultMzIntegrationParams != nullptr)
+    mp_defaultMzIntegrationParams =
+      other.mp_defaultMzIntegrationParams->clone(this);
 
-  mcsp_msRunDataSet            = other.mcsp_msRunDataSet;
-  m_defaultMzIntegrationParams = other.m_defaultMzIntegrationParams;
   m_defaultMsFragmentationSpec = other.m_defaultMsFragmentationSpec;
 
-  assign(other.begin(), other.end());
+  m_steps.assign(other.m_steps.begin(), other.m_steps.end());
 
   m_filterMap = other.m_filterMap;
-
-  return *this;
 }
 
-
 void
 ProcessingFlow::setMsRunDataSetCstSPtr(MsRunDataSetCstSPtr ms_run_data_set_csp)
 {
   mcsp_msRunDataSet = ms_run_data_set_csp;
 }
 
-
 MsRunDataSetCstSPtr
 ProcessingFlow::getMsRunDataSetCstSPtr() const
 {
   return mcsp_msRunDataSet;
 }
 
+const std::vector<ProcessingStepCstSPtr> &
+ProcessingFlow::getStepsCstRef() const
+{
+  return m_steps;
+}
+
+std::vector<ProcessingStepCstSPtr> &
+ProcessingFlow::getStepsRef()
+{
+  return m_steps;
+}
 
 void
 ProcessingFlow::setDefaultMzIntegrationParams(
   const pappso::MzIntegrationParams &mz_integration_params)
 {
-  m_defaultMzIntegrationParams = mz_integration_params;
+  if(mp_defaultMzIntegrationParams)
+    delete mp_defaultMzIntegrationParams;
+  mp_defaultMzIntegrationParams = mz_integration_params.clone(this);
 }
 
-
-const pappso::MzIntegrationParams &
-ProcessingFlow::getDefaultMzIntegrationParams() const
+pappso::MzIntegrationParams *
+ProcessingFlow::getDefaultMzIntegrationParams()
 {
-  return m_defaultMzIntegrationParams;
+  return mp_defaultMzIntegrationParams;
 }
 
+/* Heap-allocated*/
+pappso::MzIntegrationParams *
+ProcessingFlow::getSensibleMzIntegrationParams() const
+{
+  // pappso::MzIntegrationParams are a set of parameters that are required
+  // to configure the way mass spectra (m/z data) are handled mathematically.
+  // In particular, if two mass spectra are to be combined into a new third
+  // mass spectrum, a number of criteria can influence the result.
+  //
+  // 1. Do all the points from both spectra (as long as they have distinct m/z
+  // values) need to be found as such in the combined spectrum ?
+  //
+  // 2. Are bins required to pool together points that have their m/z value so
+  // close that they are actually a single point in a trace ? If so, the
+  // MzIntegrationParams allow the user to define how bins are going to be
+  // crafted for binning the m/z values in a meaningful manner depending on the
+  // resolving power of the instrument.
+
+  // Because users do most often work on many mass spectra acquired on the same
+  // mass spectrometer, the MzIntegrationParams do not change for a while. It is
+  // thus desirable to establish a mechanism by which the user can trigger
+  // the storage on disk of the binning logic parameters that do no change.
+  //
+  // The MzIntegrationParams are dual:
+  //
+  // 1. The binning logic params are those that
+  // configure the size of the bins and it is desirable that they be stored
+  // on disk because they are the same over a large analysis session.
+  //
+  // 2. The other two members m_smallestMz and m_greatestMz values describe
+  // the very first and very last points of the spectrum. If binning is
+  // required, the generated bins span the [ m_smallestMz -- m_greatestMz ] m/z
+  // range. These two values are specific, by definition, of the data set
+  // at hand and are thus not useful to be stored on disk. Indeed, these
+  // two values are not stored on disk.
+  //
+  // There is a last parameter that is not directly involved in the binning
+  // work, the bit that indicates if the 0-value points need to be removed or
+  // not.
+
+  // Get the MzIntegrationParams from the MsRunDataSet because that one
+  // will contain the proper m/z values that we can store for later use.
+  // HEAP ALLOCATED
+  pappso::MzIntegrationParams *mz_integration_params_from_data_set_p =
+    mcsp_msRunDataSet->craftMzIntegrationParams();
+
+  // This call cannot fail.
+  Q_ASSERT(mz_integration_params_from_data_set_p);
+
+  double smallest_mz = mz_integration_params_from_data_set_p->getSmallestMz();
+  double greatest_mz = mz_integration_params_from_data_set_p->getGreatestMz();
+
+  // The first approach is to check if there are MzIntegrationParams stored
+  // as settings on disk.
+  pappso::MzIntegrationParams *heap_allocated_mz_integration_params_p = nullptr;
+
+  pappso::MzIntegrationParams settings_mz_integ_params;
+  pappso::MzIntegrationParams::InitializationResult saved_settings_result =
+    static_cast<Application *>(qApp)->getMzIntegrationParamsFromSavedSettings(
+      settings_mz_integ_params);
+
+  if(saved_settings_result ==
+     pappso::MzIntegrationParams::InitializationResult::FULL)
+    {
+      // Good, all the parameters are set.
+      heap_allocated_mz_integration_params_p =
+        new pappso::MzIntegrationParams();
+      heap_allocated_mz_integration_params_p->initialize(
+        settings_mz_integ_params);
+      heap_allocated_mz_integration_params_p->setMzValues(smallest_mz,
+                                                          greatest_mz);
+      return heap_allocated_mz_integration_params_p;
+    }
+
+  // If the binning logic parameters were not full, that might be because
+  // some values were not set because they not needed, in particular, if
+  // there is no binning, then the other binning logic parameters are not
+  // needed, which in fact makes the binning logic parameters full if
+  // decimal places and remove zero-val data ponts were also set.
+  if(static_cast<bool>(
+       saved_settings_result &
+       pappso::MzIntegrationParams::InitializationResult::BINNING_TYPE))
+    {
+      if(settings_mz_integ_params.getBinningType() ==
+         pappso::MzIntegrationParams::BinningType::NONE)
+        {
+          if(static_cast<bool>(saved_settings_result &
+                               pappso::MzIntegrationParams::
+                                 InitializationResult::DECIMAL_PLACES))
+            {
+              if(static_cast<bool>(
+                   saved_settings_result &
+                   pappso::MzIntegrationParams::InitializationResult::
+                     REMOVE_ZERO_DATA_POINTS))
+                {
+                  // This is enough to return these values.
+                  heap_allocated_mz_integration_params_p =
+                    new pappso::MzIntegrationParams();
+                  heap_allocated_mz_integration_params_p->initialize(
+                    settings_mz_integ_params, saved_settings_result);
+                  heap_allocated_mz_integration_params_p->setMzValues(
+                    smallest_mz, greatest_mz);
+                  return heap_allocated_mz_integration_params_p;
+                }
+            }
+        }
+    }
+
+  // Are there non-nullptr default MzIntegrationParams ?
+
+  if(mp_defaultMzIntegrationParams != nullptr)
+    {
+      heap_allocated_mz_integration_params_p =
+        new pappso::MzIntegrationParams();
+      heap_allocated_mz_integration_params_p->initialize(
+        *mp_defaultMzIntegrationParams);
+      heap_allocated_mz_integration_params_p->setMzValues(smallest_mz,
+                                                          greatest_mz);
+      return heap_allocated_mz_integration_params_p;
+    }
+
+  // Try to get the MzIntegrationParams from the most recent
+  // processing flow step.
+  const pappso::MzIntegrationParams *recent_mz_integration_params_p =
+    mostRecentMzIntegrationParams();
+
+  if(recent_mz_integration_params_p != nullptr)
+    {
+      heap_allocated_mz_integration_params_p =
+        new pappso::MzIntegrationParams();
+      heap_allocated_mz_integration_params_p->initialize(
+        *recent_mz_integration_params_p);
+      heap_allocated_mz_integration_params_p->setMzValues(smallest_mz,
+                                                          greatest_mz);
+      return heap_allocated_mz_integration_params_p;
+    }
+
+  // Last resort... use the MzIntegrationParams gotten from the MsRunDataSet.
+  return mz_integration_params_from_data_set_p;
+}
 
 void
 ProcessingFlow::setDefaultMsFragmentationSpec(
@@ -138,31 +286,51 @@ ProcessingFlow::setDefaultMsFragmentationSpec(
   m_defaultMsFragmentationSpec = ms_fragmentation_spec;
 }
 
-
 const MsFragmentationSpec &
 ProcessingFlow::getDefaultMsFragmentationSpec() const
 {
   return m_defaultMsFragmentationSpec;
 }
 
-
-std::vector<ProcessingStepCstSPtr>
-ProcessingFlow::steps()
-{
-  std::vector<ProcessingStepCstSPtr> steps;
-
-  steps.assign(begin(), end());
-
-  return steps;
-}
-
-
 const std::map<QString, pappso::FilterNameInterfaceCstSPtr> &
-ProcessingFlow::getFilterMap() const
+ProcessingFlow::getFilterMapCstRef() const
 {
   return m_filterMap;
 }
 
+std::map<QString, pappso::FilterNameInterfaceCstSPtr> &
+ProcessingFlow::getFilterMapRef()
+{
+  return m_filterMap;
+}
+
+void
+ProcessingFlow::addFilter(pappso::FilterNameInterfaceCstSPtr filter_csp)
+{
+  QString filter_name = filter_csp->name();
+
+  using Pair     = std::pair<QString, pappso::FilterNameInterfaceCstSPtr>;
+  using Map      = std::map<QString, pappso::FilterNameInterfaceCstSPtr>;
+  using Iterator = Map::iterator;
+
+  std::pair<Iterator, bool> res =
+    m_filterMap.insert(Pair(filter_name, filter_csp));
+
+  if(!res.second)
+    {
+      // Insertion failed because one other same filter by that name was
+      // already in the map. Set the new value.
+
+      res.first->second = filter_csp;
+    }
+  // else: the insert operation was performed fine.
+}
+
+std::size_t
+ProcessingFlow::removeFilter(const QString &filter_name)
+{
+  return m_filterMap.erase(filter_name);
+}
 
 pappso::FilterNameInterfaceCstSPtr
 ProcessingFlow::filter(const QString &filter_name) const
@@ -179,37 +347,6 @@ ProcessingFlow::filter(const QString &filter_name) const
   return found_iterator->second;
 }
 
-
-void
-ProcessingFlow::addFilter(pappso::FilterNameInterfaceCstSPtr filter_csp)
-{
-  QString filter_name = filter_csp->name();
-
-  using Pair     = std::pair<QString, pappso::FilterNameInterfaceCstSPtr>;
-  using Map      = std::map<QString, pappso::FilterNameInterfaceCstSPtr>;
-  using Iterator = Map::iterator;
-
-  std::pair<Iterator, bool> res =
-    m_filterMap.insert(Pair(filter_name, filter_csp));
-
-  if(!res.second)
-    {
-      // Insertion failed because one other same filter by that name was already
-      // in the map. Set the new value.
-
-      res.first->second = filter_csp;
-    }
-  // else: the insert operation was performed fine.
-}
-
-
-std::size_t
-ProcessingFlow::removeFilter(const QString &filter_name)
-{
-  return m_filterMap.erase(filter_name);
-}
-
-
 bool
 ProcessingFlow::innermostRange(
   ProcessingType src_processing_type_mask,
@@ -218,27 +355,30 @@ ProcessingFlow::innermostRange(
   bool store_only_2d_steps,
   bool store_only_rhomboid) const
 {
-  // qDebug() << "Searching for innermost range for source ProcessingType mask:"
-  //          << src_processing_type_mask.toBriefDesc() << "in a flow of" <<
-  //          size()
+  // qDebug() << "Searching for innermost range for source ProcessingType mask: "
+  //          << src_processing_type_mask.toBriefDesc()
+  //          << "in a ProcessingFlow holding" << getStepsCstRef().size()
   //          << "steps";
 
   // We are asked to get the innermost range for all steps having their
   // processing type matching the processing_type_mask.
 
-  // processing_type_mask specifies a source processing type, that might be
-  // someghing like "ANY_RT" or "ANY_DT" or "ANY_MZ".
+  // processing_type_mask specifies a source processing type, that might
+  // be someghing like "ANY_RT" or "ANY_DT" or "ANY_MZ".
 
-  // We iterate in the steps of this processing flow and check that their source
-  // type matches processing_type_mask. If so, we look at the axis data kind and
-  // check for the innermost range.
+  // We iterate in the steps of this processing flow and check that their
+  // source type matches processing_type_mask. If so, we look at the axis
+  // data kind and check for the innermost range.
 
   ProcessingType src_processing_type("NOT_SET");
   ProcessingType x_src_processing_type("NOT_SET");
   ProcessingType y_src_processing_type("NOT_SET");
 
-  double inner_range_start = std::numeric_limits<double>::quiet_NaN();
-  double inner_range_end   = std::numeric_limits<double>::quiet_NaN();
+  double inner_range_start = qQNaN();
+  double inner_range_end   = qQNaN();
+
+  // if(qIsNaN(inner_range_start))
+  //   qDebug() << "It is indeed NaN!";
 
   bool is_first_iterated_item = true;
 
@@ -246,9 +386,10 @@ ProcessingFlow::innermostRange(
 
   // A ProcessingFlow is a vector of ProcessingStepCstSPtr.
 
-  for(auto &step_csp : *this)
+  for(const ProcessingStepCstSPtr &step_csp : m_steps)
     {
-      // qDebug() << "Iterating in step:" << step_csp->toString();
+      // qDebug().noquote() << "20250904 - Iterating in step:\n"
+      //                    << step_csp->toString(0, "  ") << step_csp.get();
 
       double range_start;
       double range_end;
@@ -256,9 +397,10 @@ ProcessingFlow::innermostRange(
       ProcessingType iter_x_processing_type = step_csp->m_xSrcType;
       ProcessingType iter_y_processing_type = step_csp->m_ySrcType;
 
-      // qDebug() << "Iterating in ProcessingStep of x and y src types:"
-      //<< iter_x_processing_type.toBriefDesc() << "and"
-      //<< iter_y_processing_type.toBriefDesc();
+      // qDebug().noquote() << "20250904 - This step has X axis source type:"
+      //                    << iter_x_processing_type.toBriefDesc()
+      //                    << "and Y axis source type:"
+      //                    << iter_y_processing_type.toBriefDesc();
 
       // Check the processing type. We may get here any kind of mono- or
       // bi-dimensional processing type, like MZ_TO_ANY or DT_RT_TO_ANY.
@@ -275,26 +417,26 @@ ProcessingFlow::innermostRange(
       // Is the currently iterated step mono- or two-dimensional ?
       if(step_csp->msp_integrationScope->is1D())
         {
-          // This is the simplest situation, there is only one dimension, the x
-          // dimension, that is of interest.
+          // This is the simplest situation, there is only one dimension,
+          // the x dimension, that is of interest.
 
-          // qDebug() << "That step is 1D";
+          // qDebug() << "20250904 - This step is 1D";
 
           step_csp->msp_integrationScope->range(
-            pappso::Axis::x, range_start, range_end);
+            pappso::Enums::Axis::x, range_start, range_end);
 
           if(is_first_iterated_item)
             {
               inner_range_start = range_start;
               inner_range_end   = range_end;
 
-              // qDebug() << "First iterated step, with inner range:"
-              //<< inner_range_start << "-" << inner_range_end;
+              // qDebug() << "20250904 - First iterated step, with inner range:"
+              //          << inner_range_start << "-" << inner_range_end;
 
               if(!store_only_2d_steps)
                 {
-                  // qDebug() << "Step is 1D, setting step as innermost step as"
-                  //             "requested.";
+                  // qDebug() << "20250904 - Step is 1D, setting step as "
+                  //             "innermost step as requested.";
                   innermost_step_csp = step_csp;
                 }
 
@@ -309,15 +451,15 @@ ProcessingFlow::innermostRange(
               // need to compare with those of this last step so as
               // to update the innermost range values if necessary.
 
-              // This variable will report if the currently iterated-into step
-              // has range values that make them innermost with respect to
-              // the previous got ones.
+              // This variable will report if the currently iterated-into
+              // step has range values that make them innermost with
+              // respect to the previous got ones.
               bool was_at_least_one_range_value_inner = false;
 
               // If the new x-axis value is greater than the previous one,
-              // then that means that we are reducing the range at the left
-              // side, so this new range start value has to become the new
-              // innermost range start value.
+              // then that means that we are reducing the range at the
+              // left side, so this new range start value has to become
+              // the new innermost range start value.
 
               if(range_start > inner_range_start)
                 {
@@ -325,25 +467,27 @@ ProcessingFlow::innermostRange(
 
                   was_at_least_one_range_value_inner = true;
 
-                  // qDebug() << "New inner range start:" << inner_range_start;
+                  // qDebug() << "New inner range start:" <<
+                  // inner_range_start;
                 }
 
               // If the new x-axis value is smaller that the previous one,
-              // then that means that we are reducing the range at the right
-              // side, so this new range end value has to become the new
-              // innmermost range end value.
+              // then that means that we are reducing the range at the
+              // right side, so this new range end value has to become the
+              // new innmermost range end value.
               if(range_end < inner_range_end)
                 {
                   inner_range_end = range_end;
 
                   was_at_least_one_range_value_inner = true;
-                  // qDebug() << "New inner range end:" << inner_range_end;
+                  // qDebug() << "New inner range end:" <<
+                  // inner_range_end;
                 }
 
               if(was_at_least_one_range_value_inner && !store_only_2d_steps)
                 {
-                  // qDebug() << "Even if 1D, setting step as innermost step as
-                  // " "requested.";
+                  // qDebug() << "Even if 1D, setting step as innermost
+                  // step as " "requested.";
                   innermost_step_csp = step_csp;
                 }
             }
@@ -352,81 +496,83 @@ ProcessingFlow::innermostRange(
         }
       else
         {
-          // qDebug() << "That step is 2D, either Rect or Rhomb";
+          // qDebug() << "20250904 - This step is 2D, either Rect or Rhomb";
 
-          // At this point, we know the selection polygon is either Rectangle or
-          // Rhomboid, which means we have to check what actual source types the
-          // iterated step has because we need to know what is the type of the
-          // different selection polygon axes. Indeed, we will compare only
-          // range values from the iterated step for the right either horizontal
-          // (X) or vertical (Y) dimension to the ones already encountered in
-          // this iteration over all the steps of the processing flow.
+          // At this point, we know the selection polygon is either
+          // Rectangle or Rhomboid, which means we have to check what
+          // actual source types the iterated step has because we need to
+          // know what is the type of the different selection polygon
+          // axes. Indeed, we will compare only range values from the
+          // iterated step for the right either horizontal (X) or vertical
+          // (Y) dimension to the ones already encountered in this
+          // iteration over all the steps of the processing flow.
 
           if(step_csp->m_xSrcType.bitMatches(src_processing_type_mask))
             {
               // qDebug() << "Step's m_xSrcType.bitMatches"
               //          << src_processing_type_mask.toBriefDesc();
 
-              // The x axis is the axis we need to check the innermost range of.
-              // Get the range values.
+              // The x axis is the axis we need to check the innermost
+              // range of. Get the range values.
 
-              //*step_csp->m_selectionPolygon.rangeX(range_start, range_end);
               step_csp->msp_integrationScope->range(
-                pappso::Axis::x, range_start, range_end);
+                pappso::Enums::Axis::x, range_start, range_end);
 
-              // qDebug() << "Gotten range values:" << range_start << "-"
-              //          << range_end;
+              qDebug() << "20250904 -Gotten range values:" << range_start << "-"
+                       << range_end;
             }
           else if(step_csp->m_ySrcType.bitMatches(src_processing_type_mask))
             {
               // qDebug() << "Step's m_ySrcType.bitMatches"
               //          << src_processing_type_mask.toBriefDesc();
 
-              // The y axis is the axis we need to check the innermost range of.
-              // Get the range values.
+              // The y axis is the axis we need to check the innermost
+              // range of. Get the range values.
 
-              //**step_csp->m_selectionPolygon.rangeY(range_start, range_end);
               step_csp->msp_integrationScope->range(
-                pappso::Axis::y, range_start, range_end);
+                pappso::Enums::Axis::y, range_start, range_end);
 
-              // qDebug() << "Gotten range values:" << range_start << "-"
+              // qDebug() << "20250904 -Gotten range values:" << range_start << "-"
               //          << range_end;
             }
           else
             qFatal("Programming error.");
 
-          // And now use the gotten range values of the currently iterated step
-          // to establish if that dimension is inner or not.
+          // And now use the gotten range values of the currently iterated
+          // step to establish if that dimension is inner or not.
 
           if(is_first_iterated_item)
             {
-              // Special situation where we are just setting values because
-              // this is the first step that we iterate into and thus
-              // we have no other values to perform comparisons with, whe
-              // just seed the system.
+              // qDebug()
+              //   << "20250904 - This was the first item we iterated into.";
+
+              // Special situation where we are just setting values
+              // because this is the first step that we iterate into and
+              // thus we have no other values to perform comparisons with,
+              // whe just seed the system.
               inner_range_start = range_start;
               inner_range_end   = range_end;
 
               // qDebug() << "First iterated step, with inner range:"
-              //<< inner_range_start << "-" << inner_range_end;
+              //          << inner_range_start << "-" << inner_range_end;
 
               // qDebug() << "Setting step as innermost step.";
-              innermost_step_csp = step_csp;
+              // innermost_step_csp = step_csp;
 
               is_first_iterated_item = false;
             }
           else
             {
-              // qDebug() << "Not first iterated step.";
+              // qDebug() << "20250904 - Not first iterated step.";
 
               // This is not the first step we iterate into,
               // so there are already range values, that we
               // need to compare with those of this last step so as
               // to update the innermost range values if necessary.
 
-              // This variable will report if the currently iterated-into step
-              // has range values that make them innermost with respect to
-              // the previous got ones.
+              // This variable will report if the currently iterated-into
+              // step has range values that make them innermost with
+              // respect to the previous got ones.
               bool was_at_least_one_range_value_inner = false;
 
               if(range_start > inner_range_start)
@@ -435,7 +581,8 @@ ProcessingFlow::innermostRange(
 
                   was_at_least_one_range_value_inner = true;
 
-                  // qDebug() << "New inner range start:" << inner_range_start;
+                  // qDebug() << "20250904 -New inner range start:"
+                  //          << inner_range_start;
                 }
 
               if(range_end < inner_range_end)
@@ -444,12 +591,13 @@ ProcessingFlow::innermostRange(
 
                   was_at_least_one_range_value_inner = true;
 
-                  // qDebug() << "New inner range end:" << inner_range_end;
+                  // qDebug() << "20250904 -New inner range end:"
+                  //          << inner_range_end;
                 }
 
               if(was_at_least_one_range_value_inner)
                 {
-                  // qDebug() << "Setting step as innermost step.";
+                  // qDebug() << "20250904 -Setting step as innermost step.";
                   // innermost_step_csp = step_csp;
                 }
             }
@@ -459,19 +607,20 @@ ProcessingFlow::innermostRange(
         }
     }
 
-  // qDebug() << "Finished iterating in the vector of steps.";
+  // qDebug() << "20250904 -Finished iterating in the vector of steps.";
 
-  // At this point we have iterated in all the steps. To know if at least one
-  // step was found matching the src_processing_type_mask, we can test the
-  // inner_range_(start|end) values against NaN.
+  // At this point we have iterated in all the steps. To know if at least
+  // one step was found matching the src_processing_type_mask, we can test
+  // the inner_range_(start|end) values against NaN.
 
   // We can't just check innermost_step_csp because the params might
   // tell not to save the step.
 
-  if(std::isnan(inner_range_start) || std::isnan(inner_range_end))
+  if(qIsNaN(inner_range_start) || qIsNaN(inner_range_end))
     return false;
 
-  // We know we can update the values in the variables passed as out params.
+  // We know we can update the values in the variables passed as out
+  // params.
   out_range.first  = inner_range_start;
   out_range.second = inner_range_end;
 
@@ -491,7 +640,8 @@ ProcessingFlow::innermostRange(
           if(!store_only_rhomboid)
             {
               // qDebug()
-              //<< "The caller wants *all* 2D steps, not only the skewed ones.";
+              //<< "The caller wants *all* 2D steps, not only the skewed
+              // ones.";
               should_store_the_step_in_the_end = true;
             }
           else
@@ -499,13 +649,14 @@ ProcessingFlow::innermostRange(
               if(innermost_step_csp->msp_integrationScope->isRhomboid())
                 {
                   should_store_the_step_in_the_end = true;
-                  // qDebug() << "The caller wants *only* the 2D skewed steps
-                  // and "
+                  // qDebug() << "The caller wants *only* the 2D skewed
+                  // steps and "
                   //             "the step *is* rhomboid";
                 }
               // else
               //   {
-              //     qDebug() << "The caller wants *only* the 2D rhomboid steps
+              //     qDebug() << "The caller wants *only* the 2D rhomboid
+              //     steps
               //     "
               //                 "and sthe step is *not* rhomboid";
               //   }
@@ -515,7 +666,8 @@ ProcessingFlow::innermostRange(
       // qDebug() << "Not a single step was found.";
     }
   // else
-  // qDebug() << "The caller does *not* want the innermost step to be stored.";
+  // qDebug() << "The caller does *not* want the innermost step to be
+  // stored.";
 
   // At this point, if we have to store the step, check that another
   // call by another processing type mask has not set it already
@@ -559,7 +711,6 @@ ProcessingFlow::innermostRange(
   return true;
 }
 
-
 bool
 ProcessingFlow::innermostRange(
   const QString src_processing_type_mask,
@@ -575,32 +726,6 @@ ProcessingFlow::innermostRange(
                         store_only_skewed);
 }
 
-
-#if 0
-    bool
-      ProcessingFlow::innermostRtRange(
-          std::pair<ProcessingType, ProcessingStep *> &pair) const
-      {
-        return innermostRange(ProcessingType("RT_TO_ANY"), pair);
-      }
-
-
-    bool
-      ProcessingFlow::innermostMzRange(double &range_start, double &range_end) const
-      {
-        return innermostRange(ProcessingType("MZ_TO_ANY"), range_start, range_end);
-      }
-
-
-    bool
-      ProcessingFlow::innermostMzRange(
-          std::pair<ProcessingType, ProcessingStep *> &pair) const
-      {
-        return innermostRange(ProcessingType("MZ_TO_ANY"), pair);
-      }
-
-#endif
-
 size_t
 ProcessingFlow::greatestMsLevel() const
 {
@@ -610,11 +735,11 @@ ProcessingFlow::greatestMsLevel() const
 
   size_t greatest_ms_level = m_defaultMsFragmentationSpec.getMsLevel();
 
-  for(auto &&step : *this)
+  for(const ProcessingStepCstSPtr &step_csp : m_steps)
     {
-      if(step->getMsLevel() > greatest_ms_level)
+      if(step_csp->getMsLevel() > greatest_ms_level)
         {
-          greatest_ms_level = step->getMsLevel();
+          greatest_ms_level = step_csp->getMsLevel();
         }
     }
 
@@ -624,27 +749,27 @@ ProcessingFlow::greatestMsLevel() const
   return greatest_ms_level;
 }
 
-
 ProcessingStepCstSPtr
 ProcessingFlow::oldestStep() const
 {
   // We rely on the QDateTime instance in the steps to check which of
   // the step was created last.
 
-  if(!size())
+  if(!m_steps.size())
     return nullptr;
 
-  if(size() == 1)
-    return front();
+  if(m_steps.size() == 1)
+    return m_steps.front();
 
-  ProcessingStepCstSPtr oldest_step_csp = front();
+  ProcessingStepCstSPtr oldest_step_csp = m_steps.front();
 
   // Seed the temporary date and time with the first step in the
   // vector.
-  QDateTime temp_date_time = front()->m_dateAndTime;
+  QDateTime temp_date_time = m_steps.front()->m_dateAndTime;
 
-  for(std::vector<ProcessingStepCstSPtr>::const_iterator iterator = begin() + 1;
-      iterator != end();
+  for(std::vector<ProcessingStepCstSPtr>::const_iterator iterator =
+        m_steps.begin() + 1;
+      iterator != m_steps.end();
       ++iterator)
     {
       // Is the iterated step older than temp_date_time?
@@ -658,71 +783,6 @@ ProcessingFlow::oldestStep() const
   return oldest_step_csp;
 }
 
-
-ProcessingStepCstSPtr
-ProcessingFlow::mostRecentStep() const
-{
-  // We rely on the QDateTime instance in the steps to check which of
-  // the step was created last.
-
-  // Calling from on an empty container causes undefined behaviour.
-  if(!size())
-    return nullptr;
-
-  if(size() == 1)
-    return front();
-
-  ProcessingStepCstSPtr most_recent_step_csp = nullptr;
-
-  QDateTime date_time;
-  date_time.setDate(QDate(1900, 1, 1));
-
-  for(auto &&step_p : *this)
-    {
-      // qDebug();
-
-      if(step_p->m_dateAndTime > date_time)
-        most_recent_step_csp = step_p;
-    }
-
-  return most_recent_step_csp;
-}
-
-
-std::vector<ProcessingStepCstSPtr>
-ProcessingFlow::stepsMatchingDestType(const ProcessingType &processing_type,
-                                      bool with_valid_fragmentation_spec) const
-{
-  std::vector<ProcessingStepCstSPtr> processing_steps;
-
-  for(auto &&step_csp : *this)
-    {
-
-      if(step_csp->m_destType.bitMatches(processing_type))
-        {
-          if(with_valid_fragmentation_spec)
-            {
-              if(step_csp->getMsFragmentationSpec().isValid())
-                processing_steps.push_back(step_csp);
-            }
-          else
-            processing_steps.push_back(step_csp);
-        }
-    }
-
-  return processing_steps;
-}
-
-
-std::vector<ProcessingStepCstSPtr>
-ProcessingFlow::stepsMatchingDestType(const QString &processing_type,
-                                      bool with_valid_fragmentation_spec) const
-{
-  return stepsMatchingDestType(ProcessingType(processing_type),
-                               with_valid_fragmentation_spec);
-}
-
-
 ProcessingStepCstSPtr
 ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
 {
@@ -732,16 +792,16 @@ ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
   // We want a step that is older than date_time. But we also want
   // that the step be the most recent older step, that is, the closest
   // older step.
-  if(!size())
+  if(!m_steps.size())
     return nullptr;
 
-  if(size() == 1)
+  if(m_steps.size() == 1)
     {
-      if(front()->m_dateAndTime < date_time)
+      if(m_steps.front()->m_dateAndTime < date_time)
         {
           // qDebug() << "Returning unique older:" <<
           // front()->m_dateAndTime;
-          return front();
+          return m_steps.front();
         }
     }
   else
@@ -753,8 +813,9 @@ ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
 
   ProcessingStepCstSPtr older_step_csp = nullptr;
 
-  for(std::vector<ProcessingStepCstSPtr>::const_iterator iterator = begin();
-      iterator != end();
+  for(std::vector<ProcessingStepCstSPtr>::const_iterator iterator =
+        m_steps.begin();
+      iterator != m_steps.end();
       ++iterator)
     {
       // qDebug() << "Iterating in time:" <<
@@ -791,6 +852,98 @@ ProcessingFlow::closestOlderStep(const QDateTime &date_time) const
   return older_step_csp;
 }
 
+ProcessingStepCstSPtr
+ProcessingFlow::mostRecentStep() const
+{
+  // We rely on the QDateTime instance in the steps to check which of
+  // the step was created last.
+
+  // Calling from on an empty container causes undefined behaviour.
+  if(!m_steps.size())
+    return nullptr;
+
+  if(m_steps.size() == 1)
+    return m_steps.front();
+
+  ProcessingStepCstSPtr most_recent_step_csp = nullptr;
+
+  QDateTime date_time;
+  date_time.setDate(QDate(1900, 1, 1));
+
+  for(const ProcessingStepCstSPtr &step_csp : m_steps)
+    {
+      // qDebug();
+
+      if(step_csp->m_dateAndTime > date_time)
+        most_recent_step_csp = step_csp;
+    }
+
+  return most_recent_step_csp;
+}
+
+std::vector<ProcessingStepCstSPtr>
+ProcessingFlow::stepsMatchingSrcTypeX(const ProcessingType &processing_type,
+                                      bool with_valid_fragmentation_spec) const
+{
+  std::vector<ProcessingStepCstSPtr> processing_steps;
+
+  for(const ProcessingStepCstSPtr &step_csp : m_steps)
+    {
+
+      if(step_csp->m_xSrcType.bitMatches(processing_type))
+        {
+          if(with_valid_fragmentation_spec)
+            {
+              if(step_csp->getMsFragmentationSpec().isValid())
+                processing_steps.push_back(step_csp);
+            }
+          else
+            processing_steps.push_back(step_csp);
+        }
+    }
+
+  return processing_steps;
+}
+
+std::vector<ProcessingStepCstSPtr>
+ProcessingFlow::stepsMatchingSrcTypeX(const QString &processing_type,
+                                      bool with_valid_fragmentation_spec) const
+{
+  return stepsMatchingSrcTypeX(ProcessingType(processing_type),
+                               with_valid_fragmentation_spec);
+}
+
+std::vector<ProcessingStepCstSPtr>
+ProcessingFlow::stepsMatchingDestType(const ProcessingType &processing_type,
+                                      bool with_valid_fragmentation_spec) const
+{
+  std::vector<ProcessingStepCstSPtr> processing_steps;
+
+  for(const ProcessingStepCstSPtr &step_csp : m_steps)
+    {
+
+      if(step_csp->m_destType.bitMatches(processing_type))
+        {
+          if(with_valid_fragmentation_spec)
+            {
+              if(step_csp->getMsFragmentationSpec().isValid())
+                processing_steps.push_back(step_csp);
+            }
+          else
+            processing_steps.push_back(step_csp);
+        }
+    }
+
+  return processing_steps;
+}
+
+std::vector<ProcessingStepCstSPtr>
+ProcessingFlow::stepsMatchingDestType(const QString &processing_type,
+                                      bool with_valid_fragmentation_spec) const
+{
+  return stepsMatchingDestType(ProcessingType(processing_type),
+                               with_valid_fragmentation_spec);
+}
 
 const pappso::MzIntegrationParams *
 ProcessingFlow::mostRecentMzIntegrationParams() const
@@ -866,7 +1019,6 @@ ProcessingFlow::mostRecentMzIntegrationParams() const
   return nullptr;
 }
 
-
 QString
 ProcessingFlow::toString(int offset, const QString &spacer) const
 {
@@ -880,7 +1032,7 @@ ProcessingFlow::toString(int offset, const QString &spacer) const
 
   // text += lead;
   // text += spacer;
-  text += "Sample name:\n";
+  text += "Sample name: ";
   if(mcsp_msRunDataSet == nullptr)
     text += "nullptr";
   else
@@ -890,8 +1042,11 @@ ProcessingFlow::toString(int offset, const QString &spacer) const
   // text += lead;
   // text += spacer;
   // text += "Default m/z integration params:\n";
-  text += m_defaultMzIntegrationParams.toString(offset, spacer);
-  text += "\n";
+  if(mp_defaultMzIntegrationParams != nullptr)
+    {
+      text += mp_defaultMzIntegrationParams->toString(offset, spacer);
+      text += "\n";
+    }
 
   // text += lead;
   // text += spacer;
@@ -900,15 +1055,15 @@ ProcessingFlow::toString(int offset, const QString &spacer) const
   text += "\n";
 
   // Only show the steps if there are any !
-  if(size())
+  if(m_steps.size())
     {
       // text += lead;
       // text += spacer;
       // text += "The steps:\n";
 
-      for(auto &&step : *this)
+      for(const ProcessingStepCstSPtr &step_csp : m_steps)
         {
-          text += step->toString(offset, spacer);
+          text += QString("-> %1").arg(step_csp->toString(offset, spacer));
           // text += "\n";
         }
     }
@@ -932,8 +1087,21 @@ ProcessingFlow::toString(int offset, const QString &spacer) const
   return text;
 }
 
+void
+ProcessingFlow::registerJsConstructor(QJSEngine *engine)
+{
+  if(!engine)
+    {
+      qWarning() << "Cannot register class: engine is null";
+      return;
+    }
 
-} // namespace minexpert
+  // Register the meta object as a constructor
+  QJSValue jsMetaObject =
+    engine->newQMetaObject(&ProcessingFlow::staticMetaObject);
+  engine->globalObject().setProperty("ProcessingFlow", jsMetaObject);
+}
 
 
+} // namespace MineXpert
 } // namespace MsXpS
