@@ -40,11 +40,18 @@
 /////////////////////// Qt includes
 #include <QString>
 #include <QDateTime>
+#include <QtQml>
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/filters/filterinterface.h>
-#include <pappsomspp/processing/filters/filtersuitestring.h>
+#include <pappsomspp/core/processing/filters/filterinterface.h>
+#include <pappsomspp/core/processing/filters/filtersuitestring.h>
+
+
+/////////////////////// libXpertMass includes
+// For MSXPS_REGISTER_JS_CLASS(NS_IDENT, CLASS_NAME)
+// At the end of the file.
+#include <MsXpS/libXpertMassGui/ScriptingEnginesBridge.hpp>
 
 
 /////////////////////// Local includes
@@ -54,28 +61,52 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class ProcessingType;
 class ProcessingStep;
 
-class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
+class ProcessingFlow: public QObject
 {
+  Q_OBJECT
+  QML_ELEMENT
 
   public:
-  ProcessingFlow();
-  ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp);
-  ProcessingFlow(const ProcessingFlow &other);
+  Q_INVOKABLE explicit ProcessingFlow(QObject *parent = nullptr);
+  Q_INVOKABLE explicit ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp,
+                             QObject *parent = nullptr);
 
   virtual ~ProcessingFlow();
 
-  ProcessingFlow &operator=(const ProcessingFlow &other);
+  Q_INVOKABLE ProcessingFlow *clone(QObject *parent = nullptr) const;
 
-  std::vector<ProcessingStepCstSPtr> steps();
+  Q_INVOKABLE void initialize(const ProcessingFlow &other);
+
+  void setMsRunDataSetCstSPtr(MsRunDataSetCstSPtr ms_run_data_set_csp);
+  MsRunDataSetCstSPtr getMsRunDataSetCstSPtr() const;
+
+  const std::vector<ProcessingStepCstSPtr> &getStepsCstRef() const;
+  std::vector<ProcessingStepCstSPtr> &getStepsRef();
+
+  Q_INVOKABLE pappso::MzIntegrationParams *
+  getSensibleMzIntegrationParams() const;
+
+  Q_INVOKABLE void setDefaultMzIntegrationParams(
+    const pappso::MzIntegrationParams &mz_integration_params);
+
+  Q_INVOKABLE pappso::MzIntegrationParams *getDefaultMzIntegrationParams();
+
+  Q_INVOKABLE const pappso::MzIntegrationParams *
+  mostRecentMzIntegrationParams() const;
+
+  void setDefaultMsFragmentationSpec(
+    const MsFragmentationSpec &ms_fragmentation_spec);
+  const MsFragmentationSpec &getDefaultMsFragmentationSpec() const;
 
   const std::map<QString, pappso::FilterNameInterfaceCstSPtr> &
-  getFilterMap() const;
+  getFilterMapCstRef() const;
+  std::map<QString, pappso::FilterNameInterfaceCstSPtr> &getFilterMapRef();
 
   void addFilter(pappso::FilterNameInterfaceCstSPtr filter_csp);
   std::size_t removeFilter(const QString &filter_name);
@@ -87,7 +118,7 @@ class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
                  std::pair<double, double> &out_range,
                  std::vector<ProcessingStepCstSPtr> *out_processing_steps_p,
                  bool store_only_2d_steps = true,
-                 bool store_only_skewed   = true) const;
+                 bool store_only_rhomboid   = true) const;
 
   bool innermostRange(
     const QString src_processing_type_mask,
@@ -96,12 +127,20 @@ class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
     bool store_only_2d_steps                                   = true,
     bool store_only_rhomboid                                   = true) const;
 
-  size_t greatestMsLevel() const;
+  Q_INVOKABLE size_t greatestMsLevel() const;
 
   ProcessingStepCstSPtr oldestStep() const;
   ProcessingStepCstSPtr closestOlderStep(const QDateTime &date_time) const;
   ProcessingStepCstSPtr mostRecentStep() const;
 
+  std::vector<ProcessingStepCstSPtr>
+  stepsMatchingSrcTypeX(const ProcessingType &processing_type,
+                        bool with_valid_fragmentation_spec = false) const;
+
+  std::vector<ProcessingStepCstSPtr>
+  stepsMatchingSrcTypeX(const QString &processing_type,
+                        bool with_valid_fragmentation_spec = false) const;
+
   std::vector<ProcessingStepCstSPtr>
   stepsMatchingDestType(const ProcessingType &processing_type,
                         bool with_valid_fragmentation_spec = false) const;
@@ -110,29 +149,21 @@ class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
   stepsMatchingDestType(const QString &processing_type,
                         bool with_valid_fragmentation_spec = false) const;
 
-  void setDefaultMzIntegrationParams(
-    const pappso::MzIntegrationParams &mz_integration_params);
-  const pappso::MzIntegrationParams &getDefaultMzIntegrationParams() const;
-  const pappso::MzIntegrationParams *mostRecentMzIntegrationParams() const;
+  Q_INVOKABLE QString toString(int offset            = 0,
+                               const QString &spacer = QString()) const;
 
-  void setDefaultMsFragmentationSpec(
-    const MsFragmentationSpec &ms_fragmentation_spec);
-  const MsFragmentationSpec &getDefaultMsFragmentationSpec() const;
-
-
-  void setMsRunDataSetCstSPtr(MsRunDataSetCstSPtr ms_run_data_set_csp);
-  MsRunDataSetCstSPtr getMsRunDataSetCstSPtr() const;
-
-  QString toString(int offset = 0, const QString &spacer = QString()) const;
+  static void registerJsConstructor(QJSEngine *engine);
 
   protected:
   MsRunDataSetCstSPtr mcsp_msRunDataSet = nullptr;
 
+  std::vector<ProcessingStepCstSPtr> m_steps;
+
   // Note that each step has an optional pappso::MzIntegrationParams *. This one
   // is the default one when not a single step has mz integration params. This
   // one is set automatically in the first graph obtained when displaying the
   // TIC chromatogram right after having loaded the ms run from file.
-  pappso::MzIntegrationParams m_defaultMzIntegrationParams;
+  pappso::MzIntegrationParams *mp_defaultMzIntegrationParams = nullptr;
 
   // Same for MsFragmentationSpec
   MsFragmentationSpec m_defaultMsFragmentationSpec;
@@ -143,6 +174,6 @@ class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
 };
 
 
-} // namespace minexpert
-
+} // namespace MineXpert
+MSXPS_REGISTER_JS_CLASS(MsXpS::MineXpert, ProcessingFlow)
 } // namespace MsXpS
