@@ -39,22 +39,20 @@
 #include <QDebug>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/integrationscope.h>
-#include <pappsomspp/processing/combiners/integrationscoperect.h>
-#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
+#include <pappsomspp/core/processing/combiners/integrationscope.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperhomb.h>
 
 /////////////////////// Local includes
 #include "ProcessingStep.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
-ProcessingStep::ProcessingStep()
-  : m_dateAndTime(QDateTime::currentDateTimeUtc())
+ProcessingStep::ProcessingStep(): m_dateAndTime(QDateTime::currentDateTimeUtc())
 {
   // So that we know it is not nullptr;
   msp_integrationScope = std::make_shared<pappso::IntegrationScopeBase>();
@@ -78,15 +76,13 @@ ProcessingStep::ProcessingStep(const ProcessingStep &other)
     m_yAxisDataKind(other.m_yAxisDataKind)
 {
   if(other.mpa_mzIntegrationParams != nullptr)
-    mpa_mzIntegrationParams =
-      new pappso::MzIntegrationParams(*other.mpa_mzIntegrationParams);
+    mpa_mzIntegrationParams = other.mpa_mzIntegrationParams->clone(nullptr);
 
   if(other.mpa_msFragmentationSpec != nullptr)
     mpa_msFragmentationSpec =
       new MsFragmentationSpec(*other.mpa_msFragmentationSpec);
 }
 
-
 ProcessingStep::~ProcessingStep()
 {
   if(mpa_mzIntegrationParams != nullptr)
@@ -96,7 +92,6 @@ ProcessingStep::~ProcessingStep()
     delete mpa_msFragmentationSpec;
 }
 
-
 ProcessingStep &
 ProcessingStep::operator=(const ProcessingStep &other)
 {
@@ -116,8 +111,7 @@ ProcessingStep::operator=(const ProcessingStep &other)
   m_yAxisDataKind = other.m_yAxisDataKind;
 
   if(other.mpa_mzIntegrationParams != nullptr)
-    mpa_mzIntegrationParams =
-      new pappso::MzIntegrationParams(*other.mpa_mzIntegrationParams);
+    mpa_mzIntegrationParams = mpa_mzIntegrationParams->clone(nullptr);
 
   if(other.mpa_msFragmentationSpec != nullptr)
     mpa_msFragmentationSpec =
@@ -126,40 +120,36 @@ ProcessingStep::operator=(const ProcessingStep &other)
   return *this;
 }
 
-
 void
-ProcessingStep::setSrcProcessingType(pappso::Axis axis,
+ProcessingStep::setSrcProcessingType(pappso::Enums::Axis axis,
                                      const ProcessingType &processing_type)
 {
-  if(axis == pappso::Axis::x)
+  if(axis == pappso::Enums::Axis::x)
     m_xSrcType = processing_type;
-  else if(axis == pappso::Axis::y)
+  else if(axis == pappso::Enums::Axis::y)
     m_ySrcType = processing_type;
   else
     qFatal("Programming error.");
 }
 
-
 void
-ProcessingStep::setSrcProcessingType(pappso::Axis axis,
+ProcessingStep::setSrcProcessingType(pappso::Enums::Axis axis,
                                      const QString &processing_type)
 {
   return setSrcProcessingType(axis, ProcessingType(processing_type));
 }
 
-
 ProcessingType
-ProcessingStep::getSrcProcessingType(pappso::Axis axis) const
+ProcessingStep::getSrcProcessingType(pappso::Enums::Axis axis) const
 {
-  if(axis == pappso::Axis::x)
+  if(axis == pappso::Enums::Axis::x)
     return m_xSrcType;
-  else if(axis == pappso::Axis::y)
+  else if(axis == pappso::Enums::Axis::y)
     return m_ySrcType;
 
   return ProcessingType("NOT_SET");
 }
 
-
 void
 ProcessingStep::setDestProcessingType(const ProcessingType &processing_type)
 {
@@ -199,68 +189,69 @@ ProcessingStep::resetIntegrationScope()
 }
 
 void
-ProcessingStep::setDataKind(pappso::Axis axis, pappso::DataKind data_kind)
+ProcessingStep::setDataKind(pappso::Enums::Axis axis,
+                            pappso::Enums::DataKind data_kind)
 {
-  if(static_cast<int>(axis) & static_cast<int>(pappso::Axis::x))
+  if(static_cast<int>(axis) & static_cast<int>(pappso::Enums::Axis::x))
     m_xAxisDataKind = data_kind;
-  else if(static_cast<int>(axis) & static_cast<int>(pappso::Axis::y))
+  else if(static_cast<int>(axis) & static_cast<int>(pappso::Enums::Axis::y))
     m_yAxisDataKind = data_kind;
   else
     qFatal("The axis provided is not correct.");
 }
 
-
-pappso::DataKind
-ProcessingStep::getDataKind(pappso::Axis axis) const
+pappso::Enums::DataKind
+ProcessingStep::getDataKind(pappso::Enums::Axis axis) const
 {
-  if(static_cast<int>(axis) & static_cast<int>(pappso::Axis::x))
+  if(static_cast<int>(axis) & static_cast<int>(pappso::Enums::Axis::x))
     return m_xAxisDataKind;
-  else if(static_cast<int>(axis) & static_cast<int>(pappso::Axis::y))
+  else if(static_cast<int>(axis) & static_cast<int>(pappso::Enums::Axis::y))
     return m_yAxisDataKind;
   else
     qFatal("The axis provided is not correct.");
 }
 
-
 bool
-ProcessingStep::getRangeForAxis(pappso::Axis axis,
+ProcessingStep::getRangeForAxis(pappso::Enums::Axis axis,
                                 double &range_start,
                                 double &range_end) const
 {
   return msp_integrationScope->range(axis, range_start, range_end);
 }
 
-
 bool
 ProcessingStep::getRangeForAxisX(double &range_start, double &range_end) const
 {
-  return getRangeForAxis(pappso::Axis::x, range_start, range_end);
+  return getRangeForAxis(pappso::Enums::Axis::x, range_start, range_end);
 }
 
-
 bool
 ProcessingStep::getRangeForAxisY(double &range_start, double &range_end) const
 {
-  return getRangeForAxis(pappso::Axis::y, range_start, range_end);
+  return getRangeForAxis(pappso::Enums::Axis::y, range_start, range_end);
 }
 
+// Taking ownership
+void
+ProcessingStep::setMzIntegrationParams(
+  pappso::MzIntegrationParams *mz_integration_params_p)
+{
+  mpa_mzIntegrationParams = mz_integration_params_p;
+}
 
 void
 ProcessingStep::setMzIntegrationParams(
   const pappso::MzIntegrationParams &mz_integration_params)
 {
-  mpa_mzIntegrationParams =
-    new pappso::MzIntegrationParams(mz_integration_params);
+  mpa_mzIntegrationParams = mz_integration_params.clone(nullptr);
 }
 
-
 const pappso::MzIntegrationParams *
-ProcessingStep::getMzIntegrationParamsPtr() const
+ProcessingStep::getMzIntegrationParams() const
 {
   return mpa_mzIntegrationParams;
 }
 
-
 void
 ProcessingStep::setMsFragmentationSpec(
   const MsFragmentationSpec &fragmentation_spec)
@@ -271,7 +262,6 @@ ProcessingStep::setMsFragmentationSpec(
   mpa_msFragmentationSpec = new MsFragmentationSpec(fragmentation_spec);
 }
 
-
 MsFragmentationSpec
 ProcessingStep::getMsFragmentationSpec() const
 {
@@ -281,14 +271,12 @@ ProcessingStep::getMsFragmentationSpec() const
   return MsFragmentationSpec();
 }
 
-
 MsFragmentationSpec *
 ProcessingStep::getMsFragmentationSpecPtr()
 {
   return mpa_msFragmentationSpec;
 }
 
-
 size_t
 ProcessingStep::getMsLevel() const
 {
@@ -298,7 +286,6 @@ ProcessingStep::getMsLevel() const
   return 0;
 }
 
-
 bool
 ProcessingStep::hasValidFragmentationSpec() const
 {
@@ -308,7 +295,6 @@ ProcessingStep::hasValidFragmentationSpec() const
     return false;
 }
 
-
 bool
 ProcessingStep::isValid() const
 {
@@ -329,56 +315,49 @@ ProcessingStep::isValid() const
   if(!msp_integrationScope->is1D() && !msp_integrationScope->is2D())
     return false;
 
-  if(m_xAxisDataKind == pappso::DataKind::unset ||
-     m_yAxisDataKind == pappso::DataKind::unset)
+  if(m_xAxisDataKind == pappso::Enums::DataKind::unset ||
+     m_yAxisDataKind == pappso::Enums::DataKind::unset)
     return false;
 
   return true;
 }
 
-
 bool
 ProcessingStep::srcMatches(std::bitset<32> bit_set) const
 {
   return (m_xSrcType.bitMatches(bit_set) || m_ySrcType.bitMatches(bit_set));
 }
 
-
 bool
 ProcessingStep::srcMatches(const ProcessingType &processing_type) const
 {
   return srcMatches(processing_type.bitSet());
 }
 
-
 bool
 ProcessingStep::srcMatches(const QString &brief_desc) const
 {
   return srcMatches(ProcessingType(brief_desc));
 }
 
-
 bool
 ProcessingStep::destMatches(std::bitset<32> bit_set) const
 {
   return (m_destType.bitMatches(bit_set));
 }
 
-
 bool
 ProcessingStep::destMatches(const ProcessingType &processing_type) const
 {
   return destMatches(processing_type.bitSet());
 }
 
-
 bool
 ProcessingStep::destMatches(const QString &brief_desc) const
 {
   return destMatches(ProcessingType(brief_desc));
 }
 
-
 QString
 ProcessingStep::toString(int offset, const QString &spacer) const
 {
@@ -387,10 +366,10 @@ ProcessingStep::toString(int offset, const QString &spacer) const
   for(int iter = 0; iter < offset; ++iter)
     lead += spacer;
 
-  QString text = lead;
-  text += "Processing step at: ";
-  text += m_dateAndTime.toString("yyyyMMdd-HH:mm:ss");
-  text += "\n";
+  QString text  = lead;
+  text         += "Processing step at: ";
+  text         += m_dateAndTime.toString("yyyyMMdd-HH:mm:ss");
+  text         += "\n";
 
   text += "X axis Source Processing type: ";
   text += m_xSrcType.toBriefDesc();
@@ -412,11 +391,17 @@ ProcessingStep::toString(int offset, const QString &spacer) const
   text += QString::number(static_cast<int>(m_yAxisDataKind), 10);
   text += "\n";
 
-  text += msp_integrationScope->toString();
-  text += "\n";
+  QString integration_scope = msp_integrationScope->toString();
+  if(!integration_scope.isEmpty())
+  {
+      text += "Step's integration scope:";
+      text += msp_integrationScope->toString();
+      text += "\n";
+    }
 
   if(mpa_mzIntegrationParams != nullptr)
     {
+      text += "Step's m/z integration params:\n";
       // text += lead;
       // text +=  spacer;
       text += mpa_mzIntegrationParams->toString(offset + 2, spacer);
@@ -425,6 +410,7 @@ ProcessingStep::toString(int offset, const QString &spacer) const
 
   if(mpa_msFragmentationSpec != nullptr)
     {
+      text += "Step's fragmentation spec:\n";
       // text += lead;
       // text +=  spacer;
       text += mpa_msFragmentationSpec->toString(offset + 2, spacer);
@@ -435,6 +421,6 @@ ProcessingStep::toString(int offset, const QString &spacer) const
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
