@@ -44,31 +44,20 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-#include <pappsomspp/processing/combiners/selectionpolygon.h>
-#include <pappsomspp/processing/combiners/integrationscopebase.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/selectionpolygon.h>
+#include <pappsomspp/core/processing/combiners/integrationscopebase.h>
 
 /////////////////////// Local includes
 #include "ProcessingType.hpp"
 // #include "ProcessingFlow.hpp"
 #include "MsFragmentationSpec.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-struct ProcessingTypeCompare
-{
-  bool
-  operator()(const ProcessingType &a, const ProcessingType &b) const
-  {
-    return a.bitSet().to_string() < b.bitSet().to_string();
-  }
-};
-
-
 class ProcessingStep
 {
 
@@ -91,23 +80,24 @@ class ProcessingStep
   void setProcessingType(const ProcessingType &processing_type);
   ProcessingType getProcessingType() const;
 
-  void setSrcProcessingType(pappso::Axis axis,
+  void setSrcProcessingType(pappso::Enums::Axis axis,
                             const ProcessingType &processing_type);
-  void setSrcProcessingType(pappso::Axis axis, const QString &processing_type);
-  ProcessingType getSrcProcessingType(pappso::Axis axis) const;
+  void setSrcProcessingType(pappso::Enums::Axis axis, const QString &processing_type);
+  ProcessingType getSrcProcessingType(pappso::Enums::Axis axis) const;
 
   void setDestProcessingType(const ProcessingType &processing_type);
   void setDestProcessingType(const QString &processing_type);
   ProcessingType getDestProcessingType() const;
 
-  void setIntegrationScope(pappso::IntegrationScopeBaseCstSPtr integration_scope_csp);
+  void setIntegrationScope(
+    pappso::IntegrationScopeBaseCstSPtr integration_scope_csp);
   pappso::IntegrationScopeBaseCstSPtr getIntegrationScope() const;
   void resetIntegrationScope();
 
-  void setDataKind(pappso::Axis axis, pappso::DataKind data_kind);
-  pappso::DataKind getDataKind(pappso::Axis axis) const;
+  void setDataKind(pappso::Enums::Axis axis, pappso::Enums::DataKind data_kind);
+  pappso::Enums::DataKind getDataKind(pappso::Enums::Axis axis) const;
 
-  bool getRangeForAxis(pappso::Axis axis,
+  bool getRangeForAxis(pappso::Enums::Axis axis,
                        double &range_start,
                        double &range_end) const;
   bool getRangeForAxisX(double &range_start, double &range_end) const;
@@ -115,7 +105,11 @@ class ProcessingStep
 
   void setMzIntegrationParams(
     const pappso::MzIntegrationParams &mz_integration_params);
-  const pappso::MzIntegrationParams *getMzIntegrationParamsPtr() const;
+
+  void
+  setMzIntegrationParams(pappso::MzIntegrationParams *mz_integration_params_p);
+
+  const pappso::MzIntegrationParams *getMzIntegrationParams() const;
 
   void setMsFragmentationSpec(const MsFragmentationSpec &fragmentation_spec);
   MsFragmentationSpec getMsFragmentationSpec() const;
@@ -148,8 +142,8 @@ class ProcessingStep
 
   // We need to know which kind of data are along the axes that make the
   // integration scope..
-  pappso::DataKind m_xAxisDataKind = pappso::DataKind::unset;
-  pappso::DataKind m_yAxisDataKind = pappso::DataKind::unset;
+  pappso::Enums::DataKind m_xAxisDataKind = pappso::Enums::DataKind::unset;
+  pappso::Enums::DataKind m_yAxisDataKind = pappso::Enums::DataKind::unset;
 
   // When integrating to m/z spectra we need to configure the integration. This
   // class instance allows to do so. Because not all the specs need such
@@ -162,7 +156,6 @@ class ProcessingStep
   MsFragmentationSpec *mpa_msFragmentationSpec = nullptr;
 };
 
-
 typedef std::shared_ptr<ProcessingStep> ProcessingStepSPtr;
 typedef std::shared_ptr<const ProcessingStep> ProcessingStepCstSPtr;
 
@@ -179,6 +172,6 @@ struct ProcessingStepCompare
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
