@@ -47,14 +47,14 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 bool ProcessingType::mapFilled = false;
 
 // clang-format off
 std::vector<ProcessingTypeStringPair> ProcessingType::processingTypes =
-{ 
+{
 	std::pair<QString, QString>("NOT_SET", "Not set"),
 
   // These are the new types conforming to the new idea of a processing step's
@@ -82,6 +82,7 @@ std::vector<ProcessingTypeStringPair> ProcessingType::processingTypes =
 	std::pair<QString, QString>("MZ_RT", "Mass spectrum, Tic|Xic chrom."),
 
 	std::pair<QString, QString>("RT", "Tic|Xic chrom."),
+	std::pair<QString, QString>("SOCKET_RT", "Socket, fake Tic|Xic chrom."),
 
 	std::pair<QString, QString>("INT", "Tic intensity"),
  //std::pair<QString, QString>("", ""),
@@ -168,6 +169,7 @@ ProcessingType::registerProcessingTypes()
     "DT_RT",
     "MZ_RT",
     "RT",
+    "SOCKET_RT",
      };
   // clang-format on
   registerProcessingCompositeTypes(
@@ -604,6 +606,6 @@ ProcessingType::bitMatches(const QString &mask) const
 /// End non static comparison and bit matching ///
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
