@@ -45,93 +45,81 @@
 /////////////////////// Local includes
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 #include "ProcessingStep.hpp"
-#include <pappsomspp/processing/combiners/integrationscoperect.h>
-#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
-
-int qualifiedMassSpectrumVectorMassDataIntegratorMetaTypeId = qRegisterMetaType<
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator>(
-  "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator");
-
-int qualMassSpecVecMassDataIntegratorSPtrMetaTypeId = qRegisterMetaType<
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr>(
-  "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr");
-
+#include <pappsomspp/core/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/core/processing/combiners/integrationscoperhomb.h>
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 // Needed for qRegisterMetaType
 QualifiedMassSpectrumVectorMassDataIntegrator::
-  QualifiedMassSpectrumVectorMassDataIntegrator()
+  QualifiedMassSpectrumVectorMassDataIntegrator(QObject *parent)
+  : QObject(parent),
+    mp_processingFlow(new ProcessingFlow(dynamic_cast<QObject *>(this)))
 {
 }
 
-
 QualifiedMassSpectrumVectorMassDataIntegrator::
   QualifiedMassSpectrumVectorMassDataIntegrator(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp)
-  : mcsp_msRunDataSet(ms_run_data_set_csp),
-    m_processingFlow(processing_flow),
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent)
+  : QObject(parent),
+    mcsp_msRunDataSet(ms_run_data_set_csp),
+    mp_processingFlow(processing_flow.clone(dynamic_cast<QObject *>(this))),
     mcsp_qualifiedMassSpectraToIntegrateVector(
       qualified_mass_spectra_to_integrate_sp)
 {
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
+  mp_processingFlow->setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
 
   // qDebug() << "Going to call setInnermostRanges().";
   setInnermostRanges();
 }
 
-
-// Needed for qRegisterMetaType
-QualifiedMassSpectrumVectorMassDataIntegrator::
-  QualifiedMassSpectrumVectorMassDataIntegrator(
-    const QualifiedMassSpectrumVectorMassDataIntegrator &other)
-  : QObject(),
-    mcsp_msRunDataSet(other.mcsp_msRunDataSet),
-    m_processingFlow(other.m_processingFlow),
-    mcsp_qualifiedMassSpectraToIntegrateVector(
-      other.mcsp_qualifiedMassSpectraToIntegrateVector)
-{
-  // qDebug();
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
-  setInnermostRanges();
-}
-
-
 QualifiedMassSpectrumVectorMassDataIntegrator::
   ~QualifiedMassSpectrumVectorMassDataIntegrator()
 {
 }
 
-
 MsRunDataSetCstSPtr
 QualifiedMassSpectrumVectorMassDataIntegrator::getMsRunDataSet() const
 {
   return mcsp_msRunDataSet;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::setProcessingFlow(
   const ProcessingFlow &processing_flow)
 {
-  m_processingFlow = processing_flow;
+  delete mp_processingFlow;
+
+  mp_processingFlow = processing_flow.clone(dynamic_cast<QObject *>(this));
 
   // qDebug() << "Going to call setInnermostRanges().";
   setInnermostRanges();
 }
 
-
 const ProcessingFlow &
-QualifiedMassSpectrumVectorMassDataIntegrator::getProcessingFlow() const
+QualifiedMassSpectrumVectorMassDataIntegrator::getProcessingFlowCstRef() const
 {
-  return m_processingFlow;
+  return *mp_processingFlow;
 }
 
+ProcessingFlow &
+QualifiedMassSpectrumVectorMassDataIntegrator::getProcessingFlowRef()
+{
+  return *mp_processingFlow;
+}
+
+ProcessingFlow *
+QualifiedMassSpectrumVectorMassDataIntegrator::getProcessingFlow()
+{
+  return mp_processingFlow;
+}
 
 pappso::QualifiedMassSpectrumCstSPtr
 QualifiedMassSpectrumVectorMassDataIntegrator::checkQualifiedMassSpectrum(
@@ -184,14 +172,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkQualifiedMassSpectrum(
   return qualified_mass_spectrum_csp;
 }
 
-
 const pappso::MapTrace &
 QualifiedMassSpectrumVectorMassDataIntegrator::getMapTrace() const
 {
   return m_mapTrace;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::setMaxThreadUseCount(
   std::size_t number)
@@ -199,14 +185,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setMaxThreadUseCount(
   m_maxThreadUseCount = number;
 }
 
-
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegrator::getMaxThreadUseCount()
 {
   return m_maxThreadUseCount;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::cancelOperation()
 {
@@ -218,7 +202,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::cancelOperation()
   emit cancelOperationSignal();
 }
 
-
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegrator::bestThreadCount()
 {
@@ -248,7 +231,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::bestThreadCount()
   return ideal_thread_count;
 }
 
-
 std::pair<std::size_t, std::size_t>
 QualifiedMassSpectrumVectorMassDataIntegrator::bestParallelIntegrationParams(
   [[maybe_unused]] std::size_t node_count)
@@ -264,7 +246,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::bestParallelIntegrationParams(
   return std::pair<std::size_t, int>(ideal_thread_count, nodes_per_thread);
 }
 
-
 using Iterator =
   std::vector<pappso::QualifiedMassSpectrumCstSPtr>::const_iterator;
 
@@ -390,7 +371,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::calculateIteratorPairs(
   return iterators;
 }
 
-
 std::vector<std::pair<Iterator, Iterator>>
 QualifiedMassSpectrumVectorMassDataIntegrator::calculateIteratorPairs(
   Iterator begin_iterator,
@@ -464,7 +444,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::calculateIteratorPairs(
   return iterators;
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkMsLevel(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -492,7 +471,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsLevel(
   // mass spectra that have as MS level matching that greatest MS level as
   // recorded in the steps of the processing flow.
 
-  std::size_t greatest_ms_level = m_processingFlow.greatestMsLevel();
+  std::size_t greatest_ms_level = mp_processingFlow->greatestMsLevel();
 
   // qDebug().noquote() << "Greatest ms level in the processing flow:"
   //<< greatest_ms_level
@@ -532,7 +511,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsLevel(
   return true;
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
   ProcessingStepCstSPtr processing_step_csp,
@@ -626,7 +604,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
   return true;
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -644,7 +621,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
 
   // A processing flow contains a number of processing steps.
 
-  for(auto &&step_csp : m_processingFlow)
+  for(auto &&step_csp : mp_processingFlow->getStepsCstRef())
     {
       if(!checkMsFragmentation(step_csp, qualified_mass_spectrum_csp))
         return false;
@@ -653,11 +630,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
   return true;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
 {
-  // qDebug();
+  qDebug().noquote()
+    << "20250904 - Setting innermost ranges for processing flow:"
+    << mp_processingFlow->toString(0, "  ");
 
   m_innermostSteps2D.clear();
 
@@ -692,12 +670,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   // for the analysis of the data. The check<DataKind>Range() functions do
   // monitor the m_innermostSteps2D vector for rhomboid-shaped rectangles.
 
-  m_dtRange.first  = std::numeric_limits<double>::quiet_NaN();
-  m_dtRange.second = std::numeric_limits<double>::quiet_NaN();
+  m_dtRange.first  = qQNaN();
+  m_dtRange.second = qQNaN();
 
   // true: only 2D steps
   // true: only skewed 2D steps
-  if(m_processingFlow.innermostRange(
+  if(mp_processingFlow->innermostRange(
        "ANY_DT", range_pair, &m_innermostSteps2D, true, true))
     {
       // qDebug() << "innermost DT range:" << range_pair.first << "-"
@@ -707,12 +685,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
       m_dtRange.second = range_pair.second;
     }
 
-  m_mzRange.first  = std::numeric_limits<double>::quiet_NaN();
-  m_mzRange.second = std::numeric_limits<double>::quiet_NaN();
+  m_mzRange.first  = qQNaN();
+  m_mzRange.second = qQNaN();
 
   // true: only 2D steps
   // true: only skewed 2D steps
-  if(m_processingFlow.innermostRange(
+  if(mp_processingFlow->innermostRange(
        "ANY_MZ", range_pair, &m_innermostSteps2D, true, true))
     {
       qDebug() << "innermost MZ range:" << range_pair.first << "-"
@@ -725,8 +703,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
       qDebug() << "m_mzRange.second:" << m_mzRange.second;
     }
 
-  m_rtRange.first  = std::numeric_limits<double>::quiet_NaN();
-  m_rtRange.second = std::numeric_limits<double>::quiet_NaN();
+  m_rtRange.first  = qQNaN();
+  m_rtRange.second = qQNaN();
 
   // When dealing with steps that are created for a 2D selection in a color map,
   // for example, there might be skewed selection polygons. For these selection
@@ -741,7 +719,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
 
   // true: only 2D steps
   // true: only skewed 2D steps
-  if(m_processingFlow.innermostRange(
+  if(mp_processingFlow->innermostRange(
        "ANY_RT", range_pair, &m_innermostSteps2D, true, true))
     {
       // qDebug() << "innermost RT range:" << range_pair.first << "-"
@@ -766,7 +744,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   //<< "steps";
 }
 
-
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
   std::vector<pappso::IntegrationScopeSpec> &integration_scope_specs)
@@ -785,7 +762,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
 
   for(auto &&step_csp : m_innermostSteps2D)
     {
-      //**if(step_csp->getSelectionPolygon().isRectangle())
       if(step_csp->getIntegrationScope()->isRectangle())
         {
           // The selection polygon is rectangle, which means that the ranges
@@ -796,9 +772,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
           // shape, where it is necessary to look for each m/z value if it is
           // inside the rhomboid shape or not.
 
-          // qDebug() << "Currently iterated step's selection polygon *is* "
-          //"rectangle. Skipping it."
-          //<< step.toString();
+          qDebug()
+            << "20250904 Currently iterated step's selection polygon *is* "
+               "rectangle. Skipping it."
+            << step_csp->toString();
 
           continue;
         }
@@ -811,12 +788,14 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
             "Rectangle.");
         }
 
-      // qDebug() << "Iterating in inner most step 2D:" << step.toString();
+      qDebug() << "20250904 Iterating in inner most step 2D:"
+               << step_csp->toString();
 
       // There are two kinds of processing types of interest: DT_MZ_TO_ANY and
       // MZ_RT_TO_ANY.
 
-      if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("MZ"))
+      if(step_csp->getSrcProcessingType(pappso::Enums::Axis::x)
+           .bitMatches("MZ"))
         {
           // qDebug() << "Step's x source type matches MZ";
 
@@ -834,34 +813,37 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
           // Now, y:MZ in the transposed scope.
 
           // But in the original scope, y is still either DT or RT.
-          if(step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
+          if(step_csp->getSrcProcessingType(pappso::Enums::Axis::y)
+               .bitMatches("DT"))
             {
               // qDebug() << "We are handling a DT_MZ step source type";
 
               // We want the selection polygon to have x:DT and y:MZ.
               integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
-                local_integration_scope_sp, pappso::DataKind::dt));
+                local_integration_scope_sp, pappso::Enums::DataKind::dt));
             }
-          else if(step_csp->getSrcProcessingType(pappso::Axis::y)
+          else if(step_csp->getSrcProcessingType(pappso::Enums::Axis::y)
                     .bitMatches("RT"))
             {
               // qDebug() << "We are handling a MZ_RT step source type";
 
               // We want the selection polygon to have x:RT and y:MZ.
               integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
-                local_integration_scope_sp, pappso::DataKind::rt));
+                local_integration_scope_sp, pappso::Enums::DataKind::rt));
             }
           else
             qFatal("Programming error.");
         }
-      else if(step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("MZ"))
+      else if(step_csp->getSrcProcessingType(pappso::Enums::Axis::y)
+                .bitMatches("MZ"))
         {
           // qDebug() << "Step's y source type matches MZ";
 
           // We want the integration scope to have MZ as the y-axis dimension.
           // No need to transpose.
 
-          if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("DT"))
+          if(step_csp->getSrcProcessingType(pappso::Enums::Axis::x)
+               .bitMatches("DT"))
             {
               // qDebug() << "We are handling a DT_MZ step source type";
 
@@ -869,9 +851,9 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
               integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
                 std::const_pointer_cast<pappso::IntegrationScopeBase>(
                   step_csp->getIntegrationScope()),
-                pappso::DataKind::dt));
+                pappso::Enums::DataKind::dt));
             }
-          else if(step_csp->getSrcProcessingType(pappso::Axis::x)
+          else if(step_csp->getSrcProcessingType(pappso::Enums::Axis::x)
                     .bitMatches("RT"))
             {
               // qDebug() << "We are handling a MZ_RT step source type";
@@ -880,7 +862,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
               integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
                 std::const_pointer_cast<pappso::IntegrationScopeBase>(
                   step_csp->getIntegrationScope()),
-                pappso::DataKind::rt));
+                pappso::Enums::DataKind::rt));
             }
           else
             qFatal("Programming error.");
@@ -894,7 +876,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
   return integration_scope_specs.size();
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -908,12 +889,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
   // Get the format of the file, because that will condition the
   // way we provide mobility values.
 
-  pappso::MsDataFormat file_format =
+  pappso::Enums::MsDataFormat file_format =
     qualified_mass_spectrum_csp->getMassSpectrumId()
       .getMsRunIdCstSPtr()
       ->getMsDataFormat();
 
-  if(file_format == pappso::MsDataFormat::brukerTims)
+  if(file_format == pappso::Enums::MsDataFormat::brukerTims)
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
@@ -946,8 +927,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
 
       // A skewed selection polygon was found.
 
-      if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("DT") &&
-         step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("RT"))
+      if(step_csp->getSrcProcessingType(pappso::Enums::Axis::x)
+           .bitMatches("DT") &&
+         step_csp->getSrcProcessingType(pappso::Enums::Axis::y)
+           .bitMatches("RT"))
         {
           // That had DT and RT axes.
 
@@ -966,9 +949,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
           //<< "for qualified mass spectrum with dt|rt:" << dt << "|"
           //<< rt << "succeeded.";
         }
-      else if(step_csp->getSrcProcessingType(pappso::Axis::x)
+      else if(step_csp->getSrcProcessingType(pappso::Enums::Axis::x)
                 .bitMatches("RT") &&
-              step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
+              step_csp->getSrcProcessingType(pappso::Enums::Axis::y)
+                .bitMatches("DT"))
         {
           // That had DT and RT axes.
 
@@ -998,7 +982,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
   return true;
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -1027,12 +1010,12 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
   // Get the format of the file, because that will condition the
   // way we provide mobility values.
 
-  pappso::MsDataFormat file_format =
+  pappso::Enums::MsDataFormat file_format =
     qualified_mass_spectrum_csp->getMassSpectrumId()
       .getMsRunIdCstSPtr()
       ->getMsDataFormat();
 
-  if(file_format == pappso::MsDataFormat::brukerTims)
+  if(file_format == pappso::Enums::MsDataFormat::brukerTims)
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
@@ -1077,7 +1060,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
   return checkInnermostDtRt2DSteps(qualified_mass_spectrum_csp);
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkRtRange(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
@@ -1105,6 +1087,6 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkRtRange(
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
