@@ -45,65 +45,64 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
 #include "QualifiedMassSpectrumVectorMassDataIntegratorToDt.hpp"
 #include "ProcessingStep.hpp"
 
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToDtMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt");
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToDtSPtrMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr");
-
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 // Needed for qRegisterMetaType
 QualifiedMassSpectrumVectorMassDataIntegratorToDt::
-  QualifiedMassSpectrumVectorMassDataIntegratorToDt()
+  QualifiedMassSpectrumVectorMassDataIntegratorToDt(QObject *parent)
+  : QualifiedMassSpectrumVectorMassDataIntegrator(parent)
 {
 }
 
-
 QualifiedMassSpectrumVectorMassDataIntegratorToDt::
   QualifiedMassSpectrumVectorMassDataIntegratorToDt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp)
+    const QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent)
   : QualifiedMassSpectrumVectorMassDataIntegrator(
       ms_run_data_set_csp,
       processing_flow,
-      qualified_mass_spectra_to_integrate_sp)
+      qualified_mass_spectra_to_integrate_sp,
+      parent)
 {
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
+  mp_processingFlow->setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
 }
 
-
-// Needed for qRegisterMetaType
-QualifiedMassSpectrumVectorMassDataIntegratorToDt::
-  QualifiedMassSpectrumVectorMassDataIntegratorToDt(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToDt &other)
-  : QualifiedMassSpectrumVectorMassDataIntegrator(other)
-{
-}
-
-
 QualifiedMassSpectrumVectorMassDataIntegratorToDt::
   ~QualifiedMassSpectrumVectorMassDataIntegratorToDt()
 {
 }
 
+QualifiedMassSpectrumVectorMassDataIntegrator *
+QualifiedMassSpectrumVectorMassDataIntegratorToDt::clone(QObject *parent) const
+{
+  QualifiedMassSpectrumVectorMassDataIntegratorToDt *copy =
+    new QualifiedMassSpectrumVectorMassDataIntegratorToDt(
+      mcsp_msRunDataSet,
+      *mp_processingFlow,
+      mcsp_qualifiedMassSpectraToIntegrateVector,
+      parent);
+
+  copy->m_maxThreadUseCount = m_maxThreadUseCount;
+  copy->m_innermostSteps2D.assign(m_innermostSteps2D.begin(),
+                                  m_innermostSteps2D.end());
+  copy->m_dtRange = m_dtRange;
+  copy->m_mzRange = m_mzRange;
+  copy->m_rtRange = m_rtRange;
+
+  return copy;
+}
 
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
@@ -134,7 +133,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
   // We need a processing flow to work, and, in particular, a processing step
   // from which to find the specifics of the calculation.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // When constructing this integrator, the processing flow passed as parameter
@@ -156,7 +155,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
-  // qDebug() << "Now filling-in the selection_polygon_specs for any 2D step that "
+  // qDebug() << "Now filling-in the selection_polygon_specs for any 2D step
+  // that "
   //             "has a source type involving the MZ data kind.";
 
   std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
@@ -302,14 +302,14 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
           // Get the format of the file, because that will condition the
           // way we provide mobility values.
 
-          pappso::MsDataFormat file_format =
+          pappso::Enums::MsDataFormat file_format =
             qualified_mass_spectrum_csp->getMassSpectrumId()
               .getMsRunIdCstSPtr()
               ->getMsDataFormat();
 
           bool ok = false;
 
-          if(file_format == pappso::MsDataFormat::brukerTims)
+          if(file_format == pappso::Enums::MsDataFormat::brukerTims)
             {
               // Start by looking if there is a OneOverK0 valid value, which
               // means we have effectively handled a genuine mobility scan
@@ -543,6 +543,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
