@@ -41,8 +41,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -51,58 +51,36 @@
 #include "ProcessingFlow.hpp"
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-class QualifiedMassSpectrumVectorMassDataIntegratorToDt;
-
-typedef std::shared_ptr<QualifiedMassSpectrumVectorMassDataIntegratorToDt>
-  QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr;
-
-typedef std::shared_ptr<const QualifiedMassSpectrumVectorMassDataIntegratorToDt>
-  QualifiedMassSpectrumVectorMassDataIntegratorToDtCstSPtr;
-
 class QualifiedMassSpectrumVectorMassDataIntegratorToDt
   : public QualifiedMassSpectrumVectorMassDataIntegrator
 {
   Q_OBJECT
 
   public:
-  QualifiedMassSpectrumVectorMassDataIntegratorToDt();
+  QualifiedMassSpectrumVectorMassDataIntegratorToDt(QObject *parent = nullptr);
 
   QualifiedMassSpectrumVectorMassDataIntegratorToDt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp);
-
-  QualifiedMassSpectrumVectorMassDataIntegratorToDt(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToDt &other);
+    const QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent = nullptr);
 
   virtual ~QualifiedMassSpectrumVectorMassDataIntegratorToDt();
 
+  QualifiedMassSpectrumVectorMassDataIntegrator *
+  clone(QObject *parent) const override;
+
   public slots:
-
-
   void integrate();
-  signals:
-
-  protected:
-  private:
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
 
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToDtMetaTypeId;
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToDtSPtrMetaTypeId;
