@@ -45,8 +45,8 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -54,62 +54,59 @@
 #include "ProcessingStep.hpp"
 #include "ProcessingType.hpp"
 
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz");
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtrMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::
-      QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtr>(
-    "MsXpS::minexpert::"
-    "QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtr");
-
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
-// Needed for qRegisterMetaType
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
-  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz()
-  : QualifiedMassSpectrumVectorMassDataIntegrator()
+  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(QObject *parent)
+  : QualifiedMassSpectrumVectorMassDataIntegrator(parent)
 {
 }
 
-
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp)
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent)
   : QualifiedMassSpectrumVectorMassDataIntegrator(
       ms_run_data_set_csp,
       processing_flow,
-      qualified_mass_spectra_to_integrate_sp)
+      qualified_mass_spectra_to_integrate_sp,
+      parent)
 {
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
+  mp_processingFlow->setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
 }
 
-
-// Needed for qRegisterMetaType
-QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
-  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz &other)
-  : QualifiedMassSpectrumVectorMassDataIntegrator(other)
-{
-}
-
-
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   ~QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz()
 {
 }
 
+QualifiedMassSpectrumVectorMassDataIntegrator *
+QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::clone(
+  QObject *parent) const
+{
+  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz *copy =
+    new QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(
+      mcsp_msRunDataSet,
+      *mp_processingFlow,
+      mcsp_qualifiedMassSpectraToIntegrateVector,
+      parent);
+
+  copy->m_maxThreadUseCount = m_maxThreadUseCount;
+  copy->m_innermostSteps2D.assign(m_innermostSteps2D.begin(),
+                                  m_innermostSteps2D.end());
+  copy->m_dtRange = m_dtRange;
+  copy->m_mzRange = m_mzRange;
+  copy->m_rtRange = m_rtRange;
+
+  return copy;
+}
 
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapKeyCellCount()
@@ -118,7 +115,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapKeyCellCount()
   return m_colorMapKeyCellCount;
 }
 
-
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapMzCellCount()
   const
@@ -126,36 +122,32 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapMzCellCount()
   return m_colorMapMzCellCount;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapMinKey() const
 {
   return m_colorMapMinKey;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapMaxKey() const
 {
   return m_colorMapMaxKey;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapMinMz() const
 {
   return m_colorMapMinMz;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::getColorMapMaxMz() const
 {
   return m_colorMapMaxMz;
 }
 
-
 using Map = std::map<double, pappso::MapTrace>;
+
 const std::shared_ptr<Map> &
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   getDoubleMapTraceMapSPtr() const
@@ -163,14 +155,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   return m_doubleMapTraceMapSPtr;
 }
 
-pappso::DataKind
+pappso::Enums::DataKind
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   getLastIntegrationDataKind() const
 {
   return m_lastIntegrationDataKind;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
 {
@@ -201,11 +192,11 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
   // have to plot mz data against one or the other is by looking into the
   // processing flow's processing type.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   ProcessingStepCstSPtr last_processing_step_csp =
-    m_processingFlow.mostRecentStep();
+    mp_processingFlow->mostRecentStep();
 
   ProcessingType last_processing_type =
     last_processing_step_csp->getDestProcessingType();
@@ -216,19 +207,19 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
   // have no other means to know what kind of integration we have performed.
 
   if(last_processing_type.bitMatches("DT_MZ"))
-    m_lastIntegrationDataKind = pappso::DataKind::dt;
+    m_lastIntegrationDataKind = pappso::Enums::DataKind::dt;
   else if(last_processing_type.bitMatches("MZ_RT"))
-    m_lastIntegrationDataKind = pappso::DataKind::rt;
+    m_lastIntegrationDataKind = pappso::Enums::DataKind::rt;
   else
     qFatal("Programming error. The processing is not allowed here.");
 
   // Choose the right message to emit and make sanity checks.
-  if(m_lastIntegrationDataKind == pappso::DataKind::rt)
+  if(m_lastIntegrationDataKind == pappso::Enums::DataKind::rt)
     {
       emit setTaskDescriptionTextSignal(
         "Integrating to a TIC chromatogram/mass spectrum color map");
     }
-  else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
+  else if(m_lastIntegrationDataKind == pappso::Enums::DataKind::dt)
     {
       emit setTaskDescriptionTextSignal(
         "Integrating to a drift spectrum/mass spectrum color map");
@@ -238,13 +229,17 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
 
   // Check the mz integration params to see if the user wants binning or not.
 
-  if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-     pappso::BinningType::NONE)
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
+
+  if(mz_integration_params_p->getBinningType() ==
+     pappso::MzIntegrationParams::BinningType::NONE)
     {
       integrateNoBinning();
     }
-  else if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-          pappso::BinningType::ARBITRARY)
+  else if(mz_integration_params_p->getBinningType() ==
+          pappso::MzIntegrationParams::BinningType::ARBITRARY)
     {
       integrateArbitraryBinning();
     }
@@ -254,12 +249,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
 
   QString chrono_string;
 
-  if(m_lastIntegrationDataKind == pappso::DataKind::rt)
+  if(m_lastIntegrationDataKind == pappso::Enums::DataKind::rt)
     chrono_string = pappso::Utils::chronoIntervalDebugString(
       "Integration to RT / MZ colormap took:",
       chrono_start_time,
       chrono_end_time);
-  else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
+  else if(m_lastIntegrationDataKind == pappso::Enums::DataKind::dt)
     chrono_string = pappso::Utils::chronoIntervalDebugString(
       "Integration to DT / MZ colormap took:",
       chrono_start_time,
@@ -274,7 +269,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
   return;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
 {
@@ -310,19 +304,22 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
+  // We need to know the decimal places, so get them from the processing flow's
+  // most sensible MzIntegrationParams.
 
-  pappso::MzIntegrationParams local_mz_integration_params =
-    m_processingFlow.getDefaultMzIntegrationParams();
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
+  int decimal_places = mz_integration_params_p->getDecimalPlaces();
 
   // qDebug().noquote() << "Starting integration with mz integration params:"
   //<< local_mz_integration_params.toString();
 
-  // Instanciate a plus combiner that will be used as a template for all the
+  // Instantiate a plus combiner that will be used as a template for all the
   // combiners operating concurrently below. Note that because we do not make
   // bins, we just need a TracePlusCombiner and not a MassSpectrumPlusCombiner.
 
-  pappso::TracePlusCombiner template_plus_combiner(
-    local_mz_integration_params.getDecimalPlaces());
+  pappso::TracePlusCombiner template_plus_combiner(decimal_places);
 
   // Using a shared pointer make it easy to handle the copying of the map to
   // users of that map without bothering.
@@ -406,7 +403,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
           if(m_isOperationCancelled)
             break;
 
-
           pappso::TracePlusCombiner trace_plus_combiner(template_plus_combiner);
 
           // Make the computation.
@@ -481,14 +477,14 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
           // Get the format of the file, because that will condition the
           // way we provide mobility values.
 
-          pappso::MsDataFormat file_format =
+          pappso::Enums::MsDataFormat file_format =
             qualified_mass_spectrum_csp->getMassSpectrumId()
               .getMsRunIdCstSPtr()
               ->getMsDataFormat();
 
           bool ok = false;
 
-          if(file_format == pappso::MsDataFormat::brukerTims)
+          if(file_format == pappso::Enums::MsDataFormat::brukerTims)
             {
               // Start by looking if there is a OneOverK0 valid value, which
               // means we have effectively handled a genuine mobility scan
@@ -556,11 +552,11 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
 
           double first_key; // that is, either rt or dt.
 
-          if(m_lastIntegrationDataKind == pappso::DataKind::rt)
+          if(m_lastIntegrationDataKind == pappso::Enums::DataKind::rt)
             {
               first_key = rt_value;
             }
-          else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
+          else if(m_lastIntegrationDataKind == pappso::Enums::DataKind::dt)
             {
               first_key = ion_mobility_value;
             }
@@ -689,8 +685,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
   // single map trace. For that we instanciate another combiner,
   // set the bins to it and then compute the combinations using it.
 
-  pappso::TracePlusCombiner trace_plus_combiner(
-    local_mz_integration_params.getDecimalPlaces());
+  pappso::TracePlusCombiner trace_plus_combiner(decimal_places);
 
   int iter = 0;
 
@@ -818,7 +813,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
   return;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   integrateArbitraryBinning()
@@ -860,42 +854,31 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   // Prepare the template for all the combiners we'll use in the different
   // threads.
 
-  pappso::MzIntegrationParams local_mz_integration_params =
-    m_processingFlow.getDefaultMzIntegrationParams();
+  // Prepare the template for all the combiners we'll use in the different
+  // threads.
+  // We need to know the decimal places, so get them from the processing flow's
+  // most sensible MzIntegrationParams.
 
-  // qDebug().noquote() << "Starting integration with mz integration params:"
-  //<< local_mz_integration_params.toString();
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
+  int decimal_places = mz_integration_params_p->getDecimalPlaces();
 
   // Instanciate a plus combiner that will be used as a template for all the
   // combiners operating concurrently below. Note that because we are computing
   // with binning, we need a MassSpectrumPlusCombiner and not a
   // TracePlusCombiner.
 
-  pappso::MassSpectrumPlusCombiner template_plus_combiner(
-    local_mz_integration_params.getDecimalPlaces());
+  pappso::MassSpectrumPlusCombiner template_plus_combiner(decimal_places);
 
-  // It is now necessary to perform the bin computation (if any binning is
-  // required).
-
-  if(!local_mz_integration_params.isValid())
-    {
-      qDebug() << "The mz integration params are not valid.";
-
-      // If the mz integration params are not valid, then we cannot know the
-      // start and end of the bins ! We need to resort to the statistical
-      // data that were computed right after having loaded the file.
-
-      local_mz_integration_params.setSmallestMz(
-        mcsp_msRunDataSet->getMsRunDataSetStats().m_minMz);
-
-      local_mz_integration_params.setGreatestMz(
-        mcsp_msRunDataSet->getMsRunDataSetStats().m_maxMz);
-    }
+  // To create the bins, we need the smallest and greatest m/z values in the
+  // data set. Fortunately, the getSensibleMzIntegrationParams() does just that:
+  // start by seeking these values from the data set.
 
   // qDebug() << "Now starting creation of the bins.";
 
   // Now we can create the bins!
-  std::vector<double> bins = local_mz_integration_params.createBins();
+  std::vector<double> bins = mz_integration_params_p->createBins();
 
   // debug_string = QString(
   //"Number of bins: %1\n"
@@ -1083,12 +1066,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
           // Get the format of the file, because that will condition the
           // way we provide mobility values.
 
-          pappso::MsDataFormat file_format =
+          pappso::Enums::MsDataFormat file_format =
             qualified_mass_spectrum_csp->getMassSpectrumId()
               .getMsRunIdCstSPtr()
               ->getMsDataFormat();
 
-          if(file_format == pappso::MsDataFormat::brukerTims)
+          if(file_format == pappso::Enums::MsDataFormat::brukerTims)
             {
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
@@ -1116,13 +1099,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
           double first_key; // that is, either rt or dt.
 
-          if(m_lastIntegrationDataKind == pappso::DataKind::rt)
+          if(m_lastIntegrationDataKind == pappso::Enums::DataKind::rt)
             {
               first_key = rt_value;
               // qDebug() << "The dt|rt key is actually a RT key with value:"
               //<< first_key;
             }
-          else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
+          else if(m_lastIntegrationDataKind == pappso::Enums::DataKind::dt)
             {
               first_key = ion_mobility_value;
               // qDebug() << "The dt|rt key is actually a DT key with value:"
@@ -1303,11 +1286,10 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   // single map trace. For that we instanciate another mass spectrum combiner,
   // set the bins to it and then compute the combinations using it.
 
-  pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner(
-    local_mz_integration_params.getDecimalPlaces());
+  pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner(decimal_places);
 
-  if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-     pappso::BinningType::ARBITRARY)
+  if(mz_integration_params_p->getBinningType() ==
+     pappso::MzIntegrationParams::BinningType::ARBITRARY)
     {
       mass_spectrum_plus_combiner.setBins(bins);
     }
@@ -1488,6 +1470,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
   return;
 }
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
