@@ -46,67 +46,67 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 #include "QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
+#include "ProcessingFlow.hpp"
 #include "ProcessingStep.hpp"
 
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToMzMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz");
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToMzSPtrMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr");
-
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 // Needed for qRegisterMetaType
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::
-  QualifiedMassSpectrumVectorMassDataIntegratorToMz()
-  : QualifiedMassSpectrumVectorMassDataIntegrator()
+  QualifiedMassSpectrumVectorMassDataIntegratorToMz(QObject *parent)
+  : QualifiedMassSpectrumVectorMassDataIntegrator(parent)
 {
 }
 
-
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   QualifiedMassSpectrumVectorMassDataIntegratorToMz(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp)
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent)
   : QualifiedMassSpectrumVectorMassDataIntegrator(
       ms_run_data_set_csp,
       processing_flow,
-      qualified_mass_spectra_to_integrate_sp)
+      qualified_mass_spectra_to_integrate_sp,
+      parent)
 {
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
+  mp_processingFlow->setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
 }
 
-
-// Needed for qRegisterMetaType
-QualifiedMassSpectrumVectorMassDataIntegratorToMz::
-  QualifiedMassSpectrumVectorMassDataIntegratorToMz(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToMz &other)
-  : QualifiedMassSpectrumVectorMassDataIntegrator(other)
-{
-}
-
-
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   ~QualifiedMassSpectrumVectorMassDataIntegratorToMz()
 {
 }
 
+QualifiedMassSpectrumVectorMassDataIntegrator *
+QualifiedMassSpectrumVectorMassDataIntegratorToMz::clone(QObject *parent) const
+{
+  QualifiedMassSpectrumVectorMassDataIntegratorToMz *copy_p =
+    new QualifiedMassSpectrumVectorMassDataIntegratorToMz(
+      mcsp_msRunDataSet,
+      *mp_processingFlow,
+      mcsp_qualifiedMassSpectraToIntegrateVector,
+      parent);
+
+  copy_p->m_maxThreadUseCount = m_maxThreadUseCount;
+  copy_p->m_innermostSteps2D.assign(m_innermostSteps2D.begin(),
+                                  m_innermostSteps2D.end());
+  copy_p->m_dtRange = m_dtRange;
+  copy_p->m_mzRange = m_mzRange;
+  copy_p->m_rtRange = m_rtRange;
+
+  return copy_p;
+}
 
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrate()
@@ -120,19 +120,30 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrate()
   // We need to clear the map trace!
   m_mapTrace.clear();
 
-  if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-     pappso::BinningType::NONE)
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
+
+    // qDebug().noquote() << "20250904 - Got sensible mz integration params:"
+    // << mz_integration_params_p->toString();
+
+  if(mz_integration_params_p->getBinningType() ==
+     pappso::MzIntegrationParams::BinningType::NONE)
     {
-      // qDebug() << "Integrating to MZ without binning.";
+      // qDebug() << "Integrating to MZ without binning:"
+      //          << mz_integration_params_p->toString();
       integrateToMzNoBinning();
     }
-  else if(m_processingFlow.getDefaultMzIntegrationParams().getBinningType() ==
-          pappso::BinningType::ARBITRARY)
+  else if(mz_integration_params_p->getBinningType() ==
+          pappso::MzIntegrationParams::BinningType::ARBITRARY)
     {
-      // qDebug() << "Integrating to MZ with arbitrary binning.";
+      qDebug() << "Integrating to MZ with arbitrary binning:"
+               << mz_integration_params_p->toString();
       integrateToMzArbitraryBinning();
     }
 
+  delete mz_integration_params_p;
+
   std::chrono::system_clock::time_point chrono_end_time =
     std::chrono::system_clock::now();
 
@@ -146,7 +157,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrate()
   return;
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 {
@@ -172,7 +182,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // We need a processing flow to work, and, in particular, a processing step
   // from which to find the specifics of the calculation.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // When constructing this integrator, the processing flow passed as parameter
@@ -201,11 +211,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // Prepare the template for all the combiners we'll use in the different
   // threads.
 
-  pappso::MzIntegrationParams mz_integration_params =
-    m_processingFlow.getDefaultMzIntegrationParams();
+  // Heap-allocated
+  pappso::MzIntegrationParams *mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
 
-  pappso::TracePlusCombiner template_plus_combiner(
-    mz_integration_params.getDecimalPlaces());
+  int decimal_places = mz_integration_params_p->getDecimalPlaces();
+
+  pappso::TracePlusCombiner template_plus_combiner(decimal_places);
 
   // Now we need to check a number of things:
   //
@@ -400,12 +412,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
           // Get the format of the file, because that will condition the
           // way we provide mobility values.
 
-          pappso::MsDataFormat file_format =
+          pappso::Enums::MsDataFormat file_format =
             qualified_mass_spectrum_csp->getMassSpectrumId()
               .getMsRunIdCstSPtr()
               ->getMsDataFormat();
 
-          if(file_format == pappso::MsDataFormat::brukerTims)
+          if(file_format == pappso::Enums::MsDataFormat::brukerTims)
             {
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
@@ -492,8 +504,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 
   pappso::TracePlusCombiner trace_plus_combiner;
 
-  trace_plus_combiner.setDecimalPlaces(
-    m_processingFlow.getDefaultMzIntegrationParams().getDecimalPlaces());
+  trace_plus_combiner.setDecimalPlaces(decimal_places);
 
   m_isOperationCancelled = false;
   int iter               = 0;
@@ -531,17 +542,17 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   return true;
 }
 
-
 bool
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   integrateToMzArbitraryBinning()
 {
-  // qDebug();
-
   // If there are no data, nothing to do.
   std::size_t mass_spectra_count =
     mcsp_qualifiedMassSpectraToIntegrateVector->size();
 
+    qDebug() << "20250904 - Integration in arbitrary binning mode of"
+    << mass_spectra_count << "spectr[um,a].";
+
   if(!mass_spectra_count)
     {
       // qDebug() << "The qualified mass spectrum vector is empty, nothing to
@@ -560,35 +571,26 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // We need a processing flow to work, and, in particular, a processing step
   // from which to find the specifics of the calculation.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // In this case where binning is requested, we need to craft the bins, and for
   // that we need proper mz integration params.
 
-  pappso::MzIntegrationParams local_mz_integration_params =
-    m_processingFlow.getDefaultMzIntegrationParams();
+  // Heap-allocated
+  pappso::MzIntegrationParams *sensible_mz_integration_params_p =
+    mp_processingFlow->getSensibleMzIntegrationParams();
 
-  if(!local_mz_integration_params.isValid())
-    {
-      // qDebug() << "The mz integration params are not valid.";
+  qDebug().noquote() << "20250904 - Sensible MzIntegrationParams:"
+           << sensible_mz_integration_params_p->toString(0, "  ");
 
-      // If the mz integration params are not valid, then we cannot know the
-      // start and end of the bins ! We need to resort to the statistical data
-      // that were computed right after having loaded the file.
-
-      local_mz_integration_params.setSmallestMz(
-        mcsp_msRunDataSet->getMsRunDataSetStats().m_minMz);
-
-      local_mz_integration_params.setGreatestMz(
-        mcsp_msRunDataSet->getMsRunDataSetStats().m_maxMz);
-    }
-
-  // qDebug().noquote() << "Starting integration with mz integration params:"
-  //<< local_mz_integration_params.toString();
+  qDebug().noquote() << "20250904 - The ms run data set stats:"
+  << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
 
   // Now we can create the bins!
-  std::vector<double> bins = local_mz_integration_params.createBins();
+  std::vector<double> bins = sensible_mz_integration_params_p->createBins();
+
+  qDebug() << "20250904 - The bins were created, count:" << bins.size();
 
 #if 0
   QString bins_before = "Bins:\n";
@@ -643,7 +645,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // threads.
 
   pappso::MassSpectrumPlusCombiner template_plus_combiner(
-    local_mz_integration_params.getDecimalPlaces());
+    sensible_mz_integration_params_p->getDecimalPlaces());
 
   template_plus_combiner.setBins(bins);
 
@@ -806,6 +808,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
           if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
             {
+              qDebug() << "There is a mz range for the integration:"
+              << "[" << m_mzRange.first << "-" << m_mzRange.second << "]";
+
               filtered_trace.initialize(
                 *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
 
@@ -834,12 +839,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
               // Get the format of the file, because that will condition the
               // way we provide mobility values.
 
-              pappso::MsDataFormat file_format =
+              pappso::Enums::MsDataFormat file_format =
                 qualified_mass_spectrum_csp->getMassSpectrumId()
                   .getMsRunIdCstSPtr()
                   ->getMsDataFormat();
 
-              if(file_format == pappso::MsDataFormat::brukerTims)
+              if(file_format == pappso::Enums::MsDataFormat::brukerTims)
                 {
                   QVariant ion_mobility_variant_value =
                     qualified_mass_spectrum_csp->getParameterValue(
@@ -928,7 +933,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // set the bins to it and then compute the combinations using it.
 
   pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner(
-    local_mz_integration_params.getDecimalPlaces());
+    sensible_mz_integration_params_p->getDecimalPlaces());
 
   mass_spectrum_plus_combiner.setBins(bins);
 
@@ -968,6 +973,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
