@@ -45,7 +45,7 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -53,61 +53,59 @@
 #include "ProcessingStep.hpp"
 #include "ProcessingType.hpp"
 
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToRtDtMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt");
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtrMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr>(
-    "MsXpS::minexpert::"
-    "QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr");
-
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
 // Needed for qRegisterMetaType
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::
-  QualifiedMassSpectrumVectorMassDataIntegratorToRtDt()
-  : QualifiedMassSpectrumVectorMassDataIntegrator()
+  QualifiedMassSpectrumVectorMassDataIntegratorToRtDt(QObject *parent)
+  : QualifiedMassSpectrumVectorMassDataIntegrator(parent)
 {
 }
 
-
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::
   QualifiedMassSpectrumVectorMassDataIntegratorToRtDt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp)
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent)
   : QualifiedMassSpectrumVectorMassDataIntegrator(
       ms_run_data_set_csp,
       processing_flow,
-      qualified_mass_spectra_to_integrate_sp)
+      qualified_mass_spectra_to_integrate_sp,
+      parent)
 {
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
+  mp_processingFlow->setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
 }
 
-
-// Needed for qRegisterMetaType
-QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::
-  QualifiedMassSpectrumVectorMassDataIntegratorToRtDt(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToRtDt &other)
-  : QualifiedMassSpectrumVectorMassDataIntegrator(other)
-{
-}
-
-
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::
   ~QualifiedMassSpectrumVectorMassDataIntegratorToRtDt()
 {
 }
 
+QualifiedMassSpectrumVectorMassDataIntegrator *
+QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::clone(QObject *parent) const
+{
+  QualifiedMassSpectrumVectorMassDataIntegratorToRtDt *copy =
+    new QualifiedMassSpectrumVectorMassDataIntegratorToRtDt(
+      mcsp_msRunDataSet,
+      *mp_processingFlow,
+      mcsp_qualifiedMassSpectraToIntegrateVector,
+      parent);
+
+  copy->m_maxThreadUseCount = m_maxThreadUseCount;
+  copy->m_innermostSteps2D.assign(m_innermostSteps2D.begin(),
+                                  m_innermostSteps2D.end());
+  copy->m_dtRange = m_dtRange;
+  copy->m_mzRange = m_mzRange;
+  copy->m_rtRange = m_rtRange;
+
+  return copy;
+}
 
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapKeyCellCount()
@@ -116,7 +114,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapKeyCellCount()
   return m_colorMapKeyCellCount;
 }
 
-
 std::size_t
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapMzCellCount()
   const
@@ -124,36 +121,32 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapMzCellCount()
   return m_colorMapMzCellCount;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapMinKey() const
 {
   return m_colorMapMinKey;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapMaxKey() const
 {
   return m_colorMapMaxKey;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapMinMz() const
 {
   return m_colorMapMinMz;
 }
 
-
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getColorMapMaxMz() const
 {
   return m_colorMapMaxMz;
 }
 
-
 using Map = std::map<double, pappso::MapTrace>;
+
 const std::shared_ptr<Map> &
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getRtMapTraceMapSPtr()
   const
@@ -161,14 +154,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::getRtMapTraceMapSPtr()
   return m_rtMapTraceMapSPtr;
 }
 
-pappso::DataKind
+pappso::Enums::DataKind
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::
   getLastIntegrationDataKind() const
 {
   return m_lastIntegrationDataKind;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
 {
@@ -199,7 +191,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
   // In this integration, we are going to craft the data to create a colormap
   // that will plot dt data against rt data or vice versa.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // When constructing this integrator, the processing flow passed as parameter
@@ -380,14 +372,14 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
           // Get the format of the file, because that will condition the
           // way we provide mobility values.
 
-          pappso::MsDataFormat file_format =
+          pappso::Enums::MsDataFormat file_format =
             qualified_mass_spectrum_csp->getMassSpectrumId()
               .getMsRunIdCstSPtr()
               ->getMsDataFormat();
 
           bool ok = false;
 
-          if(file_format == pappso::MsDataFormat::brukerTims)
+          if(file_format == pappso::Enums::MsDataFormat::brukerTims)
             {
               // Start by looking if there is a OneOverK0 valid value, which
               // means we have effectively handled a genuine mobility scan
@@ -733,6 +725,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
