@@ -45,7 +45,7 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -53,63 +53,60 @@
 #include "ProcessingStep.hpp"
 #include "ProcessingType.hpp"
 
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToTicIntMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicInt>(
-    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicInt");
-
-int qualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtrMetaTypeId =
-  qRegisterMetaType<
-    MsXpS::minexpert::
-      QualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtr>(
-    "MsXpS::minexpert::"
-    "QualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtr");
-
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
 QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::
-  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt()
-  : QualifiedMassSpectrumVectorMassDataIntegrator()
+  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(QObject *parent)
+  : QualifiedMassSpectrumVectorMassDataIntegrator(parent)
 {
 }
 
-
 QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::
   QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp)
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent)
   : QualifiedMassSpectrumVectorMassDataIntegrator(
       ms_run_data_set_csp,
       processing_flow,
-      qualified_mass_spectra_to_integrate_sp)
+      qualified_mass_spectra_to_integrate_sp,
+      parent)
 {
-  m_processingFlow.setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
+  mp_processingFlow->setMsRunDataSetCstSPtr(mcsp_msRunDataSet);
 }
 
-
-// Needed for qRegisterMetaType
-QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::
-  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToTicInt &other)
-  : QualifiedMassSpectrumVectorMassDataIntegrator()
-{
-  Q_UNUSED(other)
-}
-
-
 QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::
   ~QualifiedMassSpectrumVectorMassDataIntegratorToTicInt()
 {
   // qDebug() << "Destroying integrator:" << this;
 }
 
+QualifiedMassSpectrumVectorMassDataIntegrator *
+QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::clone(
+  QObject *parent) const
+{
+  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt *copy =
+    new QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
+      mcsp_msRunDataSet,
+      *mp_processingFlow,
+      mcsp_qualifiedMassSpectraToIntegrateVector,
+      parent);
+
+  copy->m_maxThreadUseCount = m_maxThreadUseCount;
+  copy->m_innermostSteps2D.assign(m_innermostSteps2D.begin(),
+                                  m_innermostSteps2D.end());
+  copy->m_dtRange = m_dtRange;
+  copy->m_mzRange = m_mzRange;
+  copy->m_rtRange = m_rtRange;
+
+  return copy;
+}
 
 double
 QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::getTicIntensity() const
@@ -117,7 +114,6 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::getTicIntensity() const
   return m_ticIntensity;
 }
 
-
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
 {
@@ -147,12 +143,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
   // We need a processing flow to work, and, in particular, a processing step
   // from which to find the specifics of the calculation.
 
-  if(!m_processingFlow.size())
+  if(!mp_processingFlow->getStepsCstRef().size())
     qFatal("The processing flow cannot be empty. Program aborted.");
 
   // Get the most recent step that holds all the specifics of this integration.
   ProcessingStepCstSPtr most_recent_processing_step_csp =
-    m_processingFlow.mostRecentStep();
+    mp_processingFlow->mostRecentStep();
 
   if(!most_recent_processing_step_csp->getDestProcessingType().bitMatches(
        "INT"))
@@ -353,17 +349,17 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
               // Get the format of the file, because that will condition the
               // way we provide mobility values.
 
-              pappso::MsDataFormat file_format =
+              pappso::Enums::MsDataFormat file_format =
                 qualified_mass_spectrum_csp->getMassSpectrumId()
                   .getMsRunIdCstSPtr()
                   ->getMsDataFormat();
 
-              if(file_format == pappso::MsDataFormat::brukerTims)
+              if(file_format == pappso::Enums::MsDataFormat::brukerTims)
                 {
                   QVariant ion_mobility_variant_value =
                     qualified_mass_spectrum_csp->getParameterValue(
 
-pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
+                      pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
                   if(ion_mobility_variant_value.isValid())
                     {
@@ -451,6 +447,6 @@ pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
