@@ -39,10 +39,10 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/msrun/msrundatasettreenode.h>
-#include <pappsomspp/msrun/msrundatasettreevisitor.h>
-#include <pappsomspp/processing/combiners/tracepluscombiner.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/msrun/msrundatasettreenode.h>
+#include <pappsomspp/core/msrun/msrundatasettreevisitor.h>
+#include <pappsomspp/core/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -50,12 +50,12 @@
 #include "ProcessingFlow.hpp"
 #include "MsRunDataSet.hpp"
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
-#include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class RtDtColorMapTreeNodeCombinerVisitor;
@@ -71,7 +71,7 @@ class RtDtColorMapTreeNodeCombinerVisitor
   public:
   RtDtColorMapTreeNodeCombinerVisitor(MsRunDataSetCstSPtr ms_run_data_set_csp,
                                       const ProcessingFlow &processing_flow,
-                                      pappso::DataKind data_kind);
+                                      pappso::Enums::DataKind data_kind);
 
   RtDtColorMapTreeNodeCombinerVisitor(
     const RtDtColorMapTreeNodeCombinerVisitor &other);
@@ -88,7 +88,7 @@ class RtDtColorMapTreeNodeCombinerVisitor
 
   const std::map<double, pappso::MapTrace> &getDoubleMapTraceMap() const;
 
-  pappso::DataKind getDataKind() const;
+  pappso::Enums::DataKind getDataKind() const;
 
   virtual bool
   checkProcessingStep(const ProcessingStep &step,
@@ -112,7 +112,7 @@ class RtDtColorMapTreeNodeCombinerVisitor
 
   protected:
   // Are we handling dt or rt data in relation to mz?
-  pappso::DataKind m_dataKind;
+  pappso::Enums::DataKind m_dataKind;
 
   pappso::TracePlusCombiner m_combiner;
 
@@ -127,6 +127,6 @@ class RtDtColorMapTreeNodeCombinerVisitor
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
