@@ -46,51 +46,34 @@
 /////////////////////// Local includes
 #include "TicChromTreeNodeCombinerVisitor.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
 TicChromTreeNodeCombinerVisitor::TicChromTreeNodeCombinerVisitor(
   MsRunDataSetCstSPtr ms_run_data_set_csp,
-  const ProcessingFlow &processing_flow)
-  : BaseMsRunDataSetTreeNodeVisitor(ms_run_data_set_csp, processing_flow)
+  const ProcessingFlow &processing_flow,
+  QObject *parent)
+  : BaseMsRunDataSetTreeNodeVisitor(
+      ms_run_data_set_csp, processing_flow, parent)
 {
 }
 
-
-TicChromTreeNodeCombinerVisitor::TicChromTreeNodeCombinerVisitor(
-  const TicChromTreeNodeCombinerVisitor &other)
-  : BaseMsRunDataSetTreeNodeVisitor(other),
-    m_ticChromMapTrace(other.m_ticChromMapTrace)
-{
-}
-
-
-TicChromTreeNodeCombinerVisitor &
-TicChromTreeNodeCombinerVisitor::operator=(
-  const TicChromTreeNodeCombinerVisitor &other)
-{
-  if(this == &other)
-    return *this;
-
-  BaseMsRunDataSetTreeNodeVisitor::operator=(other);
-
-  mcsp_msRunDataSet  = other.mcsp_msRunDataSet;
-  m_processingFlow   = other.m_processingFlow;
-  m_ticChromMapTrace = other.m_ticChromMapTrace;
-
-  return *this;
-}
-
-
 TicChromTreeNodeCombinerVisitor::~TicChromTreeNodeCombinerVisitor()
 {
   // qDebug();
 }
 
+BaseMsRunDataSetTreeNodeVisitor *
+TicChromTreeNodeCombinerVisitor::clone(QObject *parent) const
+{
+  TicChromTreeNodeCombinerVisitor *copy = new TicChromTreeNodeCombinerVisitor(
+    mcsp_msRunDataSet, *mp_processingFlow, parent);
+
+  return copy;
+}
 
 // void
 // TicChromTreeNodeCombinerVisitor::nodesToProcess(std::size_t nodes_to_process)
@@ -108,7 +91,6 @@ TicChromTreeNodeCombinerVisitor::getTicChromMapTrace() const
   return m_ticChromMapTrace;
 }
 
-
 bool
 TicChromTreeNodeCombinerVisitor::visit(const pappso::MsRunDataSetTreeNode &node)
 {
@@ -220,6 +202,6 @@ TicChromTreeNodeCombinerVisitor::visit(const pappso::MsRunDataSetTreeNode &node)
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
