@@ -46,8 +46,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/msrun/msrunreader.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/msrun/msrunreader.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -57,7 +57,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class TicChromatogramFromMassSpecDataFile;
@@ -154,9 +154,9 @@ class TicChromatogramFromMassSpecDataFile
   std::size_t m_setQualifiedMassSpectrumCount = 0;
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 } // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(MsXpS::minexpert::TicChromatogramFromMassSpecDataFileSPtr)
+Q_DECLARE_METATYPE(MsXpS::MineXpert::TicChromatogramFromMassSpecDataFileSPtr)
 extern int ticChromatogramFromMassSpecDataFileSPtrMetaTypeId;
