@@ -53,7 +53,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 const double PI = 3.14159265358979323846;
@@ -265,134 +265,6 @@ binaryRepresentation(int value)
 }
 
 
-//! Produce a shortened version of a string.
-/*!
- * Often, it is necessary to display in a graphical user interface a very long
- * string that cannot fit in the provided widget. This function returns a
- * shortened version of the input string.
- *
- * For example, "Interesting bits of information are often lost where there are
- * too many details", becomes "Interes...details".
- *
- * \param text reference to the string to be shortened
- * \param charsLeft number of characters to be left at the left of the
- * elision string
- * \param charsRight number of characters to be left at the right of the
- * elision string
- * \param delimitor string to use as the elision delimitor
- */
-QString
-elideText(const QString &text,
-          int charsLeft,
-          int charsRight,
-          const QString &delimitor)
-{
-  // We want to elide text. For example, imagine we have text = "that
-  // is beautiful stuff", with charsLeft 4 and charsRight 4 and
-  // delimitor "...". Then the result would be "that...tuff"
-
-  if(charsLeft < 1 || charsRight < 1)
-    {
-      return text;
-    }
-
-  int size = text.size();
-
-  // If the text string is already too short, no need to elide
-  // anything.
-  if((charsLeft + charsRight + delimitor.size()) >= size)
-    {
-      return text;
-    }
-
-  QString result = text.left(charsLeft);
-  result.append(delimitor);
-  result.append(text.right(charsRight));
-
-  return result;
-}
-
-
-//! Convert a very long text to a paragraph.
-/*!
- * When a text string is too long to be displayed in a line of reasonable
- * length, insert newline characters at positions calculated to yield a
- * paragraph of a given width.
- *
- * The text is left-justified with the most fitting line size possible.
- *
- * \param text string to be converted to a paragraph (a stanza)
- * \param width width in characters of the stanza
- * \return a new string with the stanzified text
- */
-QString
-stanzify(const QString &text, int width)
-{
-  QString result = text;
-
-  // First, replace all the existing newline chars with spaces.
-
-  result = result.replace("\n", " ");
-
-  int iter = width;
-
-  // Then, iterate in the obtained string and every width characters try to
-  // insert a newline character by iterating back to the left and searching
-  // for a space.
-
-  for(; iter < result.size(); iter += width)
-    {
-      // Now iterate in reverse and search for a space where to insert a
-      // newline
-
-      int jter = iter;
-
-      for(; jter >= 0; --jter)
-        {
-          if(result.at(jter) == ' ')
-            {
-              result[jter] = '\n';
-              break;
-            }
-        }
-    }
-
-  return result;
-}
-
-
-//! Convert a very long text to paragraphs.
-/*!
- * When a text string is too long to be displayed in a line of reasonable
- * length, insert newline characters at positions calculated to yield a
- * paragraph of a given width.
- *
- * The text is left-justified with the most fitting line size possible.
- *
- * \param text string to be converted to a paragraph (a stanza)
- * \param width width in characters of the stanza
- * \return a new string with the stanzified text
- */
-QString
-stanzifyParagraphs(const QString &text, int width)
-{
-  QString result;
-
-  QStringList paragraphList = text.split("\n");
-
-  for(int iter = 0; iter < paragraphList.size(); ++iter)
-    {
-      QString line = paragraphList.at(iter);
-
-      QString stanzifiedLine = stanzify(line, width);
-
-      result.append(stanzifiedLine);
-      result.append("\n");
-    }
-
-  return result;
-}
-
 
 //! Determine the number of zero decimals between the decimal point and the
 //! first non-zero decimal.
@@ -488,6 +360,6 @@ pointerAsString(void *pointer)
 }
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
