@@ -64,7 +64,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
@@ -81,24 +81,6 @@ enum MassType
 };
 
 
-//! Kind of entity handled in a JavaScript object creation operation.
-/*!
- * When creating JavaScript objects, define which kind of entity is being
- * created.
- *
- * \sa msXpSlibXpertMassGui::ScriptingWnd
- * \sa msXpSlibXpertMassGui::ScriptingObjectTreeWidgetItem
- */
-enum ScriptEntityType
-{
-  UndefinedEntity,
-  StringEntity,
-  FunctionEntity,
-  ArrayOrListEntity,
-  QObjectEntity,
-  IntegerEntity,
-  DoubleEntity
-};
 
 extern const double PI;
 
@@ -128,15 +110,6 @@ QString &unspacifyString(QString &text);
 
 QString binaryRepresentation(int value);
 
-QString elideText(const QString &text,
-                  int charsLeft            = 4,
-                  int charsRight           = 4,
-                  const QString &delimitor = "...");
-
-QString stanzify(const QString &text, int width);
-
-QString stanzifyParagraphs(const QString &text, int width);
-
 int zeroDecimals(double value);
 
 double ppm(double value, double ppm);
@@ -154,6 +127,6 @@ double removeRes(double value, double res);
 QString pointerAsString(void *pointer);
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
